(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     67867,       2029]*)
(*NotebookOutlinePosition[     76825,       2261]*)
(*  CellTagsIndexPosition[     74874,       2211]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[ButtonBox["\[UpperLeftArrow]",
  ButtonData:>{"CaseStudies-IsolatedTheorems.nb", "c:1"},
  ButtonStyle->"Navigation",
  ButtonNote->"Isolated Theorems"]], "SingleParagraph",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Equivalence Relations and Partitions I", "Section",
  CounterAssignments->{{"Section", 12}, {"TableHead", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsection", 0}, {"Subsubsection", 0}},
  CellTags->"c:1"],

Cell[CellGroupData[{

Cell["Exploration Round 1: Basic Notions", "Subsection",
  CellTags->"c:2"],

Cell[TextData[{
  "We start out with the basic definitions of ",
  StyleBox["reflexivity",
    FontSlant->"Italic"],
  ", ",
  StyleBox["symmetry",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["transitivity",
    FontSlant->"Italic"],
  ". We give them as single definitions because this will give us additional \
flexibility later in composing knowledge bases for particular proofs. For the \
first part of the presentation, we use an ",
  StyleBox["intensional concept of a relation",
    FontSlant->"Italic"],
  ", meaning that a relation ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " is viewed as a ",
  StyleBox["predicate",
    FontSlant->"Italic"],
  " in logic and we say that ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is in relation ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " if, and only if, ",
  Cell[BoxData[
      \(TraditionalForm\`R[x, y]\)]],
  " holds. Having set theory available, we could also use an ",
  StyleBox["extensional concept of a relation",
    FontSlant->"Italic"],
  " and model relations in set theory, where a relation ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " on a set ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  " is seen as some subset of ",
  Cell[BoxData[
      \(TraditionalForm\`X\[Cross]X\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " are said to be in relation ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " if, and only if,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]x, 
          y\[RightAngleBracket] \[Element] R\)]],
  ", see part 2 of the exploration in Section ",
  ButtonBox["14",
    ButtonData:>{"CaseStudies-EquivalenceRelations2.nb", None},
    ButtonStyle->"Hyperlink"],
  ". The flow of exploration is, of course, similar in both approaches, the \
proof differ in subtleties. We decided to present the intensional version, \
because some of the features of the prover will be presented in this first \
part, which would not appear, when using the extensional approach. For the \
second part of the exploration on topics related to equivalence relations and \
partitions, we will then switch to the extensional model of a relation, \
because we will arrive at notions such as ",
  StyleBox["equality of relations",
    FontSlant->"Italic"],
  ", which is then easier to formulate in the representation of sets. Again, \
some of the features of the prover can be demonstrated in that approach, \
which would not show up using the intensional model."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<reflexivity\>", 
      any[\(\[Tilde]\)\(\(,\)\(A\)\)], \
\[IndentingNewLine]is\[Dash]reflexive\_A[ \[Tilde] ] : \[NegativeThickSpace]\
\[NegativeMediumSpace]\(\(\[DoubleLeftRightArrow]\)\(\[ForAll] \+\(x \
\[Element] A\)x \[Tilde] x\)\)\), "]"}]], "Input",
  CellTags->"Definition (reflexivity)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<symmetry\>", 
      any[\(\[Tilde]\)\(\(,\)\(A\)\)], \
\[IndentingNewLine]is\[Dash]symmetric\_A[ \[Tilde] ] : \[NegativeThickSpace]\
\[NegativeMediumSpace]\(\(\[DoubleLeftRightArrow]\)\(\[ForAll] \+\(x, y \
\[Element] A\)\((x \[Tilde] y \[Implies] y \[Tilde] x)\)\)\)\), 
      "]"}]], "Input",
  CellTags->"Definition (symmetry)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<transitivity\>", 
      any[\(\[Tilde]\)\(\(,\)\(A\)\)], \[IndentingNewLine]is\[Dash]transitive\
\_A[ \[Tilde] ] : \[NegativeThickSpace]\[NegativeMediumSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\[ForAll] \+\(x, y, z \[Element] A\)\((x \[Tilde] 
                    y \[And] y \[Tilde] z \[Implies] x \[Tilde] z)\)\)\)\), 
      "]"}]], "Input",
  CellTags->"Definition (transitivity)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<equivalence\>\"", ",", \(any[\(\[Tilde]\)\(\(,\)\(A\)\)]\), ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(is\[Dash]equivalence\_A[ \[Tilde] ]\), ":", 
          "\[NegativeThickSpace]\[NegativeMediumSpace]", 
          RowBox[{"\[DoubleLeftRightArrow]", 
            RowBox[{
              StyleBox["\[And]",
                Background->None], 
              RowBox[{
                StyleBox["{",
                  SpanMaxSize->Infinity,
                  Background->None], 
                StyleBox[GridBox[{
                      {\(is\[Dash]reflexive\_A[ \[Tilde] ]\)},
                      {\(is\[Dash]symmetric\_A[ \[Tilde] ]\)},
                      {\(is\[Dash]transitive\_A[ \[Tilde] ]\)}
                      },
                    ColumnAlignments->{Left}],
                  Background->None], 
                StyleBox["}",
                  ShowContents->False,
                  Background->None]}]}]}]}]}], " ", "]"}]], "Input",
  CellTags->"Definition (equivalence)"],

Cell[TextData[{
  "Typically, in an exploration of a new theory, one starts doing some simple \
computations with the new notions introduced in order to develop some \
familiarity with the new concepts. From the computations one might then \
conjecture properties of the new notions from observations made in the \
computations. In the sequel, we investigate the set ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " of integers less or equal 10, and a relation ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " being fulfilled for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " if, and only if, ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " have the same remainder when divided by 5. Using the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Formal Text language, we can define ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " as follows:"
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Constants\>\"", ",", \(any[x, y]\), ",", "\[IndentingNewLine]", 
        GridBox[{
            {\(A10 = {\(i\)\( | \+\(i = 0, \[Ellipsis], 10\)\)}\), 
              "\"\<A\>\""},
            {\(R[x, 
                  y] : \[NegativeThickSpace]\[NegativeMediumSpace]\(\(\
\[DoubleLeftRightArrow]\)\((Mod[x, 5] = Mod[y, 5])\)\)\), "\"\<R\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Definition (Constants)"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[is\[Dash]reflexive\_A10[R], 
      using \[Rule] \[LeftAngleBracket]Definition["\<reflexivity\>"], 
          Definition["\<Constants\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      UnderscriptBox["\[ForAll]", 
        RowBox[{
          StyleBox["x",
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "\[Element]", 
          RowBox[{"{", 
            RowBox[{
              StyleBox["i",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              UnderscriptBox["\[VerticalSeparator]", 
                RowBox[{
                  RowBox[{
                    StyleBox["i",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "=", "0"}], ",", "\[Ellipsis]", ",", 
                  "10"}]]}], "}"}]}]], 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"Mod", "[", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", "5"}], "]"}], "=", 
          RowBox[{"Mod", "[", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", "5"}], "]"}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Adding more and more knowledge on built\[Dash]in language constructs, one \
can finally check the properties for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  "."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[is\[Dash]reflexive\_A10[R], 
      using \[Rule] \[LeftAngleBracket]Definition["\<reflexivity\>"], 
          Definition["\<Constants\>"]\[RightAngleBracket], 
      built\[Dash]in \[Rule] \(Built\[Dash]in["\<Quantifiers\>"]\)[
          SetOf]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      UnderscriptBox["\[ForAll]", 
        RowBox[{
          StyleBox["x",
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          "\[Element]", \({0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10}\)}]], 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"Mod", "[", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", "5"}], "]"}], "=", 
          RowBox[{"Mod", "[", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", "5"}], "]"}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[is\[Dash]reflexive\_A10[R], 
      using \[Rule] \[LeftAngleBracket]Definition["\<reflexivity\>"], 
          Definition["\<Constants\>"]\[RightAngleBracket], 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], Built\[Dash]in["\<Quantifiers\>"], 
          Built\[Dash]in["\<Connectives\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[is\[Dash]symmetric\_A10[R], 
      using \[Rule] \[LeftAngleBracket]Definition["\<symmetry\>"], 
          Definition["\<Constants\>"]\[RightAngleBracket], 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], Built\[Dash]in["\<Quantifiers\>"], 
          Built\[Dash]in["\<Connectives\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[is\[Dash]transitive\_A10[R], 
      using \[Rule] \[LeftAngleBracket]Definition["\<transitivity\>"], 
          Definition["\<Constants\>"]\[RightAngleBracket], 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], Built\[Dash]in["\<Quantifiers\>"], 
          Built\[Dash]in["\<Connectives\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[is\[Dash]equivalence\_A10[R], 
      using \[Rule] \[LeftAngleBracket]Definition["\<equivalence\>"], 
          Definition["\<reflexivity\>"], Definition["\<symmetry\>"], 
          Definition["\<transitivity\>"], 
          Definition["\<Constants\>"]\[RightAngleBracket], 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], Built\[Dash]in["\<Quantifiers\>"], 
          Built\[Dash]in["\<Connectives\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
The operator \"\[VerticalBar]\" is available among the \
built\[Dash]in predicates for \"Numbers\" and it denotes divisibility.\
\>", \
"SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[is\[Dash]transitive\_A10[ \[VerticalBar] ], 
      using \[Rule] \[LeftAngleBracket]Definition["\<transitivity\>"], 
          Definition["\<Constants\>"]\[RightAngleBracket], 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], Built\[Dash]in["\<Quantifiers\>"], 
          Built\[Dash]in["\<Connectives\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[is\[Dash]symmetric\_A10[ \[VerticalBar] ], 
      using \[Rule] \[LeftAngleBracket]Definition["\<symmetry\>"], 
          Definition["\<Constants\>"]\[RightAngleBracket], 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], Built\[Dash]in["\<Quantifiers\>"], 
          Built\[Dash]in["\<Connectives\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[is\[Dash]reflexive\_A10[ \[VerticalBar] ], 
      using \[Rule] \[LeftAngleBracket]Definition["\<reflexivity\>"], 
          Definition["\<Constants\>"]\[RightAngleBracket], 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], Built\[Dash]in["\<Quantifiers\>"], 
          Built\[Dash]in["\<Connectives\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[is\[Dash]equivalence\_A10[ \[VerticalBar] ], 
      using \[Rule] \[LeftAngleBracket]Definition["\<equivalence\>"], 
          Definition["\<reflexivity\>"], Definition["\<symmetry\>"], 
          Definition["\<transitivity\>"], 
          Definition["\<Constants\>"]\[RightAngleBracket], 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], Built\[Dash]in["\<Quantifiers\>"], 
          Built\[Dash]in["\<Connectives\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell["\<\
In the sequel, we will not give the knowledge used in the \
computations explicitly through the options of Compute, but we will put all \
necessary knowledge into the global knowledge bases before starting the \
computations in order to keep the Compute calls concise and compact. We \
shall, however, omit the input lines for maintenance of the global knowledge \
bases.\
\>", "FirstParagraph"],

Cell[TextData[{
  "We start now with some first proofs on equivalence relations. We do not \
deeply explore equivalence relations as such, because we want to proceed \
quickly to the notions of equivalence class and factor set. Some knowledge on \
equivalence relations will, however, be necessary later, thus, we give the \
propositions together with the proofs in advance. Note that, since no sets do \
yet occur, we use the PC prover implemented by Daniela Vasaru, see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Vasa00PhD",
            ButtonData:>"Vasa00PhD",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "D. Vasaru-Dupr\[EGrave], 2000, Automated Theorem Proving by \
Integrating Proving, Solving and Compu ..."],
          "Text"], TraditionalForm]]],
  "]."
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<common successor\>", 
      any[\(\[Tilde]\)\(\(,\)\(A\)\)], 
      with[is\[Dash]equivalence\_A[ \[Tilde] ]], \[IndentingNewLine]\[ForAll] \
\+\(x, y \[Element] A\)\((x \[Tilde] 
              y \[DoubleLeftRightArrow] \(\[Exists] \+\(z \[Element] A\)\((x \
\[Tilde] z \[And] y \[Tilde] z)\)\))\)\), "]"}]], "Input",
  CellTags->"Proposition (common successor)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<common successor\>"]\), 
        ",", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<equivalence\>"], 
            Definition["\<transitivity\>"], 
            Definition["\<symmetry\>"]\[RightAngleBracket]\), ",", 
        "\[IndentingNewLine]", \(by \[Rule] PC\), ",", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, AllowIntroduceQuantifiers \[Rule] True, 
              UseCyclicRules \[Rule] True}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "CommonSuccessorPC.nb", CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], 
      "[", \("\<common predecessor \[DoubleLeftArrow]\>", 
      any[\(\[Tilde]\)\(\(,\)\(A\)\)], 
      with[is\[Dash]equivalence\_A[ \[Tilde] ]], \[IndentingNewLine]\[ForAll] \
\+\(x, y \[Element] A\)\((x \[Tilde] 
              y \[DoubleLeftArrow] \(\[Exists] \+\(z \[Element] A\)\((z \
\[Tilde] x \[And] z \[Tilde] y)\)\))\)\), "]"}]], "Input",
  CellTags->"Proposition (common predecessor \[DoubleLeftArrow])"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<common predecessor \[DoubleLeftArrow]\>"]\), 
        ",", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<equivalence\>"], 
            Definition["\<transitivity\>"], 
            Definition["\<symmetry\>"]\[RightAngleBracket]\), ",", 
        "\[IndentingNewLine]", \(by \[Rule] PC\), ",", "\[IndentingNewLine]", 
        
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, AllowIntroduceQuantifiers \[Rule] True, 
              UseCyclicRules \[Rule] True}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "CommonPredecessor<-PC.nb", CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exploration Round 2: Equivalence Class", "Subsection",
  CellTags->"c:3"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<class\>", 
      any[x, \(\(\[Tilde]\)\(\(,\)\(A\)\)\)], \[IndentingNewLine]class\_\(A,  \
\[Tilde] \)[
          x] := {a \[Element] A \[VerticalSeparator] 
            a \[Tilde] x \[And] x \[Element] A}\), "]"}]], "Input",
  CellTags->"Definition (class)"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[class\_\(A10, R\)[5]]\)], "Input"],

Cell[BoxData[
    \({0, 5, 10}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[class\_\(A10, R\)[3]]\)], "Input"],

Cell[BoxData[
    \({3, 8}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[class\_\(A10, R\)[0]]\)], "Input"],

Cell[BoxData[
    \({0, 5, 10}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<equal classes\>", 
      any[x \[Element] A, y \[Element] A, \(\(\[Tilde]\)\(\(,\)\(A\)\)\)], 
      with[is\[Dash]equivalence\_A[ \[Tilde] ]], \[IndentingNewLine]x \
\[Tilde] y \[Implies] \((class\_\(A,  \[Tilde] \)[x] = 
            class\_\(A,  \[Tilde] \)[y])\)\), "]"}]], "Input",
  CellTags->"Proposition (equal classes)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<equal classes\>"]\), 
        ",", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<equivalence\>"], 
            Definition["\<transitivity\>"], Definition["\<symmetry\>"], 
            Definition["\<class\>"]\[RightAngleBracket]\), ",", 
        "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, AllowIntroduceQuantifiers \[Rule] True, 
              UseCyclicRules \[Rule] True, DisableProver \[Rule] {STC, PND}, 
              ApplyBuiltIns \[Rule] {}}\),
          "UnHighlightedText"], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 50\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "EqualClasses.nb", CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[TextData[{
  "An aspect worth mentioning in the above proof is, that the definition for \
class is expanded ",
  StyleBox["before",
    FontSlant->"Italic"],
  " set equality is split up into the two branches proving mutual inclusion. \
This is so, because the inference rule for ",
  StyleBox["set equality",
    FontSlant->"Italic"],
  " only applies when at least one of the constituents can be recognized to \
be a set, which is not the case in formula (6). A human might delay the \
expansion of the definition and first split up equality. For this to happen \
in the Set Theory prover, one must tell the prover that terms of the form ",
  Cell[BoxData[
      \(TraditionalForm\`class\_\(A,  \[Tilde] \)[x]\)]],
  " are sets. One way to achieve this is to set"
}], "SingleParagraph"],

Cell[BoxData[
    \(IsSet[\[Bullet][class\___[___]]] := True\)], "Input"],

Cell["\<\
which would from now on allow the prover to identify equivalence \
classes as sets. The proof does not differ much, just that the expansion of \
the class definition is delayed to happen as first proof step in the \
individual branches, respectively. Through simple computations, one might \
have the suspicion that an element is always contained in its own equivalence \
class. At least, this holds in the concrete example.\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[0 \[Element] class\_\(A10, R\)[0]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[\[ForAll] \+\(x \[Element] A10\)x \[Element] 
          class\_\(A10, R\)[x]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
In general, of course, this question cannot be answered by \
computations, we must provide a proof.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<in own class\>", 
      any[x \[Element] A, \(\(\[Tilde]\)\(\(,\)\(A\)\)\)], 
      with[is\[Dash]equivalence\_A[ \[Tilde] ]], \[IndentingNewLine]x \
\[Element] class\_\(A,  \[Tilde] \)[x]\), "]"}]], "Input",
  CellTags->"Proposition (in own class)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<in own class\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<equivalence\>"], 
            Definition["\<reflexivity\>"], 
            Definition["\<class\>"]\[RightAngleBracket]\), ",", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, ApplyBuiltIns \[Rule] {"\<goal\>"}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, "InOwnClass.nb",
         CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell["\<\
An immediate consequence of this fact is, that the equivalence \
class of an element of the set is never empty.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<non-empty class\>", 
      any[x \[Element] A, \(\(\[Tilde]\)\(\(,\)\(A\)\)\)], 
      with[is\[Dash]equivalence\_A[ \[Tilde] ]], \
\[IndentingNewLine]class\_\(A,  \[Tilde] \)[x] \[NotEqual] \[EmptySet]\), 
      "]"}]], "Input",
  CellTags->"Proposition (non-empty class)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<non-empty class\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<equivalence\>"], 
            Definition["\<reflexivity\>"], 
            Definition["\<class\>"]\[RightAngleBracket]\), ",", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, RWInsideQuantifiers \[Rule] True, 
              ApplyBuiltIns \[Rule] {"\<goal\>"}}\),
          "UnHighlightedText"], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 40\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "NonemptyClass.nb", CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[TextData[{
  "The previous proof could be made by far shorter when using \
Proposition[\"in own class\"] in the knowledge base. We want to present this \
variant, in order to show some features of the prover, which might be ",
  StyleBox["necessary to use",
    FontSlant->"Italic"],
  " in other examples:"
}], "SingleParagraph"],

Cell[TextData[{
  "Formula (3) introduces an existential quantifier. No special solving \
techniques but matching are available for the existential goal. By setting \
the option ",
  Cell[BoxData[
      \(TraditionalForm\`RWInsideQuantifiers \[Rule] True\)]],
  " for the QR prover, we allow the definition of class to be expanded inside \
the quantifier."
}], "ItemizedText"],

Cell[TextData[{
  "Formula (5) still allows no successful match for the existentially \
quantified variable, thus, we expand membership inside the quantifier, which \
is an inference rule for STS explained in Section ",
  ButtonBox["10",
    ButtonData:>{"Part2.nb", "Sec:STS"},
    ButtonStyle->"Hyperlink"],
  ". After this, a successful match is possible in formula (6)."
}], "ItemizedText"]
}, Open  ]],

Cell["Exploration Round 3: Factor Set", "Subsection",
  CellTags->"c:4"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<factor set\>", 
      any[A,  \[Tilde] ], \[IndentingNewLine]\(factor\[Dash]set\_ \[Tilde] \)[
          A] := {\(class\_\(A,  \[Tilde] \)[
              x]\)\( \[VerticalSeparator] \+\(x \[Element] A\)\)}\), 
      "]"}]], "Input",
  CellTags->"Definition (factor set)"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[factor\[Dash]set\_R[A10]]\)], "Input"],

Cell[BoxData[
    \({{1, 6}, {2, 7}, {3, 8}, {4, 9}, {0, 5, 10}}\)], "Output"]
}, Open  ]],

Cell["\<\
The factor set, at least in this example, has some properties that \
could also be observed in other example computations:\
\>", "SingleParagraph"],

Cell["\<\
It contains all elements of the original set in at least one of the \
elements.\
\>", "ItemizedText",
  CellDingbat->None,
  CellFrameLabels->{{Cell[ 
          TextData[ {
            CounterBox[ "Text"], "."}]], Inherited}, {Inherited, Inherited}},
  CounterAssignments->{{"Text", 0}}],

Cell["The elements are pairwise disjoint.", "ItemizedText",
  CellDingbat->None,
  CellFrameLabels->{{Cell[ 
          TextData[ {
            CounterBox[ "Text"], "."}]], Inherited}, {Inherited, Inherited}}],

Cell["No element is empty.", "ItemizedText",
  CellDingbat->None,
  CellFrameLabels->{{Cell[ 
          TextData[ {
            CounterBox[ "Text"], "."}]], Inherited}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["Covering", "Subsubsection",
  CellTags->"c:5"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<covering\>", 
      any[M, A], \[IndentingNewLine]is\[Dash]covering[M, 
          A] : \[NegativeThickSpace]\[NegativeThickSpace]\(\(\
\[DoubleLeftRightArrow]\)\((\(\[Union]M\) = A)\)\)\), "]"}]], "Input",
  CellTags->"Definition (covering)"],

Cell["\<\
Observation 1 from the previous computation is captured in the \
following Lemma:\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", \("\<factor set is covering\>", 
      any[A,  \[Tilde] ], 
      with[is\[Dash]equivalence\_A[ \[Tilde] ]], \
\[IndentingNewLine]is\[Dash]covering[\(factor\[Dash]set\_ \[Tilde] \)[A], 
        A]\), "]"}]], "Input",
  CellTags->"Lemma (factor set is covering)"],

Cell["\<\
As in many other cases also, we show the two directions separately. \
The reason for this is that different settings for the prover options are \
found appropriate in either direction.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", \("\<factor set is part\>", 
      any[A,  \[Tilde] ], 
      with[is\[Dash]equivalence\_A[ \[Tilde] ]], \
\[IndentingNewLine]\(\[Union]\(factor\[Dash]set\_ \[Tilde] \)[
            A]\) \[SubsetEqual] A\), "]"}]], "Input",
  CellTags->"Lemma (factor set is part)"],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Lemma["\<factor set is part\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<factor set\>"], 
            Definition["\<class\>"]\[RightAngleBracket]\), ",", 
        RowBox[{"ProverOptions", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              
              StyleBox[\(DisableInferenceRule \[Rule] \
{\[Cent]KBSetEquality}\),
                "HighlightedText"], 
              StyleBox[",",
                "UnHighlightedText"], 
              StyleBox[\(GRWTarget \[Rule] {"\<goal\>", "\<kb\>"}\),
                "UnHighlightedText"], 
              StyleBox[",",
                "UnHighlightedText"], 
              StyleBox[\(AllowIntroduceQuantifiers \[Rule] True\),
                "UnHighlightedText"], 
              StyleBox[",",
                "UnHighlightedText"], 
              StyleBox[\(RWInsideQuantifiers \[Rule] True\),
                "UnHighlightedText"], 
              StyleBox[",",
                "UnHighlightedText"], 
              StyleBox[\(DisableProver \[Rule] {STC, PND}\),
                "UnHighlightedText"], 
              StyleBox[",",
                "UnHighlightedText"], 
              StyleBox[\(ApplyBuiltIns \[Rule] {}\),
                "UnHighlightedText"]}], 
            StyleBox["}",
              "UnHighlightedText"]}]}], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 35\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "UnionClassesPart.nb", CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"],

Cell[TextData[{
  "We deactivate the rule \[Cent]KBSetEquality because otherwise the set \
equality (12) in the knowledge base would be expanded instead of being used \
for substituting ",
  Cell[BoxData[
      \(TraditionalForm\`A2\_0\)]],
  " in formula (6). When expanding (12) the proof still succeeds, but is less \
elegant. In the above proof, the inference rule \[Cent]MembershipByIncl, see \
Section ",
  ButtonBox["7",
    ButtonData:>{"Part2.nb", "Sec:STP"},
    ButtonStyle->"Hyperlink"],
  ", could also be applied: we could prove ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\((4)\), " ", 
            StyleBox[\(A1\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "\[Element]", 
          StyleBox[\(A\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], TraditionalForm]]],
  " by proving ",
  Cell[BoxData[
      \(TraditionalForm\`A2\_0 \[SubsetEqual] A\_0\)]],
  " since we already know ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\((6)\), " ", 
            StyleBox[\(A1\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "\[Element]", 
          StyleBox[\(A2\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], TraditionalForm]]],
  ". We must activate this rule by setting the option ",
  Cell[BoxData[
      \(TraditionalForm\`STPMembershipByInclusion \[Rule] True\)]],
  ", which also leads to a successful proof, where we do not even have to \
deactivate expansion of set equality."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Lemma["\<factor set is part\>"]\), 
        ",", \(using \[Rule] \[LeftAngleBracket]Definition["\<factor set\>"], 
            Definition["\<class\>"]\[RightAngleBracket]\), ",", 
        RowBox[{"ProverOptions", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              StyleBox[\(STPMembershipByInclusion \[Rule] True\),
                "HighlightedText"], ",", 
              StyleBox[\(GRWTarget \[Rule] {"\<goal\>", "\<kb\>"}\),
                "UnHighlightedText"], 
              StyleBox[",",
                "UnHighlightedText"], 
              StyleBox[\(AllowIntroduceQuantifiers \[Rule] True\),
                "UnHighlightedText"], 
              StyleBox[",",
                "UnHighlightedText"], 
              StyleBox[\(RWInsideQuantifiers \[Rule] True\),
                "UnHighlightedText"], 
              StyleBox[",",
                "UnHighlightedText"], 
              StyleBox[\(DisableProver \[Rule] {STC, PND}\),
                "UnHighlightedText"], 
              StyleBox[",",
                "UnHighlightedText"], 
              StyleBox[\(ApplyBuiltIns \[Rule] {}\),
                "UnHighlightedText"]}], 
            StyleBox["}",
              "UnHighlightedText"]}]}]}], "]"}]], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "UnionClassesPart-byInclusion.nb", CharacterEncoding -> "ISO8859-1"], 
      None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", \("\<factor set covers\>", 
      any[A,  \[Tilde] ], 
      with[is\[Dash]equivalence\_A[ \[Tilde] ]], \
\[IndentingNewLine]\(\[Union]\(factor\[Dash]set\_ \[Tilde] \)[
            A]\) \[SupersetEqual] A\), "]"}]], "Input",
  CellTags->"Lemma (factor set covers)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Lemma["\<factor set covers\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Proposition["\<in own class\>"], 
            Definition["\<factor set\>"]\[RightAngleBracket]\), ",", 
        StyleBox[\(ProverOptions \[Rule] {EarlyRewriting \[Rule] True, 
              GRWTarget \[Rule] {"\<goal\>"}, 
              AllowIntroduceQuantifiers \[Rule] True, 
              RWInsideQuantifiers \[Rule] True, RWSetOperators \[Rule] True, 
              DisableProver \[Rule] {STC, PND}, ApplyBuiltIns \[Rule] {}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "UnionClassesCovers.nb", CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[TextData[{
  "The most interesting part in this proof is, of course, the \
\"solve\"-situation in formula (7). As already motivated in Section ",
  ButtonBox["10",
    ButtonData:>{"Part2.nb", "Sec:STS"},
    ButtonStyle->"Hyperlink"],
  ", a proof situation of that kind will always appear, when a formula"
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{" ", 
      FormBox[\(z \[Element] \(\[Union]{T\_x\( | \+x\)C\_x}\)\),
        "TraditionalForm"]}]], "DisplayFormula"],

Cell["\<\
needs to be proven. We handle proof situations of that type \
by\
\>", "SingleParagraph"],

Cell[TextData[{
  "first introducing a ",
  StyleBox["solve constant",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(x2\^*\)\)]],
  " for the existentially quantified x2, "
}], "ItemizedText"],

Cell[TextData[{
  "then ",
  StyleBox["expanding membership",
    FontSlant->"Italic"],
  " in a set abstraction, thus introducing another existential quantifier, \
and"
}], "ItemizedText"],

Cell[TextData[{
  "finally instantiating the existential quantifier by ",
  StyleBox["matching",
    FontSlant->"Italic"],
  " against the assumptions ",
  "and, from that, instantiating the solve constant."
}], "ItemizedText"],

Cell[TextData[{
  "For proving the equality of two sets, which was the original proof task, \
we employ a special inference rule in case one of the corresponding subset \
relations is already among the assumptions, see also Section ",
  ButtonBox["7",
    ButtonData:>{"Part2.nb", "Sec:STP"},
    ButtonStyle->"Hyperlink"],
  "."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Lemma["\<factor set is covering\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Lemma["\<factor set covers\>"], 
            Lemma["\<factor set is part\>"], 
            Definition["\<covering\>"]\[RightAngleBracket]\), ",", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>"}, 
              DisableProver \[Rule] {STC, STS, STKBR, PND}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "FactorSetIsCovering.nb", CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Disjoint Classes", "Subsubsection",
  CellTags->"c:6"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<disjoint\>", 
      any[M], \[IndentingNewLine]are\[Dash]disjoint[
          M] : \[NegativeThickSpace]\[NegativeThickSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\(\[ForAll] \+\(A, B \[Element] M\)\)\+\(A \
\[NotEqual] B\)\((A \[Intersection] B = \[EmptySet])\)\)\)\), "]"}]], "Input",\

  CellTags->"Definition (disjoint)"],

Cell["\<\
Observation 2 from above computation is put into another Lemma now.\
\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", \("\<factor set disjoint\>", 
      any[A,  \[Tilde] ], 
      with[is\[Dash]equivalence\_A[ \[Tilde] ]], \
\[IndentingNewLine]are\[Dash]disjoint[\(factor\[Dash]set\_ \[Tilde] \)[A]]\), 
      "]"}]], "Input",
  CellTags->"Lemma (factor set disjoint)"],

Cell["\<\
First we prove the contraposition of Proposition[\"equal \
classes\"], since this will be more useful in this form in the proof of the \
above lemma. It might be that, by appropriate improvements in predicate logic \
proving, the prover might be smart enough to find out by itself, that it is \
preferable to use contrapositions of implications in the knowledge base when \
doing a proof by contradiction, as it is the case in the proof of \
Lemma[\"factor set disjoint\"].\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<distinct classes\>\"", ",", 
        RowBox[{"any", "[", GridBox[{
              {\(x, y \[Element] A\)},
              {\(\(\[Tilde]\)\(\(,\)\(A\)\)\)}
              }], "]"}], ",", \(with[is\[Dash]equivalence\_A[ \[Tilde] ]]\), 
        ",", "\[IndentingNewLine]", \(class\_\(A,  \[Tilde] \)[x] \[NotEqual] 
            class\_\(A,  \[Tilde] \)[y] \[Implies] x \[NotTilde] y\)}], 
      "]"}]], "Input",
  CellTags->"Proposition (distinct classes)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<distinct classes\>"]\), 
        ",", \(using \[Rule] Proposition["\<equal classes\>"]\), ",", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, DisableProver \[Rule] {STC, STP, STKBR, PND}, 
              ApplyBuiltIns \[Rule] {}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "DistinctClasses.nb", CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<not in distinct classes\>\"", ",", 
        RowBox[{"any", "[", GridBox[{
              {\(x, y, z\)},
              {\(A,  \[Tilde] \)}
              }], "]"}], ",", \(with[is\[Dash]equivalence\_A[ \[Tilde] ]]\), 
        ",", "\[IndentingNewLine]", \(x \[Element] 
              class\_\(A,  \[Tilde] \)[y] \[And] 
            x \[Element] class\_\(A,  \[Tilde] \)[z] \[Implies] 
          y \[Tilde] z\)}], "]"}]], "Input",
  PageBreakAbove->True,
  CellTags->"Proposition (not in distinct classes)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<not in distinct classes\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Proposition["\<common predecessor \[DoubleLeftArrow]\>"], 
            Definition["\<class\>"]\[RightAngleBracket]\), ",", 
        "\[IndentingNewLine]", 
        RowBox[{"ProverOptions", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              StyleBox[\(RWHigherOrder \[Rule] True\),
                "HighlightedText"], ",", 
              StyleBox[\(AllowIntroduceQuantifiers \[Rule] True\),
                "UnHighlightedText"], 
              StyleBox[",",
                "UnHighlightedText"], 
              StyleBox[\(UseCyclicRules \[Rule] True\),
                "UnHighlightedText"], 
              StyleBox[",",
                "UnHighlightedText"], 
              StyleBox[\(GRWTarget \[Rule] {"\<goal\>", "\<kb\>"}\),
                "UnHighlightedText"], 
              StyleBox[",",
                "UnHighlightedText"], 
              StyleBox[\(ApplyBuiltIns \[Rule] {}\),
                "UnHighlightedText"], 
              StyleBox[",",
                "UnHighlightedText"], 
              StyleBox[\(DisableProver \[Rule] {STC, STS, PND}\),
                "UnHighlightedText"]}], 
            StyleBox["}",
              "UnHighlightedText"]}]}], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 45\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "NotInDistinctClasses.nb", CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[TextData[{
  "Note, that the option ",
  Cell[BoxData[
      \(TraditionalForm\`RWHigherOrder \[Rule] True\)]],
  " is necessary for allowing Proposition[\"common predecessor \
\[DoubleLeftArrow]\"] to be used as a rewrite rule for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Tilde] y\)]],
  " for arbitrary \[Tilde]. This type of rewriting is then used for rewriting \
the goal (4) to the new goal (7)."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Lemma["\<factor set disjoint\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Proposition["\<not in distinct classes\>"], 
            Proposition["\<distinct classes\>"], Definition["\<disjoint\>"], 
            Definition["\<factor set\>"]\[RightAngleBracket]\), ",", 
        StyleBox[\(ProverOptions \[Rule] {RWSetOperators \[Rule] True, 
              AllowIntroduceQuantifiers \[Rule] True, 
              UseCyclicRules \[Rule] True, 
              GRWTarget \[Rule] {"\<kb\>", "\<goal\>"}, 
              ApplyBuiltIns \[Rule] {}, 
              DisableProver \[Rule] {STC, STS, PND}}\),
          "UnHighlightedText"], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 70\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "FactorSetDisjoint.nb", CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Non\[Dash]empty Classes", "Subsubsection",
  CellTags->"c:7"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<all nonempty\>", 
      any[M], \[IndentingNewLine]all\[Dash]nonempty[
          M] : \[NegativeThickSpace]\[NegativeThickSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\[ForAll] \+\(X \[Element] M\)X \[NotEqual] \
\[EmptySet]\)\)\), "]"}]], "Input",
  CellTags->"Definition (all nonempty)"],

Cell["\<\
Finally, Lemma[\"all in factor set nonempty\"] expresses what has \
been observation 3 in the computation at the beginning of this section.\
\>", \
"SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", \("\<all in factor set nonempty\>", 
      any[A,  \[Tilde] ], 
      with[is\[Dash]equivalence\_A[ \[Tilde] ]], \
\[IndentingNewLine]all\[Dash]nonempty[\(factor\[Dash]set\_ \[Tilde] \)[A]]\), 
      "]"}]], "Input",
  CellTags->"Lemma (all in factor set nonempty)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Lemma["\<all in factor set nonempty\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Proposition["\<in own class\>"], 
            Definition["\<all nonempty\>"], 
            Definition["\<factor set\>"]\[RightAngleBracket]\), ",", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, UseCyclicRules \[Rule] False, 
              AllowIntroduceQuantifiers \[Rule] True, 
              RWInsideQuantifiers \[Rule] True, ApplyBuiltIns \[Rule] {}, 
              DisableProver \[Rule] {STC, STS, PND}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "AllInFactorSetNonempty.nb", CharacterEncoding -> "ISO8859-1"], None},
    
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Partition", "Subsubsection",
  CellTags->"c:8"],

Cell[TextData[{
  "Actually, a collection of sets having just the properties observed in the \
computation is called ",
  StyleBox["a partition",
    FontSlant->"Italic"],
  " of the original set."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<partition\>\"", ",", \(any[M, A]\), ",", "\[IndentingNewLine]", 
        RowBox[{\(is\[Dash]partition[M, A]\), ":", 
          "\[NegativeThickSpace]\[NegativeThickSpace]", 
          RowBox[{"\[DoubleLeftRightArrow]", "\[IndentingNewLine]", 
            RowBox[{"\[And]", 
              RowBox[{
                StyleBox["{",
                  SpanMaxSize->Infinity], GridBox[{
                    {\(is\[Dash]covering[M, A]\)},
                    {\(are\[Dash]disjoint[M]\)},
                    {\(all\[Dash]nonempty[M]\)}
                    },
                  ColumnAlignments->{Left}], 
                StyleBox["}",
                  ShowContents->False]}]}]}]}]}], " ", "]"}]], "Input",
  CellTags->"Definition (partition)"],

Cell["\<\
The 3 observations from the beginning can now be \
counter\[Dash]checked in one computation.\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[is\[Dash]partition[factor\[Dash]set\_R[A10], A10]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "As one might expect, this is not only true in the example, the factor set \
of a set w.r.t. to an equivalence relation is ",
  StyleBox["always",
    FontSlant->"Italic"],
  " a partition of the set."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theorem",
        FontWeight->"Bold"], "[", \("\<factor set is partition\>", 
      any[A,  \[Tilde] ], 
      with[is\[Dash]equivalence\_A[ \[Tilde] ]], \
\[IndentingNewLine]is\[Dash]partition[\(factor\[Dash]set\_ \[Tilde] \)[A], 
        A]\), "]"}]], "Input",
  CellTags->"Theorem (factor set is partition)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Theorem["\<factor set is partition\>"]\), 
        ",", \(using \[Rule] \[LeftAngleBracket]Lemma["\<factor set is \
covering\>"], Lemma["\<factor set disjoint\>"], 
            Lemma["\<all in factor set nonempty\>"], 
            Definition["\<partition\>"]\[RightAngleBracket]\), ",", 
        "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>"}, 
              RWInsideQuantifiers \[Rule] True, ApplyBuiltIns \[Rule] {}, 
              DisableProver \[Rule] {STC, STS, PND}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "FactorSetPartition.nb", CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell["\<\
The following proposition is again just the contraposition of the \
fact the all elements in a partition are pairwise disjoint. The comments \
above on possible improvements in predicate logic proving apply also \
here.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<intersecting are equal\>", any[A, P], 
      with[is\[Dash]partition[P, 
          A]], \[IndentingNewLine]\[ForAll] \+\(X, Y \[Element] P\)\((X \
\[Intersection] Y \[NotEqual] \[EmptySet] \[Implies] \((X = Y)\))\)\), 
      "]"}]], "Input",
  CellTags->"Proposition (intersecting are equal)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<intersecting are equal\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<partition\>"], 
            Definition["\<disjoint\>"]\[RightAngleBracket]\), ",", 
        "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {DisableProver \[Rule] {STC, PND}}\),
          
          "UnHighlightedText"], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 35\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "IntersectingAreEqual.nb", CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exploration Round 4: Induced relation", "Subsection",
  CellTags->"c:9"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<induced relation\>", 
      any[S, a, 
        b], \[IndentingNewLine]in\[Dash]relation\_S[a, 
          b] : \[NegativeThickSpace]\[NegativeThickSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\[Exists] \+\(M \[Element] S\)\((a \[Element] 
                  M \[And] b \[Element] M)\)\)\)\), "]"}]], "Input",
  CellTags->"Definition (induced relation)"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      in\[Dash]relation\_{{2, 4, 6, 8, 10}, {3, 6, 9}, {4, 8}, {5, 10}, {6}, \
{7}, {8}, {9}, {10}}[4, 6]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      in\[Dash]relation\_{{2, 4, 6, 8, 10}, {3, 6, 9}, {4, 8}, {5, 10}, {6}, \
{7}, {8}, {9}, {10}}[6, 9]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      in\[Dash]relation\_{{2, 4, 6, 8, 10}, {3, 6, 9}, {4, 8}, {5, 10}, {6}, \
{7}, {8}, {9}, {10}}[4, 9]]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "From these computations, one tell immediately, that the induced relation \
of this set is not transitive. Roughly, the fact that two of the sets \
intersect in ",
  Cell[BoxData[
      \(TraditionalForm\`{6}\)]],
  " allows to construct a counter\[Dash]example for transitivity. Doing more \
computations, one can confess oneself easily of this fact. Now, let's take a \
set of sets, where such intersections do not occur."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      in\[Dash]relation\_{{2, 4, 6, 8, 10}, {1, 3, 5, 7, 9}}[4, 
        6]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      in\[Dash]relation\_{{2, 4, 6, 8, 10}, {1, 3, 5, 7, 9}}[6, 
        8]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      in\[Dash]relation\_{{2, 4, 6, 8, 10}, {1, 3, 5, 7, 9}}[4, 
        8]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      in\[Dash]relation\_\(factor\[Dash]set\_R[A10]\)[0, 5]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      in\[Dash]relation\_\(factor\[Dash]set\_R[A10]\)[5, 10]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      in\[Dash]relation\_\(factor\[Dash]set\_R[A10]\)[0, 10]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["In fact, we can get much more from computation!", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      is\[Dash]reflexive\_A10[
        in\[Dash]relation\_\(factor\[Dash]set\_R[A10]\)]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      is\[Dash]symmetric\_A10[
        in\[Dash]relation\_\(factor\[Dash]set\_R[A10]\)]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      is\[Dash]transitive\_A10[
        in\[Dash]relation\_\(factor\[Dash]set\_R[A10]\)]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We shall conjecture from these experiments, that the induced relation of \
the factor set is ",
  StyleBox["always",
    FontSlant->"Italic"],
  " an equivalence relation. We will prove this fact in the subsequent \
sections."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell["Reflexivity", "Subsubsection",
  CellTags->"c:10"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<induced by partition is reflexive\>", 
      any[A, P], 
      with[is\[Dash]partition[P, 
          A]], \[IndentingNewLine]is\[Dash]reflexive\_A[
        in\[Dash]relation\_P]\), "]"}]], "Input",
  CellTags->"Proposition (induced by partition is reflexive)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<induced by partition is reflexive\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<reflexivity\>"], 
            Definition["\<induced relation\>"], Definition["\<partition\>"], 
            Definition["\<covering\>"]\[RightAngleBracket]\), ",", 
        "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {DisableProver \[Rule] {STC, PND}}\),
          
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "InducedByPartitionIsReflexive.nb", CharacterEncoding -> "ISO8859-1"],
       None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symmetry", "Subsubsection",
  CellTags->"c:11"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<induced by partition is symmetric\>", 
      any[A, P], 
      with[is\[Dash]partition[P, 
          A]], \[IndentingNewLine]is\[Dash]symmetric\_A[
        in\[Dash]relation\_P]\), "]"}]], "Input",
  CellTags->"Proposition (induced by partition is symmetric)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<induced by partition is symmetric\>"]\), 
        ",", \(using \[Rule] \[LeftAngleBracket]Definition["\<symmetry\>"], 
            Definition["\<induced relation\>"]\[RightAngleBracket]\), ",", 
        "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {DisableProver \[Rule] {STC, PND}}\),
          
          "UnHighlightedText"], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 45\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "InducedByPartitionIsSymmetric.nb", CharacterEncoding -> "ISO8859-1"],
       None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transitivity", "Subsubsection",
  CellTags->"c:12"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<induced by partition is transitive\>", 
      any[A, P], 
      with[is\[Dash]partition[P, 
          A]], \[IndentingNewLine]is\[Dash]transitive\_A[
        in\[Dash]relation\_P]\), "]"}]], "Input",
  CellTags->"Proposition (induced by partition is transitive)"],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<induced by partition is transitive\>"]\), 
        ",", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<transitivity\>"], 
            Definition["\<induced relation\>"], 
            Proposition["\<intersecting are equal\>"]\[RightAngleBracket]\), 
        ",", "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, InferMembershipIntersection \[Rule] True, 
              AllowIntroduceQuantifiers \[Rule] True, PNDLevel \[Rule] 0, 
              EarlyRewriting \[Rule] True, 
              DisableInferenceRule \[Rule] {\[Cent]KBFiniteChoice}, 
              DisableProver \[Rule] {STC, PND}}\),
          "UnHighlightedText"], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 76\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "InducedByPartitionIsTransitive.nb", CharacterEncoding -> 
        "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equivalence", "Subsubsection",
  CellTags->"c:13"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theorem",
        FontWeight->"Bold"], 
      "[", \("\<induced by partition is equivalence\>", any[A, P], 
      with[is\[Dash]partition[P, 
          A]], \[IndentingNewLine]is\[Dash]equivalence\_A[
        in\[Dash]relation\_P]\), "]"}]], "Input",
  CellTags->"Theorem (induced by partition is equivalence)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Theorem["\<induced by partition is equivalence\>"]\), 
        ",", \(using \[Rule] \[LeftAngleBracket]Proposition["\<induced by \
partition is reflexive\>"], 
            Proposition["\<induced by partition is symmetric\>"], 
            Proposition["\<induced by partition is transitive\>"], 
            Definition["\<equivalence\>"]\[RightAngleBracket]\), ",", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>"}, 
              DisableProver \[Rule] {STS, PND}}\),
          "UnHighlightedText"], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 30\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations1"}, 
        "InducedByPartitionIsEquivalence.nb", CharacterEncoding -> 
        "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timings and Statistics", "Subsection",
  CellTags->"c:14"],

Cell[TextData[{
  "In Table ",
  
  CounterBox["Section", "TimingsEq1"],
  ".",
  
  CounterBox["TableHead", "TimingsEq1"],
  " we collected the timings for all proofs done during this exploration. The \
first column refers to the label of the environment containing the goal of \
the proof, column two is the total elapsed time for proof generation, proof \
simplification, and proof display."
}], "SingleParagraph"],

Cell[BoxData[GridBox[{
        {
          StyleBox[\(Proof\ of\ \(Proposition/Lemma\)/Theorem\),
            FontFamily->"Helvetica",
            FontWeight->"Bold"], 
          StyleBox[\(Elapsed\ Time\),
            FontFamily->"Helvetica",
            FontWeight->"Bold"]},
        {"\<\"common successor\"\>", 
          StyleBox[\(22.090000000000146`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"common predecessor \[DoubleLeftArrow]\"\>", 
          StyleBox[\(10.039999999999964`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"equal classes\"\>", 
          StyleBox[\(73.90000000000009`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"in own class\"\>", 
          StyleBox[\(12.`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"non-empty class\"\>", 
          StyleBox[\(17.199999999999818`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"factor set is part\"\>", 
          StyleBox[\(10.889999999999873`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"factor set is part\"\>", 
          StyleBox[\(6.350000000000136`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"factor set covers\"\>", 
          StyleBox[\(5.829999999999927`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"factor set is covering\"\>", 
          StyleBox[\(2.2999999999999545`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"distinct classes\"\>", 
          StyleBox[\(4.150000000000091`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"not in distinct classes\"\>", 
          StyleBox[\(104.75`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"factor set disjoint\"\>", 
          StyleBox[\(85.53999999999996`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"all in factor set nonempty\"\>", 
          StyleBox[\(12.389999999999873`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"factor set is partition\"\>", 
          StyleBox[\(1.9600000000000364`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"intersecting are equal\"\>", 
          StyleBox[\(20.01000000000022`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"induced by partition is reflexive\"\>", 
          StyleBox[\(22.63000000000011`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"induced by partition is symmetric\"\>", 
          StyleBox[\(18.63000000000011`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"induced by partition is transitive\"\>", 
          StyleBox[\(1132.2200000000003`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"induced by partition is equivalence\"\>", 
          StyleBox[\(5.6799999999993815`\ Second\),
            FontWeight->"Bold"]}
        },
      ColumnWidths->Automatic,
      ColumnAlignments->{Left, Right},
      ColumnLines->True]], "2ColumnTable",
  PageWidth->600,
  CellMargins->{{Inherited, Inherited}, {Inherited, 28}},
  CounterIncrements->"TableHead",
  GridBoxOptions->{RowLines->{0.5, False}},
  CellTags->"TimingsEq1"],

Cell[TextData[{
  "Table ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["TableHead"],
  ". ",
  StyleBox["Timings for the exploration of equivalence relation, part 1", 
    "TableHeadText"]
}], "TableHead"],

Cell["\<\
Total elapsed time of all proofs together amounts to 1568.56 \
seconds, which is approximately 26 minutes.\
\>", "SingleParagraph"]
}, Open  ]],

Cell[TextData[ButtonBox["\[LowerRightArrow]",
  ButtonFunction:>(NotebookLocate[ #2]&),
  ButtonData:>{"CaseStudies-EquivalenceRelations2.nb", "c:1"},
  ButtonStyle->"Navigation",
  ButtonNote->"Equivalence Relations and Partitions II"]], "SingleParagraph",
  TextAlignment->Right]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{930, 666},
WindowMargins->{{Automatic, 123}, {Automatic, 73}},
PrintingStartingPageNumber->115,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Part 3: Case Studies"}], "Header"]}, {Cell[ 
        TextData[ {
          CounterBox[ "Section"], 
          ". Equivalence Relations and Partitions I"}], "Header"], Inherited, 
      Inherited}},
PrintingOptions->{"PrintingMargins"->{{79.1875, 79.1875}, {108, 108}},
"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->True,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", \
"wwindste", "Diss", "Main"}, "CaseStudies-EquivalenceRelations1.nb.ps", \
CharacterEncoding -> "ISO8859-1"],
"Magnification"->1},
StyleDefinitions -> "TheoremaSmartColors.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1964, 59, 215, 3, 59, "Section",
      CounterAssignments->{{"Section", 12}, {"TableHead", 0}, {
          "Equation", 0}, {"Figure", 0}, {"Subsection", 0}, {
          "Subsubsection", 0}},
      CellTags->"c:1"]},
  "c:2"->{
    Cell[2204, 66, 75, 1, 53, "Subsection",
      CellTags->"c:2"]},
  "Definition (reflexivity)"->{
    Cell[4943, 145, 392, 8, 79, "Input",
      CellTags->"Definition (reflexivity)"]},
  "Definition (symmetry)"->{
    Cell[5338, 155, 426, 9, 81, "Input",
      CellTags->"Definition (symmetry)"]},
  "Definition (transitivity)"->{
    Cell[5767, 166, 477, 9, 81, "Input",
      CellTags->"Definition (transitivity)"]},
  "Definition (equivalence)"->{
    Cell[6247, 177, 1115, 27, 112, "Input",
      CellTags->"Definition (equivalence)"]},
  "Definition (Constants)"->{
    Cell[8507, 244, 568, 14, 107, "Input",
      CellTags->"Definition (Constants)"]},
  "Proposition (common successor)"->{
    Cell[17523, 499, 459, 9, 81, "Input",
      CellTags->"Proposition (common successor)"]},
  "Proposition (common predecessor \[DoubleLeftArrow])"->{
    Cell[18887, 536, 503, 10, 81, "Input",
      CellTags->"Proposition (common predecessor \[DoubleLeftArrow])"]},
  "c:3"->{
    Cell[20374, 577, 79, 1, 53, "Subsection",
      CellTags->"c:3"]},
  "Definition (class)"->{
    Cell[20456, 580, 354, 8, 60, "Input",
      CellTags->"Definition (class)"]},
  "Proposition (equal classes)"->{
    Cell[21247, 617, 424, 8, 61, "Input",
      CellTags->"Proposition (equal classes)"]},
  "Proposition (in own class)"->{
    Cell[24597, 712, 346, 7, 61, "Input",
      CellTags->"Proposition (in own class)"]},
  "Proposition (non-empty class)"->{
    Cell[25901, 750, 370, 8, 61, "Input",
      CellTags->"Proposition (non-empty class)"]},
  "c:4"->{
    Cell[28394, 819, 72, 1, 53, "Subsection",
      CellTags->"c:4"]},
  "Definition (factor set)"->{
    Cell[28469, 822, 366, 8, 81, "Input",
      CellTags->"Definition (factor set)"]},
  "c:5"->{
    Cell[29911, 870, 52, 1, 44, "Subsubsection",
      CellTags->"c:5"]},
  "Definition (covering)"->{
    Cell[29966, 873, 337, 7, 68, "Input",
      CellTags->"Definition (covering)"]},
  "Lemma (factor set is covering)"->{
    Cell[30425, 887, 347, 8, 59, "Input",
      CellTags->"Lemma (factor set is covering)"]},
  "Lemma (factor set is part)"->{
    Cell[30997, 903, 350, 8, 68, "Input",
      CellTags->"Lemma (factor set is part)"]},
  "Lemma (factor set covers)"->{
    Cell[36637, 1059, 350, 8, 68, "Input",
      CellTags->"Lemma (factor set covers)"]},
  "c:6"->{
    Cell[40432, 1177, 60, 1, 44, "Subsubsection",
      CellTags->"c:6"]},
  "Definition (disjoint)"->{
    Cell[40495, 1180, 414, 9, 95, "Input",
      CellTags->"Definition (disjoint)"]},
  "Lemma (factor set disjoint)"->{
    Cell[41019, 1196, 337, 8, 59, "Input",
      CellTags->"Lemma (factor set disjoint)"]},
  "Proposition (distinct classes)"->{
    Cell[41870, 1216, 562, 12, 87, "Input",
      CellTags->"Proposition (distinct classes)"]},
  "Proposition (not in distinct classes)"->{
    Cell[43158, 1252, 614, 14, 87, "Input",
      PageBreakAbove->True,
      CellTags->"Proposition (not in distinct classes)"]},
  "c:7"->{
    Cell[47294, 1365, 67, 1, 44, "Subsubsection",
      CellTags->"c:7"]},
  "Definition (all nonempty)"->{
    Cell[47364, 1368, 378, 8, 79, "Input",
      CellTags->"Definition (all nonempty)"]},
  "Lemma (all in factor set nonempty)"->{
    Cell[47924, 1384, 351, 8, 59, "Input",
      CellTags->"Lemma (all in factor set nonempty)"]},
  "c:8"->{
    Cell[49329, 1425, 53, 1, 44, "Subsubsection",
      CellTags->"c:8"]},
  "Definition (partition)"->{
    Cell[49608, 1436, 852, 20, 129, "Input",
      CellTags->"Definition (partition)"]},
  "Theorem (factor set is partition)"->{
    Cell[51007, 1480, 354, 8, 59, "Input",
      CellTags->"Theorem (factor set is partition)"]},
  "Proposition (intersecting are equal)"->{
    Cell[52586, 1523, 389, 8, 81, "Input",
      CellTags->"Proposition (intersecting are equal)"]},
  "c:9"->{
    Cell[53925, 1564, 78, 1, 53, "Subsection",
      CellTags->"c:9"]},
  "Definition (induced relation)"->{
    Cell[54006, 1567, 440, 9, 79, "Input",
      CellTags->"Definition (induced relation)"]},
  "c:10"->{
    Cell[57721, 1731, 56, 1, 44, "Subsubsection",
      CellTags->"c:10"]},
  "Proposition (induced by partition is reflexive)"->{
    Cell[57780, 1734, 356, 8, 58, "Input",
      CellTags->"Proposition (induced by partition is reflexive)"]},
  "c:11"->{
    Cell[59060, 1773, 53, 1, 44, "Subsubsection",
      CellTags->"c:11"]},
  "Proposition (induced by partition is symmetric)"->{
    Cell[59116, 1776, 356, 8, 60, "Input",
      CellTags->"Proposition (induced by partition is symmetric)"]},
  "c:12"->{
    Cell[60431, 1817, 57, 1, 44, "Subsubsection",
      CellTags->"c:12"]},
  "Proposition (induced by partition is transitive)"->{
    Cell[60491, 1820, 359, 8, 58, "Input",
      CellTags->"Proposition (induced by partition is transitive)"]},
  "c:13"->{
    Cell[62119, 1864, 56, 1, 44, "Subsubsection",
      CellTags->"c:13"]},
  "Theorem (induced by partition is equivalence)"->{
    Cell[62178, 1867, 354, 8, 60, "Input",
      CellTags->"Theorem (induced by partition is equivalence)"]},
  "c:14"->{
    Cell[63667, 1911, 64, 1, 53, "Subsection",
      CellTags->"c:14"]},
  "TimingsEq1"->{
    Cell[64154, 1927, 3029, 73, 503, "2ColumnTable",
      CounterIncrements->"TableHead",
      CellTags->"TimingsEq1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 69362, 2067},
  {"c:2", 69598, 2073},
  {"Definition (reflexivity)", 69699, 2076},
  {"Definition (symmetry)", 69815, 2079},
  {"Definition (transitivity)", 69932, 2082},
  {"Definition (equivalence)", 70052, 2085},
  {"Definition (Constants)", 70172, 2088},
  {"Proposition (common successor)", 70297, 2091},
  {"Proposition (common predecessor \[DoubleLeftArrow])", 70450, 2094},
  {"c:3", 70577, 2097},
  {"Definition (class)", 70674, 2100},
  {"Proposition (equal classes)", 70791, 2103},
  {"Proposition (in own class)", 70916, 2106},
  {"Proposition (non-empty class)", 71043, 2109},
  {"c:4", 71147, 2112},
  {"Definition (factor set)", 71249, 2115},
  {"c:5", 71347, 2118},
  {"Definition (covering)", 71450, 2121},
  {"Lemma (factor set is covering)", 71573, 2124},
  {"Lemma (factor set is part)", 71701, 2127},
  {"Lemma (factor set covers)", 71824, 2130},
  {"c:6", 71925, 2133},
  {"Definition (disjoint)", 72029, 2136},
  {"Lemma (factor set disjoint)", 72150, 2139},
  {"Proposition (distinct classes)", 72280, 2142},
  {"Proposition (not in distinct classes)", 72421, 2145},
  {"c:7", 72563, 2149},
  {"Definition (all nonempty)", 72671, 2152},
  {"Lemma (all in factor set nonempty)", 72803, 2155},
  {"c:8", 72913, 2158},
  {"Definition (partition)", 73018, 2161},
  {"Theorem (factor set is partition)", 73148, 2164},
  {"Proposition (intersecting are equal)", 73290, 2167},
  {"c:9", 73402, 2170},
  {"Definition (induced relation)", 73511, 2173},
  {"c:10", 73617, 2176},
  {"Proposition (induced by partition is reflexive)", 73748, 2179},
  {"c:11", 73872, 2182},
  {"Proposition (induced by partition is symmetric)", 74003, 2185},
  {"c:12", 74127, 2188},
  {"Proposition (induced by partition is transitive)", 74259, 2191},
  {"c:13", 74384, 2194},
  {"Theorem (induced by partition is equivalence)", 74513, 2197},
  {"c:14", 74635, 2200},
  {"TimingsEq1", 74726, 2203}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 234, 5, 42, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1964, 59, 215, 3, 59, "Section",
  CounterAssignments->{{"Section", 12}, {"TableHead", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsection", 0}, {"Subsubsection", 0}},
  CellTags->"c:1"],

Cell[CellGroupData[{
Cell[2204, 66, 75, 1, 53, "Subsection",
  CellTags->"c:2"],
Cell[2282, 69, 2658, 74, 202, "SingleParagraph"],
Cell[4943, 145, 392, 8, 79, "Input",
  CellTags->"Definition (reflexivity)"],
Cell[5338, 155, 426, 9, 81, "Input",
  CellTags->"Definition (symmetry)"],
Cell[5767, 166, 477, 9, 81, "Input",
  CellTags->"Definition (transitivity)"],
Cell[6247, 177, 1115, 27, 112, "Input",
  CellTags->"Definition (equivalence)"],
Cell[7365, 206, 1139, 36, 88, "SingleParagraph"],
Cell[8507, 244, 568, 14, 107, "Input",
  CellTags->"Definition (Constants)"],

Cell[CellGroupData[{
Cell[9100, 262, 199, 3, 39, "Input"],
Cell[9302, 267, 1223, 35, 66, "Output"]
}, Open  ]],
Cell[10540, 305, 211, 6, 31, "SingleParagraph"],

Cell[CellGroupData[{
Cell[10776, 315, 286, 5, 39, "Input"],
Cell[11065, 322, 749, 22, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11851, 349, 419, 6, 58, "Input"],
Cell[12273, 357, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12348, 363, 416, 6, 59, "Input"],
Cell[12767, 371, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12842, 377, 421, 6, 58, "Input"],
Cell[13266, 385, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13341, 391, 534, 8, 78, "Input"],
Cell[13878, 401, 38, 1, 40, "Output"]
}, Open  ]],
Cell[13931, 405, 164, 4, 31, "SingleParagraph"],

Cell[CellGroupData[{
Cell[14120, 413, 436, 6, 58, "Input"],
Cell[14559, 421, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14634, 427, 431, 6, 59, "Input"],
Cell[15068, 435, 39, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15144, 441, 434, 6, 58, "Input"],
Cell[15581, 449, 39, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15657, 455, 549, 8, 78, "Input"],
Cell[16209, 465, 39, 1, 40, "Output"]
}, Open  ]],
Cell[16263, 469, 405, 7, 57, "FirstParagraph"],
Cell[16671, 478, 849, 19, 88, "Text"],
Cell[17523, 499, 459, 9, 81, "Input",
  CellTags->"Proposition (common successor)"],

Cell[CellGroupData[{
Cell[18007, 512, 571, 11, 58, "Input"],
Cell[18581, 525, 291, 8, 31, "SingleParagraph"]
}, Open  ]],
Cell[18887, 536, 503, 10, 81, "Input",
  CellTags->"Proposition (common predecessor \[DoubleLeftArrow])"],

Cell[CellGroupData[{
Cell[19415, 550, 624, 12, 96, "Input"],
Cell[20042, 564, 295, 8, 31, "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20374, 577, 79, 1, 53, "Subsection",
  CellTags->"c:3"],
Cell[20456, 580, 354, 8, 60, "Input",
  CellTags->"Definition (class)"],

Cell[CellGroupData[{
Cell[20835, 592, 62, 1, 41, "Input"],
Cell[20900, 595, 44, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20981, 601, 62, 1, 41, "Input"],
Cell[21046, 604, 40, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21123, 610, 62, 1, 41, "Input"],
Cell[21188, 613, 44, 1, 40, "Output"]
}, Open  ]],
Cell[21247, 617, 424, 8, 61, "Input",
  CellTags->"Proposition (equal classes)"],

Cell[CellGroupData[{
Cell[21696, 629, 777, 16, 96, "Input"],
Cell[22476, 647, 286, 8, 31, "SingleParagraph"]
}, Open  ]],
Cell[22777, 658, 793, 16, 88, "SingleParagraph"],
Cell[23573, 676, 73, 1, 42, "Input"],
Cell[23649, 679, 459, 7, 69, "SingleParagraph"],

Cell[CellGroupData[{
Cell[24133, 690, 75, 1, 41, "Input"],
Cell[24211, 693, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24286, 699, 118, 2, 50, "Input"],
Cell[24407, 703, 38, 1, 40, "Output"]
}, Open  ]],
Cell[24460, 707, 134, 3, 31, "SingleParagraph"],
Cell[24597, 712, 346, 7, 61, "Input",
  CellTags->"Proposition (in own class)"],

Cell[CellGroupData[{
Cell[24968, 723, 482, 9, 77, "Input"],
Cell[25453, 734, 284, 8, 31, "SingleParagraph"]
}, Open  ]],
Cell[25752, 745, 146, 3, 31, "SingleParagraph"],
Cell[25901, 750, 370, 8, 61, "Input",
  CellTags->"Proposition (non-empty class)"],

Cell[CellGroupData[{
Cell[26296, 762, 667, 14, 77, "Input"],
Cell[26966, 778, 287, 8, 31, "SingleParagraph"]
}, Open  ]],
Cell[27268, 789, 335, 7, 50, "SingleParagraph"],
Cell[27606, 798, 376, 8, 46, "ItemizedText"],
Cell[27985, 808, 394, 8, 46, "ItemizedText"]
}, Open  ]],
Cell[28394, 819, 72, 1, 53, "Subsection",
  CellTags->"c:4"],
Cell[28469, 822, 366, 8, 81, "Input",
  CellTags->"Definition (factor set)"],

Cell[CellGroupData[{
Cell[28860, 834, 66, 1, 39, "Input"],
Cell[28929, 837, 78, 1, 40, "Output"]
}, Open  ]],
Cell[29022, 841, 157, 3, 31, "SingleParagraph"],
Cell[29182, 846, 297, 8, 27, "ItemizedText",
  CounterAssignments->{{"Text", 0}}],
Cell[29482, 856, 208, 4, 27, "ItemizedText"],
Cell[29693, 862, 193, 4, 27, "ItemizedText"],

Cell[CellGroupData[{
Cell[29911, 870, 52, 1, 44, "Subsubsection",
  CellTags->"c:5"],
Cell[29966, 873, 337, 7, 68, "Input",
  CellTags->"Definition (covering)"],
Cell[30306, 882, 116, 3, 31, "SingleParagraph"],
Cell[30425, 887, 347, 8, 59, "Input",
  CellTags->"Lemma (factor set is covering)"],
Cell[30775, 897, 219, 4, 50, "SingleParagraph"],
Cell[30997, 903, 350, 8, 68, "Input",
  CellTags->"Lemma (factor set is part)"],
Cell[31350, 913, 1546, 38, 97, "Input"],
Cell[32899, 953, 290, 8, 31, "SingleParagraph"],
Cell[33192, 963, 1706, 46, 107, "SingleParagraph"],

Cell[CellGroupData[{
Cell[34923, 1013, 1295, 29, 78, "Input"],
Cell[36221, 1044, 89, 1, 40, "Output"]
}, Open  ]],
Cell[36325, 1048, 309, 9, 31, "SingleParagraph"],
Cell[36637, 1059, 350, 8, 68, "Input",
  CellTags->"Lemma (factor set covers)"],

Cell[CellGroupData[{
Cell[37012, 1071, 648, 11, 96, "Input"],
Cell[37663, 1084, 292, 8, 31, "SingleParagraph"]
}, Open  ]],
Cell[37970, 1095, 335, 7, 50, "SingleParagraph"],
Cell[38308, 1104, 145, 3, 38, "DisplayFormula"],
Cell[38456, 1109, 99, 3, 31, "SingleParagraph"],
Cell[38558, 1114, 222, 8, 27, "ItemizedText"],
Cell[38783, 1124, 189, 6, 27, "ItemizedText"],
Cell[38975, 1132, 227, 6, 27, "ItemizedText"],
Cell[39205, 1140, 352, 8, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[39582, 1152, 505, 9, 77, "Input"],
Cell[40090, 1163, 293, 8, 31, "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[40432, 1177, 60, 1, 44, "Subsubsection",
  CellTags->"c:6"],
Cell[40495, 1180, 414, 9, 95, "Input",
  CellTags->"Definition (disjoint)"],
Cell[40912, 1191, 104, 3, 31, "SingleParagraph"],
Cell[41019, 1196, 337, 8, 59, "Input",
  CellTags->"Lemma (factor set disjoint)"],
Cell[41359, 1206, 508, 8, 88, "SingleParagraph"],
Cell[41870, 1216, 562, 12, 87, "Input",
  CellTags->"Proposition (distinct classes)"],

Cell[CellGroupData[{
Cell[42457, 1232, 394, 7, 58, "Input"],
Cell[42854, 1241, 289, 8, 31, "SingleParagraph"]
}, Open  ]],
Cell[43158, 1252, 614, 14, 87, "Input",
  PageBreakAbove->True,
  CellTags->"Proposition (not in distinct classes)"],

Cell[CellGroupData[{
Cell[43797, 1270, 1513, 35, 97, "Input"],
Cell[45313, 1307, 294, 8, 31, "SingleParagraph"]
}, Open  ]],
Cell[45622, 1318, 436, 10, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[46083, 1332, 868, 17, 96, "Input"],
Cell[46954, 1351, 291, 8, 31, "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[47294, 1365, 67, 1, 44, "Subsubsection",
  CellTags->"c:7"],
Cell[47364, 1368, 378, 8, 79, "Input",
  CellTags->"Definition (all nonempty)"],
Cell[47745, 1378, 176, 4, 31, "SingleParagraph"],
Cell[47924, 1384, 351, 8, 59, "Input",
  CellTags->"Lemma (all in factor set nonempty)"],

Cell[CellGroupData[{
Cell[48300, 1396, 676, 12, 96, "Input"],
Cell[48979, 1410, 301, 9, 31, "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[49329, 1425, 53, 1, 44, "Subsubsection",
  CellTags->"c:8"],
Cell[49385, 1428, 220, 6, 31, "SingleParagraph"],
Cell[49608, 1436, 852, 20, 129, "Input",
  CellTags->"Definition (partition)"],
Cell[50463, 1458, 127, 3, 31, "SingleParagraph"],

Cell[CellGroupData[{
Cell[50615, 1465, 91, 1, 39, "Input"],
Cell[50709, 1468, 38, 1, 40, "Output"]
}, Open  ]],
Cell[50762, 1472, 242, 6, 31, "SingleParagraph"],
Cell[51007, 1480, 354, 8, 59, "Input",
  CellTags->"Theorem (factor set is partition)"],

Cell[CellGroupData[{
Cell[51386, 1492, 633, 11, 96, "Input"],
Cell[52022, 1505, 292, 8, 31, "SingleParagraph"]
}, Open  ]],
Cell[52329, 1516, 254, 5, 50, "SingleParagraph"],
Cell[52586, 1523, 389, 8, 81, "Input",
  CellTags->"Proposition (intersecting are equal)"],

Cell[CellGroupData[{
Cell[53000, 1535, 579, 13, 77, "Input"],
Cell[53582, 1550, 294, 8, 31, "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[53925, 1564, 78, 1, 53, "Subsection",
  CellTags->"c:9"],
Cell[54006, 1567, 440, 9, 79, "Input",
  CellTags->"Definition (induced relation)"],

Cell[CellGroupData[{
Cell[54471, 1580, 148, 3, 41, "Input"],
Cell[54622, 1585, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54697, 1591, 148, 3, 41, "Input"],
Cell[54848, 1596, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54923, 1602, 148, 3, 41, "Input"],
Cell[55074, 1607, 39, 1, 40, "Output"]
}, Open  ]],
Cell[55128, 1611, 465, 9, 69, "SingleParagraph"],

Cell[CellGroupData[{
Cell[55618, 1624, 118, 3, 41, "Input"],
Cell[55739, 1629, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55814, 1635, 118, 3, 41, "Input"],
Cell[55935, 1640, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56010, 1646, 118, 3, 41, "Input"],
Cell[56131, 1651, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56206, 1657, 102, 2, 41, "Input"],
Cell[56311, 1661, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56386, 1667, 103, 2, 41, "Input"],
Cell[56492, 1671, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56567, 1677, 103, 2, 41, "Input"],
Cell[56673, 1681, 38, 1, 40, "Output"]
}, Open  ]],
Cell[56726, 1685, 74, 0, 31, "SingleParagraph"],

Cell[CellGroupData[{
Cell[56825, 1689, 130, 3, 41, "Input"],
Cell[56958, 1694, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57033, 1700, 130, 3, 41, "Input"],
Cell[57166, 1705, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57241, 1711, 131, 3, 41, "Input"],
Cell[57375, 1716, 38, 1, 40, "Output"]
}, Open  ]],
Cell[57428, 1720, 268, 7, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[57721, 1731, 56, 1, 44, "Subsubsection",
  CellTags->"c:10"],
Cell[57780, 1734, 356, 8, 58, "Input",
  CellTags->"Proposition (induced by partition is reflexive)"],

Cell[CellGroupData[{
Cell[58161, 1746, 537, 10, 77, "Input"],
Cell[58701, 1758, 310, 9, 31, "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[59060, 1773, 53, 1, 44, "Subsubsection",
  CellTags->"c:11"],
Cell[59116, 1776, 356, 8, 60, "Input",
  CellTags->"Proposition (induced by partition is symmetric)"],

Cell[CellGroupData[{
Cell[59497, 1788, 572, 12, 58, "Input"],
Cell[60072, 1802, 310, 9, 31, "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[60431, 1817, 57, 1, 44, "Subsubsection",
  CellTags->"c:12"],
Cell[60491, 1820, 359, 8, 58, "Input",
  CellTags->"Proposition (induced by partition is transitive)"],
Cell[60853, 1830, 913, 18, 96, "Input"],
Cell[61769, 1850, 313, 9, 31, "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62119, 1864, 56, 1, 44, "Subsubsection",
  CellTags->"c:13"],
Cell[62178, 1867, 354, 8, 60, "Input",
  CellTags->"Theorem (induced by partition is equivalence)"],

Cell[CellGroupData[{
Cell[62557, 1879, 732, 14, 96, "Input"],
Cell[63292, 1895, 314, 9, 31, "SingleParagraph"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63667, 1911, 64, 1, 53, "Subsection",
  CellTags->"c:14"],
Cell[63734, 1914, 417, 11, 50, "SingleParagraph"],
Cell[64154, 1927, 3029, 73, 503, "2ColumnTable",
  CounterIncrements->"TableHead",
  CellTags->"TimingsEq1"],
Cell[67186, 2002, 213, 10, 36, "TableHead"],
Cell[67402, 2014, 141, 3, 31, "SingleParagraph"]
}, Open  ]],
Cell[67558, 2020, 281, 5, 42, "SingleParagraph"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

