(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     40537,       1104]*)
(*NotebookOutlinePosition[     49686,       1321]*)
(*  CellTagsIndexPosition[     47620,       1275]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[ButtonBox["\[UpperLeftArrow]",
  ButtonFunction:>(NotebookLocate[ #2]&),
  ButtonData:>{"CaseStudies-EquivalenceRelations1.nb", "c:1"},
  ButtonStyle->"Navigation",
  ButtonNote->"Equivalence Relations and Partitions I"]], "SingleParagraph",
  TextAlignment->Left],

Cell[CellGroupData[{

Cell["Equivalence Relations and Partitions II", "Section",
  CounterAssignments->{{"Section", 13}, {"TableHead", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsection", 0}, {"Subsubsection", 0}},
  CellTags->"c:1"],

Cell[TextData[{
  "In this section, we want to continue the exploration from Section ",
  ButtonBox["13",
    ButtonData:>{"CaseStudies-EquivalenceRelations1.nb", None},
    ButtonStyle->"Hyperlink"],
  ", now using the ",
  StyleBox["extensional",
    FontSlant->"Italic"],
  " concept of a relation from set theory. The exploration until the notion \
of an ",
  StyleBox["induced relation",
    FontSlant->"Italic"],
  " can be carried out in a similar flow like the exploration for the \
intensional case. We will therefore ",
  StyleBox["omit all the proofs",
    FontSlant->"Italic"],
  " and give only the modified definitions, propositions, and lemmata as they \
are needed in the new setting."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell["Reformulations of Notions for the New Setting", "Subsection",
  CellTags->"c:2"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<relation\>\"", ",", \(any[R, A, B]\), ",", "\[IndentingNewLine]", 
        GridBox[{
            {\(is\[Dash]relation[R, A, 
                  B] : \[NegativeThickSpace]\[NegativeMediumSpace]\(\(\
\[DoubleLeftRightArrow]\)\((R \[SubsetEqual] A\[Cross]B)\)\)\)},
            {\(is\[Dash]relation[R, 
                  A] : \[NegativeThickSpace]\[NegativeMediumSpace]\(\(\
\[DoubleLeftRightArrow]\)\((R \[SubsetEqual] A\[Cross]A)\)\)\)},
            {\(is\[Dash]relation[
                  R] : \[NegativeThickSpace]\[NegativeMediumSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\[Exists] \+X R \[SubsetEqual] X\[Cross]X\)\)\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Definition (relation)"],

Cell[TextData[{
  "In the sequel, we will follow the approach ",
  StyleBox["not to explicitly mention the set on which the relation acts",
    FontSlant->"Italic"],
  " but instead assume the existence of ",
  StyleBox["one set U, in which the entire exploration is carried out",
    FontSlant->"Italic"],
  " (the domain of interest, our universe). This will result in a ",
  StyleBox["non\[Dash]algorithmic formulation",
    FontSlant->"Italic"],
  ", thus, we cannot do computations using this approach. We think, however, \
that we have demonstrated enough of the computation features of the system, \
so we concentrate on proving here. The exploration of the checkerboard \
problem in the next section will combine proving and computing again. "
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Assumption",
        FontWeight->"Bold"], 
      "[", \("\<domain of interest\>", \[IndentingNewLine]\[ForAll] \+x 
          x \[Element] U\), "]"}]], "Input",
  CellTags->"Assumption (domain of interest)"],

Cell[CellGroupData[{

Cell["Definitions", "Subsubsection",
  CellTags->"c:3"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<reflexivity\>", 
      any[R], \[IndentingNewLine]is\[Dash]reflexive[
          R] : \[NegativeThickSpace]\[NegativeMediumSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\[ForAll] \+x\[LeftAngleBracket]x, 
                x\[RightAngleBracket] \[Element] R\)\)\), "]"}]], "Input",
  CellTags->"Definition (reflexivity)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<symmetry\>", 
      any[R], \[IndentingNewLine]is\[Dash]symmetric[
          R] : \[NegativeThickSpace]\[NegativeMediumSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\[ForAll] \+\(x, y\)\((\[LeftAngleBracket]x, 
                    y\[RightAngleBracket] \[Element] 
                  R \[Implies] \[LeftAngleBracket]y, 
                    x\[RightAngleBracket] \[Element] R)\)\)\)\), 
      "]"}]], "Input",
  CellTags->"Definition (symmetry)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<transitivity\>", 
      any[R], \[IndentingNewLine]is\[Dash]transitive[
          R] : \[NegativeThickSpace]\[NegativeMediumSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\[ForAll] \+\(x, y, z\)\((\[LeftAngleBracket]x, 
                      y\[RightAngleBracket] \[Element] 
                    R \[And] \[LeftAngleBracket]y, 
                      z\[RightAngleBracket] \[Element] 
                    R \[Implies] \[LeftAngleBracket]x, 
                    z\[RightAngleBracket] \[Element] R)\)\)\)\), 
      "]"}]], "Input",
  CellTags->"Definition (transitivity)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<equivalence\>\"", ",", \(any[R]\), ",", "\[IndentingNewLine]", 
        RowBox[{\(is\[Dash]equivalence[R]\), ":", 
          "\[NegativeThickSpace]\[NegativeMediumSpace]", 
          RowBox[{"\[DoubleLeftRightArrow]", 
            RowBox[{
              StyleBox["\[And]",
                Background->None], 
              RowBox[{
                StyleBox["{",
                  SpanMaxSize->Infinity,
                  Background->None], 
                StyleBox[GridBox[{
                      {\(is\[Dash]relation[R]\)},
                      {\(is\[Dash]reflexive[R]\)},
                      {\(is\[Dash]symmetric[R]\)},
                      {\(is\[Dash]transitive[R]\)}
                      },
                    ColumnAlignments->{Left}],
                  Background->None], 
                StyleBox["}",
                  ShowContents->False,
                  Background->None]}]}]}]}]}], "]"}]], "Input",
  CellTags->"Definition (equivalence)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<class\>", 
      any[x, R], \[IndentingNewLine]class\_R[
          x] := {a \[VerticalSeparator] \[LeftAngleBracket]a, 
                x\[RightAngleBracket] \[Element] R}\), "]"}]], "Input",
  CellTags->"Definition (class)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<factor set\>", 
      any[R], \[IndentingNewLine]factor\[Dash]set[
          R] := {\(class\_R[x]\)\( \[VerticalSeparator] \+x\)}\), 
      "]"}]], "Input",
  CellTags->"Definition (factor set)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<covering\>", 
      any[M], \[IndentingNewLine]is\[Dash]covering[
          M] : \[NegativeThickSpace]\[NegativeThickSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\[ForAll] \+x x \[Element] \(\[Union]M\)\)\)\), 
      "]"}]], "Input",
  CellTags->"Definition (covering)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<disjoint\>", 
      any[M], \[IndentingNewLine]are\[Dash]disjoint[
          M] : \[NegativeThickSpace]\[NegativeThickSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\(\[ForAll] \+\(A, B \[Element] M\)\)\+\(A \
\[NotEqual] B\)\((A \[Intersection] B = \[EmptySet])\)\)\)\), "]"}]], "Input",\

  CellTags->"Definition (disjoint)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<all nonempty\>", 
      any[M], \[IndentingNewLine]all\[Dash]nonempty[
          M] : \[NegativeThickSpace]\[NegativeThickSpace]\(\(\
\[DoubleLeftRightArrow]\)\(\[ForAll] \+\(X \[Element] M\)X \[NotEqual] \
\[EmptySet]\)\)\), "]"}]], "Input",
  CellTags->"Definition (all nonempty)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<partition\>\"", ",", \(any[M]\), ",", "\[IndentingNewLine]", 
        RowBox[{\(is\[Dash]partition[M]\), ":", 
          "\[NegativeThickSpace]\[NegativeThickSpace]", 
          RowBox[{"\[DoubleLeftRightArrow]", 
            RowBox[{
              StyleBox["\[And]",
                Background->None], 
              RowBox[{
                StyleBox["{",
                  SpanMaxSize->Infinity,
                  Background->None], 
                StyleBox[GridBox[{
                      {\(is\[Dash]covering[M]\)},
                      {\(are\[Dash]disjoint[M]\)},
                      {\(all\[Dash]nonempty[M]\)}
                      },
                    ColumnAlignments->{Left}],
                  Background->None], 
                StyleBox["}",
                  ShowContents->False,
                  Background->None]}]}]}]}]}], "]"}]], "Input",
  CellTags->"Definition (partition)"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Proved Knowledge", "Subsubsection",
  CellTags->"c:4"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], 
      "[", \("\<common predecessor \[DoubleLeftArrow]\>", 
      any[R], \[IndentingNewLine]is\[Dash]symmetric[R] \[And] 
          is\[Dash]transitive[
            R] \[Implies] \[ForAll] \+\(x, y\)\((\((\[LeftAngleBracket]x, 
                    y\[RightAngleBracket] \[Element] 
                  R)\) \[DoubleLeftArrow] \(\[Exists] \+z\((\
\[LeftAngleBracket]z, x\[RightAngleBracket] \[Element] 
                      R \[And] \[LeftAngleBracket]z, 
                        y\[RightAngleBracket] \[Element] R)\)\))\)\), 
      "]"}]], "Input",
  CellTags->"Proposition (common predecessor \[DoubleLeftArrow])"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], 
      "[", \("\<common successor \[DoubleLeftArrow]\>", 
      any[R], \[IndentingNewLine]is\[Dash]symmetric[R] \[And] 
          is\[Dash]transitive[
            R] \[Implies] \[ForAll] \+\(x, y\)\((\((\[LeftAngleBracket]x, 
                    y\[RightAngleBracket] \[Element] 
                  R)\) \[DoubleLeftArrow] \(\[Exists] \+z\((\
\[LeftAngleBracket]x, z\[RightAngleBracket] \[Element] 
                      R \[And] \[LeftAngleBracket]y, 
                        z\[RightAngleBracket] \[Element] R)\)\))\)\), 
      "]"}]], "Input",
  CellTags->"Proposition (common successor \[DoubleLeftArrow])"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<common successor \[Implies]\>", 
      any[R], \[IndentingNewLine]is\[Dash]equivalence[
          R] \[Implies] \[ForAll] \+\(x, y\)\((\[LeftAngleBracket]x, 
                  y\[RightAngleBracket] \[Element] 
                R \[Implies] \[Exists] \+z\((\[LeftAngleBracket]x, 
                        z\[RightAngleBracket] \[Element] 
                      R \[And] \[LeftAngleBracket]y, 
                        z\[RightAngleBracket] \[Element] R)\))\)\), 
      "]"}]], "Input",
  CellTags->"Proposition (common successor \[Implies])"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<equal classes\>", any[x, y, R], 
      with[is\[Dash]transitive[R] \[And] 
          is\[Dash]symmetric[R]], \[IndentingNewLine]\[LeftAngleBracket]x, 
            y\[RightAngleBracket] \[Element] 
          R \[Implies] \((class\_R[x] = class\_R[y])\)\), "]"}]], "Input",
  CellTags->"Proposition (equal classes)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<in own class\>", any[R], 
      with[is\[Dash]reflexive[R]], \[IndentingNewLine]\[ForAll] \+x 
          x \[Element] class\_R[x]\), "]"}]], "Input",
  CellTags->"Proposition (in own class)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<non-empty class\>", any[R], 
      with[is\[Dash]reflexive[
          R]], \[IndentingNewLine]\[ForAll] \+x class\_R[
            x] \[NotEqual] \[EmptySet]\), "]"}]], "Input",
  CellTags->"Proposition (non-empty class)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<intersecting are equal\>", any[P], 
      with[is\[Dash]partition[
          P]], \[IndentingNewLine]\[ForAll] \+\(X, Y \[Element] P\)\((X \
\[Intersection] Y \[NotEqual] \[EmptySet] \[Implies] \((X = Y)\))\)\), 
      "]"}]], "Input",
  CellTags->"Proposition (intersecting are equal)"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theorem",
        FontWeight->"Bold"], "[", \("\<factor set is partition\>", any[R], 
      with[is\[Dash]equivalence[R]], \[IndentingNewLine]is\[Dash]partition[
        factor\[Dash]set[R]]\), "]"}]], "Input",
  CellTags->"Theorem (factor set is partition)"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exploration Round: Induced relation", "Subsection",
  CellTags->"c:5"],

Cell[TextData[{
  "We enter the exploration at the stage, where the ",
  StyleBox["induced relation",
    FontSlant->"Italic"],
  " is being introduced."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<induced relation\>", 
      any[S], \[IndentingNewLine]induced\[Dash]relation[
          S] : \[NegativeThickSpace]\[NegativeThickSpace]\(\(\
\[DoubleLeftRightArrow]\)\({\[LeftAngleBracket]x, 
                y\[RightAngleBracket]\( | \+\(x, 
                  y\)\)\[Exists] \+\(M \[Element] S\)\((x \[Element] M \[And] 
                    y \[Element] M)\)}\)\)\), "]"}]], "Input",
  CellTags->"Definition (induced relation)"],

Cell["\<\
We go again for a proof that the induced relation of a partition is \
an equivalence relation.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theorem",
        FontWeight->"Bold"], 
      "[", \("\<induced by partition is equivalence\>", any[P], 
      with[is\[Dash]partition[P]], \[IndentingNewLine]is\[Dash]equivalence[
        induced\[Dash]relation[P]]\), "]"}]], "Input",
  CellTags->"Theorem (induced by partition is equivalence)"],

Cell["\<\
Since different settings for the options prove useful in the \
individual proofs, we split up the theorem into smaller portions and prove \
the resulting propositions separately.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], 
      "[", \("\<induced by partition is relation on U\>", any[P], 
      with[is\[Dash]partition[P]], \[IndentingNewLine]is\[Dash]relation[
        induced\[Dash]relation[P], U]\), "]"}]], "Input",
  CellTags->"Proposition (induced by partition is relation on U)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<induced by partition is relation on U\>"]\), 
        ",", \(using \[Rule] \[LeftAngleBracket]Definition["\<relation\>"], 
            Definition["\<induced relation\>"], 
            Assumption["\<domain of interest\>"]\[RightAngleBracket]\), ",", 
        "\[IndentingNewLine]", 
        StyleBox[\(built\[Dash]in \[Rule] Built\[Dash]in["\<Tuples\>"]\),
          "HighlightedText"], ",", "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {STPInsideQuantifiers \[Rule] True, 
              RWInsideQuantifiers \[Rule] True}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations2"}, 
        "InducedByPartitionIsRelationOnU.nb", CharacterEncoding -> 
        "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[TextData[{
  "Note, how built\[Dash]in semantics knowledge about ",
  StyleBox["Theorema\[Dash]",
    FontSlant->"Italic"],
  "tuples is applied in order to simplify the goal (18)."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<induced by partition is relation\>", 
      any[P], with[
        is\[Dash]partition[P]], \[IndentingNewLine]is\[Dash]relation[
        induced\[Dash]relation[P]]\), "]"}]], "Input",
  CellTags->"Proposition (induced by partition is relation)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<induced by partition is relation\>"]\), 
        ",", \(using \[Rule] \[LeftAngleBracket]Definition["\<relation\>"], 
            Proposition["\<induced by partition is relation on U\>"]\
\[RightAngleBracket]\), ",", "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, DisableProver \[Rule] {STC, STKBR, PND}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations2"}, 
        "InducedByPartitionIsRelation.nb", CharacterEncoding -> "ISO8859-1"], 
      None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<induced by partition is reflexive\>", 
      any[P], with[
        is\[Dash]partition[P]], \[IndentingNewLine]is\[Dash]reflexive[
        induced\[Dash]relation[P]]\), "]"}]], "Input",
  CellTags->"Proposition (induced by partition is reflexive)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<induced by partition is reflexive\>"]\), 
        ",", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<reflexivity\>"], 
            Definition["\<induced relation\>"], Definition["\<partition\>"], 
            Definition["\<covering\>"]\[RightAngleBracket]\), ",", 
        StyleBox[\(SearchDepth \[Rule] 40\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations2"}, 
        "InducedByPartitionIsReflexive.nb", CharacterEncoding -> "ISO8859-1"],
       None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell["In the above proof, we want to point out 2 proof steps:", \
"SingleParagraph"],

Cell[TextData[{
  "The goal (13) is partially solved by using Solve for the equation \
occurring in (13). See the inference rule \[Cent]PartiallySolved in the STS \
prover in Section ",
  ButtonBox["10",
    ButtonData:>{"Part2.nb", "Sec:STS"},
    ButtonStyle->"Hyperlink"],
  "."
}], "ItemizedText"],

Cell[TextData[{
  "The goal (15) is partially solved by using ",
  StyleBox["unification",
    FontSlant->"Italic"],
  " with the universally quantified assumption (6.2). See the inference rule \
\[Cent]PartiallySolved in the STS prover in Section ",
  ButtonBox["10",
    ButtonData:>{"Part2.nb", "Sec:STS"},
    ButtonStyle->"Hyperlink"],
  "."
}], "ItemizedText"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<induced by partition is symmetric\>", 
      any[P], with[
        is\[Dash]partition[P]], \[IndentingNewLine]is\[Dash]symmetric[
        induced\[Dash]relation[P]]\), "]"}]], "Input",
  CellTags->"Proposition (induced by partition is symmetric)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<induced by partition is symmetric\>"]\), 
        ",", \(using \[Rule] \[LeftAngleBracket]Definition["\<symmetry\>"], 
            Definition["\<induced relation\>"]\[RightAngleBracket]\), ",", 
        "\[IndentingNewLine]", 
        StyleBox[\(built\[Dash]in \[Rule] Built\[Dash]in["\<Tuples\>"]\),
          "HighlightedText"], ",", "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {DisableProver \[Rule] {STC, PND}}\),
          
          "UnHighlightedText"], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 48\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations2"}, 
        "InducedByPartitionIsSymmetric.nb", CharacterEncoding -> "ISO8859-1"],
       None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<induced by partition is transitive\>", 
      any[P], with[
        is\[Dash]partition[P]], \[IndentingNewLine]is\[Dash]transitive[
        induced\[Dash]relation[P]]\), "]"}]], "Input",
  CellTags->"Proposition (induced by partition is transitive)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<induced by partition is transitive\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<transitivity\>"], 
            Definition["\<induced relation\>"], 
            Proposition["\<intersecting are equal\>"]\[RightAngleBracket]\), 
        ",", "\[IndentingNewLine]", 
        StyleBox[\(built\[Dash]in \[Rule] Built\[Dash]in["\<Tuples\>"]\),
          "HighlightedText"], ",", "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, InferMembershipIntersection \[Rule] True, 
              DisableInferenceRule \[Rule] {\[Cent]KBFiniteChoice}, 
              AllowIntroduceQuantifiers \[Rule] True, 
              ApplyBuiltIns \[Rule] {"\<kb\>"}}\),
          "UnHighlightedText"], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 80\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations2"}, 
        "InducedByPartitionIsTransitive.nb", CharacterEncoding -> 
        "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell["\<\
Now we can plug together the propositions, which we have just \
proved, to get a proof for the theorem.\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Theorem["\<induced by partition is equivalence\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Proposition["\<induced by partition is relation\>"], 
            Proposition["\<induced by partition is reflexive\>"], 
            Proposition["\<induced by partition is symmetric\>"], 
            Proposition["\<induced by partition is transitive\>"], 
            Definition["\<equivalence\>"]\[RightAngleBracket]\), ",", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>"}, 
              DisableProver \[Rule] {STS, PND}}\),
          "UnHighlightedText"]}], "]"}]], "Input",
  PageBreakAbove->True],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations2"}, 
        "InducedByPartitionIsEquivalence.nb", CharacterEncoding -> 
        "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Induced Relation of a Factor Set", "Subsection",
  CellTags->"c:6"],

Cell[TextData[{
  "Now we can co one step further and investigate what happens, when we ",
  StyleBox["first",
    FontSlant->"Italic"],
  " form the factor set of an equivalence relation, and ",
  StyleBox["then",
    FontSlant->"Italic"],
  " derive the induced relation from the resulting factor set. Interestingly \
enough, this relation is identical with the original relation!"
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theorem",
        FontWeight->"Bold"], 
      "[", \("\<induced by factor set of R is R itself\>", any[R], 
      with[is\[Dash]equivalence[
          R]], \[IndentingNewLine]induced\[Dash]relation[
          factor\[Dash]set[R]] = R\), "]"}]], "Input",
  CellTags->"Theorem (induced by factor set of R is R itself)"],

Cell["\<\
Again, due to distinct prover options for the individual cases, we \
split up the theorem into two lemmata.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], 
      "[", \("\<induced by factor set of R contained in R\>", any[R], 
      with[is\[Dash]symmetric[R] \[And] 
          is\[Dash]transitive[R]], \[IndentingNewLine]induced\[Dash]relation[
          factor\[Dash]set[R]] \[SubsetEqual] R\), "]"}]], "Input",
  CellTags->"Lemma (induced by factor set of R contained in R)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Lemma["\<induced by factor set of R contained in R\>"]\), ",",
         "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<factor set\>"], 
            Definition["\<induced relation\>"], Definition["\<class\>"], 
            Proposition["\<common successor \[DoubleLeftArrow]\>"]\
\[RightAngleBracket]\), ",", "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, UseCyclicRules \[Rule] True, 
              AllowIntroduceQuantifiers \[Rule] True, 
              DisableProver \[Rule] {STC, PND}, 
              DisableInferenceRule \[Rule] {\[Cent]KBSetEquality}}\),
          "UnHighlightedText"], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 50\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations2"}, 
        "InducedByFactorSetContainedInSelf.nb", CharacterEncoding -> 
        "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], 
      "[", \("\<induced by factor set of R contains R\>", any[R], 
      with[is\[Dash]equivalence[
          R]], \[IndentingNewLine]induced\[Dash]relation[
          factor\[Dash]set[R]] \[SupersetEqual] R\), "]"}]], "Input",
  PageBreakAbove->True,
  CellTags->"Lemma (induced by factor set of R contains R)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Lemma["\<induced by factor set of R contains R\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<factor set\>"], 
            Definition["\<induced relation\>"], Definition["\<class\>"], 
            Proposition["\<common successor \[Implies]\>"], 
            Definition["\<equivalence\>"], 
            Definition["\<relation\>"]\[RightAngleBracket]\), ",", 
        "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, UseCyclicRules \[Rule] True, RWExistentialGoal \[Rule] True, 
              DisableProver \[Rule] {STC, PND}}\),
          "UnHighlightedText"], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 50\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations2"}, 
        "InducedByFactorSetContainsSelf.nb", CharacterEncoding -> 
        "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Theorem["\<induced by factor set of R is R itself\>"]\), 
        ",", \(using \[Rule] \[LeftAngleBracket]Lemma["\<induced by factor \
set of R contains R\>"], 
            Lemma["\<induced by factor set of R contained in R\>"], 
            Definition["\<equivalence\>"]\[RightAngleBracket]\), ",", 
        "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, DisableProver \[Rule] {STC, PND}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations2"}, 
        "InducedByFactorSetIsSelf.nb", CharacterEncoding -> "ISO8859-1"], 
      None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Factor Set of an Induced Relation", "Subsection",
  CellTags->"c:7"],

Cell[TextData[{
  "In the previous section we first formed the factor set and then the \
induced relation. Now we can reverse the order and check what happens, when \
we ",
  StyleBox["first",
    FontSlant->"Italic"],
  " derive the induced relation from a partition, and ",
  StyleBox["then",
    FontSlant->"Italic"],
  " form the factor set from the resulting relation. The factor set and the \
original partition are again identical!"
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theorem",
        FontWeight->"Bold"], 
      "[", \("\<factor set of induced by P is P itself\>", any[P], 
      with[is\[Dash]partition[P]], \[IndentingNewLine]factor\[Dash]set[
          induced\[Dash]relation[P]] = P\), "]"}]], "Input",
  CellTags->"Theorem (factor set of induced by P is P itself)"],

Cell[TextData[{
  "It turns out that we only need one additional lemma in order to prove the \
theorem. Of course, we could prove many little propositions in order to \
finally allow a very short proof of the theorem, as it is presented in [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Wind01c",
            ButtonData:>"Wind01c",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "W. Windsteiger, 2001, Exploring Equivalence Relations and \
Partitions using the Theorema Se ..."],
          "Text"], TraditionalForm]]],
  "]. On the other hand, giving only as much knowledge to the prover as \
necessary gives the prover the chance to show all its power even in more \
complex situations."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], 
      "[", \("\<set in partition is class wrt induced relation\>", any[P], 
      with[is\[Dash]partition[
          P]], \[IndentingNewLine]\[ForAll] \+\(X \[Element] P\)\(\[ForAll] \
\+\(y \[Element] X\)\((X = class\_\(induced\[Dash]relation[P]\)[y])\)\)\), 
      "]"}]], "Input",
  CellTags->"Lemma (set in partition is class wrt induced relation)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Lemma["\<set in partition is class wrt induced relation\>"]\),
         ",", \(using \[Rule] \[LeftAngleBracket]Definition["\<class\>"], 
            Definition["\<induced relation\>"], 
            Proposition["\<intersecting are equal\>"]\[RightAngleBracket]\), 
        ",", "\[IndentingNewLine]", 
        StyleBox[\(built\[Dash]in \[Rule] Built\[Dash]in["\<Tuples\>"]\),
          "UnHighlightedText"], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox["\[IndentingNewLine]",
          "UnHighlightedText"], 
        StyleBox[\(ProverOptions \[Rule] {GRWTarget \[Rule] {"\<goal\>", \
"\<kb\>"}, InferMembershipIntersection \[Rule] True, 
              DisableInferenceRule \[Rule] {\[Cent]KBFiniteChoice}, 
              AllowIntroduceQuantifiers \[Rule] True, 
              ApplyBuiltIns \[Rule] {"\<kb\>", "\<goal\>"}, 
              EarlyRewriting \[Rule] True}\),
          "UnHighlightedText"], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 60\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations2"}, 
        "SetInPartitionIsClassWrtInduced.nb", CharacterEncoding -> 
        "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell["\<\
As explained already earlier, we can tell the prover that an \
expression of the form factor\[Dash]set[\[Ellipsis]] ought to be treated as a \
set in order to allow the inference rule on set equality to be applied.\
\>", \
"SingleParagraph"],

Cell[BoxData[
    \(IsSet[factor\[Dash]set[_]] := True\)], "Input"],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Theorem["\<factor set of induced by P is P itself\>"]\), ",", 
        "\[IndentingNewLine]", \(using \[Rule] \
\[LeftAngleBracket]Definition["\<factor set\>"], Definition["\<partition\>"], 
            Definition["\<all nonempty\>"], Definition["\<covering\>"], 
            Lemma["\<set in partition is class wrt induced relation\>"]\
\[RightAngleBracket]\), ",", 
        StyleBox[\(built\[Dash]in \[Rule] Built\[Dash]in["\<Quantifiers\>"]\),
          
          "HighlightedText"], ",", "\[IndentingNewLine]", 
        RowBox[{"ProverOptions", "\[Rule]", 
          
          StyleBox[\({ApplyBuiltIns \[Rule] {"\<goal\>"}, 
              SimplifyFormula \[Rule] False, 
              GRWTarget \[Rule] {"\<goal\>", "\<kb\>"}, 
              ModusPonensKB \[Rule] False, RWInsideQuantifiers \[Rule] True, 
              UseCyclicRules \[Rule] True, 
              AllowIntroduceQuantifiers \[Rule] True}\),
            "UnHighlightedText"]}], 
        StyleBox[",",
          "UnHighlightedText"], 
        StyleBox[\(SearchDepth \[Rule] 70\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "EquivalenceRelations2"}, 
        "FactorSetOfInducedIsSelf.nb", CharacterEncoding -> "ISO8859-1"], 
      None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"],

Cell[BoxData[
    \(IsSet[factor\[Dash]set[_]] =. \)], "Input"],

Cell[TextData[{
  "We used built\[Dash]in knowledge about quantifiers when simplifying the \
last part of formula (34) to True, thus eliminating it from the conjunction. \
If we neglect built\[Dash]in knowledge on quantifiers by, for instance, \
disabling the STC prove module, then the final goal (53) would still contain \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["X",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["X",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[Element]", 
                StyleBox[\(P\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "\[Implies]", 
              RowBox[{
                StyleBox["X",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[Element]", 
                StyleBox[\(P\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}]}], TraditionalForm]]],
  ", which is proved in a trivial proof step. We consider it as more elegant \
to simplify the trivial quantified subformula quietly, although, by adding \
one more prove module, the proof search is more expensive and the proof takes \
about 30 seconds longer."
}], "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timings and Statistics", "Subsection",
  CellTags->"c:8"],

Cell[TextData[{
  "In Table ",
  
  CounterBox["Section", "TimingsEq2"],
  ".",
  
  CounterBox["TableHead", "TimingsEq2"],
  " we collected the timings for all proofs done during this exploration. The \
first column refers to the label of the environment containing the goal of \
the proof, column two is the total elapsed time for proof generation, proof \
simplification, and proof display."
}], "SingleParagraph"],

Cell[BoxData[GridBox[{
        {
          StyleBox[\(Proof\ of\ \(Proposition/Lemma\)/Theorem\),
            FontFamily->"Helvetica",
            FontWeight->"Bold"], 
          StyleBox[\(Elapsed\ Time\),
            FontFamily->"Helvetica",
            FontWeight->"Bold"]},
        {"\<\"induced by partition is relation on U\"\>", 
          StyleBox[\(21.69000000000051`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"induced by partition is relation\"\>", 
          StyleBox[\(2.4399999999996`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"induced by partition is reflexive\"\>", 
          StyleBox[\(28.140000000000327`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"induced by partition is symmetric\"\>", 
          StyleBox[\(22.109999999999673`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"induced by partition is transitive\"\>", 
          StyleBox[\(167.1300000000001`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"induced by partition is equivalence\"\>", 
          StyleBox[\(6.180000000000291`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"induced by factor set of R contained in R\"\>", 
          StyleBox[\(41.54999999999927`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"induced by factor set of R contains R\"\>", 
          StyleBox[\(47.350000000000364`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"induced by factor set of R is R itself\"\>", 
          StyleBox[\(7.399999999999636`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"set in partition is class wrt induced relation\"\>", 
          StyleBox[\(74.06999999999971`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"factor set of induced by P is P itself\"\>", 
          StyleBox[\(178.67000000000007`\ Second\),
            FontWeight->"Bold"]}
        },
      ColumnWidths->Automatic,
      ColumnAlignments->{Left, Right},
      ColumnLines->True]], "2ColumnTable",
  PageWidth->600,
  CellMargins->{{Inherited, Inherited}, {Inherited, 28}},
  CounterIncrements->"TableHead",
  GridBoxOptions->{RowLines->{0.5, False}},
  CellTags->"TimingsEq2"],

Cell[TextData[{
  "Table ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["TableHead"],
  ". ",
  StyleBox["Timings for the exploration of equivalence relation, part 2", 
    "TableHeadText"]
}], "TableHead"],

Cell["\<\
Total elapsed time of all proofs together amounts to 596.73 \
seconds, which is approximately 10 minutes.\
\>", "SingleParagraph"]
}, Open  ]],

Cell[TextData[ButtonBox["\[LowerRightArrow]",
  ButtonFunction:>(NotebookLocate[ #2]&),
  ButtonData:>{"CaseStudies-Checkerboard.nb", "c:1"},
  ButtonStyle->"Navigation",
  ButtonNote->"The Mutilated Checkerboard Problem"]], "SingleParagraph",
  TextAlignment->Right]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{844, 740},
WindowMargins->{{Automatic, 206}, {Automatic, 88}},
PrintingStartingPageNumber->145,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Part 3: Case Studies"}], "Header"]}, {Cell[ 
        TextData[ {
          CounterBox[ "Section"], 
          ". Equivalence Relations And Partitions II"}], "Header"], Inherited,
       Inherited}},
PrintingOptions->{"PrintingMargins"->{{79.1875, 79.1875}, {108, 108}},
"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->True,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", \
"wwindste", "Diss", "Main"}, "CaseStudies-EquivalenceRelations2.nb.ps", \
CharacterEncoding -> "ISO8859-1"],
"Magnification"->1},
StyleDefinitions -> "TheoremaSmartColors.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[2008, 59, 216, 3, 59, "Section",
      CounterAssignments->{{"Section", 13}, {"TableHead", 0}, {
          "Equation", 0}, {"Figure", 0}, {"Subsection", 0}, {
          "Subsubsection", 0}},
      CellTags->"c:1"]},
  "c:2"->{
    Cell[2976, 86, 86, 1, 53, "Subsection",
      CellTags->"c:2"]},
  "Definition (relation)"->{
    Cell[3065, 89, 842, 18, 119, "Input",
      CellTags->"Definition (relation)"]},
  "Assumption (domain of interest)"->{
    Cell[4687, 125, 250, 6, 79, "Input",
      CellTags->"Assumption (domain of interest)"]},
  "c:3"->{
    Cell[4962, 135, 55, 1, 44, "Subsubsection",
      CellTags->"c:3"]},
  "Definition (reflexivity)"->{
    Cell[5020, 138, 406, 8, 79, "Input",
      CellTags->"Definition (reflexivity)"]},
  "Definition (symmetry)"->{
    Cell[5429, 148, 532, 11, 81, "Input",
      CellTags->"Definition (symmetry)"]},
  "Definition (transitivity)"->{
    Cell[5964, 161, 656, 13, 81, "Input",
      CellTags->"Definition (transitivity)"]},
  "Definition (equivalence)"->{
    Cell[6623, 176, 1078, 27, 132, "Input",
      CellTags->"Definition (equivalence)"]},
  "Definition (class)"->{
    Cell[7704, 205, 320, 7, 58, "Input",
      CellTags->"Definition (class)"]},
  "Definition (factor set)"->{
    Cell[8027, 214, 290, 7, 81, "Input",
      CellTags->"Definition (factor set)"]},
  "Definition (covering)"->{
    Cell[8320, 223, 359, 8, 79, "Input",
      CellTags->"Definition (covering)"]},
  "Definition (disjoint)"->{
    Cell[8682, 233, 414, 9, 95, "Input",
      CellTags->"Definition (disjoint)"]},
  "Definition (all nonempty)"->{
    Cell[9099, 244, 378, 8, 79, "Input",
      CellTags->"Definition (all nonempty)"]},
  "Definition (partition)"->{
    Cell[9480, 254, 1019, 26, 110, "Input",
      CellTags->"Definition (partition)"]},
  "c:4"->{
    Cell[10536, 285, 60, 1, 44, "Subsubsection",
      CellTags->"c:4"]},
  "Proposition (common predecessor \[DoubleLeftArrow])"->{
    Cell[10599, 288, 701, 14, 81, "Input",
      CellTags->"Proposition (common predecessor \[DoubleLeftArrow])"]},
  "Proposition (common successor \[DoubleLeftArrow])"->{
    Cell[11303, 304, 697, 14, 81, "Input",
      CellTags->"Proposition (common successor \[DoubleLeftArrow])"]},
  "Proposition (common successor \[Implies])"->{
    Cell[12003, 320, 634, 12, 81, "Input",
      CellTags->"Proposition (common successor \[Implies])"]},
  "Proposition (equal classes)"->{
    Cell[12640, 334, 410, 8, 58, "Input",
      CellTags->"Proposition (equal classes)"]},
  "Proposition (in own class)"->{
    Cell[13053, 344, 287, 6, 79, "Input",
      CellTags->"Proposition (in own class)"]},
  "Proposition (non-empty class)"->{
    Cell[13343, 352, 317, 7, 79, "Input",
      CellTags->"Proposition (non-empty class)"]},
  "Proposition (intersecting are equal)"->{
    Cell[13663, 361, 383, 8, 81, "Input",
      CellTags->"Proposition (intersecting are equal)"]},
  "Theorem (factor set is partition)"->{
    Cell[14049, 371, 302, 6, 58, "Input",
      CellTags->"Theorem (factor set is partition)"]},
  "c:5"->{
    Cell[14388, 382, 76, 1, 53, "Subsection",
      CellTags->"c:5"]},
  "Definition (induced relation)"->{
    Cell[14646, 392, 524, 10, 90, "Input",
      CellTags->"Definition (induced relation)"]},
  "Theorem (induced by partition is equivalence)"->{
    Cell[15305, 409, 339, 7, 58, "Input",
      CellTags->"Theorem (induced by partition is equivalence)"]},
  "Proposition (induced by partition is relation on U)"->{
    Cell[15863, 424, 351, 7, 58, "Input",
      CellTags->"Proposition (induced by partition is relation on U)"]},
  "Proposition (induced by partition is relation)"->{
    Cell[17449, 467, 340, 7, 58, "Input",
      CellTags->"Proposition (induced by partition is relation)"]},
  "Proposition (induced by partition is reflexive)"->{
    Cell[18634, 500, 343, 7, 58, "Input",
      CellTags->"Proposition (induced by partition is reflexive)"]},
  "Proposition (induced by partition is symmetric)"->{
    Cell[20527, 558, 343, 7, 58, "Input",
      CellTags->"Proposition (induced by partition is symmetric)"]},
  "Proposition (induced by partition is transitive)"->{
    Cell[21928, 597, 346, 7, 58, "Input",
      CellTags->"Proposition (induced by partition is transitive)"]},
  "c:6"->{
    Cell[24876, 677, 77, 1, 53, "Subsection",
      CellTags->"c:6"]},
  "Theorem (induced by factor set of R is R itself)"->{
    Cell[25365, 691, 360, 8, 58, "Input",
      CellTags->"Theorem (induced by factor set of R is R itself)"]},
  "Lemma (induced by factor set of R contained in R)"->{
    Cell[25873, 706, 403, 8, 58, "Input",
      CellTags->"Lemma (induced by factor set of R contained in R)"]},
  "Lemma (induced by factor set of R contains R)"->{
    Cell[27523, 749, 393, 9, 58, "Input",
      PageBreakAbove->True,
      CellTags->"Lemma (induced by factor set of R contains R)"]},
  "c:7"->{
    Cell[30091, 822, 78, 1, 53, "Subsection",
      CellTags->"c:7"]},
  "Theorem (factor set of induced by P is P itself)"->{
    Cell[30637, 838, 347, 7, 58, "Input",
      CellTags->"Theorem (factor set of induced by P is P itself)"]},
  "Lemma (set in partition is class wrt induced relation)"->{
    Cell[31769, 867, 434, 9, 81, "Input",
      CellTags->"Lemma (set in partition is class wrt induced relation)"]},
  "c:8"->{
    Cell[37219, 1010, 63, 1, 53, "Subsection",
      CellTags->"c:8"]},
  "TimingsEq2"->{
    Cell[37705, 1026, 2163, 49, 311, "2ColumnTable",
      CounterIncrements->"TableHead",
      CellTags->"TimingsEq2"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 42068, 1143},
  {"c:2", 42304, 1149},
  {"Definition (relation)", 42402, 1152},
  {"Assumption (domain of interest)", 42526, 1155},
  {"c:3", 42631, 1158},
  {"Definition (reflexivity)", 42736, 1161},
  {"Definition (symmetry)", 42852, 1164},
  {"Definition (transitivity)", 42970, 1167},
  {"Definition (equivalence)", 43091, 1170},
  {"Definition (class)", 43207, 1173},
  {"Definition (factor set)", 43319, 1176},
  {"Definition (covering)", 43434, 1179},
  {"Definition (disjoint)", 43547, 1182},
  {"Definition (all nonempty)", 43664, 1185},
  {"Definition (partition)", 43782, 1188},
  {"c:4", 43881, 1191},
  {"Proposition (common predecessor \[DoubleLeftArrow])", 44014, 1194},
  {"Proposition (common successor \[DoubleLeftArrow])", 44187, 1197},
  {"Proposition (common successor \[Implies])", 44350, 1200},
  {"Proposition (equal classes)", 44491, 1203},
  {"Proposition (in own class)", 44616, 1206},
  {"Proposition (non-empty class)", 44743, 1209},
  {"Proposition (intersecting are equal)", 44880, 1212},
  {"Theorem (factor set is partition)", 45021, 1215},
  {"c:5", 45129, 1218},
  {"Definition (induced relation)", 45237, 1221},
  {"Theorem (induced by partition is equivalence)", 45384, 1224},
  {"Proposition (induced by partition is relation on U)", 45552, 1227},
  {"Proposition (induced by partition is relation)", 45721, 1230},
  {"Proposition (induced by partition is reflexive)", 45886, 1233},
  {"Proposition (induced by partition is symmetric)", 46052, 1236},
  {"Proposition (induced by partition is transitive)", 46219, 1239},
  {"c:6", 46342, 1242},
  {"Theorem (induced by factor set of R is R itself)", 46469, 1245},
  {"Lemma (induced by factor set of R contained in R)", 46638, 1248},
  {"Lemma (induced by factor set of R contains R)", 46804, 1251},
  {"c:7", 46952, 1255},
  {"Theorem (factor set of induced by P is P itself)", 47079, 1258},
  {"Lemma (set in partition is class wrt induced relation)", 47253, 1261},
  {"c:8", 47382, 1264},
  {"TimingsEq2", 47472, 1267}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 278, 5, 42, "SingleParagraph"],

Cell[CellGroupData[{
Cell[2008, 59, 216, 3, 59, "Section",
  CounterAssignments->{{"Section", 13}, {"TableHead", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsection", 0}, {"Subsubsection", 0}},
  CellTags->"c:1"],
Cell[2227, 64, 724, 18, 88, "SingleParagraph"],

Cell[CellGroupData[{
Cell[2976, 86, 86, 1, 53, "Subsection",
  CellTags->"c:2"],
Cell[3065, 89, 842, 18, 119, "Input",
  CellTags->"Definition (relation)"],
Cell[3910, 109, 774, 14, 107, "SingleParagraph"],
Cell[4687, 125, 250, 6, 79, "Input",
  CellTags->"Assumption (domain of interest)"],

Cell[CellGroupData[{
Cell[4962, 135, 55, 1, 44, "Subsubsection",
  CellTags->"c:3"],
Cell[5020, 138, 406, 8, 79, "Input",
  CellTags->"Definition (reflexivity)"],
Cell[5429, 148, 532, 11, 81, "Input",
  CellTags->"Definition (symmetry)"],
Cell[5964, 161, 656, 13, 81, "Input",
  CellTags->"Definition (transitivity)"],
Cell[6623, 176, 1078, 27, 132, "Input",
  CellTags->"Definition (equivalence)"],
Cell[7704, 205, 320, 7, 58, "Input",
  CellTags->"Definition (class)"],
Cell[8027, 214, 290, 7, 81, "Input",
  CellTags->"Definition (factor set)"],
Cell[8320, 223, 359, 8, 79, "Input",
  CellTags->"Definition (covering)"],
Cell[8682, 233, 414, 9, 95, "Input",
  CellTags->"Definition (disjoint)"],
Cell[9099, 244, 378, 8, 79, "Input",
  CellTags->"Definition (all nonempty)"],
Cell[9480, 254, 1019, 26, 110, "Input",
  CellTags->"Definition (partition)"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10536, 285, 60, 1, 44, "Subsubsection",
  CellTags->"c:4"],
Cell[10599, 288, 701, 14, 81, "Input",
  CellTags->"Proposition (common predecessor \[DoubleLeftArrow])"],
Cell[11303, 304, 697, 14, 81, "Input",
  CellTags->"Proposition (common successor \[DoubleLeftArrow])"],
Cell[12003, 320, 634, 12, 81, "Input",
  CellTags->"Proposition (common successor \[Implies])"],
Cell[12640, 334, 410, 8, 58, "Input",
  CellTags->"Proposition (equal classes)"],
Cell[13053, 344, 287, 6, 79, "Input",
  CellTags->"Proposition (in own class)"],
Cell[13343, 352, 317, 7, 79, "Input",
  CellTags->"Proposition (non-empty class)"],
Cell[13663, 361, 383, 8, 81, "Input",
  CellTags->"Proposition (intersecting are equal)"],
Cell[14049, 371, 302, 6, 58, "Input",
  CellTags->"Theorem (factor set is partition)"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14388, 382, 76, 1, 53, "Subsection",
  CellTags->"c:5"],
Cell[14467, 385, 176, 5, 31, "SingleParagraph"],
Cell[14646, 392, 524, 10, 90, "Input",
  CellTags->"Definition (induced relation)"],
Cell[15173, 404, 129, 3, 31, "SingleParagraph"],
Cell[15305, 409, 339, 7, 58, "Input",
  CellTags->"Theorem (induced by partition is equivalence)"],
Cell[15647, 418, 213, 4, 50, "SingleParagraph"],
Cell[15863, 424, 351, 7, 58, "Input",
  CellTags->"Proposition (induced by partition is relation on U)"],

Cell[CellGroupData[{
Cell[16239, 435, 666, 11, 96, "Input"],
Cell[16908, 448, 314, 9, 31, "SingleParagraph"]
}, Open  ]],
Cell[17237, 460, 209, 5, 31, "SingleParagraph"],
Cell[17449, 467, 340, 7, 58, "Input",
  CellTags->"Proposition (induced by partition is relation)"],

Cell[CellGroupData[{
Cell[17814, 478, 493, 8, 77, "Input"],
Cell[18310, 488, 309, 9, 31, "SingleParagraph"]
}, Open  ]],
Cell[18634, 500, 343, 7, 58, "Input",
  CellTags->"Proposition (induced by partition is reflexive)"],

Cell[CellGroupData[{
Cell[19002, 511, 437, 8, 77, "Input"],
Cell[19442, 521, 310, 9, 31, "SingleParagraph"]
}, Open  ]],
Cell[19767, 533, 84, 1, 31, "SingleParagraph"],
Cell[19854, 536, 301, 8, 46, "ItemizedText"],
Cell[20158, 546, 366, 10, 46, "ItemizedText"],
Cell[20527, 558, 343, 7, 58, "Input",
  CellTags->"Proposition (induced by partition is symmetric)"],

Cell[CellGroupData[{
Cell[20895, 569, 705, 14, 96, "Input"],
Cell[21603, 585, 310, 9, 31, "SingleParagraph"]
}, Open  ]],
Cell[21928, 597, 346, 7, 58, "Input",
  CellTags->"Proposition (induced by partition is transitive)"],

Cell[CellGroupData[{
Cell[22299, 608, 1005, 19, 115, "Input"],
Cell[23307, 629, 313, 9, 31, "SingleParagraph"]
}, Open  ]],
Cell[23635, 641, 138, 3, 31, "SingleParagraph"],

Cell[CellGroupData[{
Cell[23798, 648, 712, 12, 96, "Input",
  PageBreakAbove->True],
Cell[24513, 662, 314, 9, 31, "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24876, 677, 77, 1, 53, "Subsection",
  CellTags->"c:6"],
Cell[24956, 680, 406, 9, 50, "SingleParagraph"],
Cell[25365, 691, 360, 8, 58, "Input",
  CellTags->"Theorem (induced by factor set of R is R itself)"],
Cell[25728, 701, 142, 3, 31, "SingleParagraph"],
Cell[25873, 706, 403, 8, 58, "Input",
  CellTags->"Lemma (induced by factor set of R contained in R)"],

Cell[CellGroupData[{
Cell[26301, 718, 888, 17, 115, "Input"],
Cell[27192, 737, 316, 9, 31, "SingleParagraph"]
}, Open  ]],
Cell[27523, 749, 393, 9, 58, "Input",
  PageBreakAbove->True,
  CellTags->"Lemma (induced by factor set of R contains R)"],

Cell[CellGroupData[{
Cell[27941, 762, 877, 17, 115, "Input"],
Cell[28821, 781, 313, 9, 31, "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29171, 795, 563, 10, 96, "Input"],
Cell[29737, 807, 305, 9, 31, "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30091, 822, 78, 1, 53, "Subsection",
  CellTags->"c:7"],
Cell[30172, 825, 462, 11, 69, "SingleParagraph"],
Cell[30637, 838, 347, 7, 58, "Input",
  CellTags->"Theorem (factor set of induced by P is P itself)"],
Cell[30987, 847, 779, 18, 69, "SingleParagraph"],
Cell[31769, 867, 434, 9, 81, "Input",
  CellTags->"Lemma (set in partition is class wrt induced relation)"],

Cell[CellGroupData[{
Cell[32228, 880, 1137, 23, 115, "Input"],
Cell[33368, 905, 314, 9, 31, "SingleParagraph"]
}, Open  ]],
Cell[33697, 917, 251, 5, 50, "SingleParagraph"],
Cell[33951, 924, 67, 1, 39, "Input"],
Cell[34021, 927, 1157, 23, 115, "Input"],
Cell[35181, 952, 305, 9, 31, "SingleParagraph"],
Cell[35489, 963, 63, 1, 39, "Input"],
Cell[35555, 966, 1627, 39, 113, "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37219, 1010, 63, 1, 53, "Subsection",
  CellTags->"c:8"],
Cell[37285, 1013, 417, 11, 50, "SingleParagraph"],
Cell[37705, 1026, 2163, 49, 311, "2ColumnTable",
  CounterIncrements->"TableHead",
  CellTags->"TimingsEq2"],
Cell[39871, 1077, 213, 10, 36, "TableHead"],
Cell[40087, 1089, 140, 3, 31, "SingleParagraph"]
}, Open  ]],
Cell[40242, 1095, 267, 5, 42, "SingleParagraph"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

