(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19965,        642]*)
(*NotebookOutlinePosition[     24244,        765]*)
(*  CellTagsIndexPosition[     23562,        742]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[ButtonBox["\[UpperLeftArrow]",
  ButtonData:>{"Part3.nb", "c:1"},
  ButtonStyle->"Navigation",
  ButtonNote->"Part 3"]], "SingleParagraph",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Isolated Theorems", "Section",
  CounterAssignments->{{"Section", 11}, {"TableHead", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsection", 0}, {"Subsubsection", 0}},
  CellTags->"c:1"],

Cell[TextData[{
  "Before we enter the case studies on equivalence relations and the \
Checkerboard Problem, we will use the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Set Theory prover described in the previous sections for some proofs of \
isolated theorems, in order to"
}], "SingleParagraph"],

Cell["\<\
show how the prover performs on known proof problems from set \
theory compared to other available automated theorem proving systems and to\
\
\>", "ItemizedText"],

Cell["\<\
highlight specific features offered by the prover, which will not \
be discussed along the case studies.\
\>", "ItemizedText"],

Cell[TextData[{
  "For comparing the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Set Theory prover with available provers, we used problems from the \
standard TPTP library, see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["SuSuTPTP",
            ButtonData:>"SuSuTPTP",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "G. Sutcliff and C. Suttner, , The TPTP Library for Automated \
Theorem Proving"],
          "Text"], TraditionalForm]]],
  "]. The TPTP (Thousands of Problems for Theorem Provers) Problem Library is \
a library of test problems for automated theorem proving (ATP) systems. We \
compared the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Set Theory prover with results known from Otter, see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["McCune94a",
            ButtonData:>"McCune94a",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "W. McCune, 1994, Otter 3.0 Reference Manual and Guide"],
          "Text"], TraditionalForm]]],
  "], although the approach to automated theorem proving chosen by ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " does not really compare to the approach of Otter, which is a prover based \
on the resolution method. ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "'s primary goal, on the other hand, is to produce nicely structured human\
\[Dash]readable proofs."
}], "FirstParagraph"],

Cell[CellGroupData[{

Cell["TPTP: SET008", "Subsection",
  CellTags->"c:2"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<SET008\>", 
      any[X, Y], \[IndentingNewLine]\((\((X\[Backslash]Y)\) \[Intersection] 
            Y)\) = \[EmptySet]\), "]"}]], "Input",
  CellTags->"Proposition (SET008)"],

Cell[TextData[{
  "The problem SET008 from TPTP has been proved successfully by Otter in 22 \
seconds. The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " proof for SET008 is a proof by contradiction and is pretty \
straight\[Dash]forward as a human would do it."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<SET008\>"]\), ",", "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {ApplyBuiltIns \[Rule] False}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "IsolatedTheorems"}, "SET008.nb", 
        CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell["TPTP: SET002", "Subsection",
  CellTags->"c:3"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<SET002\>", 
      any[X], \[IndentingNewLine]\((X \[Union] X)\) = X\), "]"}]], "Input",
  CellTags->"Proposition (SET002)"],

Cell[TextData[{
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " shows set equality by mutual inclusion. The prover can recognize from the \
context that \"=\" denotes set equality in this Proposition, since the left\
\[Dash]hand side term is formed by the set operator \"\[Union]\"."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<SET002\>"]\), ",", "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {ApplyBuiltIns \[Rule] False, 
              DisableProver \[Rule] {STC, PND}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "IsolatedTheorems"}, "SET002.nb", 
        CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell["TPTP: SET010", "Subsection",
  CellTags->"c:4"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<SET010\>", 
      any[B, C, 
        D], \[IndentingNewLine]B\[Backslash]\((C \[Intersection] 
              D)\) = \((B\[Backslash]C)\) \[Union] \((B\[Backslash]D)\)\), 
      "]"}]], "Input",
  CellTags->"Proposition (SET010)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<SET010\>"]\), ",", "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {ApplyBuiltIns \[Rule] False, 
              DisableProver \[Rule] {STC, PND}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "IsolatedTheorems"}, "SET010.nb", 
        CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell["TPTP: SET012", "Subsection",
  CellTags->"c:5"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<SET012\>", 
      any[A], \[IndentingNewLine]A = \(A\^c\)\^c\), "]"}]], "Input",
  CellTags->"Proposition (SET012)"],

Cell[BoxData[
    \(IsSet[\[Bullet][_\^c]] := True\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<SET012\>"]\), ",", "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {ApplyBuiltIns \[Rule] False, 
              DisableProver \[Rule] {STC, PND}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "IsolatedTheorems"}, "SET012.nb", 
        CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Timings and Statistics", "Subsection",
  CellTags->"c:6"],

Cell[TextData[{
  "Table ",
  
  CounterBox["Section", "TimingsIsolated"],
  ".",
  
  CounterBox["TableHead", "TimingsIsolated"],
  " compares the timings for the TPTP proofs to the results known from Otter. \
The first column refers to the label of the environment containing the goal \
of the proof, column two is the total elapsed time for proof generation, \
proof simplification, and proof display in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ". Column 3 shows the results from Otter, either the time for the \
successful proof or \">300 Second\" if Otter failed to prove the theorem in \
less than 5 minutes.  Timings given for proofs done with Otter refer to a 400 \
MHz Linux box, which is the same setting as it used for timings with ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "."
}], "SingleParagraph"],

Cell[BoxData[GridBox[{
        {
          StyleBox[\(Proof\ of\ Proposition\),
            FontFamily->"Helvetica",
            FontWeight->"Bold"], 
          StyleBox["Theorema",
            FontFamily->"Helvetica",
            FontWeight->"Bold"], 
          StyleBox["Otter",
            FontFamily->"Helvetica",
            FontWeight->"Bold"]},
        {"\<\"SET008\"\>", 
          StyleBox[\(1.6899999999999977`\ Second\),
            FontWeight->"Bold"], 
          StyleBox[\(22\ Second\),
            FontWeight->"Bold"]},
        {"\<\"SET002\"\>", 
          StyleBox[\(1.8800000000000026`\ Second\),
            FontWeight->"Bold"], 
          StyleBox[\(\(>\)\(300\ Second\)\),
            FontWeight->"Bold"]},
        {"\<\"SET010\"\>", 
          StyleBox[\(6.68`\ Second\),
            FontWeight->"Bold"], 
          StyleBox[\(\(>\)\(300\ Second\)\),
            FontWeight->"Bold"]},
        {"SET012", 
          StyleBox[\(1.96\ Second\),
            FontWeight->"Bold"], 
          StyleBox[\(\(>\)\(300\ Second\)\),
            FontWeight->"Bold"]}
        },
      ColumnWidths->Automatic,
      ColumnAlignments->{Left, Right},
      ColumnLines->True]], "3ColumnTable",
  PageWidth->600,
  CellMargins->{{Inherited, Inherited}, {Inherited, 28}},
  CounterIncrements->"TableHead",
  GridBoxOptions->{RowLines->{0.5, False}},
  CellTags->"TimingsIsolated"],

Cell[TextData[{
  "Table ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["TableHead"],
  ". ",
  StyleBox["Timings for proofs of isolated theorems", "TableHeadText"]
}], "TableHead"]
}, Open  ]],

Cell[TextData[{
  "We want to state clearly that the approach of proving isolated theorems, \
as it is done when attacking problems from the TPTP collection, is definitely \
not in the focus of interest for ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system tries to provide useful support for mathematicians doing their day\
\[Dash]to\[Dash]day work, therefore we did not elaborate many of the proofs \
from the TPTP library."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell["Selected Exercises for Students", "Subsection",
  CellTags->"c:7"],

Cell["\<\
The examples from this section are all exercises that have been \
given to students at the Polytechnic School for Software Engineering in a \
basic mathematics course, where students are taught the language of \
mathematics and the basic proving techniques. In all of these examples,  it \
was sufficiently difficult for students to come up with an exact and correct \
proof.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<Powerset of Union\>", 
      any[X, Y], \[IndentingNewLine]\[ScriptCapitalP][
          X \[Union] Y] \[SupersetEqual] \[ScriptCapitalP][
            X] \[Union] \[ScriptCapitalP][Y]\), "]"}]], "Input",
  CellTags->"Proposition (Powerset of Union)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<Powerset of Union\>"]\), ",", 
        "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {ApplyBuiltIns \[Rule] False, 
              DisableProver \[Rule] {STS, PND}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "IsolatedTheorems"}, "PowersetUnion.nb", 
        CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Intersection with Union\>\"", ",", \(any[X, Y]\), ",", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox["X",
                  FontWeight->"Plain",
                  Background->None], "\[Union]", 
                StyleBox["Y",
                  FontWeight->"Plain",
                  Background->None]}], ")"}], "\[Intersection]", 
            StyleBox["X",
              FontWeight->"Plain",
              Background->None]}], "=", 
          StyleBox["X",
            FontWeight->"Plain",
            Background->None]}]}], "]"}]], "Input",
  CellTags->"Proposition (Intersection with Union)"],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<Intersection with Union\>"]\), ",", 
        "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {ApplyBuiltIns \[Rule] False, 
              DisableProver \[Rule] {STS, PND}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "IsolatedTheorems"}, 
        "IntersectionUnion.nb", CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Intersection with Difference\>\"", ",", \(any[X, Y]\), ",", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox["X",
                  FontWeight->"Plain",
                  Background->None], "\[Backslash]", "Y"}], ")"}], 
            "\[Intersection]", "Y"}], "=", 
          StyleBox["\[EmptySet]",
            FontWeight->"Plain",
            Background->None]}]}], "]"}]], "Input",
  CellTags->"Proposition (Intersection with Difference)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<Intersection with Difference\>"]\), ",", 
        "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {ApplyBuiltIns \[Rule] False, 
              DisableProver \[Rule] {STS, PND}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "IsolatedTheorems"}, 
        "IntersectionDifference.nb", CharacterEncoding -> "ISO8859-1"], None},
    
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell["Example from MIZAR", "Subsection",
  PageBreakAbove->True,
  CellTags->"c:8"],

Cell[TextData[{
  "The following proof of a theorem in set theory has been produced using the \
MIZAR system, see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Vogt00",
            ButtonData:>"Vogt00",
            ButtonStyle->"RefLink",
            ButtonNote->"C. Vogt, 2000, Demo of the MIZAR System"],
          "Text"], TraditionalForm]]],
  "]:"
}], "SingleParagraph"],

Cell["\<\
theorem Th35:
  X c= Y implies X U Y = Y
proof
  assume a1: X c= Y;
  thus X U Y c= Y
    proof
      let x;
      assume x \[Element] X U Y ;
      then x \[Element] X or x \[Element] Y by Def2;
      hence thesis by a1,TARSKI:def 3;
    end;
  let x;
  thus thesis by Def2;
end;

definition                       
  let X,Y;                       
  func X U Y means :: BOOLE:def 2
  x \[Element] it iff x \[Element] X or x \[Element] Y;     
  commutativity;                 
end;

definition                         
  let X,Y;                         
  pred X c= Y means :: TARSKI:def 3
  x \[Element] X implies x \[Element] Y;             
end;\
\>", "Program"],

Cell[TextData[{
  "The formulation and the proof of the same proposition using the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Set Theory prover looks as follows:"
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<Union with Subset\>", 
      any[X, Y], \[IndentingNewLine]X \[SubsetEqual] 
          Y \[Implies] \((X \[Union] Y = Y)\)\), "]"}]], "Input",
  CellTags->"Proposition (Union with Subset)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{\(Proposition["\<Union with Subset\>"]\), ",", 
        "\[IndentingNewLine]", 
        StyleBox[\(ProverOptions \[Rule] {ApplyBuiltIns \[Rule] False, 
              DisableProver \[Rule] {STS, PND}}\),
          "UnHighlightedText"]}], "]"}]], "Input"],

Cell[TextData[{
  "Find the proof here: ",
  ButtonBox["\[LongRightArrow]",
    ButtonData:>{
      FrontEnd`FileName[ {"Proofs", "IsolatedTheorems"}, "UnionWithSubset.nb",
         CharacterEncoding -> "ISO8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "SingleParagraph"]
}, Open  ]],

Cell[TextData[{
  "Table ",
  
  CounterBox["Section", "TimingsStudentEx"],
  ".",
  
  CounterBox["TableHead", "TimingsStudentEx"],
  " collects the timings for the proofs of in this section"
}], "SingleParagraph"],

Cell[BoxData[GridBox[{
        {
          StyleBox[\(Proof\ of\ Proposition\),
            FontFamily->"Helvetica",
            FontWeight->"Bold"], 
          StyleBox["Theorema",
            FontFamily->"Helvetica",
            FontWeight->"Bold"]},
        {"\<\"Powerset of Union\"\>", 
          StyleBox[\(3.789999999999999`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"Intersection with Union\"\>", 
          StyleBox[\(1.759999999999998`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"Intersection with Difference\"\>", 
          StyleBox[\(1.6000000000000014`\ Second\),
            FontWeight->"Bold"]},
        {"\<\"Union with Subset\"\>", 
          StyleBox[\(2.8200000000000003`\ Second\),
            FontWeight->"Bold"]}
        },
      ColumnWidths->Automatic,
      ColumnAlignments->{Left, Right},
      ColumnLines->True]], "2ColumnTable",
  PageWidth->600,
  CellMargins->{{Inherited, Inherited}, {Inherited, 28}},
  CounterIncrements->"TableHead",
  GridBoxOptions->{RowLines->{0.5, False}},
  CellTags->"TimingsStudentEx"],

Cell[TextData[{
  "Table ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["TableHead"],
  ". ",
  StyleBox["Timings for proofs of selected student examples", 
    "TableHeadText"]
}], "TableHead"],

Cell[TextData[ButtonBox["\[LowerRightArrow]",
  ButtonFunction:>(NotebookLocate[ #2]&),
  ButtonData:>{"CaseStudies-EquivalenceRelations1.nb", "c:1"},
  ButtonStyle->"Navigation",
  ButtonNote->"Equivalence Relations and Partitions I"]], "SingleParagraph",
  TextAlignment->Right]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{881, 740},
WindowMargins->{{Automatic, 42}, {Automatic, 22}},
PrintingStartingPageNumber->105,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Part 3: Case Studies"}], "Header"]}, {Cell[ 
        TextData[ {
          CounterBox[ "Section"], ".  Isolated Theorems"}], "Header"], 
      Inherited, Inherited}},
PrintingOptions->{"PrintingMargins"->{{79.1875, 79.1875}, {108, 108}},
"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", \
"wwindste", "Diss", "Main"}, "CaseStudies-IsolatedTheorems.nb.ps", \
CharacterEncoding -> "ISO8859-1"],
"Magnification"->1},
StyleDefinitions -> "TheoremaSmartColors.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1930, 59, 194, 3, 59, "Section",
      CounterAssignments->{{"Section", 11}, {"TableHead", 0}, {
          "Equation", 0}, {"Figure", 0}, {"Subsection", 0}, {
          "Subsubsection", 0}},
      CellTags->"c:1"]},
  "c:2"->{
    Cell[4288, 130, 53, 1, 53, "Subsection",
      CellTags->"c:2"]},
  "Proposition (SET008)"->{
    Cell[4344, 133, 271, 6, 58, "Input",
      CellTags->"Proposition (SET008)"]},
  "c:3"->{
    Cell[5481, 170, 53, 1, 53, "Subsection",
      CellTags->"c:3"]},
  "Proposition (SET002)"->{
    Cell[5537, 173, 219, 5, 58, "Input",
      CellTags->"Proposition (SET002)"]},
  "c:4"->{
    Cell[6676, 208, 53, 1, 53, "Subsection",
      CellTags->"c:4"]},
  "Proposition (SET010)"->{
    Cell[6732, 211, 325, 8, 58, "Input",
      CellTags->"Proposition (SET010)"]},
  "c:5"->{
    Cell[7663, 241, 53, 1, 53, "Subsection",
      CellTags->"c:5"]},
  "Proposition (SET012)"->{
    Cell[7719, 244, 212, 5, 58, "Input",
      CellTags->"Proposition (SET012)"]},
  "c:6"->{
    Cell[8625, 276, 63, 1, 53, "Subsection",
      CellTags->"c:6"]},
  "TimingsIsolated"->{
    Cell[9530, 301, 1384, 39, 143, "3ColumnTable",
      CounterIncrements->"TableHead",
      CellTags->"TimingsIsolated"]},
  "c:7"->{
    Cell[11668, 370, 72, 1, 53, "Subsection",
      CellTags->"c:7"]},
  "Proposition (Powerset of Union)"->{
    Cell[12156, 382, 345, 7, 58, "Input",
      CellTags->"Proposition (Powerset of Union)"]},
  "Proposition (Intersection with Union)"->{
    Cell[13146, 413, 808, 23, 58, "Input",
      CellTags->"Proposition (Intersection with Union)"]},
  "Proposition (Intersection with Difference)"->{
    Cell[14563, 456, 653, 18, 58, "Input",
      CellTags->"Proposition (Intersection with Difference)"]},
  "c:8"->{
    Cell[15874, 498, 83, 2, 53, "Subsection",
      PageBreakAbove->True,
      CellTags->"c:8"]},
  "Proposition (Union with Subset)"->{
    Cell[17248, 553, 285, 6, 58, "Input",
      CellTags->"Proposition (Union with Subset)"]},
  "TimingsStudentEx"->{
    Cell[18386, 592, 1076, 28, 143, "2ColumnTable",
      CounterIncrements->"TableHead",
      CellTags->"TimingsStudentEx"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 21398, 678},
  {"c:2", 21634, 684},
  {"Proposition (SET008)", 21732, 687},
  {"c:3", 21826, 690},
  {"Proposition (SET002)", 21924, 693},
  {"c:4", 22018, 696},
  {"Proposition (SET010)", 22116, 699},
  {"c:5", 22210, 702},
  {"Proposition (SET012)", 22308, 705},
  {"c:6", 22402, 708},
  {"TimingsIsolated", 22495, 711},
  {"c:7", 22632, 715},
  {"Proposition (Powerset of Union)", 22742, 718},
  {"Proposition (Intersection with Union)", 22882, 721},
  {"Proposition (Intersection with Difference)", 23034, 724},
  {"c:8", 23152, 727},
  {"Proposition (Union with Subset)", 23290, 731},
  {"TimingsStudentEx", 23409, 734}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 200, 5, 42, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1930, 59, 194, 3, 59, "Section",
  CounterAssignments->{{"Section", 11}, {"TableHead", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsection", 0}, {"Subsubsection", 0}},
  CellTags->"c:1"],
Cell[2127, 64, 309, 7, 50, "SingleParagraph"],
Cell[2439, 73, 173, 4, 46, "ItemizedText"],
Cell[2615, 79, 136, 3, 27, "ItemizedText"],
Cell[2754, 84, 1509, 42, 95, "FirstParagraph"],

Cell[CellGroupData[{
Cell[4288, 130, 53, 1, 53, "Subsection",
  CellTags->"c:2"],
Cell[4344, 133, 271, 6, 58, "Input",
  CellTags->"Proposition (SET008)"],
Cell[4618, 141, 294, 7, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[4937, 152, 239, 4, 58, "Input"],
Cell[5179, 158, 275, 8, 31, "SingleParagraph"]
}, Open  ]]
}, Open  ]],
Cell[5481, 170, 53, 1, 53, "Subsection",
  CellTags->"c:3"],
Cell[5537, 173, 219, 5, 58, "Input",
  CellTags->"Proposition (SET002)"],
Cell[5759, 180, 311, 6, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[6095, 190, 288, 5, 58, "Input"],
Cell[6386, 197, 275, 8, 31, "SingleParagraph"]
}, Open  ]],
Cell[6676, 208, 53, 1, 53, "Subsection",
  CellTags->"c:4"],
Cell[6732, 211, 325, 8, 58, "Input",
  CellTags->"Proposition (SET010)"],

Cell[CellGroupData[{
Cell[7082, 223, 288, 5, 58, "Input"],
Cell[7373, 230, 275, 8, 31, "SingleParagraph"]
}, Open  ]],
Cell[7663, 241, 53, 1, 53, "Subsection",
  CellTags->"c:5"],
Cell[7719, 244, 212, 5, 58, "Input",
  CellTags->"Proposition (SET012)"],
Cell[7934, 251, 63, 1, 39, "Input"],

Cell[CellGroupData[{
Cell[8022, 256, 288, 5, 58, "Input"],
Cell[8313, 263, 275, 8, 31, "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8625, 276, 63, 1, 53, "Subsection",
  CellTags->"c:6"],
Cell[8691, 279, 836, 20, 107, "SingleParagraph"],
Cell[9530, 301, 1384, 39, 143, "3ColumnTable",
  CounterIncrements->"TableHead",
  CellTags->"TimingsIsolated"],
Cell[10917, 342, 188, 9, 36, "TableHead"]
}, Open  ]],
Cell[11120, 354, 523, 12, 69, "SingleParagraph"],

Cell[CellGroupData[{
Cell[11668, 370, 72, 1, 53, "Subsection",
  CellTags->"c:7"],
Cell[11743, 373, 410, 7, 69, "SingleParagraph"],
Cell[12156, 382, 345, 7, 58, "Input",
  CellTags->"Proposition (Powerset of Union)"],

Cell[CellGroupData[{
Cell[12526, 393, 308, 6, 58, "Input"],
Cell[12837, 401, 282, 8, 31, "SingleParagraph"]
}, Open  ]]
}, Open  ]],
Cell[13146, 413, 808, 23, 58, "Input",
  CellTags->"Proposition (Intersection with Union)"],
Cell[13957, 438, 314, 6, 58, "Input"],
Cell[14274, 446, 286, 8, 31, "SingleParagraph"],
Cell[14563, 456, 653, 18, 58, "Input",
  CellTags->"Proposition (Intersection with Difference)"],

Cell[CellGroupData[{
Cell[15241, 478, 319, 6, 58, "Input"],
Cell[15563, 486, 296, 9, 31, "SingleParagraph"]
}, Open  ]],
Cell[15874, 498, 83, 2, 53, "Subsection",
  PageBreakAbove->True,
  CellTags->"c:8"],
Cell[15960, 502, 403, 12, 31, "SingleParagraph"],
Cell[16366, 516, 678, 28, 394, "Program"],
Cell[17047, 546, 198, 5, 31, "SingleParagraph"],
Cell[17248, 553, 285, 6, 58, "Input",
  CellTags->"Proposition (Union with Subset)"],

Cell[CellGroupData[{
Cell[17558, 563, 308, 6, 58, "Input"],
Cell[17869, 571, 284, 8, 31, "SingleParagraph"]
}, Open  ]],
Cell[18168, 582, 215, 8, 31, "SingleParagraph"],
Cell[18386, 592, 1076, 28, 143, "2ColumnTable",
  CounterIncrements->"TableHead",
  CellTags->"TimingsStudentEx"],
Cell[19465, 622, 201, 10, 36, "TableHead"],
Cell[19669, 634, 280, 5, 42, "SingleParagraph"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

