(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     74056,       2691]*)
(*NotebookOutlinePosition[     87044,       3106]*)
(*  CellTagsIndexPosition[     84501,       3010]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[ButtonBox["\[UpperLeftArrow]",
  ButtonData:>{"CaseStudies-Checkerboard.nb", "c:1"},
  ButtonStyle->"Navigation",
  ButtonNote->"Table of Contents"]], "SingleParagraph",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Conclusion", "Section",
  CounterAssignments->{{"Section", 15}, {"TableHead", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsection", 0}, {"Subsubsection", 0}},
  CellTags->"c:1"],

Cell[TextData[{
  "We presented in this thesis a set theory prover in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system. The prover uses a natural deduction oriented method to generate \
proofs and it structures proofs in phases of proving, computing, and solving, \
following the PCS paradigm invented by B. Buchberger used also in other ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " provers, notably the provers for elementary analysis. We showed the \
possibilities for practical applications of this prover by numerous examples, \
which are mostly organized in entire explorations of some mathematical theory \
involving set theory. In one of these explorations, we investigate the \
mathematical domain of \"a checkerboard with dominoes on it\" and gave a \
complete proof for the \"Mutilated Checkerboard Problem\" posed by McCarthy, \
which is considered as a benchmark problem for automated set theory proving."
}], "FirstParagraph"],

Cell["Directions for future work will be:", "Text"],

Cell[TextData[{
  "Improving the possibilities for combining special provers in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system. This endeavor might lead to the development of an entire new \
language for prover programming."
}], "ItemizedText"],

Cell[TextData[{
  "Improving the possibilities for communication between individual special \
provers in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system."
}], "ItemizedText"],

Cell["\<\
Development of specialized solving techniques for set theory.\
\>", \
"ItemizedText"],

Cell[TextData[{
  "Further investigations on the interplay between proving and computing: In \
the current prover, computation is used as a subtask for doing \
simplifications in proving. The other way round, i.e. using a prover to \
validate conditions during computations, is not yet treated deeply in \
currently available systems. From the software technological point of view, \
we see no big problems in directly connecting our computation mechanism with \
all the proving methods available in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system."
}], "ItemizedText"],

Cell["\<\
More case studies will be necessary for fine\[Dash]tuning the \
methods and enhancing current techniques.\
\>", "ItemizedText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Section",
  TaggingRules:>"GeneratedReference",
  PageBreakAbove->True,
  CellFrameLabels->{{None, Inherited}, {Inherited, Inherited}},
  CellTags->{"References", "c:2"}],

Cell[TextData[{
  ButtonBox["[AINP92]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"AINP92",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"AINP92"],
  " ",
  "P. Andrews and S. Issar and D. Nesmith and F. Pfenning",
  ". ",
  "The TPS Theorem Proving System (Abstract)",
  ". ",
  StyleBox["Journal of Symbolic Logic",
    FontSlant->"Italic"],
  ", ",
  "(",
  "57",
  ")",
  ":",
  "353\[Dash]354",
  ", ",
  "1992",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"AINP92"],

Cell[TextData[{
  ButtonBox["[Analytica]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Analytica",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Analytica"],
  " Analytica. ",
  StyleBox["Developed at Carnegie Mellon University by E. Clarke",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www.cs.cmu.edu/ andrej/analytica",
    ButtonData:>{
      URL[ "http://www.cs.cmu.edu/ andrej/analytica"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Analytica"],

Cell[TextData[{
  ButtonBox["[Andr86]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Andr86",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Andr86"],
  " ",
  "Peter B. Andrews",
  ". ",
  StyleBox["An Introduction to Mathematical Logic and Type Theory: To Truth \
Through Proof",
    FontSlant->"Italic"],
  ", ",
  "series Computer Science and Applied Mathematics",
  ". ",
  "Academic Press, Inc.",
  ", ",
  "1986",
  ". ",
  "ISBN 0-12-058535-9",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Andr86"],

Cell[TextData[{
  ButtonBox["[AnBi96]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"AnBi96",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"AnBi96"],
  " ",
  "P. Andrews and M. Bishop",
  ". ",
  "On Sets, Types, Fixed Points, and Checkerboards",
  ". ",
  "In ",
  "Pierangelo Miglioli and Ugo Moscato and Daniele Mundici and Mario Ornaghi, \
editor, ",
  StyleBox["Theorem Proving with Analytic Tableaux and Related Methods. 5th \
International Workshop, TABLEAUX '96, Palermo",
    FontSlant->"Italic"],
  ", ",
  "number 1071 in ",
  "LNAI",
  ", ",
  "pages 1\[Dash]15",
  ", ",
  "Springer",
  ", ",
  "May",
  " ",
  "1996",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"AnBi96"],

Cell[TextData[{
  ButtonBox["[APIK86]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"APIK86",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"APIK86"],
  " ",
  "P. Andrews and F. Pfenning and S. Issar and C. P. Klapper",
  ". ",
  "The TPS Theorem Proving System",
  ". ",
  "In ",
  "J. Siekmann, editor, ",
  StyleBox["8th International Conference on Automated Deduction",
    FontSlant->"Italic"],
  ", ",
  "number 230 in ",
  "LNCS",
  ", ",
  "pages 663\[Dash]664",
  ", ",
  "Oxford, England",
  ", ",
  "Springer",
  ", ",
  "1986",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"APIK86"],

Cell[TextData[{
  ButtonBox["[Axiom]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Axiom",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Axiom"],
  " Axiom. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" by IBM Research, directed by R. Jenks",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www.nag.com/symbolic_software.asp",
    ButtonData:>{
      URL[ "http://www.nag.com/symbolic_software.asp"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Axiom"],

Cell[TextData[{
  ButtonBox["[Banc95]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Banc95",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Banc95"],
  " ",
  "G. Bancerek",
  ". ",
  "The Mutilated Chessboard Problem - checked by MIZAR",
  ". ",
  "In ",
  "Roman Matuszewski, editor, ",
  StyleBox["The QED Workshop II",
    FontSlant->"Italic"],
  ", ",
  "pages 25\[Dash]26",
  ", ",
  "Warshaw University",
  ". ",
  "1995",
  ". ",
  "Technical Report L/1/95",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Banc95"],

Cell[TextData[{
  ButtonBox["[Beli99a]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Beli99a",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Beli99a"],
  " ",
  "Belinfante, Johan",
  ". ",
  "Computer Proofs in G\[ODoubleDot]del's Class Theory with Equational \
Definitions for Composite and Cross",
  ". ",
  StyleBox["Journal of Automated Reasoning",
    FontSlant->"Italic"],
  ", ",
  "22",
  ":",
  "311\[Dash]339",
  ", ",
  "1999",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Beli99a"],

Cell[TextData[{
  ButtonBox["[Beli99b]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Beli99b",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Beli99b"],
  " ",
  "Belinfante, Johan",
  ". ",
  "On Computer-Assisted Proofs in Ordinal Number Theory",
  ". ",
  StyleBox["Journal of Automated Reasoning",
    FontSlant->"Italic"],
  ", ",
  "22",
  ":",
  "341\[Dash]378",
  ", ",
  "1999",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Beli99b"],

Cell[TextData[{
  ButtonBox["[BeFr68]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"BeFr68",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"BeFr68"],
  " ",
  "P. Bernays and A. Fraenkel",
  ". ",
  StyleBox["Axiomatic Set Theory",
    FontSlant->"Italic"],
  ", ",
  "series Studies in Logic and the Foundations of Mathematics",
  ". ",
  "North-Holland Publishing Company",
  ", ",
  "2 edition",
  ", ",
  "1968",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"BeFr68"],

Cell[TextData[{
  ButtonBox["[Buch65]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Buch65",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Buch65"],
  " ",
  "B. Buchberger",
  ". ",
  StyleBox["An Algorithm for Finding a Basis for the Residue Class Ring of a \
Zero-Dimensional Polynomial Ideal (German)",
    FontSlant->"Italic"],
  ". ",
  "Univ. Innsbruck, Dept. of Math.",
  ", ",
  "Innsbruck, Austria",
  ", ",
  "1965",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buch65"],

Cell[TextData[{
  ButtonBox["[Buch91]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Buch91",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Buch91"],
  " ",
  "B. Buchberger",
  ". ",
  "Logic for Computer Science",
  ". ",
  "Lecture notes University of Linz",
  ", ",
  "1991",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buch91"],

Cell[TextData[{
  ButtonBox["[Buch93]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Buch93",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Buch93"],
  " ",
  "B. Buchberger",
  ". ",
  "Mathematica: A System For Doing Mathematics by Computer?",
  ". ",
  "In ",
  "A. Miola and M. Temperini, editor, ",
  StyleBox["Advances in the Design of Symbolic Computation Systems",
    FontSlant->"Italic"],
  ", ",
  "pages 2\[Dash]29",
  ", ",
  "Springer Verlag, Wien - New York",
  ", ",
  "1997",
  ". ",
  "Invited Talk at DISCO 93, Gmunden, Austria",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buch93"],

Cell[TextData[{
  ButtonBox["[Buch96]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Buch96",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Buch96"],
  " ",
  "B. Buchberger",
  ". ",
  "Mathematics: An Introduction to Mathematics Integrating the Pure and \
Algorithmic Aspect. Volume I: A Logical Basis for Mathematics",
  ". ",
  "Lecture notes for the mathematics course in the first and second semester \
at the Fachhochschule for Software Engineering in Hagenberg, Austria",
  ", ",
  "1996",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buch96"],

Cell[TextData[{
  ButtonBox["[Buch96a]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Buch96a",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Buch96a"],
  " ",
  "B. Buchberger",
  ". ",
  "Symbolic Computation: Computer Algebra and Logic",
  ". ",
  "In ",
  "F. Baader and K.U. Schulz, editor, ",
  StyleBox["FroCoS: Frontiers of Combined Systems",
    FontSlant->"Italic"],
  ", ",
  "Applied Logic Series",
  ", ",
  "pages 193\[Dash]220",
  ", ",
  "Kluwer Academic Press",
  ", ",
  "1996",
  ". ",
  "Invited talk at the FroCoS InProceedings in Munich, March 26-29, 1996",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buch96a"],

Cell[TextData[{
  ButtonBox["[Buch96b]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Buch96b",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Buch96b"],
  " ",
  "B. Buchberger",
  ". ",
  "Mathematica as a Rewrite Language",
  ". ",
  "In ",
  "T. Ida, editor, ",
  StyleBox["Proceedings of the Fuji Conference on Functional Logic \
Programming, Shonan Village, Nov 1-4, 1996",
    FontSlant->"Italic"],
  ", ",
  "Telos publishing InProceedings",
  ", ",
  "1996",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buch96b"],

Cell[TextData[{
  ButtonBox["[Buch97]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Buch97",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Buch97"],
  " ",
  "B. Buchberger and T. Jebelean and F. Kriftner and M. Marin and E. Tomuta \
and D. Vasaru",
  ". ",
  "A Survey of the \\em Theorema Project",
  ". ",
  "In ",
  "W. Kuechlin, editor, ",
  StyleBox["Proceedings of ISSAC'97 (International Symposium on Symbolic and \
Algebraic Computation",
    FontSlant->"Italic"],
  ", ",
  "pages 384\[Dash]391",
  ", ",
  "Maui, Hawaii",
  ", ",
  "ACM Press",
  ", ",
  "July",
  " ",
  "1997",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buch97"],

Cell[TextData[{
  ButtonBox["[Buch98]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Buch98",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Buch98"],
  " ",
  "B. Buchberger",
  ". ",
  "Theorema: The Current Status",
  ". ",
  "In ",
  "B. Buchberger and T. Jebelean, editor, ",
  StyleBox["Proceedings of the Second International Theorema Workshop",
    FontSlant->"Italic"],
  ", ",
  "pages 5\[Dash]37",
  ", ",
  "1998",
  ". ",
  "RISC report 98-10",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buch98"],

Cell[TextData[{
  ButtonBox["[Buch99i]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Buch99i",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Buch99i"],
  " ",
  "B. Buchberger",
  ". ",
  "Theorema: A Proving System Based on Mathematica",
  ". ",
  "International Symposium on Symbolic and Numeric Scientific Computing, \
RISC, Hagenberg, Austria",
  ", ",
  "1999",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buch99i"],

Cell[TextData[{
  ButtonBox["[Buch99k]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Buch99k",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Buch99k"],
  " ",
  "B. Buchberger",
  ". ",
  "Theory Exploration Versus Theorem Proving",
  ". ",
  "In ",
  "A. Armando and T. Jebelean, editor, ",
  StyleBox["Electronic Notes in Theoretical Computer Science",
    FontSlant->"Italic"],
  ", ",
  "volume 23-3 of ",
  "pages 67\[Dash]69",
  ", ",
  "Elsevier",
  ", ",
  "1999",
  ". ",
  "CALCULEMUS Workshop, University of Trento, Trento, Italy",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buch99k"],

Cell[TextData[{
  ButtonBox["[Buch99v]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Buch99v",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Buch99v"],
  " ",
  "B. Buchberger",
  ". ",
  "Theorema: A System for Supporting Mathematical Proving",
  ". ",
  "Workshop of the Japanese Consortium on Formal Methods, Nagoya, Japan",
  ", ",
  "1999",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buch99v"],

Cell[TextData[{
  ButtonBox["[Buch00m]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Buch00m",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Buch00m"],
  " ",
  "B. Buchberger and D. Vasaru",
  ". ",
  "The Theorema PCS Prover",
  ". ",
  "Jahrestagung der DMV, Dresden, September 18-22",
  ", ",
  "2000",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buch00m"],

Cell[TextData[{
  ButtonBox["[Buch00n]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Buch00n",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Buch00n"],
  " ",
  "B. Buchberger",
  ". ",
  "Future Directions for the Theorema System",
  ". ",
  "Personal communication during a Theorema seminar",
  ", ",
  "2000",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buch00n"],

Cell[TextData[{
  ButtonBox["[BuEtal99b]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"BuEtal99b",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"BuEtal99b"],
  " ",
  "B. Buchberger and C. Dupr\[EGrave] and T. Jebelean and K. Kriftner and K. \
Nakagawa and D. Vasaru and W. Windsteiger",
  ". ",
  "Theorema: A Short Demo",
  ". ",
  "In ",
  StyleBox["Proceedings of the International Mathematica Symposium '99",
    FontSlant->"Italic"],
  ", ",
  "RISC, Austria",
  ", ",
  "August",
  " ",
  "1999",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"BuEtal99b"],

Cell[TextData[{
  ButtonBox["[BuEtal00a]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"BuEtal00a",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"BuEtal00a"],
  " ",
  "B. Buchberger and C. Dupr\[EGrave] and T. Jebelean and K. Kriftner and K. \
Nakagawa and D. Vasaru and W. Windsteiger",
  ". ",
  "The Theorema Project: A Progress Report",
  ". ",
  "In ",
  "M. Kerber and M. Kohlhase, editor, ",
  StyleBox["Proceedings of the 8th Symposium on the Integration of Symbolic \
Computation and Mechanized Reasoning, St. Andrews, Scotland, August 6-7",
    FontSlant->"Italic"],
  ", ",
  "pages 100\[Dash]115",
  ", ",
  "2000",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"BuEtal00a"],

Cell[TextData[{
  ButtonBox["[BuEtAl00b]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"BuEtAl00b",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"BuEtAl00b"],
  " ",
  "Theorema Group",
  ". ",
  "Theorema: A System for Supporting Mathematical Proving Implemented in \
Mathematica",
  ". ",
  "Conference of the Association for Symbolic Logic, Chicago",
  ", ",
  "2000",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"BuEtAl00b"],

Cell[TextData[{
  ButtonBox["[BuNa00a]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"BuNa00a",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"BuNa00a"],
  " ",
  "B. Buchberger and K. Nakagawa",
  ". ",
  "Logicographic Symbols: A New Concept in Logic Syntax",
  ". ",
  "In ",
  StyleBox["Proceedings of the INTAS Conference on Rewriting Techniques and \
Efficient Theorem Proving",
    FontSlant->"Italic"],
  ", ",
  "2000",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"BuNa00a"],

Cell[TextData[{
  ButtonBox["[BuWi98a]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"BuWi98a",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"BuWi98a"],
  " ",
  "Buchberger, B. and Windsteiger, W.",
  ". ",
  "The Theorema Language: Implementing Object- and Meta-Level Usage of \
Symbols",
  ". ",
  "In ",
  StyleBox["Proceedings of Calculemus 98, Eindhoven, Netherlands",
    FontSlant->"Italic"],
  ", ",
  "1998",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"BuWi98a"],

Cell[TextData[{
  ButtonBox["[BuIr96]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"BuIr96",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"BuIr96"],
  " ",
  "A. Bundy and A. Ireland",
  ". ",
  "Productive Use of Failure in Inductive Proofs",
  ". ",
  StyleBox["Journal of Automated Reasoning, Special Issue: Automated \
Mathematical Induction",
    FontSlant->"Italic"],
  ", ",
  "16",
  "(",
  "1-2",
  ")",
  ":",
  "79\[Dash]111",
  ", ",
  "March",
  " ",
  "1996",
  ". ",
  "(H. Zhang (ed.)",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"BuIr96"],

Cell[TextData[{
  ButtonBox["[Chur41]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Chur41",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Chur41"],
  " ",
  "A. Church",
  ". ",
  "The Calculi of Lambda-conversion",
  ". ",
  StyleBox["Ann. Math. Studies",
    FontSlant->"Italic"],
  ", ",
  "(",
  "6",
  ")",
  ":",
  "1941",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Chur41"],

Cell[TextData[{
  ButtonBox["[Coll75]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Coll75",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Coll75"],
  " ",
  "G. E. Collins",
  ". ",
  "Quantifier Elimination for Real Closed Fields by Cylindrical Algebraic \
Decomposition",
  ". ",
  "In ",
  StyleBox["Second GI Conference on Automata Theory and Formal Languages",
    FontSlant->"Italic"],
  ", ",
  "number 33 in ",
  "LNCS",
  ", ",
  "pages 134\[Dash]183",
  ", ",
  "Springer Verlag, Berlin",
  ", ",
  "1975",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Coll75"],

Cell[TextData[{
  ButtonBox["[Coq]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Coq",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Coq"],
  " Coq. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at Inria, France",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://pauillac.inria.fr/coq",
    ButtonData:>{
      URL[ "http://pauillac.inria.fr/coq"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Coq"],

Cell[TextData[{
  ButtonBox["[CuFe74]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"CuFe74",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"CuFe74"],
  " ",
  "Haskell B. Curry and Robert Feys",
  ". ",
  StyleBox["Combinatory Logic",
    FontSlant->"Italic"],
  ", ",
  "North-Holland Publishing Company",
  ", ",
  "3 edition",
  ", ",
  "1974",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"CuFe74"],

Cell[TextData[{
  ButtonBox["[Curry63]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Curry63",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Curry63"],
  " ",
  "Haskell B. Curry",
  ". ",
  StyleBox["Foundations of Mathematical Logic",
    FontSlant->"Italic"],
  ", ",
  "series McGraw-Hill Series in Higher Mathematics",
  ". ",
  "McGraw-Hill Book Company Inc.",
  ", ",
  "1963",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Curry63"],

Cell[TextData[{
  ButtonBox["[Derive]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Derive",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Derive"],
  " Derive. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at the University of Hawaii, directed by D. Stoutemyer",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://education.ti.com/product/software/derive/features/\
features.html",
    ButtonData:>{
      URL[ 
      "http://education.ti.com/product/software/derive/features/features.\
html"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Derive"],

Cell[TextData[{
  ButtonBox["[Ebbi79]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Ebbi79",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Ebbi79"],
  " ",
  "H.D. Ebbinghaus",
  ". ",
  StyleBox["Einf\[UDoubleDot]hrung in die Mengenlehre",
    FontSlant->"Italic"],
  ", ",
  "Wissenschaftliche Buchgesellschaft Darmstadt",
  ", ",
  "2 edition",
  ", ",
  "1979",
  ". ",
  "ISBN 3-534-06709-6",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Ebbi79"],

Cell[TextData[{
  ButtonBox["[EFT92]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"EFT92",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"EFT92"],
  " ",
  "H.D. Ebbinghaus and J. Flum and W. Thomas",
  ". ",
  StyleBox["Einf\[UDoubleDot]hrung in die mathematische Logik",
    FontSlant->"Italic"],
  ", ",
  "BI Wissenschaftsverlag Mannheim/Leipzig/Wien/Z\[UDoubleDot]rich",
  ", ",
  "3 edition",
  ", ",
  "1992",
  ". ",
  "ISBN 3-411-15603-1",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"EFT92"],

Cell[TextData[{
  ButtonBox["[Eqp]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Eqp",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Eqp"],
  " Eqp. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at Argonne National Laboratories, directed by W. McCune",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www-unix.mcs.anl.gov/AR/eqp",
    ButtonData:>{
      URL[ "http://www-unix.mcs.anl.gov/AR/eqp"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Eqp"],

Cell[TextData[{
  ButtonBox["[Form00]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Form00",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Form00"],
  " ",
  "Andrea Formisano",
  ". ",
  StyleBox["Theory-based resolution and automated set reasoning",
    FontSlant->"Italic"],
  ". ",
  "Universita degli Studi di Roma ``La Sapienza''",
  ", ",
  "2000",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Form00"],

Cell[TextData[{
  ButtonBox["[Frae76]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Frae76",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Frae76"],
  " ",
  "Abraham A. Fraenkel",
  ". ",
  StyleBox["Abstract Set Theory",
    FontSlant->"Italic"],
  ", ",
  "series Studies in Logic and the Foundations of Mathematics",
  ". ",
  "North-Holland Publishing Company",
  ", ",
  "4 edition",
  ", ",
  "1976",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Frae76"],

Cell[TextData[{
  ButtonBox["[Gall86]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Gall86",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Gall86"],
  " ",
  "J.H. Gallier",
  ". ",
  StyleBox["Logic for Computer Science",
    FontSlant->"Italic"],
  ", ",
  "series Foundations of Automated Theorem Proving",
  ". ",
  "Harper & Row",
  ", ",
  "1986",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Gall86"],

Cell[TextData[{
  ButtonBox["[Gap]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Gap",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Gap"],
  " Gap. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at University of Aachen",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www-history.mcs.st-and.ac.uk/ gap",
    ButtonData:>{
      URL[ "http://www-history.mcs.st-and.ac.uk/ gap"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Gap"],

Cell[TextData[{
  ButtonBox["[Goed40]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Goed40",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Goed40"],
  " ",
  "K. G\[ODoubleDot]del",
  ". ",
  StyleBox["The Consistency of the Axiom of Choice and the Generalized \
Continuum-Hypothesis with the Axioms of Set Theory",
    FontSlant->"Italic"],
  ", ",
  "Princeton University Press",
  ", ",
  "1940",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Goed40"],

Cell[TextData[{
  ButtonBox["[Hol]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Hol",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Hol"],
  " Hol. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at the University of Cambridge, directed by R. Milner",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www.cl.cam.ac.uk/Research/HVG/HOL",
    ButtonData:>{
      URL[ "http://www.cl.cam.ac.uk/Research/HVG/HOL"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Hol"],

Cell[TextData[{
  ButtonBox["[JeKo00a]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"JeKo00a",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"JeKo00a"],
  " ",
  "T. Jebelean and B. Konev",
  ". ",
  "Using Meta-variables for Natural Deduction in Theorema",
  ". ",
  "In ",
  "M. Kerber and M. Kohlhase, editor, ",
  StyleBox["Proceedings of the CALCULEMUS 2000 8th Symposium on the \
Integration of Symbolic Computation and Mechanized Reasoning",
    FontSlant->"Italic"],
  ", ",
  "pages 160\[Dash]175",
  ", ",
  "St. Andrews, Scotland",
  ", ",
  "August 6-7",
  " ",
  "2000",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"JeKo00a"],

Cell[TextData[{
  ButtonBox["[JeKo00b]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"JeKo00b",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"JeKo00b"],
  " ",
  "B. Konev and T. Jebelean",
  ". ",
  "Combining Level-Saturation Strategies and Meta-Variables for Predicate \
Logic Proving in Theorema",
  ". ",
  "In ",
  StyleBox["Proceedings of IMACS ACA 2000, St.Petersburg, Russia",
    FontSlant->"Italic"],
  ", ",
  "June",
  " ",
  "2000",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"JeKo00b"],

Cell[TextData[{
  ButtonBox["[Konev99a]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Konev99a",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Konev99a"],
  " ",
  "B. Konev",
  ". ",
  "Metavariable Method for Natural Deduction Within Theorema",
  ". ",
  "RISC - Report 99-34",
  ", ",
  "1999",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Konev99a"],

Cell[TextData[{
  ButtonBox["[Krif98]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Krif98",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Krif98"],
  " ",
  "F. Kriftner",
  ". ",
  "Theorema: The Language",
  ". ",
  "In ",
  "B. Buchberger and T. Jebelean, editor, ",
  StyleBox["Proceedings of the Second International Theorema Workshop",
    FontSlant->"Italic"],
  ", ",
  "pages 39\[Dash]54",
  ", ",
  "1998",
  ". ",
  "RISC report 98-10",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Krif98"],

Cell[TextData[{
  ButtonBox["[Mace]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Mace",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Mace"],
  " Mace. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at Argonne National Laboratories, directed by W. McCune",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www-unix.mcs.anl.gov/AR/mace",
    ButtonData:>{
      URL[ "http://www-unix.mcs.anl.gov/AR/mace"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Mace"],

Cell[TextData[{
  ButtonBox["[Macsyma]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Macsyma",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Macsyma"],
  " Macsyma. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" by the MATH lab group at MIT",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www.ma.utexas.edu/users/wfs/maxima.html",
    ButtonData:>{
      URL[ "http://www.ma.utexas.edu/users/wfs/maxima.html"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Macsyma"],

Cell[TextData[{
  ButtonBox["[Maed97]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Maed97",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Maed97"],
  " ",
  "R. Maeder",
  ". ",
  StyleBox["Programming in Mathematica",
    FontSlant->"Italic"],
  ", ",
  "Addison-Wesley",
  ", ",
  "3 edition",
  ", ",
  "1997",
  ". ",
  "ISBN 0-201-85449-X",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Maed97"],

Cell[TextData[{
  ButtonBox["[Magma]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Magma",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Magma"],
  " Magma. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at University of Sydney, directed by J. Cannon",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www.maths.usyd.edu.au:8000/u/magma",
    ButtonData:>{
      URL[ "http://www.maths.usyd.edu.au:8000/u/magma"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Magma"],

Cell[TextData[{
  ButtonBox["[Manna74]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Manna74",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Manna74"],
  " ",
  "Z. Manna",
  ". ",
  StyleBox["Mathematical Theory of Computation",
    FontSlant->"Italic"],
  ", ",
  "McGraw-Hill Book Company",
  ", ",
  "1974",
  ". ",
  "ISBN 0-07-039910-7",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Manna74"],

Cell[TextData[{
  ButtonBox["[Maple]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Maple",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Maple"],
  " Maple. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at University of Waterloo, directed by G. Gonnet",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www.maplesoft.com",
    ButtonData:>{
      URL[ "http://www.maplesoft.com"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Maple"],

Cell[TextData[{
  ButtonBox["[Mathematica]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Mathematica",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Mathematica"],
  " Mathematica. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at Wolfram Research Inc., directed by S. Wolfram",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www.wolfram.com",
    ButtonData:>{
      URL[ "http://www.wolfram.com"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Mathematica"],

Cell[TextData[{
  ButtonBox["[McCarthy64]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"McCarthy64",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"McCarthy64"],
  " ",
  "J. McCarthy",
  ". ",
  "A Tough Nut for Proof Procedures",
  ". ",
  "Stanford AI project memo",
  ", ",
  "1964",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"McCarthy64"],

Cell[TextData[{
  ButtonBox["[McCarthy95]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"McCarthy95",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"McCarthy95"],
  " ",
  "J. McCarthy",
  ". ",
  "The Mutilated Checkerboard in Set Theory",
  ". ",
  "In ",
  "Roman Matuszewski, editor, ",
  StyleBox["The QED Workshop II",
    FontSlant->"Italic"],
  ", ",
  "pages 25\[Dash]26",
  ", ",
  "Warshaw University",
  ". ",
  "1995",
  ". ",
  "Technical Report L/1/95",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"McCarthy95"],

Cell[TextData[{
  ButtonBox["[McCune94]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"McCune94",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"McCune94"],
  " ",
  "W. McCune",
  ". ",
  "A Davis-Putnam Program and its Application to Finite First-Order Model \
Search: Quasigroup Existence Problems",
  ". ",
  "Primary documentation of MACE, downloadable from \
http://www-unix.mcs.anl.gov/AR/mace",
  ", ",
  "1994",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"McCune94"],

Cell[TextData[{
  ButtonBox["[McCune94a]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"McCune94a",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"McCune94a"],
  " ",
  "W. McCune",
  ". ",
  "Otter 3.0 Reference Manual and Guide",
  ". ",
  "94/6",
  ", ",
  "Argonne National Laboratory",
  ", ",
  "1994",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"McCune94a"],

Cell[TextData[{
  ButtonBox["[McCune95]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"McCune95",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"McCune95"],
  " ",
  "W. McCune",
  ". ",
  "Another Crack in a Tough Nut",
  ". ",
  StyleBox["Association for Automated Reasoning Newsletter",
    FontSlant->"Italic"],
  ", ",
  "(",
  "31",
  ")",
  ":",
  "1\[Dash]3",
  ", ",
  "1995",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"McCune95"],

Cell[TextData[{
  ButtonBox["[McCuPa96]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"McCuPa96",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"McCuPa96"],
  " ",
  "W. McCune and R. Padmanabhan",
  ". ",
  StyleBox["Automated Deduction in Equational Logic and Cubic Curves",
    FontSlant->"Italic"],
  ", ",
  "series Lecture Notes in Computer Science (AI subseries)",
  ". ",
  "Springer Verlag",
  ", ",
  "1996",
  ". ",
  "ISBN 3-540-61398-6",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"McCuPa96"],

Cell[TextData[{
  ButtonBox["[Mizar]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Mizar",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Mizar"],
  " Mizar. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at the University of Warszaw, directed by A. Trybulec",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://mizar.uwb.edu.pl/system",
    ButtonData:>{
      URL[ "http://mizar.uwb.edu.pl/system"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Mizar"],

Cell[TextData[{
  ButtonBox["[Naka00PhD]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Naka00PhD",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Naka00PhD"],
  " ",
  "Koji Nakagawa",
  ". ",
  StyleBox["Proof Presentation in Automated Theorema Proving",
    FontSlant->"Italic"],
  ". ",
  "RISC Institute",
  ", ",
  "2000",
  ". ",
  "Ongoing",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Naka00PhD"],

Cell[TextData[{
  ButtonBox["[Nqthm]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Nqthm",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Nqthm"],
  " Nqthm. ",
  StyleBox["Also known as Boyer-Moore Prover, developed at the University of \
Texas, directed by R. Boyer",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["ftp://ftp.cs.utexas.edu/pub/boyer/nqthm/index.html",
    ButtonData:>{
      URL[ "ftp://ftp.cs.utexas.edu/pub/boyer/nqthm/index.html"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Nqthm"],

Cell[TextData[{
  ButtonBox["[Omega]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Omega",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Omega"],
  " Omega. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at the University of Saarbr\[UDoubleDot]cken, directed by J. \
Siekmann",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www.ags.uni-sb.de/ omega",
    ButtonData:>{
      URL[ "http://www.ags.uni-sb.de/ omega"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Omega"],

Cell[TextData[{
  ButtonBox["[Otter]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Otter",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Otter"],
  " Otter. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at Argonne National Laboratories, directed by W. McCune",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www-unix.mcs.anl.gov/AR/otter",
    ButtonData:>{
      URL[ "http://www-unix.mcs.anl.gov/AR/otter"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Otter"],

Cell[TextData[{
  ButtonBox["[Quine63]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Quine63",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Quine63"],
  " ",
  "W. Quine",
  ". ",
  StyleBox["Set Theory and its Logic",
    FontSlant->"Italic"],
  ", ",
  "Belknap Press of Harvard University Press",
  ", ",
  "Cambridge, Massachusetts",
  ", ",
  "1963",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Quine63"],

Cell[TextData[{
  ButtonBox["[Reduce]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Reduce",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Reduce"],
  " Reduce. ",
  StyleBox["Developed by Tony Hearn",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www.uni-koeln.de/REDUCE",
    ButtonData:>{
      URL[ "http://www.uni-koeln.de/REDUCE"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Reduce"],

Cell[TextData[{
  ButtonBox["[Robi65]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Robi65",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Robi65"],
  " ",
  "J. A. Robinson",
  ". ",
  "A Machine-oriented Logic Based on the Resolution Principle",
  ". ",
  StyleBox["Journal ACM",
    FontSlant->"Italic"],
  ", ",
  "12",
  "(",
  "1",
  ")",
  ":",
  "23\[Dash]41",
  ", ",
  "January",
  " ",
  "1965",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Robi65"],

Cell[TextData[{
  ButtonBox["[RuWh10]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"RuWh10",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"RuWh10"],
  " B. Russell and A. Whitehead. ",
  StyleBox["Principia Mathematica",
    FontSlant->"Italic"],
  ", Cambridge University Press, 1910. Reprinted 1980. "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"RuWh10"],

Cell[TextData[{
  ButtonBox["[Setheo]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Setheo",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Setheo"],
  " Setheo. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at University of Munich",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://wwwjessen.informatik.tu-muenchen.de/ setheo",
    ButtonData:>{
      URL[ "http://wwwjessen.informatik.tu-muenchen.de/ setheo"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Setheo"],

Cell[TextData[{
  ButtonBox["[Spass]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Spass",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Spass"],
  " Spass. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at MPI Saarbr\[UDoubleDot]cken",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://spass.mpi-sb.mpg.de/index.html",
    ButtonData:>{
      URL[ "http://spass.mpi-sb.mpg.de/index.html"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Spass"],

Cell[TextData[{
  ButtonBox["[Subr93]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Subr93",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Subr93"],
  " ",
  "S. Subramanian",
  ". ",
  StyleBox["A Mechanized Framework for Specifying Problem Domains and \
Verifying Plans",
    FontSlant->"Italic"],
  ". ",
  "University of Austin, Texas",
  ", ",
  "1993",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Subr93"],

Cell[TextData[{
  ButtonBox["[Subr96]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Subr96",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Subr96"],
  " ",
  "S. Subramanian",
  ". ",
  "An interactive solution to the n x n mutilated checkerboard problem",
  ". ",
  StyleBox["Journal of Logic and Computation",
    FontSlant->"Italic"],
  ", ",
  "6",
  "(",
  "4",
  ")",
  ":",
  "573\[Dash]598",
  ", ",
  "August",
  " ",
  "1996",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Subr96"],

Cell[TextData[{
  ButtonBox["[SuSuTPTP]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"SuSuTPTP",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"SuSuTPTP"],
  " ",
  "G. Sutcliff and C. Suttner",
  ". ",
  "The TPTP Library for Automated Theorem Proving",
  ". ",
  ButtonBox["http://www.cs.miami.edu/ tptp",
    ButtonData:>{
      URL[ "http://www.cs.miami.edu/ tptp"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"SuSuTPTP"],

Cell[TextData[{
  ButtonBox["[TaZa71]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"TaZa71",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"TaZa71"],
  " ",
  "G. Takeuti and W.M. Zaring",
  ". ",
  StyleBox["Introduction to Axiomatic Set Theory",
    FontSlant->"Italic"],
  ", ",
  "series Graduate Texts in Mathematics 1",
  ". ",
  "Springer Verlag",
  ", ",
  "1971",
  ". ",
  "ISBN 0-387-05302-6",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"TaZa71"],

Cell[TextData[{
  ButtonBox["[Tomu98]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Tomu98",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Tomu98"],
  " ",
  "Elena Tomuta",
  ". ",
  StyleBox["An Architecture for Combining Provers and its Applications in the \
Theorema System",
    FontSlant->"Italic"],
  ". ",
  "The Research Institute for Symbolic Computation, Johannes Kepler \
University",
  ", ",
  "1998",
  ". ",
  "RISC report 98-14",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Tomu98"],

Cell[TextData[{
  ButtonBox["[Tps]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Tps",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Tps"],
  " Tps. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at Carnegie Mellon University, directed by P. Andrews",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://gtps.math.cmu.edu/tps-about.html",
    ButtonData:>{
      URL[ "http://gtps.math.cmu.edu/tps-about.html"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Tps"],

Cell[TextData[{
  ButtonBox["[TVM98]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"TVM98",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"TVM98"],
  " ",
  "E. Tomuta and D. Vasaru and M. Marin",
  ". ",
  "Handling Provers Cooperation in Theorema",
  ". ",
  "In ",
  "B. Buchberger and T. Jebelean, editor, ",
  StyleBox["Proceedings of the Second International Theorema Workshop",
    FontSlant->"Italic"],
  ", ",
  "pages 55\[Dash]75",
  ", ",
  "1998",
  ". ",
  "RISC report 98-10",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"TVM98"],

Cell[TextData[{
  ButtonBox["[Vasa00PhD]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Vasa00PhD",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Vasa00PhD"],
  " ",
  "D. Vasaru-Dupr\[EGrave]",
  ". ",
  StyleBox["Automated Theorem Proving by Integrating Proving, Solving and \
Computing",
    FontSlant->"Italic"],
  ". ",
  "RISC Institute",
  ", ",
  "May",
  " ",
  "2000",
  ". ",
  "RISC report 00-19",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Vasa00PhD"],

Cell[TextData[{
  ButtonBox["[Vogt00]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Vogt00",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Vogt00"],
  " ",
  "C. Vogt",
  ". ",
  "Demo of the MIZAR System",
  ". ",
  "Seminar talk in the frame of the Theorema seminar",
  ", ",
  "2000",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Vogt00"],

Cell[TextData[{
  ButtonBox["[Waldmeister]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Waldmeister",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Waldmeister"],
  " Waldmeister. ",
  StyleBox["Developed",
    FontSlant->"Italic"],
  StyleBox[" at University of Kaiserslautern",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://agent.informatik.uni-kl.de/waldmeister",
    ButtonData:>{
      URL[ "http://agent.informatik.uni-kl.de/waldmeister"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Waldmeister"],

Cell[TextData[{
  ButtonBox["[Wind92]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Wind92",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Wind92"],
  " W. Windsteiger. Gr\[ODoubleDot]bner Bases: A Characterization by Syzygy \
Completeness and an Implementation. RISC-Linz, University of Linz, Austria, \
1992. "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Wind92"],

Cell[TextData[{
  ButtonBox["[Wind96]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Wind96",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Wind96"],
  " W. Windsteiger. Algorithmische Mathematik VI. Lecture notes for the \
mathematics course in the sixth semester at the Fachhochschule for Software \
Engineering in Hagenberg, Austria, in german, 1996. "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Wind96"],

Cell[TextData[{
  ButtonBox["[Wind99a]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Wind99a",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Wind99a"],
  " ",
  "W. Windsteiger",
  ". ",
  "Building up Hierarchical Mathematical Domains Using Functors in \
Mathematica",
  ". ",
  "In ",
  "A. Armando and T. Jebelean, editor, ",
  StyleBox["Electronic Notes in Theoretical Computer Science",
    FontSlant->"Italic"],
  ", ",
  "volume 23-3 of ",
  "pages 83\[Dash]102",
  ", ",
  "Elsevier",
  ", ",
  "1999",
  ". ",
  "Calculemus 99 Workshop, Trento, Italy",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Wind99a"],

Cell[TextData[{
  ButtonBox["[Wind99b]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Wind99b",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Wind99b"],
  " ",
  "W. Windsteiger",
  ". ",
  "Theorema: Overview on Using the System and Details on Composing \
Hierarchical Knowledge Bases",
  ". ",
  "15",
  ", ",
  "RISC Institute",
  ", ",
  "1999",
  ". ",
  "Talk at the School on Logic and Computation, Edinburgh, England",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Wind99b"],

Cell[TextData[{
  ButtonBox["[Wind01c]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Wind01c",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Wind01c"],
  " ",
  "W. Windsteiger",
  ". ",
  "Exploring Equivalence Relations and Partitions using the Theorema Set \
Theory Prover",
  ". ",
  "??",
  ", ",
  "RISC Institute",
  ", ",
  "May",
  " ",
  "2001",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Wind01c"],

Cell[TextData[{
  ButtonBox["[Wolf96]",
    ButtonFunction:>(CompoundExpression[ 
        Needs[ "AuthorTools`BibliographyTools`"], 
        Symbol[ 
        "AuthorTools`BibliographyTools`Private`EditReferenceSC"][ #2]]&),
    ButtonEvaluator->Automatic,
    ButtonData:>"Wolf96",
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->"Wolf96"],
  " ",
  "Stephen Wolfram",
  ". ",
  StyleBox["The Mathematica Book",
    FontSlant->"Italic"],
  ", ",
  "Wolfram Media/Cambridge University Press",
  ", ",
  "3rd edition",
  ", ",
  "1996",
  ". "
}], "SingleParagraph",
  CellMargins->{{10, Inherited}, {Inherited, Inherited}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Wolf96"]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowToolbars->"EditBar",
WindowSize->{721, 669},
WindowMargins->{{Automatic, 225}, {Automatic, 161}},
PrintingStartingPageNumber->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page", CounterFunction :> RomanNumeral]}], 
        "PageNumber"], Inherited, None}, {None, Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page", CounterFunction :> RomanNumeral]}], 
        "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{79.1875, 79.1875}, {108, 108}},
"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->True,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", \
"wwindste", "Diss", "Main"}, "Conclusion.nb.ps", CharacterEncoding -> \
"ISO8859-1"],
"Magnification"->1},
StyleDefinitions -> "TheoremaSmartColors.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1960, 59, 187, 3, 59, "Section",
      CounterAssignments->{{"Section", 15}, {"TableHead", 0}, {
          "Equation", 0}, {"Figure", 0}, {"Subsection", 0}, {
          "Subsubsection", 0}},
      CellTags->"c:1"]},
  "References"->{
    Cell[4501, 126, 190, 4, 59, "Section",
      PageBreakAbove->True,
      CellTags->{"References", "c:2"}]},
  "c:2"->{
    Cell[4501, 126, 190, 4, 59, "Section",
      PageBreakAbove->True,
      CellTags->{"References", "c:2"}]},
  "AINP92"->{
    Cell[4694, 132, 774, 30, 50, "SingleParagraph",
      CellTags->"AINP92"]},
  "Analytica"->{
    Cell[5471, 164, 801, 23, 50, "SingleParagraph",
      CellTags->"Analytica"]},
  "Andr86"->{
    Cell[6275, 189, 806, 29, 50, "SingleParagraph",
      CellTags->"Andr86"]},
  "AnBi96"->{
    Cell[7084, 220, 987, 37, 88, "SingleParagraph",
      CellTags->"AnBi96"]},
  "APIK86"->{
    Cell[8074, 259, 894, 35, 69, "SingleParagraph",
      CellTags->"APIK86"]},
  "Axiom"->{
    Cell[8971, 296, 819, 25, 31, "SingleParagraph",
      CellTags->"Axiom"]},
  "Banc95"->{
    Cell[9793, 323, 821, 32, 50, "SingleParagraph",
      CellTags->"Banc95"]},
  "Beli99a"->{
    Cell[10617, 357, 796, 29, 50, "SingleParagraph",
      CellTags->"Beli99a"]},
  "Beli99b"->{
    Cell[11416, 388, 743, 28, 50, "SingleParagraph",
      CellTags->"Beli99b"]},
  "BeFr68"->{
    Cell[12162, 418, 771, 28, 50, "SingleParagraph",
      CellTags->"BeFr68"]},
  "Buch65"->{
    Cell[12936, 448, 783, 27, 50, "SingleParagraph",
      CellTags->"Buch65"]},
  "Buch91"->{
    Cell[13722, 477, 634, 23, 31, "SingleParagraph",
      CellTags->"Buch91"]},
  "Buch93"->{
    Cell[14359, 502, 903, 32, 69, "SingleParagraph",
      CellTags->"Buch93"]},
  "Buch96"->{
    Cell[15265, 536, 852, 25, 69, "SingleParagraph",
      CellTags->"Buch96"]},
  "Buch96a"->{
    Cell[16120, 563, 935, 34, 69, "SingleParagraph",
      CellTags->"Buch96a"]},
  "Buch96b"->{
    Cell[17058, 599, 822, 29, 50, "SingleParagraph",
      CellTags->"Buch96b"]},
  "Buch97"->{
    Cell[17883, 630, 946, 36, 69, "SingleParagraph",
      CellTags->"Buch97"]},
  "Buch98"->{
    Cell[18832, 668, 811, 30, 50, "SingleParagraph",
      CellTags->"Buch98"]},
  "Buch99i"->{
    Cell[19646, 700, 723, 24, 50, "SingleParagraph",
      CellTags->"Buch99i"]},
  "Buch99k"->{
    Cell[20372, 726, 899, 33, 69, "SingleParagraph",
      CellTags->"Buch99k"]},
  "Buch99v"->{
    Cell[21274, 761, 702, 23, 50, "SingleParagraph",
      CellTags->"Buch99v"]},
  "Buch00m"->{
    Cell[21979, 786, 663, 23, 50, "SingleParagraph",
      CellTags->"Buch00m"]},
  "Buch00n"->{
    Cell[22645, 811, 669, 23, 50, "SingleParagraph",
      CellTags->"Buch00n"]},
  "BuEtal99b"->{
    Cell[23317, 836, 862, 30, 69, "SingleParagraph",
      CellTags->"BuEtal99b"]},
  "BuEtal00a"->{
    Cell[24182, 868, 986, 30, 88, "SingleParagraph",
      CellTags->"BuEtal00a"]},
  "BuEtAl00b"->{
    Cell[25171, 900, 729, 24, 50, "SingleParagraph",
      CellTags->"BuEtAl00b"]},
  "BuNa00a"->{
    Cell[25903, 926, 783, 26, 50, "SingleParagraph",
      CellTags->"BuNa00a"]},
  "BuWi98a"->{
    Cell[26689, 954, 774, 26, 50, "SingleParagraph",
      CellTags->"BuWi98a"]},
  "BuIr96"->{
    Cell[27466, 982, 858, 36, 50, "SingleParagraph",
      CellTags->"BuIr96"]},
  "Chur41"->{
    Cell[28327, 1020, 685, 28, 31, "SingleParagraph",
      CellTags->"Chur41"]},
  "Coll75"->{
    Cell[29015, 1050, 873, 33, 69, "SingleParagraph",
      CellTags->"Coll75"]},
  "Coq"->{
    Cell[29891, 1085, 764, 25, 31, "SingleParagraph",
      CellTags->"Coq"]},
  "CuFe74"->{
    Cell[30658, 1112, 702, 26, 50, "SingleParagraph",
      CellTags->"CuFe74"]},
  "Curry63"->{
    Cell[31363, 1140, 741, 26, 50, "SingleParagraph",
      CellTags->"Curry63"]},
  "Derive"->{
    Cell[32107, 1168, 912, 28, 50, "SingleParagraph",
      CellTags->"Derive"]},
  "Ebbi79"->{
    Cell[33022, 1198, 753, 28, 50, "SingleParagraph",
      CellTags->"Ebbi79"]},
  "EFT92"->{
    Cell[33778, 1228, 802, 28, 50, "SingleParagraph",
      CellTags->"EFT92"]},
  "Eqp"->{
    Cell[34583, 1258, 815, 25, 50, "SingleParagraph",
      CellTags->"Eqp"]},
  "Form00"->{
    Cell[35401, 1285, 711, 24, 50, "SingleParagraph",
      CellTags->"Form00"]},
  "Frae76"->{
    Cell[36115, 1311, 763, 28, 50, "SingleParagraph",
      CellTags->"Frae76"]},
  "Gall86"->{
    Cell[36881, 1341, 709, 26, 50, "SingleParagraph",
      CellTags->"Gall86"]},
  "Gap"->{
    Cell[37593, 1369, 795, 25, 31, "SingleParagraph",
      CellTags->"Gap"]},
  "Goed40"->{
    Cell[38391, 1396, 755, 25, 50, "SingleParagraph",
      CellTags->"Goed40"]},
  "Hol"->{
    Cell[39149, 1423, 825, 25, 50, "SingleParagraph",
      CellTags->"Hol"]},
  "JeKo00a"->{
    Cell[39977, 1450, 939, 33, 69, "SingleParagraph",
      CellTags->"JeKo00a"]},
  "JeKo00b"->{
    Cell[40919, 1485, 802, 28, 50, "SingleParagraph",
      CellTags->"JeKo00b"]},
  "Konev99a"->{
    Cell[41724, 1515, 655, 23, 50, "SingleParagraph",
      CellTags->"Konev99a"]},
  "Krif98"->{
    Cell[42382, 1540, 804, 30, 50, "SingleParagraph",
      CellTags->"Krif98"]},
  "Mace"->{
    Cell[43189, 1572, 822, 25, 50, "SingleParagraph",
      CellTags->"Mace"]},
  "Macsyma"->{
    Cell[44014, 1599, 832, 25, 50, "SingleParagraph",
      CellTags->"Macsyma"]},
  "Maed97"->{
    Cell[44849, 1626, 702, 28, 31, "SingleParagraph",
      CellTags->"Maed97"]},
  "Magma"->{
    Cell[45554, 1656, 830, 25, 50, "SingleParagraph",
      CellTags->"Magma"]},
  "Manna74"->{
    Cell[46387, 1683, 700, 26, 50, "SingleParagraph",
      CellTags->"Manna74"]},
  "Maple"->{
    Cell[47090, 1711, 798, 25, 31, "SingleParagraph",
      CellTags->"Maple"]},
  "Mathematica"->{
    Cell[47891, 1738, 824, 25, 50, "SingleParagraph",
      CellTags->"Mathematica"]},
  "McCarthy64"->{
    Cell[48718, 1765, 646, 23, 31, "SingleParagraph",
      CellTags->"McCarthy64"]},
  "McCarthy95"->{
    Cell[49367, 1790, 826, 32, 50, "SingleParagraph",
      CellTags->"McCarthy95"]},
  "McCune94"->{
    Cell[50196, 1824, 776, 25, 69, "SingleParagraph",
      CellTags->"McCune94"]},
  "McCune94a"->{
    Cell[50975, 1851, 665, 25, 31, "SingleParagraph",
      CellTags->"McCune94a"]},
  "McCune95"->{
    Cell[51643, 1878, 741, 30, 50, "SingleParagraph",
      CellTags->"McCune95"]},
  "McCuPa96"->{
    Cell[52387, 1910, 806, 28, 50, "SingleParagraph",
      CellTags->"McCuPa96"]},
  "Mizar"->{
    Cell[53196, 1940, 815, 25, 31, "SingleParagraph",
      CellTags->"Mizar"]},
  "Naka00PhD"->{
    Cell[54014, 1967, 706, 26, 50, "SingleParagraph",
      CellTags->"Naka00PhD"]},
  "Nqthm"->{
    Cell[54723, 1995, 845, 24, 50, "SingleParagraph",
      CellTags->"Nqthm"]},
  "Omega"->{
    Cell[55571, 2021, 835, 26, 50, "SingleParagraph",
      CellTags->"Omega"]},
  "Otter"->{
    Cell[56409, 2049, 829, 25, 50, "SingleParagraph",
      CellTags->"Otter"]},
  "Quine63"->{
    Cell[57241, 2076, 713, 26, 50, "SingleParagraph",
      CellTags->"Quine63"]},
  "Reduce"->{
    Cell[57957, 2104, 739, 23, 31, "SingleParagraph",
      CellTags->"Reduce"]},
  "Robi65"->{
    Cell[58699, 2129, 762, 33, 50, "SingleParagraph",
      CellTags->"Robi65"]},
  "RuWh10"->{
    Cell[59464, 2164, 652, 18, 50, "SingleParagraph",
      CellTags->"RuWh10"]},
  "Setheo"->{
    Cell[60119, 2184, 830, 25, 31, "SingleParagraph",
      CellTags->"Setheo"]},
  "Spass"->{
    Cell[60952, 2211, 806, 25, 31, "SingleParagraph",
      CellTags->"Spass"]},
  "Subr93"->{
    Cell[61761, 2238, 714, 25, 50, "SingleParagraph",
      CellTags->"Subr93"]},
  "Subr96"->{
    Cell[62478, 2265, 792, 33, 50, "SingleParagraph",
      CellTags->"Subr96"]},
  "SuSuTPTP"->{
    Cell[63273, 2300, 765, 24, 50, "SingleParagraph",
      CellTags->"SuSuTPTP"]},
  "TaZa71"->{
    Cell[64041, 2326, 759, 28, 50, "SingleParagraph",
      CellTags->"TaZa71"]},
  "Tomu98"->{
    Cell[64803, 2356, 801, 28, 50, "SingleParagraph",
      CellTags->"Tomu98"]},
  "Tps"->{
    Cell[65607, 2386, 823, 25, 50, "SingleParagraph",
      CellTags->"Tps"]},
  "TVM98"->{
    Cell[66433, 2413, 843, 30, 69, "SingleParagraph",
      CellTags->"TVM98"]},
  "Vasa00PhD"->{
    Cell[67279, 2445, 767, 29, 50, "SingleParagraph",
      CellTags->"Vasa00PhD"]},
  "Vogt00"->{
    Cell[68049, 2476, 643, 23, 31, "SingleParagraph",
      CellTags->"Vogt00"]},
  "Waldmeister"->{
    Cell[68695, 2501, 853, 25, 50, "SingleParagraph",
      CellTags->"Waldmeister"]},
  "Wind92"->{
    Cell[69551, 2528, 661, 17, 50, "SingleParagraph",
      CellTags->"Wind92"]},
  "Wind96"->{
    Cell[70215, 2547, 703, 17, 50, "SingleParagraph",
      CellTags->"Wind96"]},
  "Wind99a"->{
    Cell[70921, 2566, 918, 34, 69, "SingleParagraph",
      CellTags->"Wind99a"]},
  "Wind99b"->{
    Cell[71842, 2602, 782, 28, 50, "SingleParagraph",
      CellTags->"Wind99b"]},
  "Wind01c"->{
    Cell[72627, 2632, 712, 28, 50, "SingleParagraph",
      CellTags->"Wind01c"]},
  "Wolf96"->{
    Cell[73342, 2662, 698, 26, 50, "SingleParagraph",
      CellTags->"Wolf96"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 75502, 2728},
  {"References", 75745, 2734},
  {"c:2", 75868, 2738},
  {"AINP92", 75994, 2742},
  {"Analytica", 76091, 2745},
  {"Andr86", 76188, 2748},
  {"AnBi96", 76282, 2751},
  {"APIK86", 76376, 2754},
  {"Axiom", 76469, 2757},
  {"Banc95", 76562, 2760},
  {"Beli99a", 76657, 2763},
  {"Beli99b", 76754, 2766},
  {"BeFr68", 76850, 2769},
  {"Buch65", 76945, 2772},
  {"Buch91", 77040, 2775},
  {"Buch93", 77135, 2778},
  {"Buch96", 77230, 2781},
  {"Buch96a", 77326, 2784},
  {"Buch96b", 77423, 2787},
  {"Buch97", 77519, 2790},
  {"Buch98", 77614, 2793},
  {"Buch99i", 77710, 2796},
  {"Buch99k", 77807, 2799},
  {"Buch99v", 77904, 2802},
  {"Buch00m", 78001, 2805},
  {"Buch00n", 78098, 2808},
  {"BuEtal99b", 78197, 2811},
  {"BuEtal00a", 78298, 2814},
  {"BuEtAl00b", 78399, 2817},
  {"BuNa00a", 78498, 2820},
  {"BuWi98a", 78595, 2823},
  {"BuIr96", 78691, 2826},
  {"Chur41", 78786, 2829},
  {"Coll75", 78882, 2832},
  {"Coq", 78975, 2835},
  {"CuFe74", 79068, 2838},
  {"Curry63", 79165, 2841},
  {"Derive", 79262, 2844},
  {"Ebbi79", 79358, 2847},
  {"EFT92", 79453, 2850},
  {"Eqp", 79545, 2853},
  {"Form00", 79638, 2856},
  {"Frae76", 79734, 2859},
  {"Gall86", 79830, 2862},
  {"Gap", 79923, 2865},
  {"Goed40", 80016, 2868},
  {"Hol", 80109, 2871},
  {"JeKo00a", 80203, 2874},
  {"JeKo00b", 80301, 2877},
  {"Konev99a", 80400, 2880},
  {"Krif98", 80498, 2883},
  {"Mace", 80592, 2886},
  {"Macsyma", 80687, 2889},
  {"Maed97", 80784, 2892},
  {"Magma", 80879, 2895},
  {"Manna74", 80975, 2898},
  {"Maple", 81071, 2901},
  {"Mathematica", 81171, 2904},
  {"McCarthy64", 81276, 2907},
  {"McCarthy95", 81380, 2910},
  {"McCune94", 81482, 2913},
  {"McCune94a", 81583, 2916},
  {"McCune95", 81684, 2919},
  {"McCuPa96", 81784, 2922},
  {"Mizar", 81881, 2925},
  {"Naka00PhD", 81979, 2928},
  {"Nqthm", 82077, 2931},
  {"Omega", 82171, 2934},
  {"Otter", 82265, 2937},
  {"Quine63", 82361, 2940},
  {"Reduce", 82458, 2943},
  {"Robi65", 82554, 2946},
  {"RuWh10", 82650, 2949},
  {"Setheo", 82746, 2952},
  {"Spass", 82841, 2955},
  {"Subr93", 82936, 2958},
  {"Subr96", 83032, 2961},
  {"SuSuTPTP", 83130, 2964},
  {"TaZa71", 83228, 2967},
  {"Tomu98", 83324, 2970},
  {"Tps", 83417, 2973},
  {"TVM98", 83509, 2976},
  {"Vasa00PhD", 83607, 2979},
  {"Vogt00", 83706, 2982},
  {"Waldmeister", 83807, 2985},
  {"Wind92", 83908, 2988},
  {"Wind96", 84004, 2991},
  {"Wind99a", 84101, 2994},
  {"Wind99b", 84199, 2997},
  {"Wind01c", 84297, 3000},
  {"Wolf96", 84394, 3003}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 230, 5, 42, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1960, 59, 187, 3, 59, "Section",
  CounterAssignments->{{"Section", 15}, {"TableHead", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsection", 0}, {"Subsubsection", 0}},
  CellTags->"c:1"],
Cell[2150, 64, 968, 16, 152, "FirstParagraph"],
Cell[3121, 82, 51, 0, 31, "Text"],
Cell[3175, 84, 264, 6, 46, "ItemizedText"],
Cell[3442, 92, 193, 6, 27, "ItemizedText"],
Cell[3638, 100, 95, 3, 27, "ItemizedText"],
Cell[3736, 105, 588, 11, 103, "ItemizedText"],
Cell[4327, 118, 137, 3, 27, "ItemizedText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4501, 126, 190, 4, 59, "Section",
  PageBreakAbove->True,
  CellTags->{"References", "c:2"}],
Cell[4694, 132, 774, 30, 50, "SingleParagraph",
  CellTags->"AINP92"],
Cell[5471, 164, 801, 23, 50, "SingleParagraph",
  CellTags->"Analytica"],
Cell[6275, 189, 806, 29, 50, "SingleParagraph",
  CellTags->"Andr86"],
Cell[7084, 220, 987, 37, 88, "SingleParagraph",
  CellTags->"AnBi96"],
Cell[8074, 259, 894, 35, 69, "SingleParagraph",
  CellTags->"APIK86"],
Cell[8971, 296, 819, 25, 31, "SingleParagraph",
  CellTags->"Axiom"],
Cell[9793, 323, 821, 32, 50, "SingleParagraph",
  CellTags->"Banc95"],
Cell[10617, 357, 796, 29, 50, "SingleParagraph",
  CellTags->"Beli99a"],
Cell[11416, 388, 743, 28, 50, "SingleParagraph",
  CellTags->"Beli99b"],
Cell[12162, 418, 771, 28, 50, "SingleParagraph",
  CellTags->"BeFr68"],
Cell[12936, 448, 783, 27, 50, "SingleParagraph",
  CellTags->"Buch65"],
Cell[13722, 477, 634, 23, 31, "SingleParagraph",
  CellTags->"Buch91"],
Cell[14359, 502, 903, 32, 69, "SingleParagraph",
  CellTags->"Buch93"],
Cell[15265, 536, 852, 25, 69, "SingleParagraph",
  CellTags->"Buch96"],
Cell[16120, 563, 935, 34, 69, "SingleParagraph",
  CellTags->"Buch96a"],
Cell[17058, 599, 822, 29, 50, "SingleParagraph",
  CellTags->"Buch96b"],
Cell[17883, 630, 946, 36, 69, "SingleParagraph",
  CellTags->"Buch97"],
Cell[18832, 668, 811, 30, 50, "SingleParagraph",
  CellTags->"Buch98"],
Cell[19646, 700, 723, 24, 50, "SingleParagraph",
  CellTags->"Buch99i"],
Cell[20372, 726, 899, 33, 69, "SingleParagraph",
  CellTags->"Buch99k"],
Cell[21274, 761, 702, 23, 50, "SingleParagraph",
  CellTags->"Buch99v"],
Cell[21979, 786, 663, 23, 50, "SingleParagraph",
  CellTags->"Buch00m"],
Cell[22645, 811, 669, 23, 50, "SingleParagraph",
  CellTags->"Buch00n"],
Cell[23317, 836, 862, 30, 69, "SingleParagraph",
  CellTags->"BuEtal99b"],
Cell[24182, 868, 986, 30, 88, "SingleParagraph",
  CellTags->"BuEtal00a"],
Cell[25171, 900, 729, 24, 50, "SingleParagraph",
  CellTags->"BuEtAl00b"],
Cell[25903, 926, 783, 26, 50, "SingleParagraph",
  CellTags->"BuNa00a"],
Cell[26689, 954, 774, 26, 50, "SingleParagraph",
  CellTags->"BuWi98a"],
Cell[27466, 982, 858, 36, 50, "SingleParagraph",
  CellTags->"BuIr96"],
Cell[28327, 1020, 685, 28, 31, "SingleParagraph",
  CellTags->"Chur41"],
Cell[29015, 1050, 873, 33, 69, "SingleParagraph",
  CellTags->"Coll75"],
Cell[29891, 1085, 764, 25, 31, "SingleParagraph",
  CellTags->"Coq"],
Cell[30658, 1112, 702, 26, 50, "SingleParagraph",
  CellTags->"CuFe74"],
Cell[31363, 1140, 741, 26, 50, "SingleParagraph",
  CellTags->"Curry63"],
Cell[32107, 1168, 912, 28, 50, "SingleParagraph",
  CellTags->"Derive"],
Cell[33022, 1198, 753, 28, 50, "SingleParagraph",
  CellTags->"Ebbi79"],
Cell[33778, 1228, 802, 28, 50, "SingleParagraph",
  CellTags->"EFT92"],
Cell[34583, 1258, 815, 25, 50, "SingleParagraph",
  CellTags->"Eqp"],
Cell[35401, 1285, 711, 24, 50, "SingleParagraph",
  CellTags->"Form00"],
Cell[36115, 1311, 763, 28, 50, "SingleParagraph",
  CellTags->"Frae76"],
Cell[36881, 1341, 709, 26, 50, "SingleParagraph",
  CellTags->"Gall86"],
Cell[37593, 1369, 795, 25, 31, "SingleParagraph",
  CellTags->"Gap"],
Cell[38391, 1396, 755, 25, 50, "SingleParagraph",
  CellTags->"Goed40"],
Cell[39149, 1423, 825, 25, 50, "SingleParagraph",
  CellTags->"Hol"],
Cell[39977, 1450, 939, 33, 69, "SingleParagraph",
  CellTags->"JeKo00a"],
Cell[40919, 1485, 802, 28, 50, "SingleParagraph",
  CellTags->"JeKo00b"],
Cell[41724, 1515, 655, 23, 50, "SingleParagraph",
  CellTags->"Konev99a"],
Cell[42382, 1540, 804, 30, 50, "SingleParagraph",
  CellTags->"Krif98"],
Cell[43189, 1572, 822, 25, 50, "SingleParagraph",
  CellTags->"Mace"],
Cell[44014, 1599, 832, 25, 50, "SingleParagraph",
  CellTags->"Macsyma"],
Cell[44849, 1626, 702, 28, 31, "SingleParagraph",
  CellTags->"Maed97"],
Cell[45554, 1656, 830, 25, 50, "SingleParagraph",
  CellTags->"Magma"],
Cell[46387, 1683, 700, 26, 50, "SingleParagraph",
  CellTags->"Manna74"],
Cell[47090, 1711, 798, 25, 31, "SingleParagraph",
  CellTags->"Maple"],
Cell[47891, 1738, 824, 25, 50, "SingleParagraph",
  CellTags->"Mathematica"],
Cell[48718, 1765, 646, 23, 31, "SingleParagraph",
  CellTags->"McCarthy64"],
Cell[49367, 1790, 826, 32, 50, "SingleParagraph",
  CellTags->"McCarthy95"],
Cell[50196, 1824, 776, 25, 69, "SingleParagraph",
  CellTags->"McCune94"],
Cell[50975, 1851, 665, 25, 31, "SingleParagraph",
  CellTags->"McCune94a"],
Cell[51643, 1878, 741, 30, 50, "SingleParagraph",
  CellTags->"McCune95"],
Cell[52387, 1910, 806, 28, 50, "SingleParagraph",
  CellTags->"McCuPa96"],
Cell[53196, 1940, 815, 25, 31, "SingleParagraph",
  CellTags->"Mizar"],
Cell[54014, 1967, 706, 26, 50, "SingleParagraph",
  CellTags->"Naka00PhD"],
Cell[54723, 1995, 845, 24, 50, "SingleParagraph",
  CellTags->"Nqthm"],
Cell[55571, 2021, 835, 26, 50, "SingleParagraph",
  CellTags->"Omega"],
Cell[56409, 2049, 829, 25, 50, "SingleParagraph",
  CellTags->"Otter"],
Cell[57241, 2076, 713, 26, 50, "SingleParagraph",
  CellTags->"Quine63"],
Cell[57957, 2104, 739, 23, 31, "SingleParagraph",
  CellTags->"Reduce"],
Cell[58699, 2129, 762, 33, 50, "SingleParagraph",
  CellTags->"Robi65"],
Cell[59464, 2164, 652, 18, 50, "SingleParagraph",
  CellTags->"RuWh10"],
Cell[60119, 2184, 830, 25, 31, "SingleParagraph",
  CellTags->"Setheo"],
Cell[60952, 2211, 806, 25, 31, "SingleParagraph",
  CellTags->"Spass"],
Cell[61761, 2238, 714, 25, 50, "SingleParagraph",
  CellTags->"Subr93"],
Cell[62478, 2265, 792, 33, 50, "SingleParagraph",
  CellTags->"Subr96"],
Cell[63273, 2300, 765, 24, 50, "SingleParagraph",
  CellTags->"SuSuTPTP"],
Cell[64041, 2326, 759, 28, 50, "SingleParagraph",
  CellTags->"TaZa71"],
Cell[64803, 2356, 801, 28, 50, "SingleParagraph",
  CellTags->"Tomu98"],
Cell[65607, 2386, 823, 25, 50, "SingleParagraph",
  CellTags->"Tps"],
Cell[66433, 2413, 843, 30, 69, "SingleParagraph",
  CellTags->"TVM98"],
Cell[67279, 2445, 767, 29, 50, "SingleParagraph",
  CellTags->"Vasa00PhD"],
Cell[68049, 2476, 643, 23, 31, "SingleParagraph",
  CellTags->"Vogt00"],
Cell[68695, 2501, 853, 25, 50, "SingleParagraph",
  CellTags->"Waldmeister"],
Cell[69551, 2528, 661, 17, 50, "SingleParagraph",
  CellTags->"Wind92"],
Cell[70215, 2547, 703, 17, 50, "SingleParagraph",
  CellTags->"Wind96"],
Cell[70921, 2566, 918, 34, 69, "SingleParagraph",
  CellTags->"Wind99a"],
Cell[71842, 2602, 782, 28, 50, "SingleParagraph",
  CellTags->"Wind99b"],
Cell[72627, 2632, 712, 28, 50, "SingleParagraph",
  CellTags->"Wind01c"],
Cell[73342, 2662, 698, 26, 50, "SingleParagraph",
  CellTags->"Wolf96"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

