(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     60318,       1542]*)
(*NotebookOutlinePosition[     62114,       1597]*)
(*  CellTagsIndexPosition[     62020,       1590]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[ButtonBox["\[UpperLeftArrow]",
  ButtonData:>{"MasterTOC.nb", None},
  ButtonStyle->"Navigation",
  ButtonNote->"Table of Contents"]], "SingleParagraph",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  CellTags->"c:1"],

Cell[TextData[{
  "In this thesis we present a Set Theory prover within the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system. ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " is a mathematical computing environment that aims at being a support for \
mathematicians during ",
  StyleBox["all phases",
    FontSlant->"Italic"],
  " of mathematical work. While special areas of mathematics developed \
powerful computer systems tailored towards applications in special areas, \
there is now a growing awareness for the necessity of reuniting some fields \
of mathematics that have drifted apart during the last decades. Certainly, \
the areas of ",
  StyleBox["computer algebra",
    FontSlant->"Italic"],
  " and ",
  StyleBox["automated theorem proving",
    FontSlant->"Italic"],
  " are two examples of nearly separated fields of science with very powerful \
software systems available in either of them. Another instance of the same \
phenomenon are the quasi disjoint worlds of ",
  StyleBox["symbolic computation",
    FontSlant->"Italic"],
  " and ",
  StyleBox["numerical mathematics",
    FontSlant->"Italic"],
  "."
}], "FirstParagraph"],

Cell[TextData[{
  "The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system, which is the outcome of the work done in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " project group directed by Bruno Buchberger at the RISC Institute in \
Hagenberg, Austria, is an attempt to bridge the gap between computer algebra \
(CA) and automated theorem proving (ATP). In both fields, there exist \
sophisticated software packages:"
}], "Text"],

Cell[TextData[{
  StyleBox["Computer Algebra Systems (CAS)",
    FontWeight->"Bold"],
  ", sometimes also addressed as ",
  StyleBox["Symbolic Computation Systems",
    FontSlant->"Italic"],
  ", provide a wide range of algorithms from CA, such as symbolically solving \
systems of polynomial equations, symbolic differentiation and integration, \
symbolically solving differential equations, simplification of terms, or \
factorization of polynomials combined with numerical variants of some of the \
symbolic algorithms and combined also with graphics facilities for plotting \
functions in 2D and 3D. The most commonly used systems are [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Mathematica",
            ButtonData:>"Mathematica",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Mathematica, , developed at Wolfram Research Inc., directed by \
S. Wolfram"],
          "Text"], TraditionalForm]],
    ButtonBoxOptions->{ButtonFrame->"None"}],
  "]",
  ", [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Maple",
            ButtonData:>"Maple",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Maple, , developed at University of Waterloo, directed by G. \
Gonnet"],
          "Text"], TraditionalForm]]],
  "], [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Axiom",
            ButtonData:>"Axiom",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Axiom, , developed by IBM Research, directed by R. Jenks"],
          "Text"], TraditionalForm]]],
  "], [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Derive",
            ButtonData:>"Derive",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Derive, , developed at the University of Hawaii, directed by \
D. Stoutemyer"],
          "Text"], TraditionalForm]]],
  "], [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Macsyma",
            ButtonData:>"Macsyma",
            ButtonStyle->"RefLink",
            ButtonNote->"Macsyma, , developed by the MATH lab group at MIT"],
          "Text"], TraditionalForm]]],
  "], [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Magma",
            ButtonData:>"Magma",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Magma, , developed at University of Sydney, directed by J. \
Cannon"],
          "Text"], TraditionalForm]]],
  "], [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Gap",
            ButtonData:>"Gap",
            ButtonStyle->"RefLink",
            ButtonNote->"Gap, , developed at University of Aachen"],
          "Text"], TraditionalForm]]],
  "], and [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Reduce",
            ButtonData:>"Reduce",
            ButtonStyle->"RefLink",
            ButtonNote->"Reduce, , devoleped by Tony Hearn"],
          "Text"], TraditionalForm]]],
  "]. We do neither want to go into details about the individual systems, nor \
should the order in the enumeration allow any conclusions on the quality of \
the systems. Naming Mathematica in the first rank is due to personal \
preference and the fact that Mathematica is certainly to most successful \
system from the commercial point of view. All of the systems have in common \
that they serve as algorithm libraries that allow powerful computations, \
where most of the systems can be considered as ",
  StyleBox["general purpose systems",
    FontSlant->"Italic"],
  " in the sense that they offer \"all of computer algebra\". An exception \
is, maybe, Magma, which evolved from former Cayley, a software system \
specialized for group theory."
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["Theorem Proving Systems (TPS)",
    FontWeight->"Bold"],
  ", on the other hand, are typically implementations of certain techniques \
developed in the area of automated theorem proving. Compared to CAS, which \
are widely used also among non\[Dash]mathematicians such as physicists, \
engineers, and people in financial business, TPS have not yet managed to \
penetrate non\[Dash]mathematical communities considerably. They are used \
mainly among scientist working in the area of theorem proving in one or the \
other way. Consequently, they offer poor facilities concerning user front\
\[Dash]end and user friendliness in general. As opposed to CAS, the theorem \
proving systems are method\[Dash]oriented in the sense that each of the \
systems is based on ",
  StyleBox["one method",
    FontSlant->"Italic"],
  " for proving implemented in the system. There are many systems around \
meanwhile, we want to mention [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Otter",
            ButtonData:>"Otter",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Otter, , developed at Argonne National Laboratories, directed \
by W. McCune"],
          "Text"], TraditionalForm]]],
  "], [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Setheo",
            ButtonData:>"Setheo",
            ButtonStyle->"RefLink",
            ButtonNote->"Setheo, , developed at University of Munich"],
          "Text"], TraditionalForm]]],
  "], [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Spass",
            ButtonData:>"Spass",
            ButtonStyle->"RefLink",
            ButtonNote->"Spass, , developed at MPI Saarbr\[UDoubleDot]cken"],
          "Text"], TraditionalForm]]],
  "], and [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Waldmeister",
            ButtonData:>"Waldmeister",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Waldmeister, , developed at University of Kaiserslautern"],
          "Text"], TraditionalForm]]],
  "] specialized on proving in ",
  StyleBox["first order logic",
    FontSlant->"Italic"],
  " mainly by the ",
  StyleBox["resolution method",
    FontSlant->"Italic"],
  ", [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Tps",
            ButtonData:>"Tps",
            ButtonStyle->"RefLink",
            ButtonNote->"Tps, , developed at Carnegie Mellon University"],
          "Text"], TraditionalForm]]],
  "], [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Coq",
            ButtonData:>"Coq",
            ButtonStyle->"RefLink",
            ButtonNote->"Coq, , developed at Inria, France"],
          "Text"], TraditionalForm]]],
  "], [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Hol",
            ButtonData:>"Hol",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Hol, , developed at the University of Cambridge, directed by \
R. Milner"],
          "Text"], TraditionalForm]]],
  "], and [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Nqthm",
            ButtonData:>"Nqthm",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Nqthm, , also known as Boyer-Moore Prover, developed at the \
University of Texas, directed  ..."],
          "Text"], TraditionalForm]]],
  "] as proving systems for ",
  StyleBox["higher order logic",
    FontSlant->"Italic"],
  ", and again others the model checker [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Mace",
            ButtonData:>"Mace",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Mace, , developed at Argonne National Laboratories, directed \
by W. McCune"],
          "Text"], TraditionalForm]]],
  "], the equational prover [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Eqp",
            ButtonData:>"Eqp",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Eqp, , developed at Argonne National Laboratories, directed by \
W. McCune"],
          "Text"], TraditionalForm]]],
  "], the AI\[Dash]oriented [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Omega",
            ButtonData:>"Omega",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Omega, , developed at the University of \
Saarbr\[UDoubleDot]cken, directed by J. Siekmann"],
          "Text"], TraditionalForm]]],
  "], and the proof checker [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Mizar",
            ButtonData:>"Mizar",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Mizar, , developed at the University of Warszaw, directed by \
A. Trybulec"],
          "Text"], TraditionalForm]]],
  "], which also offers voluminous libraries of available proven knowledge. \
The Mizar system, definitely, was one of the first systems to recognize the \
importance of ",
  StyleBox["organizing knowledge",
    FontSlant->"Italic"],
  " in combination with systems around that automatically generate new \
knowledge and, on the other hand, depend on rigorously organized knowledge \
bases."
}], "ItemizedText"],

Cell[TextData[{
  "However, there is a big gap between the two worlds: CAS lack almost \
entirely any facilities for ",
  StyleBox["proving",
    FontSlant->"Italic"],
  " that certain facts actually hold. There is an \"implicit assumption\" in \
(the users of ) these systems, however, that ",
  Cell[BoxData[
      \(TraditionalForm\`f[x] = y\)]],
  " holds for any computation with input ",
  Cell[BoxData[
      \(TraditionalForm\`f[x]\)]],
  " resulting in ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ". It is by no means only due to programming bugs that no CAS has the above \
property, but it is much more the fact that the knowledge, with respect to \
which computations are performed, is in most of the cases implicitly assumed \
by the system and rarely transparent to the user. In symbolic computation \
systems, another source for inconsistencies is hidden in the handling of ",
  StyleBox["symbolic expressions",
    FontSlant->"Italic"],
  " in the input, i.e. parameters in the input. For a symbolic solution \
involving a parameter ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ", how can one rely on that the solution is true ",
  StyleBox["for all possible values",
    FontSlant->"Italic"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "? Is it even true for all ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "? On the other hand, TPS lack completely any machinery for performing \
computations."
}], "FirstParagraph"],

Cell[TextData[{
  "Analyzing the work of a mathematician, the observation is now that \
computer support for \"doing mathematics\" can roughly be reduced to ",
  StyleBox["proving",
    FontSlant->"Italic"],
  ", ",
  StyleBox["solving",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["computing",
    FontSlant->"Italic"],
  ", where the first activity is covered by TPS and the latter fall into the \
area of CAS. A straight\[Dash]forward combination of a CAS with a TPS by \
separating the different working phases and letting the TPS support the \
proving phase and letting the CAS support the solving and computing phase is \
difficult because ",
  StyleBox["conversions",
    FontSlant->"Italic"],
  " between the respective systems have to be performed and it is hardly \
possible to conserve the underlying logic from one system under the \
conversion. (The fact that there ",
  StyleBox["is",
    FontSlant->"Italic"],
  " actually a gap between these two fields is also apparent since the \
CALCULEMUS project, a big consortium funded by the European Community with \
RISC as one of the initiators, has been granted, whose central goal is to \
bring together computer algebra and automated theorem proving.) Therefore, \
several approaches are undertaken to combine CAS and TPS in a systematic \
manner, where one of the approaches is to add theorem proving to an available \
CAS, for instance Mathematica, as it is also done in the [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Analytica",
            ButtonData:>"Analytica",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Analytica, , developed at Carnegie Mellon University by E \
.Clarke"],
          "Text"], TraditionalForm]]],
  "] system. Analytica, however, relies essentially on computations performed \
in Mathematica and views the results as proven knowledge. "
}], "Text"],

Cell[TextData[{
  "The approach taken by ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " to fill the above mentioned gap is to ",
  StyleBox["design an entirely new mathematical language",
    FontSlant->"Italic"],
  ", which is designed to cover all needs for describing the computational as \
well as the reasoning part of mathematics. See [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Buch96a",
            ButtonData:>"Buch96a",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "B. Buchberger, 1996, Symbolic Computation: Computer Algebra \
and Logic"],
          "Text"], TraditionalForm]]],
  "] for a detailed analysis of the open gaps and some preliminary \
investigations on the design of a language for mathematics that would satisfy \
the needs. The choice for Mathematica to build the system upon has been made \
mainly for two reasons:"
}], "Text"],

Cell[TextData[{
  "The programming language offered by Mathematica is very powerful and \
allows implementation on a sophisticated level. In particular, the pattern \
matching mechanism allowing also sequence variables (in Mathematica this \
concept is available through patterns involving \"",
  StyleBox["_ _", "Text"],
  "\" and \"_ _ _\") is well\[Dash]suited for the implementation of theorem \
provers in natural deduction style, see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Buch96b",
            ButtonData:>"Buch96b",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "B. Buchberger, 1996, Mathematica as a Rewrite Language"],
          "Text"], TraditionalForm]]],
  "]."
}], "ItemizedText"],

Cell["\<\
The user front\[Dash]end of Mathematica was the first user \
interface offering so\[Dash]called \"notebook facilities\" for composing \
interactive documents consisting of input, output, and graphics enhanced with \
text\[Dash]processing capabilities such as text, structuring constructs for \
section grouping on various levels, different fonts in variable sizes, etc.\
\
\>", "ItemizedText"],

Cell[TextData[{
  "[",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Buch96",
            ButtonData:>"Buch96",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "B. Buchberger, 1996, Mathematics: An Introduction to \
Mathematics Integrating the Pure and  ..."],
          "Text"], TraditionalForm]]],
  "] contains a systematic build\[Dash]up of mathematics along the \
algorithmic axis with a prototype implementation of parts of the language in \
Mathematica Version 2. With the release of Mathematica Version 3, the front\
\[Dash]end then allowed two\[Dash]dimensional mathematical syntax with all \
types of special characters commonly used in mathematical formulae in text as \
well as in the input and the output of the system. The possibility for the \
user to define own parsing rules for input and own formatting rules for the \
output offered the opportunity for ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " to implement the language for mathematics as sketched in [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Buch96",
            ButtonData:>"Buch96",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "B. Buchberger, 1996, Mathematics: An Introduction to \
Mathematics Integrating the Pure and  ..."],
          "Text"], TraditionalForm]]],
  "] on top of Mathematica 3 using all the power of the programming language \
as it was already known from previous releases."
}], "FirstParagraph"],

Cell[TextData[{
  "Starting from then, first prototypes of an induction prover for natural \
numbers and tuples, a simplifier for equalities, and a basic natural \
deduction prover have quickly been implemented and many indications for the \
feasibility of the approach could be read off the first examples of using the \
prototype implementations. The focus in that period of the project was put, \
however, mainly on the system's reasoning components because, on the \
computational side, the entire algorithm collection of Mathematica was at its \
disposal. A semantics for the algorithmic subpart of the language has soon \
been implemented in Mathematica on the basis of [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Buch96",
            ButtonData:>"Buch96",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "B. Buchberger, 1996, Mathematics: An Introduction to \
Mathematics Integrating the Pure and  ..."],
          "Text"], TraditionalForm]]],
  "], see also [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Krif98",
            ButtonData:>"Krif98",
            ButtonStyle->"RefLink",
            ButtonNote->"F. Kriftner, 1998, Theorema: The Language"],
          "Text"], TraditionalForm]]],
  "]. At the same time, the author gathered some experience in connecting \
classical mathematical texts using classical notation with an algorithmic \
version of parts of classical mathematical notation based on the prototype \
language from [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Buch96",
            ButtonData:>"Buch96",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "B. Buchberger, 1996, Mathematics: An Introduction to \
Mathematics Integrating the Pure and  ..."],
          "Text"], TraditionalForm]]],
  "], see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Wind96",
            ButtonData:>"Wind96",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Windsteiger, W., 1996, AlgorithMische Mathematik VI"],
          "Text"], TraditionalForm]]],
  "]. These experiences, together with the common aim to design ",
  StyleBox["one new language",
    FontSlant->"Italic"],
  " for both computation ",
  StyleBox["and",
    FontSlant->"Italic"],
  " proving, then led to the design and the implementation of syntax and \
semantics of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language as it is available still in the current version of the system, \
see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["BuWi98a",
            ButtonData:>"BuWi98a",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Buchberger, B. and Windsteiger, W., 1998, The Theorema \
Language: Implementing Object- and  ..."],
          "Text"], TraditionalForm]]],
  "].\nAlthough being commonly accepted as a suitable frame for all of \
mathematics, ",
  StyleBox["set theory",
    FontSlant->"Italic"],
  " lacks its presence among the automated theorem proving systems. It is \
rather surprising, given the fact that most of the mathematics in practical \
use is built upon set theory and uses constructs from set theory in one or \
the other way, that there are virtually no theorem proving systems around \
that support mechanized proofs for theorems involving notions from set \
theory! Investigations in set theory are mostly concerned with ",
  StyleBox["inventing new axiomatizations of set theory",
    FontSlant->"Italic"],
  " suitable for computerized proofs in these theories, see for instance [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Form00",
            ButtonData:>"Form00",
            ButtonStyle->"RefLink",
            ButtonNote->
              "Andrea Formisano, 2000, Theory-based resolution and automated \
set reasoning"],
          "Text"], TraditionalForm]]],
  "], or they ",
  StyleBox["apply known proving techniques",
    FontSlant->"Italic"],
  " from the area of mechanized reasoning for theorems in set theory, see for \
instance [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Beli99a",
            ButtonData:>"Beli99a",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Belinfante, Johan, 1999, Computer Proofs in \
G\[ODoubleDot]del's Class Theory with Equational Definitio ..."],
          "Text"], TraditionalForm]]],
  "] and [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Beli99b",
            ButtonData:>"Beli99b",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Belinfante, Johan, 1999, On Computer-Assisted Proofs in \
Ordinal Number Theory"],
          "Text"], TraditionalForm]]],
  "], who uses a program named \"G\[ODoubleDot]del\" to automatically \
generate conjectures in set theory and then applies Otter  to prove them \
after translating the conjectures to first order logic.\nThe development of a \
set theory prover and its implementation within ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " was driven mainly by two motivations:"
}], "Text"],

Cell[TextData[{
  "The ",
  StyleBox["absence of a general automated set theory prover",
    FontSlant->"Italic"],
  " among available proving systems. There is no automated theorem proving \
system, which provides knowledge on set theory at the level of the inference \
engine, which makes translating formulations in set theory into some other \
theory supported by automated provers superfluous."
}], "ItemizedText"],

Cell[TextData[{
  "The experiments in [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Wind96",
            ButtonData:>"Wind96",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Windsteiger, W., 1996, AlgorithMische Mathematik VI"],
          "Text"], TraditionalForm]]],
  "] using an executable version of a mathematical language to formulate \
mathematical statements showed that ",
  StyleBox["many results can be obtained by mere expression evaluation, i.e. \
computation",
    FontSlant->"Italic"],
  ". However, when organizing bigger collections of rewrite rules performing \
the computations, some care must be taken to put conditions on the rules \
guiding the application of ",
  StyleBox["always an appropriate rule in the appropriate situation",
    FontSlant->"Italic"],
  ". It turned out quickly then, that during some of the computations one \
would actually need a small proof in order to verify a condition that allows \
to proceed in the correct way. On the other hand, some of the basic lemmata \
could be \"proved\" by just doing \"logic evaluations\", whereas others could \
not be proven without having an inference mechanism at hand that is \
substantially more powerful than just rewriting."
}], "ItemizedText"],

Cell[TextData[{
  "The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Set Theory prover that we present in this thesis, supports the automated \
generation of proofs for mathematical statements that involve notions from \
set theory in a form as commonly used by mathematicians in their day\[Dash]to\
\[Dash]day work. It is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " based on a particular axiomatization of set theory, such as the \
frequently used Zermelo\[Dash]Fraenkel set theory or \
G\[ODoubleDot]del\[Dash]Bernays\[Dash]von Neumann set theory, but it supports \
notions as they are likely to appear when formalizing some mathematical \
theory using set theory. Set theory goes back originally to ",
  StyleBox["Georg Cantor",
    FontSlant->"Italic"],
  ", who tried to formalize what in his intuition was captured by \
\[LeftGuillemet]collection of things having certain properties\
\[RightGuillemet]. Cantor's work was continued then by ",
  StyleBox["Frege",
    FontSlant->"Italic"],
  ", who introduced the principle of ",
  StyleBox["comprehension",
    FontSlant->"Italic"],
  ", which allows to form the set of all ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " that satisfy the property ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  ", denoted by ",
  Cell[BoxData[
      \(TraditionalForm\`{x | \[Phi]\_x}\)]],
  ". Unfortunately, as pointed out by Russell's famous paradox, this \
principle was too naive and would lead soon to contradictions that make such \
a theory worthless."
}], "FirstParagraph"],

Cell[TextData[{
  "The motivation for modern set theory was from then on to come up with \
collections of axioms that describe a useful theory but make paradoxa such as \
Russell's impossible. ",
  StyleBox["Russell",
    FontSlant->"Italic"],
  " himself, together with ",
  StyleBox["Whitehead",
    FontSlant->"Italic"],
  ", see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["RuWh10",
            ButtonData:>"RuWh10",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "B. Russell and A. Whitehead, 1910, Principia Mathematica"],
          "Text"], TraditionalForm]]],
  "], proposed ",
  StyleBox["types",
    FontSlant->"Italic"],
  " as a possible way out, which led to the development of what is nowadays \
known as ",
  StyleBox["type theory",
    FontSlant->"Italic"],
  ". Another approach was taken by ",
  StyleBox["Zermelo",
    FontSlant->"Italic"],
  ", whose basic idea was to restrict the comprehension principle to the so\
\[Dash]called ",
  StyleBox["separation axiom",
    FontSlant->"Italic"],
  ", which basically allows comprehension only for such properties \[Phi], \
which separate elements from an entity that has already the property of being \
a set. The most important refinements of this approach were made by ",
  StyleBox["Fraenkel",
    FontSlant->"Italic"],
  ", see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Frae76",
            ButtonData:>"Frae76",
            ButtonStyle->"RefLink",
            ButtonNote->"Abraham A. Fraenkel, 1976, Abstract Set Theory"],
          "Text"], TraditionalForm]]],
  "], and ",
  StyleBox["von Neumann",
    FontSlant->"Italic"],
  ", who added as last axiom the axiom of regularity. The axiomatization \
resulting from this work is called ZF (Zermelo\[Dash]Fraenkel set theory). At \
the same time, an alternative approach has been chosen by von Neumann himself \
and ",
  StyleBox["Bernays",
    FontSlant->"Italic"],
  ", see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["BeFr68",
            ButtonData:>"BeFr68",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "P. Bernays and A. Fraenkel, 1968, Axiomatic Set Theory"],
          "Text"], TraditionalForm]]],
  "] or [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Quine63",
            ButtonData:>"Quine63",
            ButtonStyle->"RefLink",
            ButtonNote->"W. Quine, 1963, Set Theory and its Logic"],
          "Text"], TraditionalForm]]],
  "], with refinements by ",
  StyleBox["G\[ODoubleDot]del",
    FontSlant->"Italic"],
  ", see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Goed40",
            ButtonData:>"Goed40",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "K. G\[ODoubleDot]del, 1940, The Consistency of the Axiom of \
Choice and the Generalized Continuum-Hypot ..."],
          "Text"], TraditionalForm]]],
  "], by introducing the concept of ",
  StyleBox["classes",
    FontSlant->"Italic"],
  ". In addition to classes, there is a predicate telling whether some class \
is a set or not. The membership predicate \"\[Element]\" is then only allowed \
for sets, thus avoiding contradictions in the style of Russell in this theory \
often referred to as NGB for von \
Neumann\[Dash]G\[ODoubleDot]del\[Dash]Bernays.\nWhatever axiomatization is \
laid at the ground, it turned out that set theory is a suitable language for \
building up mathematics as it was shown in the volumes of Bourbaki. The idea \
of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Set Theory prover is now to provide a tool supporting these practical \
applications of set theory. We want to make clear that our prover uses ",
  StyleBox["no new axiomatization for computerized set theory",
    FontSlant->"Italic"],
  " as in [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Form00",
            ButtonData:>"Form00",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Andrea Formisano, 2000, Theory-based resolution and automated \
set reasoning"],
          "Text"], TraditionalForm]]],
  "] nor is it tailored towards on one of the existing axiomatizations \
exclusively. Rather, it provides inference rules in the style of ",
  StyleBox["natural deduction",
    FontSlant->"Italic"],
  " for statements containing commonly used constructs available in set \
theory, such as union, intersection, subsets, cross product, and set \
formation constructs similar to the comprehension principle, since these are \
basically the same in all axiomatizations of set theory, be it ZF or be it \
NGB. The task of a proper axiomatization is to guarantee the existence of all \
these sets or to guarantee that all these classes are sets actually. In the \
",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system, on the other hand, we ",
  StyleBox["assume the existence of all occurring sets",
    FontSlant->"Italic"],
  " and we leave it to the user to build up theories using ",
  StyleBox["some set theory",
    FontSlant->"Italic"],
  " that justifies all what is done. We provide natural proof rules to treat \
set theoretic constructs when they occur in the proof goal or in the \
knowledge base aiming at generating proofs similar to proofs done by a well\
\[Dash]trained human mathematician. The style of these rules is, roughly, as \
sketched in the following proof rules:"
}], "Text"],

Cell[TextData[{
  "\[LeftGuillemet]If we have to prove ",
  Cell[BoxData[
      \(TraditionalForm\`a \[Element] {x | \[Phi]\_x}\)]],
  " w.r.t. some knowledge base ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa]\)]],
  ", then it is sufficient to prove ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(x \[Rule] a\)\)]],
  " w.r.t. ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa]\)]],
  "\[RightGuillemet] or "
}], "ItemizedText"],

Cell[TextData[{
  "\[LeftGuillemet]If we know ",
  Cell[BoxData[
      \(TraditionalForm\`a \[Element] {x | \[Phi]\_x}\)]],
  " then we can conclude ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(x \[Rule] a\)\)]],
  "\[RightGuillemet]."
}], "ItemizedText"],

Cell[TextData[{
  "Furthermore, we provide ",
  StyleBox["simplification rules",
    FontSlant->"Italic"],
  ", in particular, for finite sets that allow, for instance,"
}], "SingleParagraph"],

Cell[TextData[{
  "to simplify ",
  Cell[BoxData[
      \(TraditionalForm\`3 \[Element] {2, 3, 4}\)]],
  " to \"True\" or"
}], "ItemizedText"],

Cell[TextData[{
  "to simplify ",
  Cell[BoxData[
      \(TraditionalForm\`{1} \[SubsetEqual] {2, 3, 4}\)]],
  " to \"False\"."
}], "ItemizedText"],

Cell[TextData[{
  "Finally, we provide some specialized techniques for handling proof \
situations ",
  StyleBox["arising from handling set theoretic statements",
    FontSlant->"Italic"],
  " such as"
}], "SingleParagraph"],

Cell[TextData[{
  "to treat ",
  Cell[BoxData[
      \(TraditionalForm\`\[Exists] \+x\((\[Phi]\_x \[And] \[Tau]\_x = 
            a)\)\)]],
  ", which comes from expanding ",
  Cell[BoxData[
      \(TraditionalForm\`a \[Element] \(\[Union]{\[Tau]\_x | \
\[Phi]\_x}\)\)]],
  ", by ",
  StyleBox["introducing solve constants",
    FontSlant->"Italic"],
  "."
}], "ItemizedText"],

Cell[TextData[{
  "The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Set Theory prover is neatlessly integrated into the existing proving \
environment of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system as well as its simplification component behaves consistent with \
the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " computation philosophy. "
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell["Statement of Originality", "Subsection",
  CellTags->"c:3"],

Cell[TextData[{
  "The work described in this thesis is based on the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " software system, which is implemented on the basis of the commercially \
distributed symbolic computation software system Mathematica. Since the \
official beginning of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " project in 1994 (though it was named \"NewMath\" in those days) many \
people have contributed to the current state of the system and I will try to \
list the most important members of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " group since that time together with a brief description of the most \
important contributions of the individual co\[Dash]workers related to the \
results presented in the course of this thesis. This reflects, of course, the \
very personal view of the author who hopes to give a fair evaluation of the \
different work pieces making up the current ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system."
}], "SingleParagraph"],

Cell[TextData[{
  StyleBox["Bruno Buchberger",
    FontWeight->"Bold"],
  " is the creator of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system. The entire system is based on his ideas and ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " expresses his condensed view of mathematics having almost 40 years of \
experience in working with and in mathematics. At the same time, and I guess \
I may say that this is exceptional for a full professor, he was the person \
that actually implemented the first prototypes of provers and also the basic \
components of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language in Mathematica, making out of him a person who not only talks \
about the concepts and the philosophy of the system, but for a long period he \
was also one of the chief developers of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system. He is the engine in the project making sure that the members of \
the team never lean back in their chairs being satisfied with what has \
already been reached. Whenever we think that we could be happy with some new \
achievement, he comes up with totally new ideas and visions, being always \
several years ahead the current status of the system."
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["Tudor Jebelean",
    FontWeight->"Bold"],
  " is the co\[Dash]leader of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " group. He made vital contributions in the redesign phase of the system in \
the definition of internal structures for organizing the proof generation \
process. The proof search mechanism and the layout of the proof object as \
they are used now in the system is the result of his work together with Elena \
Tomuta. Furthermore, he developed, based on sketches of Bruno Buchberger, the \
special provers for propositional logic and general first\[Dash]order \
predicate logic. Besides that, he is a very nice and funny person, whose \
contributions in internal discussions on future system development can never \
be neglected."
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["Daniela Vasaru\[Dash]Dupr\[EAcute]",
    FontWeight->"Bold"],
  " has unfortunately left our group last year after finishing her PhD. Her \
contributions to basic ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system components for formula and proof object handling and also to the \
entire engineering of a big piece of software as ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " meanwhile is were without doubt crucial. With the implementation of the \
PCS prover for elementary analysis based on the ideas of Bruno Buchberger she \
did some important conceptual work also, which has also been useful in the \
implementation of the Set Theory prover described in this thesis."
}], "ItemizedText"],

Cell[TextData[{
  "It is the intention of this thesis to also give a comprehensive system \
description, some background also on the philosophy behind the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system, and an outlook on the possibilities for working in mathematics \
that the system particularly supports. Although we, of course, concentrate on \
personal contributions to the system, some of the system features described \
in this thesis are either based on the work of or are entirely developed by \
other people in the group. We will be very precise in clearly separating own \
contributions from contributions made by others in each part of this thesis, \
see also the subsequent section on a summary of the highlights of the \
author's contributions.\nAll examples that are presented are implemented in \
the current version of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", which is internally referred to as Version 1.1\[Alpha]. The current \
version of Mathematica, to which all the examples refer, is Version 4.0."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Short Summary of Highlights", "Subsection"],

Cell[TextData[{
  "According to a very personal assessment, the highlights of the author's \
contribution to the current status of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " software described in this thesis are:"
}], "SingleParagraph"],

Cell[TextData[{
  StyleBox["Contributions to the language design and their implementation",
    FontSlant->"Italic"],
  ": in addition to the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " object language used to formulate mathematical statements, the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system provides the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " ",
  StyleBox["Formal Text Language",
    FontSlant->"Italic"],
  ", ",
  "a language for organizing mathematical knowledge in a structured manner, \
and the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " ",
  StyleBox["User Language",
    FontSlant->"Italic"],
  ", a language for expressing mathematical activities in a concise fashion. \
It was the author's contribution to design these language layers and to \
implement them in Mathematica in such a way, that a neatless integration of \
proving and computing within ",
  StyleBox["one software system",
    FontSlant->"Italic"],
  " became possible. Moreover, the design of these language layers went hand \
in hand with a clearly structured software technological system concept based \
on ",
  StyleBox["Mathematica packages",
    FontSlant->"Italic"],
  " with an impact also on the programming style used for implementing the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system within Mathematica."
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["Design and implementation of a Set Theory prover within Theorema",
    
    FontSlant->"Italic"],
  ": based on available proving components such as basic predicate logic \
proving, rewriting using available knowledge, or proving by case distinction, \
a new prover has been developed that allows to prove theorems involving \
concepts from set theory. The set theory part of the prover actually consist \
of four components:"
}], "ItemizedText"],

Cell["\<\
The first one, named STP, reduces set theoretic notions in the \
goal. The challenge in the design of this prover was to arrange a bunch of \
proof techniques, that are generally in use for set constructions, in such a \
way that cycles are avoided and proofs come out as natural as possible, i.e. \
close to what a human would produce.\
\>", "ItemizedText",
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{45, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "The second one, named STKBR, expands set theoretic expressions in the \
knowledge base using level saturation. The prover is implemented in such \
generality that it is by no means limited to set theory and can therefore be \
used as an extensible level saturation module in future versions of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system."
}], "ItemizedText",
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{45, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "The third one, named STC, simplifies expressions applying semantic \
knowledge provided by the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language. Again, the design of its implementation allows this module to \
be a universal semantic simplification module using any semantics available \
in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system, not particularly set theory. This prover is ",
  StyleBox["the link between proving and computing",
    FontSlant->"Italic"],
  " since it makes all algorithmic knowledge implemented in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language accessible by the provers, even more, it provides a standard \
interface to all the algebraic knowledge available in the Mathematica system. \
It is the first prover implemented in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system that brings the combination of proving and computing facilities to \
life. The clean language design at the basis of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system was definitely one of the keys to make this neatless integration \
possible. "
}], "ItemizedText",
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{45, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "The fourth one, named STS, tries to instantiate existential goals \
containing set theory related sub\[Dash]expressions. No special solving \
techniques for set theory have been developed yet, but, with the experience \
gained in interfacing ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " proving with Mathematica kernel functions as done in STC, the solver \
recognizes several types of existential goals, which can, in fact, at least \
be partially solved by one of the available Mathematica solvers. In the \
context of set theory, such situations appear often when proving membership \
in set abstractions."
}], "ItemizedText",
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{45, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  StyleBox["Case studies",
    FontSlant->"Italic"],
  " using the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system as a whole for doing more than just proving have been carried out \
in several mathematical domains. It is shown, how proving and computing play \
together (on the meta\[Dash]level, in some sense) as mathematical activities \
during the exploration of mathematical theories. ",
  StyleBox["A benchmark problem for automated theorem proving in set theory",
    FontSlant->"Italic"],
  ", McCarthy's \"Mutilated Checkerboard Problem\", has been ",
  StyleBox["completely solved",
    FontSlant->"Italic"],
  " in the course of one of the case studies. Some isolated problems from the \
TPTP library, for which other provers like Otter performed badly or failed \
completely, have also been solved by the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Set Theory prover."
}], "ItemizedText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Structure of the Thesis", "Subsection"],

Cell[TextData[{
  "The structure of the thesis orients along the three main highlights \
briefly discussed in the previous section. In the first part of the thesis, a \
general introduction to the basics of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system is given focussing on the author's contributions to language and \
general system design. This part is absolutely crucial in order to be able to \
understand all later explanations on the Set Theory prover itself and its \
applications in the example section."
}], "FirstParagraph"],

Cell[TextData[{
  "First, some necessary background information on the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system is given. In the section on the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language, three layers of language are described that together make up \
the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language. This is the language, in which also the Set Theory prover \
demonstration will be formulated. It is at the same time the language, in \
which the objects are represented, on which the Set Theory prover operates. A \
careful study of these sections should help to understand those parts of the \
prover demonstration that refer to the actual implementation of the prover. \
In the frame of the user language, we explain some technical details that \
refer to system design and that were the key solution on the way to make \
proving and computing work in one language. Some of this description goes \
into details of programming in Mathematica, it can be skipped in case the \
reader's focus is not the implementation of the prover.\nIn the next section, \
we describe, how provers are to be implemented in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system. Since the system already provides the framework, in which provers \
are called, in which certain existing provers can be combined, and in which \
generated proofs are presented in a homogeneous style, new provers that are \
to be added the system must follow certain conventions in order to fit well \
into this frame. These conventions, of course, have their consequences for \
the design of the Set Theory prover. Since also the basic terminology for ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " provers is introduced in this section, it is vital to understanding the \
design and the implementation of the Set Theory prover.\nWe conclude the \
first part with a general view on automated theorem proving and a general \
introduction to the PCS prove philosophy introduced by Bruno Buchberger. \
Again, since the Set Theory prover is one concrete instance of a \
PCS\[Dash]style prover, it is recommended to read these sections before \
advancing to the Set Theory prover in part two of this thesis.\nPart two of \
the thesis then concentrates on the Set Theory prover, which actually \
consists of four prover modules that together form the prover for set theory. \
Thus, a description of the individual prove modules gives a natural structure \
for this part of the thesis. The provers follow the paradigm of natural \
deduction and we describe all inference rules applied by the respective \
provers. Each inference is accompanied by an example application of the rule \
in a concrete applicable proof situation. In these examples, we demonstrate \
how an inference rule produces a new proof situation from a given one. In \
addition, we show the natural language explanation of the inference rule as \
it will appear in the generated proofs with the intention that application of \
particular inference rules later in the case study can easily be recognized \
by the generated text in the natural language proof presentation.\nPart three \
contains some case studies of explorations of some fields of mathematics \
where the key notions involve constructions from set theory. We demonstrate \
the capabilities of the Set Theory prover and also the feasibility of the \
approach as a whole. Only few isolated examples will appear as an \
introduction to the case studies in order to give a focussed demonstration of \
specific features of some methods. These isolated proofs are followed by an \
exploration on equivalence relations, equivalence classes, factor sets, and \
partitions split into two parts: In the first part, we use an ",
  StyleBox["intensional",
    FontSlant->"Italic"],
  " representation of relations from predicate logic and we introduce the \
above mentioned concepts for this approach. We proceed until the complete \
proof of the theorem \[LeftGuillemet]The factor set w.r.t. an equivalence \
relation forms a partition of the ground set\[RightGuillemet]. Then we switch \
to an alternative approach that utilizes an ",
  StyleBox["extensional",
    FontSlant->"Italic"],
  " representation of relations as it comes from set theory. In this \
approach, the same results can be obtained as in the first one (we will omit \
the proofs), but we can continue and introduce the concept of a relation \
induced by a set of sets. Having this new notion, we can then prove two \
theorems: \[LeftGuillemet]The relation induced by the factor set of an \
equivalence relation is identical with the original equivalence relation\
\[RightGuillemet] and \[LeftGuillemet]The factor set of the relation induced \
by a partition is the partition itself\[RightGuillemet]. Finally, we present \
a case study on the Mutilated Checkerboard Problem given by John McCarthy. \
This problem has been tackled by many automated theorem provers yielding \
different solutions. McCarthy himself gave a solution on paper modelling the \
problem in set theory, where he claimed that every prover dealing with set \
theory should be able to accept his formulation and produce a proof of the \
original theorem in its set theoretic formulation. We give a solution to this \
problem using the prover presented in this thesis for exploring the theory of \
checkerboards an dominos. The thesis should \"prove\" that our prover can \
actually generate all of the proofs, hence, we include all proofs in the \
thesis. The reader can then judge from these proofs how much of the project \
goal to \[LeftGuillemet]let computer programs generate proofs that are as \
easy to understand and as easy to read as if they were produced by a well\
\[Dash]educated mathematician\[RightGuillemet]  has already been reached."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["On the Document", "Subsection"],

Cell["\<\
This thesis has been written using the Mathematica 4.1 front end as \
a collection of Mathematica notebooks. Some parts of it, such as the table of \
contents, the list of references, and the index have been produced with the \
help of the AuthorTools provided by Wolfram Research.\
\>", "FirstParagraph"],

Cell[TextData[{
  "There are two versions of the thesis, an electronic version and a printed \
version. For reading the electronic version one needs Mathematica or at least \
MathReader. Many features of the Mathematica notebook front end are used in \
the electronic form, most importantly the possibility to actually ",
  StyleBox["evaluate",
    FontSlant->"Italic"],
  " input and to have hyperlinks within the individual parts of the document. \
For most of the inputs in this thesis, one not only needs a license for \
Mathematica but also a license for ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " (consult ",
  ButtonBox["www.theorema.org",
    ButtonData:>{
      URL[ "http://www.theorema.org"], None},
    Active->True,
    ButtonStyle->"Hyperlink"],
  " for questions on licensing) and a sufficiently new version of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system. Input that can be evaluated is put into so\[Dash]called input \
cells, whose optical appearance depends on the style sheet used. The \
notebooks use an individual style sheet \"",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "SmartColors\", which is attached to each notebook. Changing to another \
style sheet may have strange effects to some parts of the document and is \
therefore not recommended. Input cells appear as"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 + 1\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell["\<\
with the corresponding output together in one \"block\". Note, \
however, that some input cells have the property \"Evaluatable\" set to \
False, so that destroying the output by accidentally evaluating the input is \
prevented. The style sheet supports two kinds of printing environment, one \
for colored printing and one for black and white printing, which can be \
chosen in case you have the electronic version on the screen and then decide \
to printout parts of the thesis on paper.\
\>", "FirstParagraph"],

Cell[TextData[{
  StyleBox["Numbering",
    FontSlant->"Italic"],
  " of pieces of the text for referring to specific parts (section, \
subsection, table, and figure numbering) is only relevant for the printed \
version. In the electronic version, the numbers referring to sections, \
subsections, tables, figures etc. are actually hyperlinks that, by clicking \
onto them, jump to the specified part.\nIn case you want to reproduce some of \
the evaluations in some version of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", always be aware of the fact that what you see on the screen as input or \
output in this thesis, might not represent exactly what you expect. For \
instance, whether something in the input is split over two lines or whether \
it is actually a ",
  StyleBox["grid",
    FontSlant->"Italic"],
  " of two rows makes a difference to ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", although you cannot see the difference on the screen or on the printout. \
It makes a difference, whether you type the character \"|\" (the raw bar-key \
from the keyboard) or you type the character \"\[VerticalSeparator]\" (the \
character \"VerticalSeparator\" typed by \[EscapeKey]|\[EscapeKey]), three \
dots \"...\" (a string of three \".\" characters) are different from the \
character \"\[Ellipsis]\" (one character named \"Ellipsis\", typed by \
\[EscapeKey]...\[EscapeKey]). There are several other characters in \
Mathematica, that can potentially be mixed up. If you have the electronic \
version, a method for finding things out is to check the underlying cell \
expression by selecting the cell and choosing the menu command \"Format \
\[Rule] Show Expression\". For instance, for the cell"
}], "Text"],

Cell[BoxData[
    \({\(i\^2\)\( | \+\(i = 1, \[Ellipsis], 10\)\)}\)], "Input",
  Evaluatable->False],

Cell["the underlying cell expression is", "SingleParagraph"],

Cell[RawData["\<\
Cell[BoxData[
    RowBox[{\"{\", 
      RowBox[{
        SuperscriptBox[\"i\", \"2\"], 
        UnderscriptBox[\"|\", 
          RowBox[{
            RowBox[{\"i\", \"=\", \"1\"}], \",\", \"\\[Ellipsis]\", \",\", \
\"10\"}]]}],\"}\"}]], \"Input\",
  Evaluatable->False]\
\>"], "Input",
  Evaluatable->False],

Cell[TextData[{
  "from which one can read, that the three dots \"\[Ellipsis]\" under the \
quantifier are the \"Ellipsis\" character and not simply three dots. If you \
have the printed version and you want to try out things in a running version \
of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", then you can at least consult the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " online help, where expressions are written in Mathematica notebooks and \
you can lookup their cell structure."
}], "FirstParagraph"],

Cell[TextData[{
  "On some occasions, we intend to refer to Mathematica functions or symbols \
in running text. We will use inlined cells of style \"MathematicaInput\" \
(which is a cell style defined in the specially tailored style sheet), that \
make the symbol appear like ",
  StyleBox["Solve", "MathematicaInput"],
  ". Images included into the notebooks may appear scrambled when viewing the \
notebooks with a different version of Mathematica than the one on which the \
notebooks have been produced. We therefore include also the sources into the \
electronic version of the thesis in the subdirectory \"Include\", and at each \
place, where an image is included, we also give the filename of the original \
source of the image so that images can be viewed using some available \
rendering software in case the notebook images appear unreadable."
}], "Text"],

Cell[TextData[ButtonBox["\[LowerRightArrow]",
  ButtonData:>{"Part1.nb", "c:0"},
  ButtonStyle->"Navigation",
  ButtonNote->"Part 1"]], "SingleParagraph",
  TextAlignment->Right,
  TextJustification->0]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowToolbars->"EditBar",
WindowSize->{783, 730},
WindowMargins->{{Automatic, 161}, {Automatic, 17}},
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page", CounterFunction :> CapitalRomanNumeral]}], 
        "PageNumber"], Inherited, Cell[ 
        TextData[ {"Introduction"}], "Header"]}, {Cell[ 
        TextData[ {"Introduction"}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page", CounterFunction :> CapitalRomanNumeral]}], 
        "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{79.1875, 79.1875}, {108, 108}},
"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->True,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", \
"wwindste", "Diss", "Main"}, "Introduction.nb.ps", CharacterEncoding -> \
"ISO8859-1"],
"Magnification"->1},
StyleDefinitions -> "TheoremaSmartColors.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1944, 59, 50, 1, 59, "Section",
      CellTags->"c:1"]},
  "c:3"->{
    Cell[36385, 1017, 65, 1, 53, "Subsection",
      CellTags->"c:3"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 61846, 1580},
  {"c:3", 61923, 1583}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 214, 5, 42, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1944, 59, 50, 1, 59, "Section",
  CellTags->"c:1"],
Cell[1997, 62, 1166, 30, 133, "FirstParagraph"],
Cell[3166, 94, 454, 11, 69, "Text"],
Cell[3623, 107, 3879, 111, 217, "ItemizedText"],
Cell[7505, 220, 5425, 164, 255, "ItemizedText"],
Cell[12933, 386, 1476, 37, 152, "FirstParagraph"],
Cell[14412, 425, 1918, 43, 221, "Text"],
Cell[16333, 470, 936, 24, 107, "Text"],
Cell[17272, 496, 771, 19, 84, "ItemizedText"],
Cell[18046, 517, 403, 7, 65, "ItemizedText"],
Cell[18452, 526, 1543, 37, 133, "FirstParagraph"],
Cell[19998, 565, 5277, 137, 373, "Text"],
Cell[25278, 704, 419, 8, 65, "ItemizedText"],
Cell[25700, 714, 1303, 28, 160, "ItemizedText"],
Cell[27006, 744, 1556, 37, 171, "FirstParagraph"],
Cell[28565, 783, 5561, 145, 468, "Text"],
Cell[34129, 930, 459, 14, 27, "ItemizedText"],
Cell[34591, 946, 264, 8, 27, "ItemizedText"],
Cell[34858, 956, 192, 5, 31, "SingleParagraph"],
Cell[35053, 963, 142, 5, 27, "ItemizedText"],
Cell[35198, 970, 147, 5, 27, "ItemizedText"],
Cell[35348, 977, 224, 6, 50, "SingleParagraph"],
Cell[35575, 985, 376, 13, 33, "ItemizedText"],
Cell[35954, 1000, 406, 13, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[36385, 1017, 65, 1, 53, "Subsection",
  CellTags->"c:3"],
Cell[36453, 1020, 1034, 22, 145, "SingleParagraph"],
Cell[37490, 1044, 1272, 26, 179, "ItemizedText"],
Cell[38765, 1072, 808, 15, 122, "ItemizedText"],
Cell[39576, 1089, 743, 15, 103, "ItemizedText"],
Cell[40322, 1106, 1063, 18, 164, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41422, 1129, 51, 0, 53, "Subsection"],
Cell[41476, 1131, 253, 6, 50, "SingleParagraph"],
Cell[41732, 1139, 1391, 38, 160, "ItemizedText"],
Cell[43126, 1179, 474, 9, 84, "ItemizedText"],
Cell[43603, 1190, 465, 8, 65, "ItemizedText"],
Cell[44071, 1200, 498, 10, 65, "ItemizedText"],
Cell[44572, 1212, 1275, 29, 160, "ItemizedText"],
Cell[45850, 1243, 756, 14, 103, "ItemizedText"],
Cell[46609, 1259, 943, 21, 122, "ItemizedText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47589, 1285, 45, 0, 53, "Subsection"],
Cell[47637, 1287, 556, 10, 76, "FirstParagraph"],
Cell[48196, 1299, 5868, 89, 886, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54101, 1393, 37, 0, 53, "Subsection"],
Cell[54141, 1395, 315, 5, 57, "FirstParagraph"],
Cell[54459, 1402, 1349, 29, 164, "Text"],

Cell[CellGroupData[{
Cell[55833, 1435, 38, 1, 39, "Input"],
Cell[55874, 1438, 35, 1, 40, "Output"]
}, Open  ]],
Cell[55924, 1442, 523, 8, 76, "FirstParagraph"],
Cell[56450, 1452, 1737, 31, 240, "Text"],
Cell[58190, 1485, 100, 2, 54, "Input",
  Evaluatable->False],
Cell[58293, 1489, 60, 0, 31, "SingleParagraph"],
Cell[58356, 1491, 325, 11, 160, "Input",
  Evaluatable->False],
Cell[58684, 1504, 532, 12, 57, "FirstParagraph"],
Cell[59219, 1518, 866, 13, 145, "Text"],
Cell[60088, 1533, 202, 5, 42, "SingleParagraph"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

