(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1157330,      24591]*)
(*NotebookOutlinePosition[   1180239,      25220]*)
(*  CellTagsIndexPosition[   1175932,      25098]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[ButtonBox["\[UpperLeftArrow]",
  ButtonData:>{"Part1.nb", "c:0"},
  ButtonStyle->"Navigation",
  ButtonNote->"Part 1"]], "SingleParagraph",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
Part 2
The Set Theory Prover\
\>", "Title",
  CounterAssignments->{{"Section", 3}, {"Subtitle", 0}, {"Subsubtitle", 0}},
  CellTags->"c:1"],

Cell[TextData[{
  "In this part of the thesis, we will describe the Set Theory prover in all \
details. The description of the prover follows the structure of the software \
imposed by the general prover layout in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system already explained in Section ",
  ButtonBox["3.1",
    ButtonData:>{"Part1.nb", "Sec:ProversInTheorema"},
    ButtonStyle->"Hyperlink"],
  " in Part 1 of this thesis. The user prover, which is available for the \
user to be called in the Prove command, is the ",
  StyleBox["SetTheoryPCSProver",
    FontSlant->"Italic"],
  ", which adapts the PCS prove strategy (see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Buch00m",
            ButtonData:>"Buch00m",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "B. Buchberger and D. Vasaru, 2000, The Theorema PCS Prover"],
          "Text"], TraditionalForm]]],
  "] or [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Vasa00PhD",
            ButtonData:>"Vasa00PhD",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "D. Vasaru-Dupr\[EGrave], 2000, Automated Theorem Proving by \
Integrating Proving, Solving and Compu ..."],
          "Text"], TraditionalForm]]],
  "]) described in Section ",
  ButtonBox["3.3",
    ButtonData:>{"Part1.nb", "Sec:PCS"},
    ButtonStyle->"Hyperlink"],
  " for proofs in set theory. The prover is oriented mainly towards proving \
theorems that involve commonly used formulations from set theory, not \
priorily for proving theorems in a certain axiomatization of set theory \
itself, see also Section ",
  
  CounterBox["Section", "Sec:TheoFoundSet"],
  ". Since many areas of mathematics are formulated using set theory, this \
prover should have a wide range of practical applications in every\[Dash]day \
mathematical proving."
}], "FirstParagraph"],

Cell[TextData[{
  "The prover builds up on the PCS\[Dash]like provers already available in \
the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system in the sense that some of the special provers developed for \
general PCS proving are again part of this prover, such as"
}], "Text"],

Cell[TextData[{
  "BasicND",
  StyleBox[" representing the non\[Dash]rewrite part of predicate logic \
proving,",
    FontWeight->"Plain"]
}], "ItemizedText",
  FontWeight->"Bold"],

Cell[TextData[{
  "QR",
  StyleBox[" for \"quantified rewriting\" using rewrite\[Dash]knowledge from \
the knowledge base for rewriting formulae in the goal or the knowledge base,",
    
    FontWeight->"Plain"]
}], "ItemizedText",
  FontWeight->"Bold"],

Cell[TextData[{
  "CDP",
  StyleBox[" for proving with case distinctions.",
    FontWeight->"Plain"]
}], "ItemizedText",
  FontWeight->"Bold"],

Cell["\<\
Some of these provers needed certain modifications in order to \
cooperate appropriately with the set theory prove modules. We will briefly \
comment on the major improvements in these modules but we will mainly \
concentrate on the description of the set theory related components that were \
developed for this prover, which are:\
\>", "SingleParagraph"],

Cell[TextData[{
  StyleBox["STP",
    FontWeight->"Bold"],
  " (",
  StyleBox["S",
    FontWeight->"Bold"],
  "et ",
  StyleBox["T",
    FontWeight->"Bold"],
  "heory ",
  StyleBox["P",
    FontWeight->"Bold"],
  "roving) representing the proving part of set theory for ",
  StyleBox["reducing set theoretic statements in the goal",
    FontSlant->"Italic"],
  " during the \"P\"\[Dash]phase,"
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["STKBR",
    FontWeight->"Bold"],
  " (",
  StyleBox["S",
    FontWeight->"Bold"],
  "et ",
  StyleBox["T",
    FontWeight->"Bold"],
  "heory ",
  StyleBox["K",
    FontWeight->"Bold"],
  "nowledge ",
  StyleBox["B",
    FontWeight->"Bold"],
  "ase ",
  StyleBox["R",
    FontWeight->"Bold"],
  "ewriting) representing the proving part of set theory for ",
  StyleBox["expanding set theoretic notions in the knowledge base",
    FontSlant->"Italic"],
  ", which we consider as kind of a transition from \"P\"\[Dash]phase to \
\"C\"\[Dash]phase,"
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["STC",
    FontWeight->"Bold"],
  " (",
  StyleBox["S",
    FontWeight->"Bold"],
  "et ",
  StyleBox["T",
    FontWeight->"Bold"],
  "heory ",
  StyleBox["C",
    FontWeight->"Bold"],
  "omputing) responsible for applying semantic knowledge of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language for simplifying the goal or parts of the knowledge base during \
the \"C\"\[Dash]phase, and"
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["STS",
    FontWeight->"Bold"],
  " (",
  StyleBox["S",
    FontWeight->"Bold"],
  "et ",
  StyleBox["T",
    FontWeight->"Bold"],
  "heory ",
  StyleBox["S",
    FontWeight->"Bold"],
  "olving) for applying various techniques for instantiating existential \
goals during the \"S\"\[Dash]phase of the PCS cycle."
}], "ItemizedText"],

Cell[TextData[{
  "In order to understand the cooperation between the set theory modules with \
the PCS modules ",
  StyleBox["in detail",
    FontSlant->"Italic"],
  ", some knowledge about the peculiarities in these modules might of course \
be helpful. However, a basic understanding of the set theory prover can also \
be gained without studying the PCS components before."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell["The Theoretical Basis of the Set Theory Prover", "Section",
  CellTags->"Sec:TheoFoundSet"],

Cell[TextData[{
  "The use of set theory in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " is not tied to ",
  StyleBox["one",
    FontSlant->"Italic"],
  " particular axiomatization of set theory. Instead, we introduce \"sets\" \
on the level of the language by providing the braces \"{\" and \"}\" as a \
flexible arity matchfix function symbol used for constructing finite sets and \
the set quantifier as already described in Section ",
  ButtonBox["2.1",
    ButtonData:>{"Part1.nb", "Sec:MathLanguage"},
    ButtonStyle->"Hyperlink"],
  " in Part 1. Providing these language constructs, we implicitly assume that \
sets such as ",
  Cell[BoxData[
      \(TraditionalForm\`{a}\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{1, b}\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{x\( | \+x\)\[GothicCapitalP]\_x}\)]],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`{\[GothicCapitalT]\_x\( | \+x\)\[GothicCapitalP]\_x}\
\)]],
  " actually exist, which is typically guaranteed by some axioms of the \
underlying set theory. There are different approaches, in the \
Zermelo\[Dash]Fraenkel axiomatization (ZF) as given in [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Ebbi79",
            ButtonData:>"Ebbi79",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "H.D. Ebbinghaus, 1979, Einf\[UDoubleDot]hrung in die \
Mengenlehre"],
          "Text"], TraditionalForm]]],
  "] the existence of the singleton ",
  Cell[BoxData[
      \(TraditionalForm\`{a}\)]],
  " follows from an axiom on power sets and the existence of ",
  Cell[BoxData[
      \(TraditionalForm\`{1, b}\)]],
  " follows from the existence of singletons together with an axiom on \
unions, whereas in an axiomatization given in [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["TaZa71",
            ButtonData:>"TaZa71",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "G. Takeuti and W.M. Zaring, 1971, Introduction to Axiomatic \
Set Theory"],
          "Text"], TraditionalForm]]],
  "], which  also follows the spirit of ZF, the existence of ",
  Cell[BoxData[
      \(TraditionalForm\`{1, b}\)]],
  " is guaranteed by an axiom of pairing and the singleton ",
  Cell[BoxData[
      \(TraditionalForm\`{a}\)]],
  " is then just defined to denote the pair ",
  Cell[BoxData[
      \(TraditionalForm\`{a, a}\)]],
  ". "
}], "FirstParagraph"],

Cell[TextData[{
  "The language construct ",
  Cell[BoxData[
      \(TraditionalForm\`{x\( | \+x\)\[GothicCapitalP]\_x}\)]],
  " is typically allowed to define a set from a property ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_x\)]],
  ", sometimes this process is also called abstraction a set from a property \
",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_x\)]],
  ". The intuition behind abstraction is that ",
  Cell[BoxData[
      \(TraditionalForm\`a \[Element] {x\( | \+x\)\[GothicCapitalP]\_x}\)]],
  " if and only if ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_\(x \[Rule] a\)\)]],
  ". Abstraction goes back to Georg Cantor, who is acknowledged to be the \
founder of modern set theory. Its unrestricted use, however, immediately \
leads to Russel's paradox by forming the \"set\" ",
  Cell[BoxData[
      \(TraditionalForm\`A = {x\( | \+x\)x \[NotElement] x}\)]],
  ". Now one can easily deduce the contradiction ",
  Cell[BoxData[
      \(TraditionalForm\`A \[Element] 
        A \[DoubleLeftRightArrow] A \[NotElement] A\)]],
  ". Different axiomatizations try to resolve this antinomy in different \
ways, the classical ZF approach is to restrict the property ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_x\)]],
  " to the form ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] a \[And] \[GothicCapitalQ]\_x\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " is already known to be a set, which in ZF is called the axiom of \
separation (\"Aussonderungsprinzip\"). The existence of \"sets\" that are not \
formed by separation must be ensured through appropriate axioms, for instance \
an axiom on replacement, which guarantees the existence of the set ",
  Cell[BoxData[
      \(TraditionalForm\`{\[GothicCapitalT]\_x\( | \+x\)\[GothicCapitalP]\_x} \
:= {y\( | \+y\)\[Exists] \+x\((\[GothicCapitalP]\_x \[And] 
                    y = \[GothicCapitalT]\_x)\)}\)]],
  ". ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " does not force the user into one of the existing axiomatizations, nor \
does it check, whether \"sets\" entered into the system actually exist on the \
basis of some axiomatization like ZF or G\[ODoubleDot]del\[Dash]Bernays' \
approach. The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Set Theory prover is based on the following definitions for notions \
commonly used in set theory:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`a \[Element] {x\( | \+x\)\[GothicCapitalP]\_x} : \
\[NegativeThickSpace]\[NegativeThickSpace]\(\(\[DoubleLeftRightArrow]\)\(\
\[GothicCapitalP]\_\(x \[Rule] a\)\)\)\)], "DisplayFormula"],

Cell[BoxData[
    \(TraditionalForm\`{\[GothicCapitalT]\_x\( | \+x\)\[GothicCapitalP]\_x} := \
{y\( | \+y\)\[Exists] \+x\((\[GothicCapitalP]\_x \[And] 
                  y = \[GothicCapitalT]\_x)\)}\)], "DisplayFormula"],

Cell[BoxData[
    \(\[EmptySet] := {x\( | \+x\)x \[NotEqual] x}\)], "DisplayFormula"],

Cell[BoxData[
    \({a\_1, \[Ellipsis], 
        a\_n} := {x\( | \+x\)x = \(a\_1 \[Or] \[Ellipsis] \[Or] x = 
              a\_n\)}\ \ \ \((for\ n \[GreaterEqual] 1)\)\)], "DisplayFormula"],

Cell[BoxData[
    \(TraditionalForm\`\[GothicCapitalS]\_1 \[Union] \[Ellipsis] \[Union] \
\[GothicCapitalS]\_n := {x\( | \+x\)x \[Element] \[GothicCapitalS]\_1 \[Or] \
\[Ellipsis] \[Or] 
              x \[Element] \[GothicCapitalS]\_n}\ \ \((for\ n \[GreaterEqual] 
            2)\)\)], "DisplayFormula"],

Cell[BoxData[
    \(\(\[Union]\[GothicCapitalS]\) := {x\( | \+x\)\[Exists] \+a\((a \
\[Element] \[GothicCapitalS] \[And] x \[Element] a)\)}\)], "DisplayFormula"],

Cell[BoxData[
    \(\(\[Union]\+x \[GothicCapitalS]\_x\) := \
\(\[Union]{\(\[GothicCapitalS]\_x\)\( | \+x\)}\)\)], "DisplayFormula"],

Cell[BoxData[
    \(TraditionalForm\`\[GothicCapitalS]\_1 \[Intersection] \[Ellipsis] \
\[Intersection] \[GothicCapitalS]\_n := {x\( | \+x\)x \[Element] \
\[GothicCapitalS]\_1 \[And] \[Ellipsis] \[And] 
              x \[Element] \[GothicCapitalS]\_n}\ \ \ \((for\ n \
\[GreaterEqual] 2)\)\)], "DisplayFormula"],

Cell[BoxData[
    \(\(\[Intersection]\[GothicCapitalS]\) := {x\( | \+x\)\[ForAll] \+a\((a \
\[Element] \[GothicCapitalS] \[And] 
                  x \[Element] 
                    a)\)}\ \ \ \((if\ \[GothicCapitalS] \[NotEqual] \
\[EmptySet])\)\)], "DisplayFormula"],

Cell[BoxData[
    \(\(\[Intersection]\[EmptySet]\) := \[EmptySet]\)], "DisplayFormula"],

Cell[BoxData[
    \(\(\[Intersection]\+x \[GothicCapitalS]\_x\) := \(\[Intersection]{\(\
\[GothicCapitalS]\_x\)\( | \+x\)}\)\)], "DisplayFormula"],

Cell[BoxData[
    \(\[GothicCapitalS]\_1 \[SubsetEqual] \(\(\[GothicCapitalS]\_2\) : \
\[NegativeThickSpace]\[NegativeThickSpace]\(\(\[DoubleLeftRightArrow]\)\(\
\[ForAll] \+a a \[Element] \[GothicCapitalS]\_1\)\) \[Implies] 
          a \[Element] \[GothicCapitalS]\_2\)\)], "DisplayFormula"],

Cell[BoxData[
    \(\[GothicCapitalS]\_1 = \(\[GothicCapitalS]\_2\) : \[NegativeThickSpace]\
\[NegativeThickSpace]\(\(\[DoubleLeftRightArrow]\)\(\[ForAll] \+a 
              a \[Element] \[GothicCapitalS]\_1 \[DoubleLeftRightArrow] 
                a \[Element] \[GothicCapitalS]\_2\)\)\)], "DisplayFormula"],

Cell[BoxData[
    \(\[ScriptCapitalP][\[GothicCapitalS]] := {x\( | \+x\)x \[SubsetEqual] \
\[GothicCapitalS]}\)], "DisplayFormula"],

Cell[BoxData[
    \(\[GothicCapitalS]\_1\[Backslash]\[GothicCapitalS]\_2 := {x\( | \+x\)x \
\[Element] \[GothicCapitalS]\_1 \[And] 
            x \[NotElement] \[GothicCapitalS]\_2}\)], "DisplayFormula"],

Cell[BoxData[
    \(\[GothicCapitalS]\_1\[Cross]\[Ellipsis]\[Cross]\[GothicCapitalS]\_n := \
{\[LeftAngleBracket]x\_1, \[Ellipsis], 
              x\_n\[RightAngleBracket]\( | \+\(x\_1, \[Ellipsis], 
                x\_n\)\)x\_1 \[Element] \[GothicCapitalS]\_1 \[And] \
\[Ellipsis] \[And] 
              x\_n \[Element] \[GothicCapitalS]\_n}\ \ \ \((for\ n \
\[GreaterEqual] 2)\)\)], "DisplayFormula"],

Cell[BoxData[
    \(TraditionalForm\`a \[Element] \(\(\[GothicCapitalS]\^c\) : \
\[NegativeThickSpace]\[NegativeThickSpace]\(\(\[DoubleLeftRightArrow]\)\(a\)\)\
 \[NotElement] \[GothicCapitalS]\)\)], "DisplayFormula"],

Cell[TextData[{
  "When using the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Set Theory prover, one accepts these definitions and assumes an \
underlying axiomatic system that guarantees the existence of all sets defined \
in there."
}], "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preliminaries on Terminology", "Section",
  CellTags->"Sec:Terminology"],

Cell[TextData[{
  "We will use the following ",
  StyleBox["terminology",
    FontSlant->"Italic"],
  " in the description of the prove modules: a ",
  StyleBox["proof situation",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa] \[RightTee] \[ScriptCapitalG]\)]],
  " is made up from a knowledge base of assumptions \[CapitalKappa] and a \
goal \[ScriptCapitalG], and it should be understood as an abbreviation for \
the phrase: \[LeftGuillemet]We have to prove \[ScriptCapitalG] from \
\[CapitalKappa]\[RightGuillemet]. Typically, the goal will be a single \
formula of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language, hence we use capital script letters such as \[ScriptCapitalG] \
or \[ScriptCapitalS], whereas the knowledge base consists of a collection of \
formulae, called the assumptions. It will be convenient in the description of \
the rules to view the knowledge base just as a (possibly empty) ",
  StyleBox["sequence of formulae",
    FontSlant->"Italic"],
  ", therefore we utilize capital greek letters such as \[CapitalKappa], \
\[CapitalLambda], \[CapitalDelta], or \[CapitalGamma] as they are commonly \
used for denoting sequences of formulae. Note, however, that in the actual \
implementation of inference rules in a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " special prover, we represent the knowledge base by a Mathematica \
expression of the form \[Bullet]asml[\[Ellipsis]], as already mentioned in \
Section ",
  ButtonBox["3.1",
    ButtonData:>{"Part1.nb", "Sec:ProversInTheorema"},
    ButtonStyle->"Hyperlink"],
  ". When referring to the knowledge base in more detail, we will denote a \
sequence of formulae simply by ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalF]\_1, \[Ellipsis], \[GothicCapitalF]\
\_n\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma], \[GothicCapitalF]\_1, \
\[CapitalDelta], \[GothicCapitalF]\_2, \[CapitalLambda]\)]],
  ". In particular,"
}], "SingleParagraph"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalF], \[CapitalKappa]\)]],
  " denotes \[LeftGuillemet]a formula \[GothicCapitalF] adjoined to the \
collection of formulae \[CapitalKappa]\[RightGuillemet] and"
}], "IndentedText"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalF]\_1, \[Ellipsis], \[GothicCapitalF]\
\_n, \[CapitalKappa]\)]],
  " denotes \[LeftGuillemet]the formulae ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalF]\_1\)]],
  " through ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalF]\_n\)]],
  " adjoined to the collection of formulae \[CapitalKappa]\[RightGuillemet]."
}], "IndentedText"],

Cell[TextData[{
  "Now, the task of the special provers is essentially the execution of \
individual ",
  StyleBox["proof steps",
    FontSlant->"Italic"],
  " that ",
  StyleBox["reduce",
    FontSlant->"Italic"],
  " the proof situation, where the rules applied by the special provers \
guiding the transformations of proof situations are called ",
  StyleBox["inference rules",
    FontSlant->"Italic"],
  ". Thus, an inference rule turns a proof situation ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa] \[RightTee] \[ScriptCapitalG]\)]],
  " into a proof situation ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa]\^\[Prime] \[RightTee] \
\[ScriptCapitalG]\^\[Prime]\)]],
  " with a new goal ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\^\[Prime]\)]],
  " and a new knowledge base ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa]\^\[Prime]\)]],
  ", where we call ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa] \[RightTee] \[ScriptCapitalG]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa]\^\[Prime] \[RightTee] \
\[ScriptCapitalG]\^\[Prime]\)]],
  " the ",
  StyleBox["in\[Dash]situation",
    FontSlant->"Italic"],
  " and the ",
  StyleBox["then\[Dash]situation",
    FontSlant->"Italic"],
  " of the rule, respectively. In the description of inference rules, we will \
denote an inference rule named \[ScriptCapitalI] transforming ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa] \[RightTee] \[ScriptCapitalG]\)]],
  " into ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa]\^\[Prime] \[RightTee] \
\[ScriptCapitalG]\^\[Prime]\)]],
  " by"
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{"\[ScriptCapitalI]", ":", GridBox[{
          {\(\[CapitalKappa]\^\[Prime]\), 
            "\[RightTee]", \(\[ScriptCapitalG]\^\[Prime]\)},
          {"\[CapitalKappa]", "\[RightTee]", "\[ScriptCapitalG]"}
          },
        ColumnSpacings->0.4,
        RowLines->True]}]], "InferenceRule"],

Cell[TextData[{
  "(read as: \[LeftGuillemet]The rule \[ScriptCapitalI] justifies a proof \
step to reduce the proof of \[ScriptCapitalG] from ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa]\)]],
  " to a proof of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\^\[Prime]\)]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa]\^\[Prime]\)]],
  "\[RightGuillemet]). This notation is similar to notations used in logic \
for describing inference rules in formal prove calculi, like for instance the \
sequent calculus (e.g. [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["EFT92",
            ButtonData:>"EFT92",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "H.D. Ebbinghaus and J. Flum and W. Thomas, 1992, Einf\
\[UDoubleDot]hrung in die mathematische Logik"],
          "Text"], TraditionalForm]]],
  "]), the Gentzen calculus (e.g. [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Gall86",
            ButtonData:>"Gall86",
            ButtonStyle->"RefLink",
            ButtonNote->"J.H. Gallier, 1986, Logic for Computer Science"],
          "Text"], TraditionalForm]]],
  "]), or the calculus of natural deduction (e.g. [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Manna74",
            ButtonData:>"Manna74",
            ButtonStyle->"RefLink",
            ButtonNote->"Z. Manna, 1974, Mathematical Theory of Computation"],
          
          "Text"], TraditionalForm]]],
  "]). Certain similarities to these formalisms are desired, but we use it \
purely as a symbolic description for proof steps, and we do not refer to any \
meaning of the symbols in any known logic system, see also the examples of \
concrete examples of inference rules using this notation ",
  ButtonBox["below",
    ButtonData:>"ExInfRules",
    ButtonStyle->"Hyperlink"],
  ". ",
  StyleBox["Branching inference rules",
    FontSlant->"Italic"],
  " result in several new goals with corresponding knowledge bases, and we \
symbolize this behavior by"
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[ScriptCapitalI]", ":", 
        RowBox[{GridBox[{
              {\(\[CapitalKappa]\^\((1)\) \[RightTee] \
\(\[ScriptCapitalG]\^\((1)\)\ and\ \[Ellipsis]\ and\ \ \[CapitalKappa]\^\((n)\
\) \[RightTee] \[ScriptCapitalG]\^\((n)\)\)\)},
              {\(\[CapitalKappa] \[RightTee] \[ScriptCapitalG]\)}
              },
            RowLines->True], "  ", "or", "  ", 
          RowBox[{"\[ScriptCapitalI]", ":", GridBox[{
                {\(\[CapitalKappa]\^\((1)\) \[RightTee] \(\[ScriptCapitalG]\^\
\((1)\)\ or\ \[Ellipsis]\ or\ \ \[CapitalKappa]\^\((n)\) \[RightTee] \
\[ScriptCapitalG]\^\((n)\)\)\)},
                {\(\[CapitalKappa] \[RightTee] \[ScriptCapitalG]\)}
                },
              RowLines->True]}]}]}], "  ", ","}]], "InferenceRule"],

Cell[TextData[{
  "where the first means that ",
  StyleBox["all",
    FontSlant->"Italic"],
  " branches ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa]\^\((1)\) \[RightTee] \
\[ScriptCapitalG]\^\((1)\)\)]],
  " through ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa]\^\((n)\) \[RightTee] \
\[ScriptCapitalG]\^\((n)\)\)]],
  " have to be verified and the second indicates that it is sufficient that \
",
  StyleBox["one",
    FontSlant->"Italic"],
  " of the branches succeeds. In the actual implementation, ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "'s proof search procedure passes a third parameter to the special provers, \
the ",
  StyleBox["additional facts",
    FontSlant->"Italic"],
  " lookup table, which can be used to store book\[Dash]keeping information \
about prove progress. Through the additional facts of a proof situation it is \
possible to exchange information between the special provers combined in a \
user prover. The additional facts may change when proceeding from a proof \
situation to the subsequent proof situation, thus the additional facts are \
appropriate for storing information that depends on the proof situation. Each \
special prover may administer its own slot in the additional facts of a proof \
situation, called the prover's ",
  StyleBox["local proof context",
    FontSlant->"Italic"],
  ", in addition to the prover's ",
  StyleBox["global proof context",
    FontSlant->"Italic"],
  ", which is designed to contain global information independent of the proof \
situation. The local proof context will be omitted in the depiction of the \
inference rules, operations on the local proof context will be described by \
other means such as natural language."
}], "FirstParagraph"],

Cell[TextData[{
  "In some situations, we will demonstrate the effect of an inference rule by \
directly calling the Mathematica program implementing a special prover. Note, \
that this serves only the purpose of demonstration of the implementation! \
When actually working with ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", the exclusive access to the provers is through ",
  StyleBox["Prove", "MathematicaInput"],
  ", which then calls a ",
  StyleBox["user prover",
    FontSlant->"Italic"],
  ". Both the parameters passed as well as the result returned by the special \
prover refer to internal data structures, which we shall not explain in all \
details here, see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Tomu98",
            ButtonData:>"Tomu98",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "Elena Tomuta, 1998, An Architecture for Combining Provers and \
its Applications in the Theo ..."],
          "Text"], TraditionalForm]]],
  "]. The return value corresponds to a nested list representation of the new \
node inserted into the proof object representing the then\[Dash]situation of \
the inference rule applied. This node still contains all information \
necessary for later simplification and the natural language presentation of \
the proof, though it does not contain the actual text. The text is finally \
generated by applying the function ",
  StyleBox["ProofHeader", "MathematicaInput"],
  " to (a condensed form of) the proof object node. Again for demonstration \
purposes only, we will for most of the rules show ",
  StyleBox["the effect",
    FontSlant->"Italic"],
  " of calling ProofHeader directly, but we omit displaying the call to \
ProofHeader. The \"\[MathematicaIcon]\"\[Dash]icon on the right margin \
indicates cells that have been generated automatically by a call to \
ProofHeader. With a little bit of fantasy, these demonstrations of directly \
calling special provers and natural language generation are \
self\[Dash]explaining, they might contribute to the recognition of \
applications of particular inference rules in the concrete case studies in \
Part 3 of this thesis.\nA proof generated by the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system consists of a sequence of proof situations, starting from the \
initial proof goal and the initial knowledge base specified in the Prove call \
ending in a terminal proved situation.  A proof situation ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa] \[RightTee] \[ScriptCapitalG]\)]],
  " is ",
  StyleBox["terminal\[Dash]proved",
    FontSlant->"Italic"],
  ", if it allows a decision upon proof success, e.g. if the goal is \
identical to a formula in the knowledge base. We call an inference rule ",
  StyleBox["terminal\[Dash]proved",
    FontSlant->"Italic"],
  " if its in\[Dash]situation is terminal proved, and we denote terminal \
proved inference rules by"
}], "Text"],

Cell[BoxData[
    RowBox[{"\[ScriptCapitalI]", ":", 
      RowBox[{GridBox[{
            {"proved"},
            {\(\[CapitalKappa] \[RightTee] \[ScriptCapitalG]\)}
            },
          RowLines->True], " ", "."}]}]], "InferenceRule"],

Cell["\<\
Examples of well\[Dash]known inference rules written in this \
terminology are:\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{"AssumptionIsConclusion", ":", GridBox[{
          {"proved"},
          {\(\[CapitalGamma], \[ScriptCapitalG], \[CapitalLambda] \[RightTee] \
\[ScriptCapitalG]\)}
          },
        RowLines->True]}]], "InferenceRule",
  CellTags->"ExInfRules"],

Cell[BoxData[
    RowBox[{"ModusPonens", ":", GridBox[{
          {\(B, \[CapitalGamma], A, \[CapitalDelta], 
            A \[Implies] B, \[CapitalLambda]\), "\[RightTee]", 
            "\[ScriptCapitalG]"},
          {\(\[CapitalGamma], A, \[CapitalDelta], 
            A \[Implies] B, \[CapitalLambda]\), "\[RightTee]", 
            "\[ScriptCapitalG]"}
          },
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[BoxData[
    RowBox[{"ArbitraryButFixed", ":", GridBox[{
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicCapitalP]\_\(x\_0\)\)},
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[ForAll] \+x \[GothicCapitalP]\_x\)}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[TextData[{
  "The inference rule \"AssumptionIsConclusion\" tells, that, if the \
knowledge base contains a formula that is identical to the goal then the goal \
is proved and the proof is finished. The proof situation ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma], \[ScriptCapitalG], \[CapitalLambda] \
\[RightTee] \[ScriptCapitalG]\)]],
  " is terminal\[Dash]proved, because it successfully terminates a proof, \
thus, we call the whole inference rule terminal\[Dash]proved. The inference \
rule \"ModusPonens\" says, that, if the knowledge base contains a formula ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and an implication ",
  Cell[BoxData[
      \(TraditionalForm\`A \[Implies] B\)]],
  " then we can adjoin ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " to the knowledge base. This is in some sense an ",
  StyleBox["algorithmic formulation",
    FontSlant->"Italic"],
  " of the classical formulation of Modus Ponens, which allows from ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`A \[Implies] B\)]],
  " to infer ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  ". The rule \"ArbitraryButFixed\" implements the common proof technique for \
proving universal goals, which reduces the proof of a statement ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_x\)]],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " to the proof of ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_\(x\_0\)\)]],
  " for a ",
  StyleBox["new",
    FontSlant->"Italic"],
  " constant ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  ". In the actual implementation in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system, we use symbols starting with the \"\[Cent]\" for inference rule \
names, and currently these symbols' value is the symbol name converted to a \
string omitting the \[Cent], e.g. the name of the first rule above is the \
symbol \[Cent]AssumptionIsConclusion, whose value is the string \
\"AssumptionIsConclusion\". In the description of the rules, we use the \
symbol names, although all ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " output shows the respective strings. Note also, that the string quotes \
are not displayed in output cells. We assume that this will cause no \
confusion."
}], "FirstParagraph"],

Cell[TextData[{
  "In natural deduction calculi like [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Manna74",
            ButtonData:>"Manna74",
            ButtonStyle->"RefLink",
            ButtonNote->"Z. Manna, 1974, Mathematical Theory of Computation"],
          
          "Text"], TraditionalForm]]],
  "], this rule is called \"\[ForAll] introduction\" and it is used to infer \
",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \_x \[GothicCapitalP]\_x\)]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_x\)]],
  " following the general design of inference rules for being suitable for ",
  StyleBox["forward reasoning",
    FontSlant->"Italic"],
  ". A formal proof in such calculi is always a sequence of inference rules \
starting from axioms ending finally in the goal. This is an aspect, where ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " substantially differs from any formal prove calculus, because in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system, a proof may be a ",
  StyleBox["combination",
    FontSlant->"Italic"],
  " of ",
  StyleBox["forward reasoning",
    FontSlant->"Italic"],
  " and ",
  StyleBox["backward reasoning",
    FontSlant->"Italic"],
  " steps. In human proving, this corresponds to the alternation between ",
  StyleBox["expanding knowledge",
    FontSlant->"Italic"],
  " and ",
  StyleBox["reducing the goal",
    FontSlant->"Italic"],
  " during the search for a proof, or, as this is sometimes referred to as ",
  StyleBox["bottom\[Dash]up",
    FontSlant->"Italic"],
  " and ",
  StyleBox["top\[Dash]down",
    FontSlant->"Italic"],
  " reasoning. Thus, ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " inference rules are richer than inference rules in classical deduction \
calculi in the sense that they in addition specify whether to be applied in \
bottom\[Dash]up or top\[Dash]down fashion. This explains, why we need to \
introduce our own symbolism to describe inference rules and available notions \
do not cover our needs. Moreover, from the algorithmic point of view, the \
notation we invented comes very close to the actual implementation of \
inference rules in the frame ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " special provers. Inference rules for special provers for specialized \
areas of mathematics, like for instance the Set Theory prover, are special \
inference rules that can be derived from classical natural deduction rules \
together with definitions characteristic for the area of interest. Therefore, \
we will refer to ",
  StyleBox["known inference rules from natural deduction",
    FontSlant->"Italic"],
  " in the correctness proofs for such inference rules, see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Manna74",
            ButtonData:>"Manna74",
            ButtonStyle->"RefLink",
            ButtonNote->"Z. Manna, 1974, Mathematical Theory of Computation"],
          
          "Text"], TraditionalForm]]],
  "], pp. 108-125, for a listing of inference rules for natural deduction.\n\
Let us recall the notion of substitution from Section ",
  ButtonBox["2.1.3",
    ButtonData:>{"Part1.nb", "Sec:MetaLanguage"},
    ButtonStyle->"Hyperlink"],
  ". If ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " is some substitution on variables, we call ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_s\)]],
  " in an ",
  StyleBox["instance",
    FontSlant->"Italic"],
  " of the expression \[GothicCapitalP]. If there is a substitution ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_u = \(\[GothicCapitalU] = \
\[GothicCapitalQ]\_u\)\)]],
  ", then \[GothicCapitalP] and \[GothicCapitalQ] are said to be ",
  StyleBox["unifiable",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is called a ",
  StyleBox["unifier",
    FontSlant->"Italic"],
  " for \[GothicCapitalP] and \[GothicCapitalQ], and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[GothicCapitalP]", "\[NegativeVeryThinSpace]", 
          
          OverscriptBox[\(\(\[LowerRightArrow]\)\(\[NegativeThickSpace]\
\[NegativeThickSpace]\)\(\[LowerLeftArrow]\)\), 
            AdjustmentBox["u",
              BoxMargins->{{0.3, -0.3}, {-1, 1}},
              BoxBaselineShift->1]], "\[GothicCapitalQ]"}], 
        TraditionalForm]]],
  " denotes a ",
  StyleBox["common instance",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalU]\)]],
  " (obtained by ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ") of \[GothicCapitalP] and \[GothicCapitalQ]. If the particular unifier is \
not of interest, we omit it in the symbol and just write ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP] \[LowerRightArrow] \
\[NegativeThickSpace]\[NegativeThickSpace] \[LowerLeftArrow] \
\[GothicCapitalQ]\)]],
  " for a common instance of \[GothicCapitalP] and \[GothicCapitalQ]. A \
unifier ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is called ",
  StyleBox["the most general unifier",
    FontSlant->"Italic"],
  " for \[GothicCapitalP] and \[GothicCapitalQ] if for all unifiers ",
  Cell[BoxData[
      \(TraditionalForm\`u\&~\)]],
  " for \[GothicCapitalP] and \[GothicCapitalQ] their common instance ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[GothicCapitalP]", "\[NegativeVeryThinSpace]", 
          
          OverscriptBox[\(\(\[LowerRightArrow]\)\(\[NegativeThickSpace]\
\[NegativeThickSpace]\)\(\[LowerLeftArrow]\)\), 
            AdjustmentBox[\(u\&~\),
              BoxMargins->{{0.3, -0.3}, {-1, 1}},
              BoxBaselineShift->1]], "\[GothicCapitalQ]"}], 
        TraditionalForm]]],
  " is an instance of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[GothicCapitalP]", "\[NegativeVeryThinSpace]", 
          
          OverscriptBox[\(\(\[LowerRightArrow]\)\(\[NegativeThickSpace]\
\[NegativeThickSpace]\)\(\[LowerLeftArrow]\)\), 
            AdjustmentBox["u",
              BoxMargins->{{0.3, -0.3}, {-1, 1}},
              BoxBaselineShift->1]], "\[GothicCapitalQ]"}], 
        TraditionalForm]]],
  ". With ",
  Cell[BoxData[
      \(TraditionalForm\`s = {x \[Rule] 3, y \[Rule] 9}\)]],
  ", the formula ",
  Cell[BoxData[
      \(TraditionalForm\`3\^2 = 9\)]],
  " is an instance of ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 = y\)]],
  ". At the same time, ",
  Cell[BoxData[
      \(TraditionalForm\`3\^2 = 9\)]],
  " is also an instance of ",
  Cell[BoxData[
      \(TraditionalForm\`z = 9\)]],
  " since ",
  Cell[BoxData[
      \(TraditionalForm\`\((z = 9)\)\_\(z \[Rule] 3\^2\)\)]],
  " yields ",
  Cell[BoxData[
      \(TraditionalForm\`3\^2 = 9\)]],
  ". Hence, ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 = y\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z = 9\)]],
  " are unifiable and with ",
  Cell[BoxData[
      \(TraditionalForm\`u\&~ = {x \[Rule] 3, y \[Rule] 9, 
          z \[Rule] 3\^2}\)]],
  " we denote the common instance with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\((x\^2 = y)\), "\[NegativeVeryThinSpace]", 
            
            OverscriptBox[\(\(\[LowerRightArrow]\)\(\[NegativeThickSpace]\
\[NegativeThickSpace]\)\(\[LowerLeftArrow]\)\), 
              AdjustmentBox[\(u\&~\),
                BoxMargins->{{0.2, -0.2}, {-1, 1}},
                BoxBaselineShift->1]], \((z = 9)\)}], "=", \((3\^2 = 9)\)}], 
        TraditionalForm]]],
  ", as depicted in Figure ",
  
  CounterBox["Section", "Fig:CommonInstance"],
  ".",
  
  CounterBox["Figure", "Fig:CommonInstance"],
  "."
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\(x\^2\)\(=\)\(y\)\(\ \ \ \ \ \)\), 
            " ", \(\(z\)\(=\)\(9\)\(\ \ \ \ \ \)\)},
          {GridBox[{
                {\(\(\ \)\(\_{x \[Rule] 3, y \[Rule] 9, z \[Rule] 3\^2}\)\), 
                  StyleBox["\[LowerRightArrow]",
                    FontSize->24]}
                },
              ColumnSpacings->-0.5], " ", GridBox[{
                {
                  StyleBox["\[LowerLeftArrow]",
                    
                    FontSize->
                      24], \(\(\ \)\(\_{x \[Rule] 3, y \[Rule] 9, 
                        z \[Rule] 3\^2}\)\)}
                },
              ColumnSpacings->-0.6]},
          {" ", \(3\^2 = 9\), " "}
          },
        RowSpacings->0.2,
        ColumnSpacings->0,
        ColumnAlignments->{Right, Right, Center, Left}], 
      TraditionalForm]], "DisplayFormula",
  CounterIncrements->"Figure"],

Cell[TextData[{
  "Figure ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Figure"],
  ". ",
  StyleBox["Common instance of ", "TableHeadText"],
  StyleBox[Cell[BoxData[
      FormBox[
        StyleBox[\(x\^2 = y\),
          "TableHead"], TraditionalForm]], "TableHeadText"], 
    "TableHeadText"],
  StyleBox[" ", "TableHeadText"],
  StyleBox["and", "TableHeadText"],
  StyleBox[" ", "TableHeadText"],
  StyleBox[Cell[BoxData[
      FormBox[
        StyleBox[\(z = 9\),
          "TableHead"], TraditionalForm]], "TableHeadText"], 
    "TableHeadText"],
  StyleBox[".", "TableHeadText"]
}], "TableHead",
  CellTags->"Fig:CommonInstance"],

Cell[TextData[{
  "Alternatively, we could unify ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 = y\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z = 9\)]],
  " also by ",
  Cell[BoxData[
      \(TraditionalForm\`u = {y \[Rule] 9, z \[Rule] x\^2}\)]],
  ", resulting in the common instance ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\((x\^2 = y)\), "\[NegativeVeryThinSpace]", 
            
            OverscriptBox[\(\(\[LowerRightArrow]\)\(\[NegativeThickSpace]\
\[NegativeThickSpace]\)\(\[LowerLeftArrow]\)\), 
              AdjustmentBox["u",
                BoxMargins->{{0.2, -0.2}, {-1, 1}},
                BoxBaselineShift->1]], \((z = 9)\)}], "=", \((x\^2 = 9)\)}], 
        TraditionalForm]]],
  " as visualized in Figure ",
  
  CounterBox["Section", "Fig:MostGeneralUnifier"],
  ".",
  
  CounterBox["Figure", "Fig:MostGeneralUnifier"],
  ". The unifier ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is a candidate for the most general unifier, since the common instance ",
  Cell[BoxData[
      \(TraditionalForm\`3\^2 = 9\)]],
  " obtained by ",
  Cell[BoxData[
      \(TraditionalForm\`u\&~\)]],
  " is an instance of the common instance ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 = 9\)]],
  " obtained by ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ". In fact, ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is the most general unifier for ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 = y\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z = 9\)]],
  "."
}], "SingleParagraph"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\(x\^2\)\(=\)\(y\)\(\ \ \ \ \ \)\), 
            " ", \(\(z\)\(=\)\(9\)\(\ \)\)},
          {GridBox[{
                {\(\(\ \)\(\_{y \[Rule] 9, z \[Rule] x\^2}\)\), 
                  StyleBox["\[LowerRightArrow]",
                    FontSize->24]}
                },
              ColumnSpacings->-0.5], " ", GridBox[{
                {
                  StyleBox["\[LowerLeftArrow]",
                    
                    FontSize->
                      24], \(\(\ \)\(\_{y \[Rule] 9, z \[Rule] x\^2}\)\)}
                },
              ColumnSpacings->-0.6]},
          {" ", \(x\^2 = 9\), " "}
          },
        RowSpacings->0.2,
        ColumnSpacings->0,
        ColumnAlignments->{Right, Right, Center, Left}], 
      TraditionalForm]], "DisplayFormula",
  CounterIncrements->"Figure"],

Cell[TextData[{
  "Figure ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Figure"],
  ". ",
  StyleBox["Most general unifier for ", "TableHeadText"],
  StyleBox[Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[
              StyleBox[\(x\^2 = y\),
                "TableHead"], TraditionalForm]]]]], TraditionalForm]], 
    "TableHeadText"], "TableHeadText"],
  StyleBox[" ", "TableHeadText"],
  StyleBox["and", "TableHeadText"],
  StyleBox[" ", "TableHeadText"],
  StyleBox[Cell[BoxData[
      FormBox[
        StyleBox[\(z = 9\),
          "TableHead"], TraditionalForm]], "TableHeadText"], 
    "TableHeadText"],
  StyleBox[".", "TableHeadText"]
}], "TableHead",
  CellTags->"Fig:MostGeneralUnifier"],

Cell[TextData[{
  "An ",
  StyleBox["algorithm",
    FontSlant->"Italic"],
  " for computing the most general unifier is known since [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Robi65",
            ButtonData:>"Robi65",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "J. A. Robinson, 1965, A Machine-oriented Logic Based on the \
Resolution Principle"],
          "Text"], TraditionalForm]]],
  "], who invented unification as a basic step for the ",
  StyleBox["resolution method",
    FontSlant->"Italic"],
  " for proving unsatisfiability in predicate logic. A variant of unification \
is implemented in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " in the function ",
  StyleBox["CommonInstance", "MathematicaInput"],
  ", other implementations are under development and will be applied in \
future versions of the system. For the above example, ",
  StyleBox["CommonInstance", "MathematicaInput"],
  " would be called as follows (note the internal representation of the \
equalities and the \[Bullet][\[Ellipsis]] syntax from Section ",
  ButtonBox["2.3.3",
    ButtonData:>{"Part1.nb", "Sec:ProvingAndComputing"},
    ButtonStyle->"Hyperlink"],
  "):"
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CommonInstance[\[Bullet][\[Bullet]var[x]\^2 = \[Bullet]var[
            y], \[Bullet]var[z] = 9]]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "2"], "=", "9"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Rule]", "9"}], ",", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Rule]", 
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " are unifiable, then the function ",
  StyleBox["CommonInstance[a,b]", "MathematicaInput"],
  " returns a pair containing the unified expression ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalU]\)]],
  " and a list of substitutions ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ", such that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"a", "\[NegativeVeryThinSpace]", 
            
            OverscriptBox[\(\(\[LowerRightArrow]\)\(\[NegativeThickSpace]\
\[NegativeThickSpace]\)\(\[LowerLeftArrow]\)\), 
              AdjustmentBox["u",
                BoxMargins->{{0.3, -0.3}, {-1, 1}},
                BoxBaselineShift->1]], " \[NegativeVeryThinSpace]", "b"}], 
          "=", "\[GothicCapitalU]"}], TraditionalForm]]],
  ". If no such assignment on the variables can be found, i.e. if ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " are not unifiable, ",
  StyleBox["CommonInstance", "MathematicaInput"],
  " returns {$Failed,{}}."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CommonInstance[\[Bullet][
        u = t, \[Bullet]var[x] = \[Bullet]var[x]]]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \({$Failed, {}}\)], "Output"]
}, Open  ]],

Cell["\<\
In the sequel, we will give detailed descriptions of the inference \
rules of the individual modules and their interplay in the Set Theory PCS \
user prover.\
\>", "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Set Theory PCS User Prover", "Section",
  CellTags->"Sec:UserProver"],

Cell[TextData[{
  "The user prover combining set theory specific modules with general \
predicate logic prove techniques in PCS style is called SetTheoryPCSProver. \
The SetTheoryPCSProver can be used by giving the option ",
  StyleBox["by\[Rule]SetTheoryPCSProver", "MathematicaInput"],
  " in the call to ",
  StyleBox["Prove", "MathematicaInput"],
  " from the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " User Language. The ",
  StyleBox["Prove", "MathematicaInput"],
  " command extracts the parameters for the user prover from the options \
given to ",
  StyleBox["Prove", "MathematicaInput"],
  " as already explained in all details in ",
  ButtonBox["2.3.1",
    ButtonData:>{"Part1.nb", "Sec:Proving"},
    ButtonStyle->"Hyperlink"],
  ", and passes them on to the ",
  StyleBox["SetTheoryPCSProver", "MathematicaInput"],
  ". The user prover combines the following special provers:"
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CombinedProvers[SetTheoryPCSProver]\)], "Input"],

Cell[BoxData[
    \({TerminalND, STP, STC, STKBR, STS, BasicND, PND, QR, CDP}\)], "Output"]
}, Open  ]],

Cell["\<\
In addition to the options relevant for the special provers, the \
user prover recognizes three options:\
\>", "SingleParagraph"],

Cell[TextData[{
  StyleBox["DisableProver", "MathematicaInput"],
  " allows disabling of one or more of the special provers combined in the \
prover."
}], "ItemizedText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?DisableProver\)\)], "Input"],

Cell[BoxData[
    \("Option for SetTheoryPCSProver. `DisableProver\[Rule]proverList` \
disables all special provers contained in `proverList`."\)], "Print",
  CellTags->"Info3196237144-6946228"]
}, Open  ]],

Cell[TextData[{
  StyleBox["EarlyRewriting", "MathematicaInput"],
  " influences the sequence, in which special provers are applied."
}], "ItemizedText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?EarlyRewriting\)\)], "Input"],

Cell[BoxData[
    \("Option for SetTheoryPCSProver. If True then the QR module is tried \
before STP and BasicND, otherwise it is tried afterwards."\)], "Print",
  CellTags->"Info3196237114-3277180"]
}, Open  ]],

Cell[TextData[{
  StyleBox["TransformRanges", "MathematicaInput"],
  " modifies the representation of quantifiers in formulae occurring in the \
initial proof situation."
}], "ItemizedText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?TransformRanges\)\)], "Input"],

Cell[BoxData[
    \("Option for SetTheoryPCSProver. If True then special ranges in \
quantifiers in the goal and the knowledge base are transformed into simple \
ranges before starting the proof search."\)], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellTags->"Info3196237162-7896388"]
}, Open  ]],

Cell["\<\
Options for the special provers combined in the SetTheoryPCSProver \
are passed to the global variable handling procedure of the respective \
prover. These options will be listed and described in the subsequent sections \
on the respective prover modules.\
\>", "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell["STP: The Set Theory Proving Module", "Section",
  CellTags->"Sec:STP"],

Cell[TextData[{
  "The PCS prove strategy imposes a structure on proofs as alternating phases \
of proving, computing, and solving, as already described in detail in Section \
",
  ButtonBox["3.3",
    ButtonData:>{"Part1.nb", "Sec:PCS"},
    ButtonStyle->"Hyperlink"],
  ". The part of proving can further be subdivided into ",
  StyleBox["two phases",
    FontSlant->"Italic"],
  ", one phase modifying the knowledge base exclusively whereas the other \
phase concentrates on modifications of the goal. Set theory related knowledge \
base modification is performed in the STKBR module described in Section ",
  
  CounterBox["Section", "Sec:STKBR"],
  ", the present section is devoted to the ",
  StyleBox["STP module",
    FontSlant->"Italic"],
  " designed for ",
  StyleBox["set theory proving",
    FontSlant->"Italic"],
  " by set theory related goal reduction."
}], "FirstParagraph"],

Cell[TextData[{
  "The Set Theory proving module is implemented as a special prover named \
STP. As most of the special provers in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", STP implements individual inference rules as individual function \
definitions for ",
  StyleBox["one Mathematica function",
    FontSlant->"Italic"],
  " STP, which differ in the patterns specifying the proof situation. The \
choice, which inference rule to apply next, depends mainly on the pattern of \
the proof situation given in the inference rule, some inference rules are \
influenced in addition by ",
  StyleBox["global variables",
    FontSlant->"Italic"],
  " used by STP, some strategies depend on the proof progress stored in STP's \
",
  StyleBox["local proof context",
    FontSlant->"Italic"],
  ". Following the current design for implementing ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " provers, global prover variables are kept ",
  StyleBox["private",
    FontSlant->"Italic"],
  " in the package containing the respective prover, which prevents the user \
from directly accessing the value. Instead, each prover provides a public ",
  StyleBox["global variable handling procedure",
    FontSlant->"Italic"],
  ", through which the variables can be accessed from within the user prover. \
By this mechanism, each global variable of a special prover is accessible \
through the prover options in the user language ",
  StyleBox["Prove", "MathematicaInput"],
  " call. For the STP prover, the global variable handler is named ",
  StyleBox["SetSTPGlobals", "MathematicaInput"],
  ", and Table ",
  
  CounterBox["Section", "Tab:STPGlobals"],
  ".",
  
  CounterBox["TableHead", "Tab:STPGlobals"],
  " shows how options for SetSTPGlobals map to global variables used by STP."
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(Option\ Name\),
              "ColumnHead"], 
            StyleBox[\(Global\ Variable\ Name\),
              "ColumnHead"], \(Default\ Value\)},
          {
            StyleBox["STPLevel",
              "TableText"], 
            StyleBox["$TmaSTPLevel",
              "TableText"], "100"},
          {
            StyleBox["STPMembershipByInclusion",
              "TableText"], 
            StyleBox["$STPMemberByIncl",
              "TableText"], "False"},
          {
            StyleBox["STPFunctionProperties",
              "TableText"], 
            StyleBox["$STPFunctionProperties",
              "TableText"], "True"}
          }], NullForm]], "Table",
  GridBoxOptions->{RowLines->{0.5, False},
  ColumnLines->0.5},
  CellTags->"Tab:STPGlobals"],

Cell[TextData[{
  "Table ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["TableHead"],
  ". ",
  StyleBox["Options and global variables of the STP prover module", 
    "TableHeadText"]
}], "TableHead"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?STPLevel\)\)], "Input"],

Cell[BoxData[
    \("Option for STP adjusting the power of the STP prover. It can take \
values between 0 and 100. Some special inference rules apply only when \
STPLevel is greater than 50. This option will be superseded by an option for \
toggling individual inference rules."\)], "Print",
  CellTags->"Info3196244389-1095809"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?STPMembershipByInclusion\)\)], "Input"],

Cell[BoxData[
    \("Option for STP allowing the prover to prove membership by a deviation \
over proving an inclusion property."\)], "Print",
  CellTags->"Info3196244399-7615058"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?STPFunctionProperties\)\)], "Input"],

Cell[BoxData[
    \("Option for STP allowing the prover to apply inference rules about \
special function properties such as bijectivity, injectivity, and \
surjectivity."\)], "Print",
  CellTags->"Info3196244409-6537830"]
}, Open  ]],

Cell[CellGroupData[{

Cell["STP Inference Rules", "Subsection",
  CellTags->"c:6"],

Cell[TextData[{
  "In this section, we will list the inference rules used by the STP prover \
grouped by the outermost set theoretic predicate occurring in the goal of the \
in\[Dash]situation. The correctness of these rules follows in most cases \
directly from the definitions of the respective notions in set theory. We \
will give a correctness argument for an inference rule only when it does not \
follow ",
  StyleBox["immediately",
    FontSlant->"Italic"],
  " from the definition. We shall instead show an application of the rule in \
a concrete example together with the proof text, which will be generated \
automatically from the information contained in the proof node generated by \
the inference step."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell["Set Membership", "Subsubsection",
  CellTags->{"Sec:STPMembership", "c:7"}],

Cell["\<\
The prover applies special inference rules for membership according \
to the structure of the goal. \
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipAbstraction",
        FontWeight->"Bold"], ":", GridBox[{
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicCapitalQ]\_\(x \[Rule] \[GothicT]\)\)},
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicT] \[Element] {x\( \[VerticalSeparator] \
\+x\)\[GothicCapitalQ]\_x}\)}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell["Example call with generated natural language text:", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(a \[Element] {x\( | \+x\)x < 10}\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"MembershipAbstraction", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae[\[Bullet]lf["goal'", 
              a < 10, \[Bullet]finfo[]]]}\), ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  StyleBox[\(a < 10\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In order to prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we have to show:"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a < 10\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipAbstractionTerm",
        FontWeight->"Bold"], ":", GridBox[{
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[Exists] \+x\((\[GothicCapitalQ]\_x \[And] \((\
\[GothicT] = \[GothicCapitalT]\_x)\))\)\)},
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicT] \[Element] {\[GothicCapitalT]\_x\( \
\[VerticalSeparator] \+x\)\[GothicCapitalQ]\_x}\)}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell["Example call with generated natural language text:", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(a \[Element] {3  x\( | \+x\)x < 10}\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"MembershipAbstractionTerm\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  RowBox[{
                    UnderscriptBox["\[Exists]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "<", "10"}], "\[And]", 
                        RowBox[{"(", 
                          RowBox[{"a", "=", 
                            RowBox[{"3", "*", 
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}], ")"}]}], ")"}]}], 
                  ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  StyleBox[
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "<", "10"}], "\[And]", 
                          RowBox[{"(", 
                            RowBox[{"a", "=", 
                              RowBox[{"3", "*", 
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}]}], ")"}]}], ")"}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In order to prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we have to show"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "<", "10"}], "\[And]", 
            RowBox[{"(", 
              RowBox[{"a", "=", 
                RowBox[{"3", "*", 
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}]}]], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipSingleton",
        FontWeight->"Bold"], ":", GridBox[{
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicT] = \[GothicCapitalT]\)},
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicT] \[Element] {\[GothicCapitalT]}\)}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(a \[Element] {3}\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"MembershipSingleton", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae[\[Bullet]lf["goal'", 
              a = 3, \[Bullet]finfo[]]]}\), ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  StyleBox[\(a = 3\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In order to prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " it suffices",
  " to show"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a = 3\)], "Conclusion"],
  Cell[" :", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipFiniteSet",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicT] \[NotEqual] \[GothicCapitalT]\_2, \[Ellipsis], \
\[GothicT] \[NotEqual] \[GothicCapitalT]\_n, \[CapitalKappa]\), 
              "\[RightTee]", \(\[GothicT] = \[GothicCapitalT]\_1\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicT] \[Element] {\[GothicCapitalT]\_1, \
\[GothicCapitalT]\_2, \[Ellipsis], \[GothicCapitalT]\_n}\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((if\ n \[GreaterEqual] 2)\)}]}]], "InferenceRule"],

Cell["Proof (Correctness of \[Cent]MembershipFiniteSet)", "SingleParagraph",
  FontWeight->"Bold"],

Cell[TextData[{
  "By definition of a finite set, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] {\[GothicCapitalT]\_1, \
\[GothicCapitalT]\_2, \[Ellipsis], \[GothicCapitalT]\_n}\)]],
  " is equivalent to ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] = \(\[GothicCapitalT]\_1 \[Or] \[GothicT] \
= \(\[GothicCapitalT]\_2 \[Or] \[Ellipsis] \[Or] \[GothicT] = \
\[GothicCapitalT]\_n\)\)\)]],
  ". For proving a disjunction we may assume the negations of all literals \
but the first one and then prove the first literal."
}], "SingleParagraph"],

Cell["\[EmptySquare]", "Text",
  CellMargins->{{Inherited, Inherited}, {Inherited, -6}},
  TextAlignment->Right,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(a \[Element] {3, 4}\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"MembershipFiniteSet", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae[\[Bullet]lf["goal'", 
              a = 3, \[Bullet]finfo[]], \[Bullet]lf["goal[1]", 
              a \[NotEqual] 4, \[Bullet]finfo[]]]}\), ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  StyleBox[\(a = 3\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goal[1]\"\>", ",", 
                      StyleBox[\(a \[NotEqual] 4\),
                        "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", "kb"}], "]"}], ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In order to prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we may assume"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[1])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[NotEqual] 4\)], "Assumption"],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[1]"],

Cell["and show:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a = 3\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell[TextData[{
  "(Note, that in all other cases the formula ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " trivially holds!)"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(a \[Element] {3, 4, 5, 6}\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"MembershipFiniteSet", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae[\[Bullet]lf["goal'", 
              a = 3, \[Bullet]finfo[]], \[Bullet]lf["goal[1]", 
              a \[NotEqual] 4, \[Bullet]finfo[]], \[Bullet]lf["goal[2]", 
              a \[NotEqual] 5, \[Bullet]finfo[]], \[Bullet]lf["goal[3]", 
              a \[NotEqual] 6, \[Bullet]finfo[]]]}\), ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  StyleBox[\(a = 3\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goal[1]\"\>", ",", 
                      StyleBox[\(a \[NotEqual] 4\),
                        "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", 
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goal[2]\"\>", ",", 
                      StyleBox[\(a \[NotEqual] 5\),
                        "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", 
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goal[3]\"\>", ",", 
                      StyleBox[\(a \[NotEqual] 6\),
                        "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", "kb"}], "]"}], ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In order to prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we may assume"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[1])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[NotEqual] 4\)], "Assumption"],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[1]"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[2])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[NotEqual] 5\)], "Assumption"],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[2]"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[3])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[NotEqual] 6\)], "Assumption"],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[3]"],

Cell["and show:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a = 3\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell[TextData[{
  "(Note, that in all other cases the formula ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " trivially holds!)"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipFiniteUnion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicT] \[NotElement] \[GothicCapitalS]\_2, \[Ellipsis], \
\[GothicT] \[NotElement] \[GothicCapitalS]\_n, \[CapitalKappa]\), 
              "\[RightTee]", \(\[GothicT] \[Element] \[GothicCapitalS]\_1\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicT] \[Element] \[GothicCapitalS]\_1 \
\[Union] \[GothicCapitalS]\_2 \[Union] \[Ellipsis] \[Union] \[GothicCapitalS]\
\_n\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((if\ n \[GreaterEqual] 2)\)}]}]], "InferenceRule"],

Cell["Proof (Correctness of \[Cent]MembershipFiniteUnion)", "SingleParagraph",
  FontWeight->"Bold"],

Cell["\<\
Since membership in a finite union of sets is defined by the finite \
disjunction of membership in the individual sets, the correctness argument \
for proving finite disjunctions applies also in this case.\
\>", \
"SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(a \[Element] A \[Union] B\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"MembershipFiniteUnion", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae[\[Bullet]lf["goal'", 
              a \[Element] A, \[Bullet]finfo[]], \[Bullet]lf["goal[1]", 
              a \[NotElement] B, \[Bullet]finfo[]]]}\), ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  StyleBox[\(a \[Element] A\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goal[1]\"\>", ",", 
                      StyleBox[\(a \[NotElement] B\),
                        "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", "kb"}], "]"}], ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "In order to prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we may assume"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[1])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[NotElement] B\)], "Assumption"],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[1]"],

Cell["and show:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] A\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell[TextData[{
  "(Note, that in all other cases the formula ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " trivially holds!)"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(a \[Element] A \[Union] B \[Union] C \[Union] D\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"MembershipFiniteUnion", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae[\[Bullet]lf["goal'", 
              a \[Element] A, \[Bullet]finfo[]], \[Bullet]lf["goal[1]", 
              a \[NotElement] B, \[Bullet]finfo[]], \[Bullet]lf["goal[2]", 
              a \[NotElement] C, \[Bullet]finfo[]], \[Bullet]lf["goal[3]", 
              a \[NotElement] D, \[Bullet]finfo[]]]}\), ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  StyleBox[\(a \[Element] A\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goal[1]\"\>", ",", 
                      StyleBox[\(a \[NotElement] B\),
                        "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", 
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goal[2]\"\>", ",", 
                      StyleBox[\(a \[NotElement] C\),
                        "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", 
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goal[3]\"\>", ",", 
                      StyleBox[\(a \[NotElement] D\),
                        "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", "kb"}], "]"}], ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "In order to prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we may assume"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[1])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[NotElement] B\)], "Assumption"],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[1]"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[2])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[NotElement] C\)], "Assumption"],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[2]"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[3])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[NotElement] D\)], "Assumption"],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[3]"],

Cell["and show:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] A\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell[TextData[{
  "(Note, that in all other cases the formula ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " trivially holds!)"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipUnaryUnion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[Exists] \+s\((\[GothicT] \[Element] s \[And] 
                    s \[Element] \[GothicCapitalS])\)\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicT] \[Element] \(\[Union]\
\[GothicCapitalS]\)\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((where\ \[GothicT]\ and\ \[GothicCapitalS]\ are\ free\ of\ s)\
\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(a \[Element] \(\[Union]A\)\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"MembershipUnaryUnion\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  RowBox[{
                    UnderscriptBox["\[Exists]", 
                      RowBox[{
                        StyleBox["A1",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"a", "\[Element]", 
                          StyleBox["A1",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "\[And]", 
                        RowBox[{
                          StyleBox["A1",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", "A"}]}], ")"}]}],
                   ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  StyleBox[
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["A1",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"a", "\[Element]", 
                            StyleBox["A1",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], "\[And]", 
                          RowBox[{
                            StyleBox["A1",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[Element]", "A"}]}], 
                        ")"}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "In order to prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we have to show"
}], "ProofText"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["A1",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"a", "\[Element]", 
              StyleBox["A1",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[And]", 
            RowBox[{
              StyleBox["A1",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Element]", "A"}]}], ")"}]}]], 
    "Conclusion"],
  Cell[" :", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell["\<\
A special case of this rule is implemented for the case that \
\[GothicCapitalS] itself is a finite set, which reduces to membership in a \
finite union. \
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipUnaryUnion",
        FontWeight->"Bold"], ":", GridBox[{
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicT] \[Element] \[GothicCapitalS]\_1 \
\[Union] \[Ellipsis] \[Union] \[GothicCapitalS]\_n\)},
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicT] \[Element] \(\[Union]{\
\[GothicCapitalS]\_1, \[Ellipsis], \[GothicCapitalS]\_n}\)\)}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell["\<\
For the union quantifier, we provide a simplified version of the \
general inference rule for the case, where the condition in the quantifier is \
omitted.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipUnionOf",
        FontWeight->"Bold"], ":", GridBox[{
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[Exists] \+x\((\[GothicT] \[Element] \
\[GothicCapitalS]\_x \[And] \[GothicCapitalC]\_x)\)\)},
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicT] \[Element] \(\(\[Union]\+x\)\+\(\
\[GothicCapitalC]\_x\)\[GothicCapitalS]\_x\)\)}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipUnionOf",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[Exists] \+x \[GothicT] \[Element] \
\[GothicCapitalS]\_x\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicT] \[Element] \(\[Union]\+x \
\[GothicCapitalS]\_x\)\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((special\ case, \ no\ condition)\)}]}]], "InferenceRule"],

Cell["Proof (Correctness of \[Cent]MembershipUnionOf, general case)", \
"SingleParagraph",
  FontWeight->"Bold"],

Cell[TextData[{
  "Assume ",
  Cell[BoxData[
      \(TraditionalForm\`\[Exists] \+x\((\[GothicT] \[Element] \
\[GothicCapitalS]\_x \[And] \[GothicCapitalC]\_x)\)\)]],
  ", thus ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] \[GothicCapitalS]\_\(x\_1\) \
\[And] \[GothicCapitalC]\_\(x\_1\)\)]],
  " for some ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  ". With ",
  Cell[BoxData[
      \(TraditionalForm\`z := \[GothicCapitalS]\_\(x\_1\)\)]],
  " we can infer ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] 
            z \[And] \[GothicCapitalC]\_\(x\_1\) \[And] 
          z = \[GothicCapitalS]\_\(x\_1\)\)]],
  ", hence  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Exists] \+z\(\[Exists] \+x\((\[GothicT] \[Element] 
                  z \[And] \[GothicCapitalC]\_x \[And] 
                z = \[GothicCapitalS]\_x)\)\)\)]],
  ". Separating the quantifiers gives ",
  Cell[BoxData[
      \(TraditionalForm\`\[Exists] \+z \[GothicT] \[Element] 
            z \[And] \[Exists] \+x\((\[GothicCapitalC]\_x \[And] 
                z = \[GothicCapitalS]\_x)\)\)]],
  ", which is, by definition of set abstraction, equivalent to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Exists] \+z \[GothicT] \[Element] z \[And] 
        z \[Element] {\[GothicCapitalS]\_x\( | \
\+x\)\[GothicCapitalC]\_x}\)]],
  ". This is equivalent to ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[GothicT]", "\[Element]", 
          RowBox[{
            StyleBox["\[Union]",
              
              SpanMaxSize->
                2], \({\[GothicCapitalS]\_x\( | \
\+x\)\[GothicCapitalC]\_x}\)}]}], TraditionalForm]]],
  " by definition of unary union, hence ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] \(\(\[Union]\+x\)\+\(\
\[GothicCapitalC]\_x\)\[GothicCapitalS]\_x\)\)]],
  "by the definition of the union quantifier."
}], "SingleParagraph"],

Cell["\[EmptySquare]", "Text",
  CellMargins->{{Inherited, Inherited}, {Inherited, -6}},
  TextAlignment->Right,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[
              RowBox[{"a", "\[Element]", 
                RowBox[{
                  UnderscriptBox[
                    UnderscriptBox[
                      StyleBox["\[Union]",
                        "HighlightedText"], 
                      "x"], \(x \[Element] \[DoubleStruckCapitalN]\)], 
                  RowBox[{"{", 
                    RowBox[{"x", ",", 
                      FractionBox[
                        StyleBox["x",
                          "HighlightedText"], "2"]}], "}"}]}]}],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"MembershipUnionOf\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  RowBox[{
                    UnderscriptBox["\[Exists]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"a", "\[Element]", 
                          RowBox[{"{", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], ",", 
                              FractionBox[
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "2"]}], "}"}]}], 
                        "\[And]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", 
                          "\[DoubleStruckCapitalN]"}]}], ")"}]}], 
                  ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  StyleBox[
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"a", "\[Element]", 
                            RowBox[{"{", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], ",", 
                                FractionBox[
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "2"]}], "}"}]}], 
                          "\[And]", 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[Element]", 
                            "\[DoubleStruckCapitalN]"}]}], ")"}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "In order to show ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we have to show"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"a", "\[Element]", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  FractionBox[
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "2"]}], "}"}]}], "\[And]", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Element]", 
              "\[DoubleStruckCapitalN]"}]}], ")"}]}]], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipFiniteIntersection",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[CapitalKappa] \[RightTee] \(\[GothicT] \[Element] \
\[GothicCapitalS]\_1\ and\ \[Ellipsis]\ and\ \ \[CapitalKappa] \[RightTee] \
\[GothicT] \[Element] \[GothicCapitalS]\_n\)\)},
            {\(\[CapitalKappa] \[RightTee] \[GothicT] \[Element] \
\[GothicCapitalS]\_1 \[Intersection] \[Ellipsis] \[Intersection] \
\[GothicCapitalS]\_n\)}
            },
          RowLines->True], 
        "   ", \((if\ n \[GreaterEqual] 2)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(a \[Element] A \[Intersection] B\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"MembershipFiniteIntersection", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae[\[Bullet]lf["goal[1]", 
              a \[Element] A, \[Bullet]finfo[]], \[Bullet]lf["goal[2]", 
              a \[Element] B, \[Bullet]finfo[]]]}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"\<\"\!\(\*
StyleBox[\\\"ProofSituation\\\",\\n\\\"HighlightedText\\\"]\)\"\>", ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal[1]\"\>", ",", 
                    StyleBox[\(a \[Element] A\),
                      "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
                ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"\<\"\!\(\*
StyleBox[\\\"ProofSituation\\\",\\n\\\"HighlightedText\\\"]\)\"\>", ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal[2]\"\>", ",", 
                    StyleBox[\(a \[Element] B\),
                      "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
                ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}]}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "We prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " by splitting up the intersection into its individual components:"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["We have to prove:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[1])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] A\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[1]"],

Cell["We have to prove:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[2])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] B\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[2]"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipUnaryIntersection",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(s \[Element] \[GothicCapitalS], \[CapitalKappa]\), 
              "\[RightTee]", \(\[GothicT] \[Element] s\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicT] \[Element] \(\[Intersection]\
\[GothicCapitalS]\)\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((where\ s\ is\ some\ new\ constant)\)}]}]], "InferenceRule"],

Cell["\<\
The correctness of this rule follows immediately from the \
definition of unary intersection together with the inference rule for \
universally quantified implications (the \"arbitrary but fixed\"\[Dash]rule).\
\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(a \[Element] \(\[Intersection]A\)\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"MembershipUnaryIntersection\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.A\"\>", ",", 
                    RowBox[{
                      StyleBox[\(A3\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[Element]", "A"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal'\"\>", ",", 
                    RowBox[{"a", "\[Element]", 
                      StyleBox[\(A3\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ",", \(\[Bullet]finfo[]\)}], 
                  "]"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  RowBox[{
                    StyleBox["a",
                      "HighlightedText"], 
                    StyleBox["\[Element]",
                      "HighlightedText"], 
                    StyleBox[\(A3\_0\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None]}], ",", \(\[Bullet]finfo[]\)}], "]"}],
               ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goal.A\"\>", ",", 
                      RowBox[{
                        StyleBox[\(A3\_0\),
                          "HighlightedText",
                          FontSlant->"Italic",
                          Background->None], 
                        StyleBox["\[Element]",
                          "HighlightedText"], 
                        StyleBox["A",
                          "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", "kb"}], "]"}], ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "For proving ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we assume"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.A)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A3\_0 \[Element] A\)], "Assumption"],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.A"],

Cell["and show:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] A3\_0\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell["\<\
Similar to the unary union, membership in a unary intersection of a \
finite set reduces to membership in a finite intersection. \
\>", \
"SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipUnaryIntersection",
        FontWeight->"Bold"], ":", GridBox[{
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicT] \[Element] \[GothicCapitalS]\_1 \
\[Intersection] \[Ellipsis] \[Intersection] \[GothicCapitalS]\_n\)},
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicT] \[Element] \(\[Intersection]{\
\[GothicCapitalS]\_1, \[Ellipsis], \[GothicCapitalS]\_n}\)\)}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell["\<\
For the intersection quantifier, we again provide a specialized \
version of the general inference rule for empty condition in the \
quantifier.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipIntersectionOf",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicCapitalC]\_\(x \[Rule] x\_1\), \[CapitalKappa]\), 
              "\[RightTee]", \(\[GothicT] \[Element] \[GothicCapitalS]\_\(x \
\[Rule] x\_1\)\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicT] \[Element] \(\(\[Intersection]\+x\)\
\+\(\[GothicCapitalC]\_x\)\[GothicCapitalS]\_x\)\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", \((where\ x\_1\ is\ some\ new\ constant)\), 
        Cell[""]}]}]], "InferenceRule"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipIntersectionOf",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicT] \[Element] \[GothicCapitalS]\_\(x \
\[Rule] x\_1\)\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicT] \[Element] \(\[Intersection]\+x \
\[GothicCapitalS]\_x\)\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((special\ case, \ no\ condition)\)}]}]], "InferenceRule"],

Cell["\<\
Proof (Correctness of \[Cent]MembershipIntersectionOf, general \
case)\
\>", "SingleParagraph",
  FontWeight->"Bold"],

Cell[TextData[{
  "Assume we can prove ",
  Cell[BoxData[
      RowBox[{"\[GothicT]", "\[Element]", 
        SubscriptBox["\[GothicCapitalS]", 
          RowBox[{
            StyleBox["x",
              FontSlant->"Italic"], "\[Rule]", 
            SubscriptBox[
              StyleBox["x",
                FontSlant->"Italic"], "1"]}]]}]]],
  "for a new constant ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  " under the additional assumption ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalC]\_\(x \[Rule] x\_1\)\)]],
  ". The assumption ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalC]\_\(x \[Rule] x\_1\)\)]],
  " allows to assume as well ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalS]\_\(x \[Rule] x\_1\) \[Element] {\
\[GothicCapitalS]\_x\( | \+x\)\[GothicCapitalC]\_x}\)]],
  " by set abstraction. With ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1 := \[GothicCapitalS]\_\(x \[Rule] x\_1\)\)]],
  " a new constant, we have ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] y\_1\)]],
  " under the assumption ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1 \[Element] {\[GothicCapitalS]\_x\( | \+x\)\
\[GothicCapitalC]\_x}\)]],
  ", from which we can generalize ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \+y 
            y \[Element] {\[GothicCapitalS]\_x\( | \+x\)\[GothicCapitalC]\_x} \
\[Implies] \[GothicT] \[Element] y\)]],
  ". By the definition of unary intersection, this is equivalent to ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[GothicT]", "\[Element]", 
          RowBox[{
            StyleBox["\[Intersection]",
              
              SpanMaxSize->
                2], \({\[GothicCapitalS]\_x\( | \
\+x\)\[GothicCapitalC]\_x}\)}]}], TraditionalForm]]],
  ", hence ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] \(\(\[Intersection]\+x\)\+\(\
\[GothicCapitalC]\_x\)\[GothicCapitalS]\_x\)\)]],
  " by the definition of the intersection quantifier."
}], "SingleParagraph"],

Cell["\[EmptySquare]", "Text",
  CellMargins->{{Inherited, Inherited}, {Inherited, -6}},
  TextAlignment->Right,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[
              RowBox[{"a", "\[Element]", 
                RowBox[{
                  UnderscriptBox[
                    UnderscriptBox[
                      StyleBox["\[Intersection]",
                        "HighlightedText"], 
                      "x"], \(x \[Element] \[DoubleStruckCapitalN]\)], 
                  RowBox[{"{", 
                    RowBox[{"x", ",", 
                      FractionBox[
                        StyleBox["x",
                          "HighlightedText"], "2"]}], "}"}]}]}],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"MembershipIntersectionOf\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.A\"\>", ",", 
                    RowBox[{
                      StyleBox[\(x\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[Element]", 
                      "\[DoubleStruckCapitalN]"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal'\"\>", ",", 
                    RowBox[{"a", "\[Element]", 
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox[\(x\_0\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], ",", 
                          FractionBox[
                            StyleBox[\(x\_0\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "2"]}], "}"}]}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}]}], "]"}]}], "}"}], ",",
         
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  StyleBox[
                    RowBox[{"a", "\[Element]", 
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox[\(x\_0\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], ",", 
                          FractionBox[
                            StyleBox[\(x\_0\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "2"]}], "}"}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goal.A\"\>", ",", 
                      RowBox[{
                        StyleBox[\(x\_0\),
                          "HighlightedText",
                          FontSlant->"Italic",
                          Background->None], 
                        StyleBox["\[Element]",
                          "HighlightedText"], 
                        StyleBox["\[DoubleStruckCapitalN]",
                          "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", "kb"}], "]"}], ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "For proving ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we assume"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.A)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(x\_0 \[Element] \[DoubleStruckCapitalN]\)], "Assumption"],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.A"],

Cell["and show:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] {x\_0, x\_0\/2}\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipDifference",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[CapitalKappa] \[RightTee] \(\[GothicT] \[Element] \
\[GothicCapitalS]\_1\ and\ \ \[CapitalKappa] \[RightTee] \[GothicT] \
\[NotElement] \[GothicCapitalS]\_2\)\)},
          {\(\[CapitalKappa] \[RightTee] \[GothicT] \[Element] \
\[GothicCapitalS]\_1\[Backslash]\[GothicCapitalS]\_2\)}
          },
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(a \[Element] A\[Backslash]B\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"MembershipDifference", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae[\[Bullet]lf["goal[1]", 
              a \[Element] A, \[Bullet]finfo[]], \[Bullet]lf["goal[2]", 
              a \[NotElement] B, \[Bullet]finfo[]]]}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"\<\"\!\(\*
StyleBox[\\\"ProofSituation\\\",\\n\\\"HighlightedText\\\"]\)\"\>", ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal[1]\"\>", ",", 
                    StyleBox[\(a \[Element] A\),
                      "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
                ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"\<\"\!\(\*
StyleBox[\\\"ProofSituation\\\",\\n\\\"HighlightedText\\\"]\)\"\>", ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal[2]\"\>", ",", 
                    StyleBox[\(a \[NotElement] B\),
                      "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
                ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}]}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "We have to prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ", thus, we have to show:"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[1])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] A\)], "Conclusion"],
  Cell[":", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[1]"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[2])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[NotElement] B\)], "Conclusion"],
  Cell[":", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[2]"],

Cell["\<\
The complement operator is supported in one of the following \
variants: as superscript \"c\" (roman letter), as superscript \"\[ScriptC]\" \
(script lower case letter), or as function symbol \"\[ScriptCapitalC]\" \
(script upper case letter). We formulate the inference rule for the first \
case only.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipComplement",
        FontWeight->"Bold"], ":", GridBox[{
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicT] \[NotElement] \[GothicCapitalS]\)},
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicT] \[Element] \[GothicCapitalS]\^c\)}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[
              RowBox[{"a", "\[Element]", 
                SuperscriptBox[
                  StyleBox["A",
                    "HighlightedText"], "c"]}],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"MembershipComplement", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae[\[Bullet]lf["goal.c", 
              a \[NotElement] A, \[Bullet]finfo[]]]}\), ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal.c\"\>", ",", 
                  StyleBox[\(a \[NotElement] A\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "Membership in the power set is reduced to set inclusion, we do not provide \
a separate named rule, see the respective rules for set inclusion in Section \
",
  
  CounterBox["Section", "Sec:STPInclusion"],
  ".",
  
  CounterBox["Subsection", "Sec:STPInclusion"],
  ".",
  
  CounterBox["Subsubsection", "Sec:STPInclusion"],
  ". The entry in the local proof context prevents from cycling when using \
the special inference rule for proving membership by reduction to the \
inclusion relation, see the inference rule \[Cent]MembershipByIncl."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(a \[Element] \[ScriptCapitalP][A]\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), 
        ",", \(\[Bullet]lkTab[{{"\<STP\>", \
\[Bullet]lkTab[{{"\<goalWasIncl\>", False}}]}}]\)}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          RowBox[{"\<\"\!\(\*
StyleBox[\\\"Inclusion\\\",\\n\\\"HighlightedText\\\"]\)\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.A\"\>", ",", 
                    RowBox[{
                      StyleBox[\(a5\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[Element]", "a"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal'\"\>", ",", 
                    RowBox[{
                      StyleBox[\(a5\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[Element]", "A"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}]}], "]"}]}], "}"}], ",",
         
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  RowBox[{
                    StyleBox[\(a5\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[Element]", "A"}], 
                  ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goal.A\"\>", ",", 
                      RowBox[{
                        StyleBox[\(a5\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "\[Element]", "a"}], 
                      ",", \(\[Bullet]finfo[]\)}], "]"}], ",", "kb"}], "]"}], 
              ",", \(\[Bullet]lkTab[{{"STP", \[Bullet]lkTab[{{"goalWasIncl", \
{a, A}}}]}}]\)}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
        ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "For proving ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we choose"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.A)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a2\_0 \[Element] a\)], "Assumption"],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.A"],

Cell["and show:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a2\_0 \[Element] A\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipCrossProduct",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[CapitalKappa] \[RightTee] \[LeftBracketingBar]\[GothicT]\
\[RightBracketingBar] = 
                n\ \ and\ \[CapitalKappa] \[RightTee] \(\[GothicT]\_1 \
\[Element] \[GothicCapitalS]\_1\ and\ \[Ellipsis]\ \ and\ \ \[CapitalKappa] \
\[RightTee] \[GothicT]\_n \[Element] \[GothicCapitalS]\_n\)\)},
            {\(\[CapitalKappa] \[RightTee] \[GothicT] \[Element] \
\[GothicCapitalS]\_1\[Cross]\[Ellipsis]\[Cross]\[GothicCapitalS]\_n\)}
            },
          RowLines->True], 
        "    ", \((if\ n \[GreaterEqual] 2)\)}]}]], "InferenceRule"],

Cell["\<\
(In the above formulation, the index of \[GothicT] stands for \
component selection of tuples.)\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            
            StyleBox[\(\[LeftAngleBracket]10, 9, 
                  8\[RightAngleBracket] \[Element] A\[Cross]B\[Cross]C\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"MembershipCrossProduct", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae[\[Bullet]lf[
              "goal'", \[LeftBracketingBar]\[LeftAngleBracket]10, 9, 
                    8\[RightAngleBracket]\[RightBracketingBar] = 
                3, \[Bullet]finfo[]], \[Bullet]lf[
              "goal[1]", \((\[LeftAngleBracket]10, 9, \
8\[RightAngleBracket])\)\_1 \[Element] A, \[Bullet]finfo[]], \[Bullet]lf[
              "goal[2]", \((\[LeftAngleBracket]10, 9, \
8\[RightAngleBracket])\)\_2 \[Element] B, \[Bullet]finfo[]], \[Bullet]lf[
              "goal[3]", \((\[LeftAngleBracket]10, 9, \
8\[RightAngleBracket])\)\_3 \[Element] C, \[Bullet]finfo[]]]}\), ",", 
        RowBox[{"{", 
          
          RowBox[{\({"ProofSituation", \[Bullet]lf[
                "goal'", \[LeftBracketingBar]\[LeftAngleBracket]10, 9, 
                      8\[RightAngleBracket]\[RightBracketingBar] = 
                  3, \[Bullet]finfo[]], \[Bullet]asml[kb], af}\), ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["\<\"ProofSituation\"\>",
                  "HighlightedText"], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal[1]\"\>", ",", 
                    
                    StyleBox[\(\((\[LeftAngleBracket]10, 9, 8\
\[RightAngleBracket])\)\_1 \[Element] A\),
                      "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
                ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"\<\"\!\(\*
StyleBox[\\\"ProofSituation\\\",\\n\\\"HighlightedText\\\"]\)\"\>", ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal[2]\"\>", ",", 
                    
                    StyleBox[\(\((\[LeftAngleBracket]10, 9, 8\
\[RightAngleBracket])\)\_2 \[Element] B\),
                      "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
                ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"\<\"\!\(\*
StyleBox[\\\"ProofSituation\\\",\\n\\\"HighlightedText\\\"]\)\"\>", ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal[3]\"\>", ",", 
                    
                    StyleBox[\(\((\[LeftAngleBracket]10, 9, 8\
\[RightAngleBracket])\)\_3 \[Element] C\),
                      "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
                ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}]}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "We prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " by checking the individual components:"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["We have to prove:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[LeftBracketingBar]\[LeftAngleBracket]10, 9, 
            8\[RightAngleBracket]\[RightBracketingBar] = 3\)], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell["We have to prove:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[1])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\((\[LeftAngleBracket]10, 9, 8\[RightAngleBracket])\)\_1 \[Element] 
        A\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[1]"],

Cell["We have to prove:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[2])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\((\[LeftAngleBracket]10, 9, 8\[RightAngleBracket])\)\_2 \[Element] 
        B\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[2]"],

Cell["We have to prove:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal[3])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\((\[LeftAngleBracket]10, 9, 8\[RightAngleBracket])\)\_3 \[Element] 
        C\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal[3]"],

Cell[TextData[{
  "The prover uses ",
  StyleBox["one special inference rule",
    FontSlant->"Italic"],
  " for proving membership: if we know ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] B\)]],
  ", then we can \"reduce\" the goal ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] A\)]],
  " to showing ",
  Cell[BoxData[
      \(TraditionalForm\`B \[SubsetEqual] A\)]],
  ". This rule must be restricted in order ",
  StyleBox["not to apply",
    FontSlant->"Italic"],
  ", when ",
  Cell[BoxData[
      \(TraditionalForm\`B \[SubsetEqual] A\)]],
  " was the ",
  StyleBox["original goal",
    FontSlant->"Italic"],
  ". As we will see later in Section ",
  
  CounterBox["Section", "Sec:STPInclusion"],
  ".",
  
  CounterBox["Subsection", "Sec:STPInclusion"],
  ".",
  
  CounterBox["Subsubsection", "Sec:STPInclusion"],
  "., we prove ",
  Cell[BoxData[
      \(TraditionalForm\`B \[SubsetEqual] A\)]],
  " by showing ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] A\)]],
  " under the additional assumption ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] B\)]],
  ". Unrestricted use of the above rule would then prove ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] A\)]],
  " by showing ",
  Cell[BoxData[
      \(TraditionalForm\`B \[SubsetEqual] A\)]],
  ", which would lead to a cycle. We use one slot of the local proof context \
of STP for memorizing an inclusion as the original proof goal. In addition, \
the prover option ",
  StyleBox["STPMembershipByInclusion", "MathematicaInput"],
  " can be used to deactivate the rule completely."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]MembershipByIncl",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[CapitalLambda], \[CapitalDelta]\), 
            "\[RightTee]", \(\[GothicCapitalS]\_1 \[SubsetEqual] \
\[GothicCapitalS]\_2\)},
          {\(\[CapitalLambda], \[GothicT] \[Element] \[GothicCapitalS]\_1, \
\[CapitalDelta]\), 
            "\[RightTee]", \(\[GothicT] \[Element] \[GothicCapitalS]\_2\)}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell["Proof (Correctness of \[Cent]MembershipByIncl)", "SingleParagraph",
  FontWeight->"Bold"],

Cell[TextData[{
  "Assume ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalS]\_1 \[SubsetEqual] \
\[GothicCapitalS]\_2\)]],
  ". Thus, if ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] \[GothicCapitalS]\_1\)]],
  " then also ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] \[GothicCapitalS]\_2\)]],
  " by definition of \[SubsetEqual]."
}], "SingleParagraph"],

Cell["\[EmptySquare]", "Text",
  CellMargins->{{Inherited, Inherited}, {Inherited, -6}},
  TextAlignment->Right,
  TextJustification->0],

Cell[TextData[{
  "In order to demonstrate this rule, we first ",
  StyleBox["activate",
    FontSlant->"Italic"],
  " it by simulating the prover option."
}], "SingleParagraph"],

Cell[BoxData[
    \(SetSTPGlobals[STPMembershipByInclusion \[Rule] True]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(a \[Element] A\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
        RowBox[{"\[Bullet]asml", "[", 
          RowBox[{
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\"\<assum\>\"", ",", 
                StyleBox[\(a \[Element] B\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], ",",
             "kb"}], "]"}], 
        ",", \(\[Bullet]lkTab[{{"\<STP\>", \
\[Bullet]lkTab[{{"\<goalWasIncl\>", False}}]}}]\)}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"MembershipByIncl", \[Bullet]usedFormulae["goal", 
            "assum"], \[Bullet]generatedFormulae[\[Bullet]lf[
              "assum\[SubsetEqual]goal", 
              B \[SubsetEqual] A, \[Bullet]finfo[]]]}\), ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"assum\[SubsetEqual]goal\"\>", ",", 
                  StyleBox[\(B \[SubsetEqual] A\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[kb]\), ",", 
              
              StyleBox[\(\[Bullet]lkTab[{{"STP", \
\[Bullet]lkTab[{{"goalWasIncl", {B, A}}}]}}]\),
                "HighlightedText"]}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
        ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "In order to show ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ", by ",
  StyleBox["(", "Label"],
  ButtonBox["assum",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "assum"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ", it suffices to show"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(assum\[SubsetEqual]goal)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(B \[SubsetEqual] A\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"assum\[SubsetEqual]goal"],

Cell[TextData[{
  "We store the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`B \[SubsetEqual] A\)]],
  " is the goal in the additional facts of the resulting proof situation, so \
that the inference rule for inclusion can take this fact into account, which \
prevents the proof search from cycling."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<assum\[SubsetEqual]goal\>\"", ",", 
            StyleBox[\(B \[SubsetEqual] A\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", 
        StyleBox[\(\[Bullet]lkTab[{{"\<STP\>", \
\[Bullet]lkTab[{{"\<goalWasIncl\>", {B, A}}}]}}]\),
          "HighlightedText"]}], "]"}]], "Input"],

Cell[BoxData[
    \(STP[\[Bullet]lf["assum\[SubsetEqual]goal", 
        B \[SubsetEqual] A, \[Bullet]finfo[]], \[Bullet]asml[
        kb], \[Bullet]lkTab[{{"STP", \[Bullet]lkTab[{{"goalWasIncl", {B, 
                    A}}}]}}]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Without this entry in the local proof context, the inclusion in the goal \
would be reduced again to membership, and the proof search is back where it \
started, see also the rules for inclusion in Section ",
  
  CounterBox["Section", "Sec:STPInclusion"],
  ".",
  
  CounterBox["Subsection", "Sec:STPInclusion"],
  ".",
  
  CounterBox["Subsubsection", "Sec:STPInclusion"],
  "."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<assum\[SubsetEqual]goal\>\"", ",", 
            StyleBox[\(B \[SubsetEqual] A\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", 
        StyleBox[\(\[Bullet]lkTab[{{"\<STP\>", \
\[Bullet]lkTab[{{"\<goalWasIncl\>", False}}]}}]\),
          "HighlightedText"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"Inclusion\"\>", 
            ",", \(\[Bullet]usedFormulae["assum\[SubsetEqual]goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"assum\[SubsetEqual]goal.A\"\>", ",", 
                    RowBox[{
                      StyleBox[\(B4\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[Element]", "B"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"assum\[SubsetEqual]goal'\"\>", ",", 
                    RowBox[{
                      StyleBox[\(B4\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[Element]", "A"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}]}], "]"}]}], "}"}], ",",
         
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"assum\[SubsetEqual]goal'\"\>", ",", 
                  RowBox[{
                    StyleBox[\(B4\_0\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None], 
                    StyleBox["\[Element]",
                      "HighlightedText"], 
                    StyleBox["A",
                      "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                "]"}], ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"assum\[SubsetEqual]goal.A\"\>", ",", 
                      RowBox[{
                        StyleBox[\(B4\_0\),
                          "HighlightedText",
                          FontSlant->"Italic",
                          Background->None], 
                        StyleBox["\[Element]",
                          "HighlightedText"], 
                        StyleBox["B",
                          "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", "kb"}], "]"}], 
              ",", \(\[Bullet]lkTab[{{"STP", \[Bullet]lkTab[{{"goalWasIncl", \
{B, A}}}]}}]\)}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
        ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set Inclusion", "Subsubsection",
  CellTags->"Sec:STPInclusion"],

Cell["\<\
Set inclusion reduces by definition to membership. In addition to \
the main inference rule that carries out this reduction we provide some \
specialized variants mainly for efficiency reasons.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]EmptySetSubset",
        FontWeight->"Bold"], ":", GridBox[{
          {"proved"},
          {\(\[CapitalKappa] \[RightTee] \[EmptySet] \[SubsetEqual] \
\[GothicCapitalS]\)}
          },
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(\[EmptySet] \[SubsetEqual] {x\( | \+x\)x < 10}\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"EmptySetSubset", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae[]}\), ",", \({}\), 
        ",", \({}\), ",", \({}\), ",", "\<\"\!\(\*
StyleBox[\\\"proved\\\",\\n\\\"HighlightedText\\\"]\)\"\>"}], "}"}]], "Output",\

  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "Formula ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " holds, because the empty set is subset of any set."
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]InclusionInEmpty",
        FontWeight->"Bold"], ":", GridBox[{
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicCapitalS] = \[EmptySet]\)},
          {"\[CapitalKappa]", 
            "\[RightTee]", \(\[GothicCapitalS] \[SubsetEqual] \[EmptySet]\)}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            
            StyleBox[\({x\( | \+x\)x \[Element] A \[And] 
                      x < 10} \[SubsetEqual] \[EmptySet]\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"InclusionInEmpty\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal.\[EmptySet]\"\>", ",", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], 
                        UnderscriptBox["\[VerticalSeparator]", 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], " "}]], 
                        RowBox[{
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[Element]", "A"}], 
                          "\[And]", 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "<", "10"}]}]}], "}"}], 
                    "=", \({}\)}], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              "]"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal.\[EmptySet]\"\>", ",", 
                  StyleBox[
                    RowBox[{
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], 
                          UnderscriptBox["\[VerticalSeparator]", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], " "}]], 
                          RowBox[{
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "\[Element]", "A"}], 
                            "\[And]", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "<", "10"}]}]}], "}"}], 
                      "=", \({}\)}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "The only possibility for ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " to hold is"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.\[EmptySet])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            UnderscriptBox["\[VerticalSeparator]", 
              RowBox[{
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], " "}]], 
            RowBox[{
              RowBox[{
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[Element]", "A"}], "\[And]", 
              RowBox[{
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "<", "10"}]}]}], "}"}], "=", \({}\)}]], 
    "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.\[EmptySet]"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]ConjunctionSubset",
        FontWeight->"Bold"], ":", GridBox[{
          {"proved"},
          {\(\[CapitalKappa] \[RightTee] {x\( | \+x\)\[Ellipsis] \[And] 
                      x \[Element] \[GothicCapitalS] \[And] \[Ellipsis]} \
\[SubsetEqual] \[GothicCapitalS]\)}
          },
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            
            StyleBox[\({x\( | \+x\)x \[Element] A \[And] 
                      x < 10} \[SubsetEqual] A\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"ConjunctionSubset", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae[]}\), ",", \({}\), 
        ",", \({}\), ",", \({}\), ",", "\<\"\!\(\*
StyleBox[\\\"proved\\\",\\n\\\"HighlightedText\\\"]\)\"\>"}], "}"}]], "Output",\

  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "It can be easily verified that formula ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " always holds."
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]DisjunctionSubset",
        FontWeight->"Bold"], ":", GridBox[{
          {"proved"},
          {\(\[CapitalKappa] \[RightTee] \[GothicCapitalS] \[SubsetEqual] \
{x\( | \+x\)\[Ellipsis] \[Or] 
                      x \[Element] \[GothicCapitalS] \[Or] \[Ellipsis]}\)}
          },
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[
              RowBox[{"A", "\[SubsetEqual]", 
                RowBox[{"{", 
                  RowBox[{"x", 
                    StyleBox[\( | \+x\),
                      "HighlightedText"], 
                    StyleBox[\(x \[Element] A \[Or] x < 10\),
                      "HighlightedText"]}], "}"}]}],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", 
        ",", \({"DisjunctionSubset", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae[]}\), ",", \({}\), 
        ",", \({}\), ",", \({}\), ",", "\<\"\!\(\*
StyleBox[\\\"proved\\\",\\n\\\"HighlightedText\\\"]\)\"\>"}], "}"}]], "Output",\

  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "It can be easily verified that formula ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " always holds."
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Unfortunately, we have to re\[Dash]code some inference rules in the STP \
module, which would normally be covered by the QR module, because we cannot \
guarantee that the QR rules are always considered prior to the STP rules. The \
sequence, in which the special provers are tested, depends on how the \
particular user prover arranges the special provers. The SetTheoryPCSProver, \
in particular, allows the option ",
  StyleBox["EarlyRewriting\[Rule]True", "MathematicaInput"],
  " in order to ",
  StyleBox["enforce",
    FontSlant->"Italic"],
  " QR to be tried ",
  StyleBox["before",
    FontSlant->"Italic"],
  " STP. Proof situations affected from this collision are those, where ",
  StyleBox["goal\[Dash]rewriting",
    FontSlant->"Italic"],
  " would apply during QR, but the goal can also be reduced \"by definition\" \
using a basic STP rule. We illustrate this in one concrete re\[Dash]coded STP \
rule, which can be deactivated by setting the prover option ",
  StyleBox["STPLevel", "MathematicaInput"],
  " to a value less or equal 50."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]Inclusion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[CapitalLambda], \[CapitalDelta], \[ForAll] \+x \
\[GothicCapitalC]\_x \[Implies] \[GothicCapitalA]\_x \[SubsetEqual] \
\[GothicCapitalB]\_x\), 
              "\[RightTee]", \(\[GothicCapitalC]\_\(x \[Rule] x\_1\)\)},
            {\(\[CapitalLambda], \[ForAll] \+x \[GothicCapitalC]\_x \
\[Implies] \[GothicCapitalA]\_x \[SubsetEqual] \[GothicCapitalB]\_x, \
\[CapitalDelta]\), 
              "\[RightTee]", \(\[GothicCapitalS]\_1 \[SubsetEqual] \
\[GothicCapitalS]\_2\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"where", " ", \(x\_1\), " ", "is", " ", 
              StyleBox["a",
                FontSlant->"Plain"], " ", "constant", " ", "such", " ", 
              "that", " ", \(\[LeftAngleBracket]\[GothicCapitalA]\_x, \
\[GothicCapitalB]\_x\[RightAngleBracket]\_\(x \[Rule] x\_1\)\)}], 
            "=", \(\[LeftAngleBracket]\[GothicCapitalS]\_1, \[GothicCapitalS]\
\_2\[RightAngleBracket]\)}], ")"}]}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            
            StyleBox[\({x\( | \+x\)x < 5} \[SubsetEqual] {x\( | \+x\)x < 
                      10}\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
        RowBox[{"\[Bullet]asml", "[", 
          RowBox[{"kbf", ",", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\"\<assum\>\"", ",", 
                StyleBox[
                  RowBox[{\(\[ForAll] \+\(k, l\)\), 
                    RowBox[{"(", 
                      RowBox[{\(k \[LessEqual] l\), "\[Implies]", 
                        RowBox[{
                          RowBox[{"{", 
                            RowBox[{"x", 
                              StyleBox[\( | \+x\),
                                "HighlightedText"], 
                              StyleBox[\(x < k\),
                                "HighlightedText"]}], 
                            StyleBox["}",
                              "HighlightedText"]}], 
                          StyleBox["\[SubsetEqual]",
                            "HighlightedText"], 
                          StyleBox[\({x\( | \+x\)x < l}\),
                            "HighlightedText"]}]}], ")"}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], ",",
             "kbl"}], "]"}], ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"Inclusion\"\>", 
            ",", \(\[Bullet]usedFormulae["goal", "assum"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal.A\"\>", ",", 
                  StyleBox[\(5 \[LessEqual] 10\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              "]"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            
            RowBox[{"\<\"ProofSituation\"\>", 
              ",", \(\[Bullet]lf["goal.A", 
                5 \[LessEqual] 10, \[Bullet]finfo[]]\), ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{"kbf", ",", "kbl", ",", 
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"assum\"\>", ",", 
                      RowBox[{
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["k",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], ",", 
                            StyleBox["l",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}]], 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["k",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "\[LessEqual]", 
                              StyleBox["l",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "\[Implies]", 
                            RowBox[{
                              RowBox[{"{", 
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], 
                                  UnderscriptBox["\[VerticalSeparator]", 
                                    RowBox[{
                                      StyleBox["x",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], " "}]], 
                                  RowBox[{
                                    StyleBox["x",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "<", 
                                    StyleBox["k",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], "}"}], 
                              "\[SubsetEqual]", 
                              RowBox[{"{", 
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], 
                                  UnderscriptBox["\[VerticalSeparator]", 
                                    RowBox[{
                                      StyleBox["x",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], " "}]], 
                                  RowBox[{
                                    StyleBox["x",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "<", 
                                    StyleBox["l",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], "}"}]}]}], 
                          ")"}]}], ",", \(\[Bullet]finfo[]\)}], "]"}]}], 
                "]"}], ",", "af"}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
        ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "In order to show ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ", by ",
  StyleBox["(", "Label"],
  ButtonBox["assum",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "assum"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ", it is sufficient to show"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.A)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(5 \[LessEqual] 10\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.A"],

Cell["\<\
(The rearrangement of the knowledge base has its reason in the \
cooperation with the inference rule on set equality.)\
\>", "FirstParagraph"],

Cell[TextData[{
  "In QR, the universally quantified implication in the knowledge base would \
be used as a mathematica transformation rule ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[GothicCapitalA]_ \[SubsetEqual] \[GothicCapitalB]_ \
\[RuleDelayed] \[GothicCapitalC]\),
          FontWeight->"Bold"], TraditionalForm]]],
  " for rewriting the goal. Thus, if the goal ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalS]\_1 \[SubsetEqual] \
\[GothicCapitalS]\_2\)]],
  " matches the left\[Dash]hand side of the rule with, say, ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " substituted for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", then the goal is rewritten to ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalC]\_\(x \[Rule] a\)\)]],
  ", which is exactly what the rule \[Cent]Inclusion does. Omitting this rule \
would ",
  StyleBox["always",
    FontSlant->"Italic"],
  " try to prove set inclusion, by definition, using reduction to membership. \
However, a human mathematician typically goes back to the definition only if \
no other method applies.",
  "\nThis collision of rules appearing in more than one special prover is \
another indication for possible future improvement for prover implementation. \
In the present structure, the prove strategy is based on ",
  StyleBox["blocks of inference rules",
    FontSlant->"Italic"],
  " grouped according to special provers, which are more or less dedicated to \
",
  StyleBox["areas of mathematics",
    FontSlant->"Italic"],
  ", such as propositional logic, predicate logic, set theory, equations, \
etc. For the future, it would be worthwhile considering a structure of ",
  StyleBox["blocks of inference rules",
    FontSlant->"Italic"],
  " grouped according to ",
  StyleBox["proof phases",
    FontSlant->"Italic"],
  ", such as \[LeftGuillemet]rewrite goal using knowledge base\
\[RightGuillemet], \[LeftGuillemet]infer new knowledge from knowledge base\
\[RightGuillemet], \[LeftGuillemet]eliminate existential, i.e. solve\
\[RightGuillemet], \[LeftGuillemet]apply basic logic\[RightGuillemet], \
\[LeftGuillemet]expand definitions\[RightGuillemet], etc.\nThe m",
  "ain reduction rule for set inclusion combines the definition of inclusion \
with the reduction of the universal implication ",
  StyleBox["in one step",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]Inclusion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(a \[Element] \[GothicCapitalS]\_1, \[CapitalKappa]\), 
              "\[RightTee]", \(a \[Element] \[GothicCapitalS]\_2\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicCapitalS]\_1 \[SubsetEqual] \
\[GothicCapitalS]\_2\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", 
        RowBox[{"(", 
          RowBox[{"where", " ", "a", " ", "is", " ", 
            StyleBox["a",
              FontSlant->"Plain"], " ", "new", " ", "constant"}], 
          ")"}]}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(A \[SubsetEqual] B\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", 
        StyleBox[\(\[Bullet]lkTab[{{"\<STP\>", \
\[Bullet]lkTab[{{"\<goalWasIncl\>", False}}]}}]\),
          "HighlightedText"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"Inclusion\"\>", ",", \(\[Bullet]usedFormulae["goal"]\),
             ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.A\"\>", ",", 
                    RowBox[{
                      StyleBox[\(A2\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[Element]", "A"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal'\"\>", ",", 
                    RowBox[{
                      StyleBox[\(A2\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[Element]", "B"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}]}], "]"}]}], "}"}], ",",
         
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  RowBox[{
                    StyleBox[\(A2\_0\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None], 
                    StyleBox["\[Element]",
                      "HighlightedText"], 
                    StyleBox["B",
                      "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                "]"}], ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goal.A\"\>", ",", 
                      RowBox[{
                        StyleBox[\(A2\_0\),
                          "HighlightedText",
                          FontSlant->"Italic",
                          Background->None], 
                        StyleBox["\[Element]",
                          "HighlightedText"], 
                        StyleBox["A",
                          "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", "kb"}], "]"}], ",", 
              RowBox[{"\[Bullet]lkTab", "[", 
                RowBox[{"{", 
                  RowBox[{"{", 
                    RowBox[{"\<\"STP\"\>", ",", 
                      StyleBox[\(\[Bullet]lkTab[{{"goalWasIncl", {A, B}}}]\),
                        "HighlightedText"]}], "}"}], "}"}], "]"}]}], "}"}], 
          "}"}], ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], 
      "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "For proving ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we choose"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.A)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A2\_0 \[Element] A\)], "Assumption"],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.A"],

Cell["and show:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A2\_0 \[Element] B\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell[TextData[{
  "The rule memorizes the original inclusion goal in the local proof context \
in order to avoid looping in combination with the ",
  StyleBox["\[Cent]MembershipByIncl", "MathematicaInput"],
  " rule, see Section ",
  
  CounterBox["Section", "Sec:STPMembership"],
  ".",
  
  CounterBox["Subsection", "Sec:STPMembership"],
  ".",
  
  CounterBox["Subsubsection", "Sec:STPMembership"],
  ". We provide special rules for the case where one or both of the sets in \
the inclusion are set abstractions, since in these cases the membership \
property in the resulting proof situation can be further reduced \
immediately."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]Inclusion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicCapitalP]\_\(x \[Rule] x\_1\), \[CapitalKappa]\), 
              "\[RightTee]", \(\[GothicCapitalQ]\_\(x \[Rule] x\_1\)\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \({x\( | \+x\)\[GothicCapitalP]\_x} \
\[SubsetEqual] {x\( | \+x\)\[GothicCapitalQ]\_x}\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", 
        RowBox[{"(", 
          RowBox[{"where", " ", \(x\_1\), " ", "is", " ", 
            StyleBox["a",
              FontSlant->"Plain"], " ", "new", " ", "constant"}], 
          ")"}]}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            
            StyleBox[\({x\( | \+x\)x < 5} \[SubsetEqual] {x\( | \+x\)x < 
                      10}\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"Inclusion\"\>", ",", \(\[Bullet]usedFormulae["goal"]\),
             ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.A\"\>", ",", 
                    RowBox[{
                      StyleBox[\(x1\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "<", "5"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal'\"\>", ",", 
                    RowBox[{
                      StyleBox[\(x1\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "<", "10"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}]}], "]"}]}], "}"}], ",",
         
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  RowBox[{
                    StyleBox[\(x1\_0\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None], 
                    StyleBox["<",
                      "HighlightedText"], 
                    StyleBox["10",
                      "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                "]"}], ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goal.A\"\>", ",", 
                      RowBox[{
                        StyleBox[\(x1\_0\),
                          "HighlightedText",
                          FontSlant->"Italic",
                          Background->None], 
                        StyleBox["<",
                          "HighlightedText"], 
                        StyleBox["5",
                          "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", "kb"}], "]"}], ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "For proving ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we choose"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.A)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(x1\_0 < 5\)], "Assumption"],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.A1"],

Cell["and show:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(x1\_0 < 10\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'2"],

Cell["\<\
Compare this proof step with the step in the example above, where \
we demonstrated the rule that reduces the inclusion in the goal by using an \
implication in the knowledge base re\[Dash]coding a rule from QR. We list the \
remaining rules of this type without examples:\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]Inclusion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicCapitalP]\_\(x \[Rule] x\_1\), \[CapitalKappa]\), 
              "\[RightTee]", \(x\_1 \[Element] \[GothicCapitalS]\_2\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \({x\( | \+x\)\[GothicCapitalP]\_x} \
\[SubsetEqual] \[GothicCapitalS]\_2\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", 
        RowBox[{"(", 
          RowBox[{"where", " ", \(x\_1\), " ", "is", " ", 
            StyleBox["a",
              FontSlant->"Plain"], " ", "new", " ", "constant"}], 
          ")"}]}]}]], "InferenceRule"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]Inclusion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(x\_1 \[Element] \[GothicCapitalS]\_1, \[CapitalKappa]\), 
              "\[RightTee]", \(\[GothicCapitalQ]\_\(x \[Rule] x\_1\)\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicCapitalS]\_1 \[SubsetEqual] {x\( | \+x\
\)\[GothicCapitalQ]\_x}\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", 
        RowBox[{"(", 
          RowBox[{"where", " ", \(x\_1\), " ", "is", " ", 
            StyleBox["a",
              FontSlant->"Plain"], " ", "new", " ", "constant"}], 
          ")"}]}]}]], "InferenceRule"],

Cell["Finally, we have an inference rule for proper inclusion.", \
"SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]ProperInclusion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[CapitalKappa] \[RightTee] \(\[GothicCapitalS]\_1 \
\[SubsetEqual] \[GothicCapitalS]\_2\ and\ \ \[CapitalKappa] \[RightTee] \
\[Exists] \+z\((z \[Element] \[GothicCapitalS]\_2 \[And] 
                        z \[NotElement] \[GothicCapitalS]\_1)\)\)\)},
            {\(\[CapitalKappa] \[RightTee] \[GothicCapitalS]\_1 \[Subset] \
\[GothicCapitalS]\_2\)}
            },
          RowLines->True], 
        "   ", \((where\ \[GothicCapitalS]\_1\ and\ \[GothicCapitalS]\_2\ are\
\ free\ of\ z)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\({x\( | \+x\)x < 5} \[Subset] {x\( | \+x\)x < 10}\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"ProperInclusion\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.\[SubsetEqual]\"\>", ",", 
                    RowBox[{
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], 
                          UnderscriptBox["\[VerticalSeparator]", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], " "}]], 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "<", "5"}]}], "}"}], 
                      "\[SubsetEqual]", 
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], 
                          UnderscriptBox["\[VerticalSeparator]", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], " "}]], 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "<", "10"}]}], "}"}]}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal'\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["x5",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["x5",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[Element]", 
                            RowBox[{"{", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], 
                                UnderscriptBox["\[VerticalSeparator]", 
                                  RowBox[{
                                    StyleBox["x",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], " "}]], 
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "<", "10"}]}], "}"}]}],
                           "\[And]", 
                          RowBox[{
                            StyleBox["x5",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[NotElement]", 
                            RowBox[{"{", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], 
                                UnderscriptBox["\[VerticalSeparator]", 
                                  RowBox[{
                                    StyleBox["x",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], " "}]], 
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "<", "5"}]}], 
                              "}"}]}]}], ")"}]}], ",", \(\[Bullet]finfo[]\)}],
                   "]"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"\<\"ProofSituation\"\>", ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.\[SubsetEqual]\"\>", ",", 
                    StyleBox[
                      RowBox[{
                        RowBox[{"{", 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], 
                            UnderscriptBox["\[VerticalSeparator]", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], " "}]], 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "<", "5"}]}], "}"}], 
                        "\[SubsetEqual]", 
                        RowBox[{"{", 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], 
                            UnderscriptBox["\[VerticalSeparator]", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], " "}]], 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "<", "10"}]}], "}"}]}],
                      "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
                ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"\<\"ProofSituation\"\>", ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal'\"\>", ",", 
                    StyleBox[
                      RowBox[{
                        UnderscriptBox["\[Exists]", 
                          RowBox[{
                            StyleBox["x5",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], " "}]], 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["x5",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "\[Element]", 
                              RowBox[{"{", 
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], 
                                  UnderscriptBox["\[VerticalSeparator]", 
                                    RowBox[{
                                      StyleBox["x",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], " "}]], 
                                  RowBox[{
                                    StyleBox["x",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "<", "10"}]}], 
                                "}"}]}], "\[And]", 
                            RowBox[{
                              StyleBox["x5",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "\[NotElement]", 
                              RowBox[{"{", 
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], 
                                  UnderscriptBox["\[VerticalSeparator]", 
                                    RowBox[{
                                      StyleBox["x",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], " "}]], 
                                  RowBox[{
                                    StyleBox["x",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "<", "5"}]}], 
                                "}"}]}]}], ")"}]}],
                      "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
                ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}]}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "For proving ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we have to show first:"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.\[SubsetEqual])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            UnderscriptBox["\[VerticalSeparator]", 
              RowBox[{
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], " "}]], 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "<", "5"}]}], "}"}], "\[SubsetEqual]", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            UnderscriptBox["\[VerticalSeparator]", 
              RowBox[{
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], " "}]], 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "<", "10"}]}], "}"}]}]], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.\[SubsetEqual]"],

Cell["It still remains to show", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["x5",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["x5",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Element]", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], 
                  UnderscriptBox["\[VerticalSeparator]", 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], " "}]], 
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "<", "10"}]}], "}"}]}], "\[And]", 
            RowBox[{
              StyleBox["x5",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[NotElement]", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], 
                  UnderscriptBox["\[VerticalSeparator]", 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], " "}]], 
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "<", "5"}]}], "}"}]}]}], ")"}]}]], 
    "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set Equality", "Subsubsection",
  CellTags->"Sec:STPEquality"],

Cell["\<\
Equality of sets is defined, by the axiom of extensionality, as \
mutual inclusion. In addition to this general reduction principle for set \
equality, we provide special rules for cases, where the empty set is \
involved, and for cases, where an inclusion property occurs in the knowledge \
base that covers one of the resulting proof branches.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]EqualsEmptySet",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[Not] \[GothicCapitalP]\_\(x \[Rule] \
x\_1\)\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \({\[GothicCapitalT]\_x\( \[VerticalSeparator] \
\+x\)\[GothicCapitalP]\_x} = \[EmptySet]\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((where\ x\_1\ is\ some\ new\ constant)\)}]}]], \
"InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["x",
                        "HighlightedText"], "2"], 
                    StyleBox[\( | \+x\),
                      "HighlightedText"], 
                    
                    StyleBox[\(x \[Element] \[DoubleStruckCapitalN] \[And] 
                        x < \(-5\)\),
                      "HighlightedText"]}], "}"}], "=", "\[EmptySet]"}],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"EqualsEmptySet\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'1\"\>", ",", 
                  RowBox[{"\[Not]", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(x\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", 
                          "\[DoubleStruckCapitalN]"}], "\[And]", 
                        RowBox[{
                          StyleBox[\(x\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "<", \((\(-5\))\)}]}], ")"}]}],
                   ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  StyleBox[
                    RowBox[{"\[Not]", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox[\(x\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[Element]", 
                            "\[DoubleStruckCapitalN]"}], "\[And]", 
                          RowBox[{
                            StyleBox[\(x\_1\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "<", \((\(-5\))\)}]}], 
                        ")"}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "We have to prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ", hence, we have to show:"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[Not] \((x\_1 \[Element] \[DoubleStruckCapitalN] \[And] 
            x\_1 < \((\(-5\))\))\)\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'1"],

Cell["\<\
The general case for being empty is covered by the following \
rule:\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]EqualsEmptySet",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {"\[CapitalKappa]", 
              "\[RightTee]", \(a \[NotElement] \[GothicCapitalS]\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicCapitalS] = \[EmptySet]\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((where\ a\ is\ some\ new\ constant)\)}]}]], "InferenceRule"],

Cell["\<\
The characterization of being non\[Dash]empty is formulated as \
follows:\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]NotEmptySet",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[Exists] \+z 
                  z \[Element] \[GothicCapitalS]\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicCapitalS] \[NotEqual] \[EmptySet]\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((where\ \[GothicCapitalS]\ is\ free\ of\ z)\)}]}]], \
"InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["x",
                        "HighlightedText"], 
                      "2"], \( | \+x\), \(x \[Element] \
\[DoubleStruckCapitalN] \[And] x < 5\)}], "}"}], "\[NotEqual]", 
                "\[EmptySet]"}],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"NotEmptySet\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal.\[Not]\[EmptySet]\"\>", ",", 
                  RowBox[{
                    UnderscriptBox["\[Exists]", 
                      RowBox[{
                        StyleBox["x6",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox["x6",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "\[Element]", 
                        RowBox[{"{", 
                          RowBox[{
                            SuperscriptBox[
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "2"], 
                            UnderscriptBox["\[VerticalSeparator]", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], " "}]], 
                            RowBox[{
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "\[Element]", 
                                "\[DoubleStruckCapitalN]"}], "\[And]", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "<", "5"}]}]}], "}"}]}], 
                      ")"}]}], ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}]}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal.\[Not]\[EmptySet]\"\>", ",", 
                  StyleBox[
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["x6",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox["x6",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", 
                          RowBox[{"{", 
                            RowBox[{
                              SuperscriptBox[
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "2"], 
                              UnderscriptBox["\[VerticalSeparator]", 
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], " "}]], 
                              RowBox[{
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "\[Element]", 
                                  "\[DoubleStruckCapitalN]"}], "\[And]", 
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "<", "5"}]}]}], 
                            "}"}]}], ")"}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[kb]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "Formula ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " means that we have to show that"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.\[Not]\[EmptySet])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["x6",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            StyleBox["x6",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "\[Element]", 
            RowBox[{"{", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "2"], 
                UnderscriptBox["\[VerticalSeparator]", 
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], " "}]], 
                RowBox[{
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[Element]", 
                    "\[DoubleStruckCapitalN]"}], "\[And]", 
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "<", "5"}]}]}], "}"}]}], ")"}]}]], 
    "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.\[Not]\[EmptySet]"],

Cell[TextData[{
  "We demonstrate one of the rules for set equality that uses a quantified \
implication in the knowledge base to reduce one of the resulting subset \
properties immediately. Several rules of this fashion are implemented in \
order to recognize some variants of implications in the assumptions analogous \
to the variants for rewriting goals using implications in QR. Like for \
inclusion, these rules apply only if the prover option ",
  StyleBox["STPLevel", "MathematicaInput"],
  " has a value greater than 50."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]SetEquality",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[CapitalLambda], \[CapitalDelta], \[ForAll] \+x \
\[GothicCapitalC]\_x \[Implies] \[GothicCapitalA]\_x \[SubsetEqual] \
\[GothicCapitalB]\_x\), 
              "\[RightTee]", \(\[GothicCapitalC]\_\(x \[Rule] x\_1\) \[And] \
\[GothicCapitalS]\_2 \[SubsetEqual] \[GothicCapitalS]\_1\)},
            {\(\[CapitalLambda], \[ForAll] \+x \[GothicCapitalC]\_x \
\[Implies] \[GothicCapitalA]\_x \[SubsetEqual] \[GothicCapitalB]\_x, \
\[CapitalDelta]\), 
              "\[RightTee]", \(\[GothicCapitalS]\_1 = \[GothicCapitalS]\_2\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"where", " ", \(x\_1\), " ", "is", " ", 
              StyleBox["a",
                FontSlant->"Plain"], " ", "constant", " ", "such", " ", 
              "that", " ", \(\[LeftAngleBracket]\[GothicCapitalA]\_x, \
\[GothicCapitalB]\_x\[RightAngleBracket]\_\(x \[Rule] x\_1\)\)}], 
            "=", \(\[LeftAngleBracket]\[GothicCapitalS]\_1, \[GothicCapitalS]\
\_2\[RightAngleBracket]\)}], ")"}]}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\({x\( | \+x\)x \[LessEqual] 5} = {x\( | \+x\)x < 6}\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
        RowBox[{"\[Bullet]asml", "[", 
          RowBox[{"kbf", ",", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\"\<assum\>\"", ",", 
                
                StyleBox[\(\[ForAll] \+\(k, l\)\((k < 
                          l \[Implies] {x\( | \+x\)x \[LessEqual] 
                                k} \[SubsetEqual] {x\( | \+x\)x < l})\)\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], ",",
             "kbl"}], "]"}], ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"SetEquality\"\>", 
            ",", \(\[Bullet]usedFormulae["goal", "assum"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal.\[SupersetEqual]\"\>", ",", 
                  RowBox[{\(5 < 6\), "\[And]", 
                    RowBox[{
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], 
                          UnderscriptBox["\[VerticalSeparator]", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], " "}]], 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "<", "6"}]}], "}"}], 
                      "\[SubsetEqual]", 
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], 
                          UnderscriptBox["\[VerticalSeparator]", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], " "}]], 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[LessEqual]", "5"}]}], 
                        "}"}]}]}], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              "]"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal.\[SupersetEqual]\"\>", ",", 
                  StyleBox[
                    RowBox[{\(5 < 6\), "\[And]", 
                      RowBox[{
                        RowBox[{"{", 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], 
                            UnderscriptBox["\[VerticalSeparator]", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], " "}]], 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "<", "6"}]}], "}"}], 
                        "\[SubsetEqual]", 
                        RowBox[{"{", 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], 
                            UnderscriptBox["\[VerticalSeparator]", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], " "}]], 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "\[LessEqual]", "5"}]}], 
                          "}"}]}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{"kbf", ",", "kbl", ",", 
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"assum\"\>", ",", 
                      RowBox[{
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["k",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], ",", 
                            StyleBox["l",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}]], 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["k",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "<", 
                              StyleBox["l",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "\[Implies]", 
                            RowBox[{
                              RowBox[{"{", 
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], 
                                  UnderscriptBox["\[VerticalSeparator]", 
                                    RowBox[{
                                      StyleBox["x",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], " "}]], 
                                  RowBox[{
                                    StyleBox["x",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "\[LessEqual]", 
                                    StyleBox["k",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], "}"}], 
                              "\[SubsetEqual]", 
                              RowBox[{"{", 
                                RowBox[{
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], 
                                  UnderscriptBox["\[VerticalSeparator]", 
                                    RowBox[{
                                      StyleBox["x",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], " "}]], 
                                  RowBox[{
                                    StyleBox["x",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "<", 
                                    StyleBox["l",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], "}"}]}]}], 
                          ")"}]}], ",", \(\[Bullet]finfo[]\)}], "]"}]}], 
                "]"}], ",", "af"}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
        ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "In order to show ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ", by ",
  StyleBox["(", "Label"],
  ButtonBox["assum",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "assum"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ", it is sufficient to show"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.\[SupersetEqual])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{\(5 < 6\), "\[And]", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              UnderscriptBox["\[VerticalSeparator]", 
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "<", "6"}]}], "}"}], "\[SubsetEqual]", 
          RowBox[{"{", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              UnderscriptBox["\[VerticalSeparator]", 
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[LessEqual]", "5"}]}], "}"}]}]}]], 
    "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.\[SupersetEqual]"],

Cell[TextData[{
  "We rearrange the knowledge base so that possibly another subset property \
in the knowledge base can come into play during the remaining proof. This is \
advantageous, in particular, when an equality ",
  Cell[BoxData[
      \(TraditionalForm\`A = B\)]],
  " is to be proven with ",
  StyleBox["both",
    FontSlant->"Italic"],
  " subset properties ",
  Cell[BoxData[
      \(TraditionalForm\`A \[SubsetEqual] B\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B \[SubsetEqual] A\)]],
  " available in the assumptions. In the first step, the equality is reduced \
using the first assumption, which is then moved to the end of the knowledge \
base. Thus, in the next proof step, the second assumptions is applied for \
reduction since it appears first in the rearranged knowledge base. It is \
sometimes necessary to split the proof of set equality into the two branches \
",
  StyleBox["manually",
    FontSlant->"Italic"],
  ", because the prover needs to apply different proof techniques in either \
branch, which means the Prove call must specify different prover options, see \
also the concrete examples in the case studies in Part 3 of this thesis."
}], "FirstParagraph"],

Cell["\<\
The main inference rule for set equality combines the axiom of \
extensionality with the reduction of the resulting universal equivalence in \
one step.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]SetEquality",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(a \[Element] \[GothicCapitalS]\_1, \[CapitalKappa] \[RightTee] 
                a \[Element] \[GothicCapitalS]\_2\ and\ \ a \[Element] \
\[GothicCapitalS]\_2, \[CapitalKappa] \[RightTee] 
                a \[Element] \[GothicCapitalS]\_1\)},
            {\(\[CapitalKappa] \[RightTee] \[GothicCapitalS]\_1 = \
\[GothicCapitalS]\_2\)}
            },
          RowLines->True], 
        "   ", \((where\ a\ is\ some\ new\ constant)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(\(\[Union]A\) = B\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", 
        StyleBox[\(\[Bullet]lkTab[{{"\<STP\>", \
\[Bullet]lkTab[{{"\<goalWasIncl\>", False}}]}}]\),
          "HighlightedText"]}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"SetEquality\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.\[SubsetEqual]\"\>", ",", 
                    RowBox[{
                      StyleBox[\(A5\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[Element]", \(\[Union]A\)}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.\[SupersetEqual]\"\>", ",", 
                    RowBox[{
                      StyleBox[\(A5\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[Element]", "B"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}]}], "]"}]}], "}"}], ",",
         
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"\<\"\!\(\*
StyleBox[\\\"ProofSituation\\\",\\n\\\"HighlightedText\\\"]\)\"\>", ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.\[SupersetEqual]\"\>", ",", 
                    RowBox[{
                      StyleBox[\(A5\_0\),
                        "HighlightedText",
                        FontSlant->"Italic",
                        Background->None], 
                      StyleBox["\[Element]",
                        "HighlightedText"], 
                      StyleBox["B",
                        "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                  "]"}], ",", 
                RowBox[{"\[Bullet]asml", "[", 
                  RowBox[{
                    RowBox[{"\[Bullet]lf", "[", 
                      RowBox[{"\<\"goal.\[SubsetEqual]\"\>", ",", 
                        RowBox[{
                          StyleBox[\(A5\_0\),
                            "HighlightedText",
                            FontSlant->"Italic",
                            Background->None], 
                          StyleBox["\[Element]",
                            "HighlightedText"], 
                          StyleBox[\(\[Union]A\),
                            "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}],
                       "]"}], ",", "kb"}], "]"}], ",", 
                RowBox[{"\[Bullet]lkTab", "[", 
                  RowBox[{"{", 
                    RowBox[{"{", 
                      RowBox[{"\<\"STP\"\>", ",", 
                        
                        StyleBox[\(\[Bullet]lkTab[{{"goalWasIncl", \
{\(\[Union]A\), B}}}]\),
                          "HighlightedText"]}], "}"}], "}"}], "]"}]}], "}"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
              RowBox[{"\<\"\!\(\*
StyleBox[\\\"ProofSituation\\\",\\n\\\"HighlightedText\\\"]\)\"\>", ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.\[SubsetEqual]\"\>", ",", 
                    RowBox[{
                      StyleBox[\(A5\_0\),
                        "HighlightedText",
                        FontSlant->"Italic",
                        Background->None], 
                      StyleBox["\[Element]",
                        "HighlightedText"], 
                      StyleBox[\(\[Union]A\),
                        "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                  "]"}], ",", 
                RowBox[{"\[Bullet]asml", "[", 
                  RowBox[{
                    RowBox[{"\[Bullet]lf", "[", 
                      RowBox[{"\<\"goal.\[SupersetEqual]\"\>", ",", 
                        RowBox[{
                          StyleBox[\(A5\_0\),
                            "HighlightedText",
                            FontSlant->"Italic",
                            Background->None], 
                          StyleBox["\[Element]",
                            "HighlightedText"], 
                          StyleBox["B",
                            "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}],
                       "]"}], ",", "kb"}], "]"}], ",", 
                RowBox[{"\[Bullet]lkTab", "[", 
                  RowBox[{"{", 
                    RowBox[{"{", 
                      RowBox[{"\<\"STP\"\>", ",", 
                        
                        StyleBox[\(\[Bullet]lkTab[{{"goalWasIncl", {B, \(\
\[Union]A\)}}}]\),
                          "HighlightedText"]}], "}"}], "}"}], "]"}]}], 
              "}"}]}], "}"}], ",", \({}\), ",", \({}\), 
        ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "We",
  " try to ",
  "show ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " by mutual inclusion:"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\[SubsetEqual]: We assume ", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.\[SubsetEqual])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A5\_0 \[Element] \(\[Union]A\)\)], "Assumption"],
  Cell["", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.\[SubsetEqual]"],

Cell["and show:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.\[SupersetEqual])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A5\_0 \[Element] B\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.\[SupersetEqual]"],

Cell["\[SupersetEqual]: Now we assume ", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.\[SupersetEqual])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A5\_0 \[Element] B\)], "Assumption"],
  Cell["", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.\[SupersetEqual]"],

Cell["and show:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.\[SubsetEqual])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A5\_0 \[Element] \(\[Union]A\)\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.\[SubsetEqual]"],

Cell[TextData[{
  "In both branches, the rule stores in the local proof context that the \
branch corresponds to set inclusion in order to avoid a cycle in combination \
with the ",
  StyleBox["\[Cent]MembershipByIncl", "MathematicaInput"],
  " rule from Section ",
  
  CounterBox["Section", "Sec:STPMembership"],
  ".",
  
  CounterBox["Subsection", "Sec:STPMembership"],
  ".",
  
  CounterBox["Subsubsection", "Sec:STPMembership"],
  ". As for inclusion, we provide special rules for the case where one or \
both of the sets in the equality are set abstractions."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]SetEquality",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicCapitalP]\_\(x \[Rule] x\_1\), \[CapitalKappa] \
\[RightTee] \[GothicCapitalQ]\_\(x \[Rule] x\_1\)\ and\ \ \[GothicCapitalQ]\_\
\(x \[Rule] x\_1\), \[CapitalKappa] \[RightTee] \[GothicCapitalP]\_\(x \
\[Rule] x\_1\)\)},
            {\(\[CapitalKappa] \[RightTee] {x\( | \+x\)\[GothicCapitalP]\_x} \
= {x\( | \+x\)\[GothicCapitalQ]\_x}\)}
            },
          RowLines->True], 
        "   ", \((where\ x\_1\ is\ some\ new\ constant)\)}]}]], \
"InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\({x\( | \+x\)x \[LessEqual] 5} = {x\( | \+x\)x < 6}\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"SetEquality\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.\[SubsetEqual]\"\>", ",", 
                    RowBox[{
                      StyleBox[\(x8\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[LessEqual]", "5"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.\[SupersetEqual]\"\>", ",", 
                    RowBox[{
                      StyleBox[\(x8\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "<", "6"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}]}], "]"}]}], "}"}], ",",
         
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"\<\"ProofSituation\"\>", ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.\[SupersetEqual]\"\>", ",", 
                    RowBox[{
                      StyleBox[\(x8\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "<", "6"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]asml", "[", 
                  RowBox[{
                    RowBox[{"\[Bullet]lf", "[", 
                      RowBox[{"\<\"goal.\[SubsetEqual]\"\>", ",", 
                        RowBox[{
                          StyleBox[\(x8\_0\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[LessEqual]", "5"}], 
                        ",", \(\[Bullet]finfo[]\)}], "]"}], ",", "kb"}], 
                  "]"}], ",", "af"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"\<\"ProofSituation\"\>", ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal.\[SubsetEqual]\"\>", ",", 
                    RowBox[{
                      StyleBox[\(x8\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[LessEqual]", "5"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]asml", "[", 
                  RowBox[{
                    RowBox[{"\[Bullet]lf", "[", 
                      RowBox[{"\<\"goal.\[SupersetEqual]\"\>", ",", 
                        RowBox[{
                          StyleBox[\(x8\_0\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "<", "6"}], 
                        ",", \(\[Bullet]finfo[]\)}], "]"}], ",", "kb"}], 
                  "]"}], ",", "af"}], "}"}]}], "}"}], ",", \({}\), 
        ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We",
  " try to ",
  "show ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " by mutual inclusion:"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["\[SubsetEqual]: We assume ", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.\[SubsetEqual])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(x8\_0 \[LessEqual] 5\)], "Assumption"],
  Cell["", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.\[SubsetEqual]"],

Cell["and show:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.\[SupersetEqual])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(x8\_0 < 6\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.\[SupersetEqual]"],

Cell["\[SupersetEqual]: Now we assume ", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.\[SupersetEqual])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(x8\_0 < 6\)], "Assumption"],
  Cell["", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.\[SupersetEqual]"],

Cell["and show:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal.\[SubsetEqual])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(x8\_0 \[LessEqual] 5\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal.\[SubsetEqual]"],

Cell["Analogously, we support the generalizations:", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]SetEquality",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicCapitalP]\_\(x \[Rule] x\_1\), \[CapitalKappa] \
\[RightTee] 
                x\_1 \[Element] \[GothicCapitalS]\_2\ and\ \ x\_1 \[Element] \
\[GothicCapitalS]\_2, \[CapitalKappa] \[RightTee] \[GothicCapitalP]\_\(x \
\[Rule] x\_1\)\)},
            {\(\[CapitalKappa] \[RightTee] {x\( | \+x\)\[GothicCapitalP]\_x} \
= \[GothicCapitalS]\_2\)}
            },
          RowLines->True], 
        "   ", \((where\ x\_1\ is\ some\ new\ constant)\)}]}]], \
"InferenceRule"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]SetEquality",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(x\_1 \[Element] \[GothicCapitalS]\_1, \[CapitalKappa] \
\[RightTee] \[GothicCapitalQ]\_\(x \[Rule] x\_1\)\ and\ \ \[GothicCapitalQ]\_\
\(x \[Rule] x\_1\), \[CapitalKappa] \[RightTee] 
                x\_1 \[Element] \[GothicCapitalS]\_1\)},
            {\(\[CapitalKappa] \[RightTee] \[GothicCapitalS]\_1 = {x\( | \
\+x\)\[GothicCapitalQ]\_x}\)}
            },
          RowLines->True], 
        "   ", \((where\ x\_1\ is\ some\ new\ constant)\)}]}]], \
"InferenceRule"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cardinality of Sets and Properties of Functions", "Subsubsection",
  CellTags->"Sec:STPFunctions"],

Cell[TextData[{
  "Introducing the concept of set ",
  StyleBox["cardinality",
    FontSlant->"Italic"],
  " is closely related to introduce ",
  StyleBox["special properties of functions",
    FontSlant->"Italic"],
  ", since properties of cardinality are often defined through the existence \
of a function from one set into another having certain special properties."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]SameCardinality",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {"\[CapitalKappa]", "\[RightTee]", 
              RowBox[{\(\[Exists] \+f\), GridBox[{
                    {"f", 
                      "\[Proportion]", \(\[GothicCapitalS]\_1\), \( \
\[RightArrow] \&bij\), \(\[GothicCapitalS]\_2\)}
                    },
                  RowSpacings->0.1,
                  ColumnSpacings->{0.1, 0.4, 0.3},
                  ColumnAlignments->{Left},
                  GridDefaultElement:>""]}]},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[LeftBracketingBar]\[GothicCapitalS]\_1\
\[RightBracketingBar] = \[LeftBracketingBar]\[GothicCapitalS]\_2\
\[RightBracketingBar]\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((where\ \[GothicCapitalS]\_1\ and\ \[GothicCapitalS]\_2\ are\
\ free\ of\ f)\)}]}]], "InferenceRule"],

Cell[TextData[{
  "The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language supports several concepts of functions:"
}], "SingleParagraph"],

Cell[TextData[{
  "An ",
  StyleBox["intensional",
    FontSlant->"Italic"],
  " function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  ", denoted by ",
  Cell[BoxData[
      FormBox[GridBox[{
            {"f", "\[Proportion]", "A", "\[RightArrow]", "B"}
            },
          RowSpacings->0.1,
          ColumnSpacings->{0.1, 0.4, 0.3},
          ColumnAlignments->{Left},
          GridDefaultElement:>""], TraditionalForm]]],
  ", represents the concept of a function from ",
  StyleBox["logic",
    FontSlant->"Italic"],
  " as \[LeftGuillemet]something that can be applied to a sequence of terms \
resulting again in a term\[RightGuillemet]."
}], "ItemizedText"],

Cell[TextData[{
  "An ",
  StyleBox["extensional",
    FontSlant->"Italic"],
  " function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  ", denoted by ",
  Cell[BoxData[
      FormBox[GridBox[{
            {"f", ":", "A", "\[RightArrow]", "B"}
            },
          RowSpacings->0.1,
          ColumnSpacings->{0.1, 0.4, 0.3},
          ColumnAlignments->{Left},
          GridDefaultElement:>""], TraditionalForm]]],
  ", represents the concept of a function from ",
  StyleBox["set theory",
    FontSlant->"Italic"],
  " as \[LeftGuillemet]a set of pairs satisfying the unique image property\
\[RightGuillemet]."
}], "ItemizedText"],

Cell[TextData[{
  "For both intensional and extensional functions, the domain and the range \
can be specified by ",
  StyleBox["sets",
    FontSlant->"Italic"],
  " or their ",
  StyleBox["characteristic predicate",
    FontSlant->"Italic"],
  ", where \"\[Rule]\" stands for a function from a set into a set and \"\
\[RuleDelayed]\" stands for a function from predicate to predicate. For \
variants of notation that are supported in the syntax of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", see the respective part in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " ",
  ButtonBox["on\[Dash]line help",
    ButtonData:>"Syntax of Theorema",
    ButtonStyle->"AddOnsLink"],
  ". The overscript position over the arrow can be used for special \
properties of functions. From the point of view of syntax, any property can \
be written over the arrow, from the point of view of semantics, the set \
theory prover understands"
}], "SingleParagraph"],

Cell[TextData[{
  StyleBox["bij", "MathematicaInput"],
  " to express a ",
  StyleBox["bijective",
    FontSlant->"Italic"],
  " function,"
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["inj", "MathematicaInput"],
  " to express an ",
  StyleBox["injective",
    FontSlant->"Italic"],
  " function, and"
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["surj", "MathematicaInput"],
  " to express a ",
  StyleBox["surjective",
    FontSlant->"Italic"],
  " function"
}], "ItemizedText"],

Cell[TextData[{
  "in case the prover option ",
  StyleBox["STPFunctionProperties", "MathematicaInput"],
  " is True. If the inference rules are deactivated, the user has the \
possibility to give the intended definitions as explicit knowledge. Thus, the \
inference rule on equal cardinality reads as \[LeftGuillemet]two sets have \
the same cardinality if there exists an (intensional) bijective function from \
one set into the other\[RightGuillemet]. In an improved version of the \
prover, the user will have the choice to prove the existence of an ",
  StyleBox["extensional ",
    FontSlant->"Italic"],
  "bijective function by giving an option to the prover."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]Bijectivity",
        FontWeight->"Bold"], ":", GridBox[{
          {
            RowBox[{"\[CapitalKappa]", "\[RightTee]", 
              RowBox[{
                RowBox[{GridBox[{
                      {"f", 
                        "\[Proportion]", \(\[GothicCapitalS]\_1\), \( \
\[RightArrow] \&inj\), \(\[GothicCapitalS]\_2\)}
                      },
                    RowSpacings->0.1,
                    ColumnSpacings->{0.1, 0.4, 0.3},
                    ColumnAlignments->{Left},
                    GridDefaultElement:>""], " ", "and", "  ", 
                  "\[CapitalKappa]"}], "\[RightTee]", GridBox[{
                    {"f", 
                      "\[Proportion]", \(\[GothicCapitalS]\_1\), \( \
\[RightArrow] \&surj\), \(\[GothicCapitalS]\_2\)}
                    },
                  RowSpacings->0.1,
                  ColumnSpacings->{0.1, 0.4, 0.3},
                  ColumnAlignments->{Left},
                  GridDefaultElement:>""]}]}]},
          {
            RowBox[{"\[CapitalKappa]", "\[RightTee]", GridBox[{
                  {"f", 
                    "\[Proportion]", \(\[GothicCapitalS]\_1\), \( \
\[RightArrow] \&bij\), \(\[GothicCapitalS]\_2\)}
                  },
                RowSpacings->0.1,
                ColumnSpacings->{0.1, 0.4, 0.3},
                ColumnAlignments->{Left},
                GridDefaultElement:>""]}]}
          },
        RowLines->True]}]], "InferenceRule"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]Injectivity",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(x \[Element] \[GothicCapitalS]\_1, 
              y \[Element] \[GothicCapitalS]\_1, 
              f[x] = f[y], \[CapitalKappa]\), "\[RightTee]", \(x = y\)},
            {"\[CapitalKappa]", "\[RightTee]", GridBox[{
                  {"f", 
                    "\[Proportion]", \(\[GothicCapitalS]\_1\), \( \
\[RightArrow] \&inj\), \(\[GothicCapitalS]\_2\)}
                  },
                RowSpacings->0.1,
                ColumnSpacings->{0.1, 0.4, 0.3},
                ColumnAlignments->{Left},
                GridDefaultElement:>""]}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((where\ x\ and\ y\ are\ new\ constants)\)}]}]], \
"InferenceRule"],

Cell[TextData[{
  "(For the case of an extensional function, the assumption on equal function \
values changes to ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]x, 
            z\[RightAngleBracket] \[Element] 
          f \[And] \[LeftAngleBracket]y, z\[RightAngleBracket] \[Element] 
          f\)]],
  " for some new constant ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", for a function from characteristic predicate to characteristic predicate \
the assumptions on membership in the domain of the function change to ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalS]\_1[x]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalS]\_1[y]\)]],
  ", respectively.)"
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[GridBox[{
                  {"exp", "\[Proportion]", "A", \( \[RightArrow] \&inj\), 
                    "\[DoubleStruckCapitalR]"}
                  },
                RowSpacings->0.1,
                ColumnSpacings->{0.1, 0.4, 0.3},
                ColumnAlignments->{Left},
                GridDefaultElement:>""],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"Injectivity\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goalinj.\"\>", ",", 
                    RowBox[{
                      StyleBox[\(A3\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[Element]", "A"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goalinj.1\"\>", ",", 
                    RowBox[{
                      StyleBox[\(A4\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[Element]", "A"}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goalinj.2\"\>", ",", 
                    RowBox[{
                      RowBox[{"exp", "[", 
                        StyleBox[\(A3\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "]"}], "=", 
                      RowBox[{"exp", "[", 
                        StyleBox[\(A4\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "]"}]}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goalinj.3\"\>", ",", 
                    RowBox[{
                      StyleBox[\(A3\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "=", 
                      StyleBox[\(A4\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ",", \(\[Bullet]finfo[]\)}], 
                  "]"}]}], "]"}], ",", "exp"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goalinj.3\"\>", ",", 
                  RowBox[{
                    StyleBox[\(A3\_0\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None], 
                    StyleBox["=",
                      "HighlightedText"], 
                    StyleBox[\(A4\_0\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None]}], ",", \(\[Bullet]finfo[]\)}], "]"}],
               ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goalinj.\"\>", ",", 
                      RowBox[{
                        StyleBox[\(A3\_0\),
                          "HighlightedText",
                          FontSlant->"Italic",
                          Background->None], 
                        StyleBox["\[Element]",
                          "HighlightedText"], 
                        StyleBox["A",
                          "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", 
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goalinj.1\"\>", ",", 
                      RowBox[{
                        StyleBox[\(A4\_0\),
                          "HighlightedText",
                          FontSlant->"Italic",
                          Background->None], 
                        StyleBox["\[Element]",
                          "HighlightedText"], 
                        StyleBox["A",
                          "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", 
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goalinj.2\"\>", ",", 
                      RowBox[{
                        RowBox[{
                          StyleBox["exp",
                            "HighlightedText"], 
                          StyleBox["[",
                            "HighlightedText"], 
                          StyleBox[\(A3\_0\),
                            "HighlightedText",
                            FontSlant->"Italic",
                            Background->None], 
                          StyleBox["]",
                            "HighlightedText"]}], 
                        StyleBox["=",
                          "HighlightedText"], 
                        RowBox[{
                          StyleBox["exp",
                            "HighlightedText"], 
                          StyleBox["[",
                            "HighlightedText"], 
                          StyleBox[\(A4\_0\),
                            "HighlightedText",
                            FontSlant->"Italic",
                            Background->None], 
                          StyleBox["]",
                            "HighlightedText"]}]}], 
                      ",", \(\[Bullet]finfo[]\)}], "]"}], ",", "kb"}], "]"}], 
              ",", "af"}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
        ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "In order to show injectivity of ",
  Cell[BoxData[
      \(TraditionalForm\`exp\)]],
  " in ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we assume"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goalinj.)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A3\_0 \[Element] A\)], "Assumption"],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goalinj."],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goalinj.1)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A4\_0 \[Element] A\)], "Assumption"],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goalinj.1"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goalinj.2)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(exp[A3\_0] = exp[A4\_0]\)], "Assumption"],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goalinj.2"],

Cell["and show", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goalinj.3)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A3\_0 = A4\_0\)], "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goalinj.3"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]Surjectivity",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(y \[Element] \[GothicCapitalS]\_2, \[CapitalKappa]\), 
              "\[RightTee]", \(\[Exists] \+x\((x \[Element] \[GothicCapitalS]\
\_1 \[And] f[x] = y)\)\)},
            {"\[CapitalKappa]", "\[RightTee]", GridBox[{
                  {"f", 
                    "\[Proportion]", \(\[GothicCapitalS]\_1\), \( \
\[RightArrow] \&surj\), \(\[GothicCapitalS]\_2\)}
                  },
                RowSpacings->0.1,
                ColumnSpacings->{0.1, 0.4, 0.3},
                ColumnAlignments->{Left},
                GridDefaultElement:>""]}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((where\ f\ and\ \[GothicCapitalS]\_1\ are\ free\ of\ x\ and\ \
y\ is\ some\ new\ constant)\)}]}]], "InferenceRule"],

Cell[TextData[{
  "(For the case of an extensional function, the assumption on equal function \
values changes to ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]x, 
          y\[RightAngleBracket] \[Element] f\)]],
  ", for a function from characteristic predicate to characteristic predicate \
the assumptions on membership in the domain and the range of the function \
change to ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalS]\_1[x]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalS]\_2[y]\)]],
  ", respectively.)"
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STP", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[GridBox[{
                  {"exp", ":", 
                    "A", \( \[RightArrow] \&surj\), \(\[DoubleStruckCapitalR]\
\^+\)}
                  },
                RowSpacings->0.1,
                ColumnSpacings->{0.1, 0.4, 0.3},
                ColumnAlignments->{Left},
                GridDefaultElement:>""],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[kb]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"Surjectivity\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goalsurj.\"\>", ",", 
                    RowBox[{
                      StyleBox[\(\[Trademark]\[DoubleStruckCapitalR]10\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], 
                      "\[Element]", \(\[DoubleStruckCapitalR]\^+\)}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goalsurj.1\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["A10",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["A10",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[Element]", "A"}], 
                          "\[And]", 
                          RowBox[{
                            RowBox[{"\[LeftAngleBracket]", 
                              RowBox[{
                                StyleBox["A10",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], ",", 
                                
                                StyleBox[\(\[Trademark]\[DoubleStruckCapitalR]\
10\_0\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}], 
                              "\[RightAngleBracket]"}], "\[Element]", 
                            "exp"}]}], ")"}]}], ",", \(\[Bullet]finfo[]\)}], 
                  "]"}]}], "]"}], ",", "exp"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goalsurj.1\"\>", ",", 
                  StyleBox[
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["A10",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["A10",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[Element]", "A"}], 
                          "\[And]", 
                          RowBox[{
                            RowBox[{"\[LeftAngleBracket]", 
                              RowBox[{
                                StyleBox["A10",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], ",", 
                                
                                StyleBox[\(\[Trademark]\[DoubleStruckCapitalR]\
10\_0\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}], 
                              "\[RightAngleBracket]"}], "\[Element]", 
                            "exp"}]}], ")"}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"goalsurj.\"\>", ",", 
                      RowBox[{
                        
                        StyleBox[\(\[Trademark]\[DoubleStruckCapitalR]10\_0\),
                          
                          "HighlightedText",
                          FontSlant->"Italic",
                          Background->None], 
                        StyleBox["\[Element]",
                          "HighlightedText"], 
                        StyleBox[\(\[DoubleStruckCapitalR]\^+\),
                          "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", "kb"}], "]"}], ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "In order to show surjectivity of ",
  Cell[BoxData[
      \(TraditionalForm\`exp\)]],
  " in ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we assume"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goalsurj.)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[Trademark]\[DoubleStruckCapitalR]10\_0 \[Element] \(\
\[DoubleStruckCapitalR]\^+\)\)], "Assumption"],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goalsurj."],

Cell["and show", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goalsurj.1)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["A10",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["A10",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Element]", "A"}], "\[And]", 
            RowBox[{
              RowBox[{"\[LeftAngleBracket]", 
                RowBox[{
                  StyleBox["A10",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], 
                  ",", \(\[Trademark]\[DoubleStruckCapitalR]10\_0\)}], 
                "\[RightAngleBracket]"}], "\[Element]", "exp"}]}], ")"}]}]], 
    "Conclusion"],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goalsurj.1"],

Cell[TextData[{
  "(The formulae appear ugly because the program to generate new constants \
chooses symbol names in a pretty straight\[Dash]forward manner. In the case \
above, the symbol \[DoubleStruckCapitalR] in the input is converted \
internally into \[Trademark]\[DoubleStruckCapitalR] in order to avoid \
collision with the symbol \[DoubleStruckCapitalR] from Mathematica, which is \
formatted in the output like \[DoubleStruckCapitalR]. The new symbol \
generator then chooses a symbol similar to \
\[Trademark]\[DoubleStruckCapitalR], ",
  Cell[BoxData[
      \(TraditionalForm\`\[Trademark]\[DoubleStruckCapitalR]10\_0\)]],
  ", for which no formatting is defined.)"
}], "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Variants of Notation", "Subsubsection",
  CellTags->"Sec:STPVariants"],

Cell[TextData[{
  "Variants of set theoretic notions, such as ",
  Cell[BoxData[
      \(TraditionalForm\`A \[ReverseElement] a\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`a \[Element] A\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`B \[SupersetEqual] A\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`A \[SubsetEqual] B\)]],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`B \[Superset] A\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`A \[Subset] B\)]],
  " are supported by silently converting the formula to regular notation and \
applying the respective inference rule for the regularized formula. Negated \
predicates, such as \[NotElement] or \[NotSubsetEqual], need not be treated \
by special inference rules, since negated operator symbols are translated \
into the negation of the corresponding operator already when parsing the \
input, i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`a \[NotElement] A\)]],
  " is parsed as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Not] \((a \[Element] A)\)\)]],
  ".  Extended quantifier syntax using special ranges and conditions for the \
set quantifier may be used in the input, it is converted to standard \
quantifier syntax during ",
  StyleBox["SimplifyQuantifier", "MathematicaInput"],
  ". Depending on the prover option ",
  StyleBox["TransformRanges", "MathematicaInput"],
  ", ",
  StyleBox["SimplifyQuantifier", "MathematicaInput"],
  " is eventually applied to goal and assumptions ",
  StyleBox["before",
    FontSlant->"Italic"],
  " the user prover starts the proof search. See Section ",
  
  CounterBox["Section", "Sec:STC"],
  " for applications, where simplification of extended set quantifiers is not \
desired."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["STKBR: The Set Theory Knowledge Base Rewriting Module", "Section",
  CellTags->"Sec:STKBR"],

Cell[TextData[{
  "In this section, we discuss the STKBR module for knowledge base rewriting \
using set theory knowledge, i.e. simplifying the knowledge base by computing \
and inferring new knowledge from known formulae using knowledge from set \
theory. Applying the same mechanism as described in Section ",
  
  CounterBox["Section", "Sec:STP"],
  " for the STP prover, we hide global variables in the private context of \
the package and make them accessible through prover options, which the user \
prover must pass to the global variable handler ",
  StyleBox["SetSTKBRGlobals", "MathematicaInput"],
  ". For the task of performing computations, the knowledge bases specified \
in the ",
  StyleBox["Prove", "MathematicaInput"],
  " call, see Section ",
  ButtonBox["2.3.1",
    ButtonData:>{"Part1.nb", "Sec:Proving"},
    ButtonStyle->"Hyperlink"],
  ", must be passed further to the global variable handler. The user \
knowledge base is ignored, the user hidden knowledge base is passed as first, \
the built\[Dash]in knowledge base is passed as the second parameter and both \
are in turn passed further to the initialization function for set theory \
computations ",
  StyleBox["InitSTKnowledgeBase", "MathematicaInput"],
  ", see Section ",
  
  CounterBox["Section", "Sec:STC"],
  " for more details on computations initiated from within a prover. In \
addition to these parameters, the options and their default values understood \
by SetSTKBRGlobals are collected in Table ",
  
  CounterBox["Section", "Tab:STKBRGlobals"],
  ".",
  
  CounterBox["TableHead", "Tab:STKBRGlobals"],
  "."
}], "SingleParagraph"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(Option\ Name\),
              "ColumnHead"], \(Default\ Value\)},
          {"ApplyBuiltIns", "True"},
          {
            StyleBox["InferMembershipIntersection",
              "TableText"], "False"},
          {
            StyleBox["UseNonMembership",
              "TableText"], "True"},
          {
            StyleBox["KBRWOnlySimplification",
              "TableText"], "False"},
          {
            "DisableInferenceRule", \({\[Cent]KBComposeIntersection, \ \
\[Cent]KBFiniteChoice}\)},
          {"ChooseFromFiniteSet", "False"}
          }], NullForm]], "Table",
  GridBoxOptions->{RowLines->{0.5, False},
  ColumnLines->0.5},
  CellTags->"Tab:STKBRGlobals"],

Cell[TextData[{
  "Table ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["TableHead"],
  ". ",
  StyleBox["Options and global variables of the STKBR prover module", 
    "TableHeadText"]
}], "TableHead"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ApplyBuiltIns\)\)], "Input"],

Cell[BoxData[
    \("Option for STC and STKBR deciding whether built\[Dash]in semantics \
knowledge should be applied for simplifications in the knowledge base."\)], \
"Print",
  CellTags->"Info3197979294-9280556"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"?", 
      StyleBox["InferMembershipIntersection",
        "TableText"]}]], "Input"],

Cell[BoxData[
    \("Option for STKBR guiding the prover whether membership in an \
intersection of sets should be inferred if possible from the knowledge base."\
\)], "Print",
  CellTags->"Info3197203038-7879917"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"?", 
      StyleBox["UseNonMembership",
        "TableText"]}]], "Input"],

Cell[BoxData[
    \("Option for STKBR allowing the prover to use non\[Dash]membership \
properties in the knowledge base in order to infer new knowledge."\)], "Print",\

  CellTags->"Info3197203052-1146766"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"?", 
      StyleBox["KBRWOnlySimplification",
        "TableText"]}]], "Input"],

Cell[BoxData[
    \("Option for STKBR telling the prover to only simplify the knowledge \
base using built\[Dash]in semantics but not to infer new knowledge."\)], \
"Print",
  CellTags->"Info3197203066-5485046"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?DisableInferenceRule\)\)], "Input"],

Cell[BoxData[
    \("Option for STKBR containing a list of inference rule names to be \
deactivated."\ This\ is\ still\ an\ experimental\ feature\ and\ is\ not\ \
fully\ \(\(supported\)\(.\)\)\)], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellTags->"Info3197203079-3105421"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ChooseFromFiniteSet\)\)], "Input"],

Cell[BoxData[
    \("Option for STKBR guiding a special inference rule that chooses \
witnesses from finite sets based on the axiom of choice. Set this option to \
True only when you accept the axiom of choice!."\)], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellTags->"Info3197203086-6729534"]
}, Open  ]],

Cell["\<\
The option DisableInferenceRule implements an experimental feature \
for disabling single inference rules by name. This mechanism, combined with a \
respective mechanism for enabling rules by name, might be a substitute for \
having individual options and corresponding global variables for turning on \
and off individual inference rules. Each inference rule must then implement \
an explicit check for applicability in addition to the implicit applicability \
criterion by syntactic matching. This option is not yet fully supported \
throughout the entire system.\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell["Overall Prover Design", "Subsection",
  CellTags->"c:13"],

Cell[TextData[{
  "The STKBR prover uses a ",
  StyleBox["level saturation",
    FontSlant->"Italic"],
  " technique, see also [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["JeKo00b",
            ButtonData:>"JeKo00b",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "B. Konev and T. Jebelean, 2000, Combining Level-Saturation \
Strategies and Meta-Variables f ..."],
          "Text"], TraditionalForm]]],
  "], for inferring new knowledge from the current knowledge base. It differs \
from most of the other special provers in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system in that it does ",
  StyleBox["not",
    FontSlant->"Italic"],
  " implement inference rules as separate definitions for ",
  StyleBox["one",
    FontSlant->"Italic"],
  " Mathematica function. This \"classic\" implementation scheme for ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " special provers, which introduces one definition per proof situation, is \
not suitable for an efficient implementation of a level saturation mechanism, \
because inferring new formulae one at the time would result in a drastic \
growth of the required search depth for the proof search. The STKBR function, \
which is the component called by the user prover for carrying out one proof \
step, is instead implemented by just one definition, which produces ",
  StyleBox["all possible new formulae during one application",
    FontSlant->"Italic"],
  ". This has the advantage, that several inference rules can be applied ",
  StyleBox["in parallel",
    FontSlant->"Italic"],
  " during one STKBR\[Dash]step instead of adding only one new formula at the \
time to the knowledge base."
}], "FirstParagraph"],

Cell["\<\
As a consequence, the STKBR function does not specify the syntactic \
pattern of the proof situation in its parameters but it is considered to be \
applicable to the current proof situation as soon as new formulae occur in \
the knowledge base compared to its previous run. This check is done with the \
help of an entry in the local proof context that stores the labels of all \
assumptions that have already been treated in the preceding saturation level. \
In case new formulae have been added to the assumptions, the saturation of \
the current knowledge level happens in two phases:\
\>", "Text"],

Cell[TextData[{
  "In a first phase, new formulae are ",
  StyleBox["simplified by computation using built\[Dash]in semantic \
knowledge",
    FontSlant->"Italic"],
  " available in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language semantics."
}], "ItemizedText"],

Cell[TextData[{
  "In a second phase, new knowledge is ",
  StyleBox["inferred",
    FontSlant->"Italic"],
  " from the simplified new formulae using inference rules for set theory. \
These inference rules are grouped into two groups, "
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["Group One",
    FontSlant->"Italic"],
  " containing rules for inferring new knowledge from ",
  StyleBox["one ",
    FontSlant->"Italic"],
  "known formula and"
}], "ItemizedText",
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{45, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  StyleBox["Group Two",
    FontSlant->"Italic"],
  " containing rules for inferring new knowledge from ",
  StyleBox["two ",
    FontSlant->"Italic"],
  "known formulae."
}], "ItemizedText",
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{45, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Matching rules from Group One are applied to the simplified new formulae, \
matching rules from Group Two are applied to ",
  StyleBox["all new pairs",
    FontSlant->"Italic"],
  " of formulae that can be formed using additionally the ",
  "simplified",
  " new formulae. Up to now, no inference rules have been implemented that \
depend on three formulae. As soon as such inference rules are needed, we will \
provide a Group Three of inference rules, which will be applied to all \
possible triples of formulae."
}], "ItemizedText",
  CellDingbat->None],

Cell[TextData[{
  "All formulae generated during these two phases are adjoined to the \
knowledge base for the new proof situation. The augmented knowledge base is \
considered to contain ",
  StyleBox["all knowledge",
    FontSlant->"Italic"],
  ", that can be made available at that point, thus, we call it a ",
  StyleBox["saturated knowledge level",
    FontSlant->"Italic"],
  ". The schematized flow of STKBR level saturation mechanism is shown in \
Figure ",
  
  CounterBox["Section", "Fig:STKBR"],
  ".",
  
  CounterBox["Figure", "Fig:STKBR"],
  ", where the boxed names are the names of the respective functions in the \
actual implementation."
}], "SingleParagraph"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.04508 
%%ImageSize: 488 510 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0019516 0.0248829 0.0019516 [
[ 0 0 0 0 ]
[ 1 1.04508 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.04508 L
0 1.04508 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02488 translate
.95238 .99532 scale
488 string
488 510 8 [488 0 0 510 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000
FFFFFFFF0000FFFF0000FFFFFF000000FFFF000000FF000000FF00000000FFFFFFFF0000
FFFF0000FFFFFF000000FFFFFF00000000FFFFFFFF000000000000FFFFFFFFFFFF000000
00FFFFFFFF000000FF00000000FFFF000000FFFFFF00000000FFFFFFFFFFFF00FFFFFF00
FFFFFFFF00000000FFFFFF00000000FFFFFFFF000000000000FFFF00000000000000FFFF
00000000FFFFFFFFFFFFFF00000000000000000000FFFF00000000FFFFFFFFFF00FFFFFF
FFFFFFFF00000000FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00
00FFFF000000000000FFFFFF000000FF00000000FF000000FFFFFF0000FFFFFFFF000000
000000FFFFFF000000FF00FF000000FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF0000
FFFFFFFF000000FFFFFF0000FFFFFF0000FFFFFF0000FFFF0000FFFFFFFFFF00FFFFFF00
FFFFFFFFFF0000FFFFFF000000FF0000FFFF0000FFFF0000FFFFFF0000000000FFFFFF00
0000FF0000FFFFFFFFFFFFFF0000FFFFFFFFFF0000FF000000FF0000FFFFFFFF00FFFFFF
FFFFFF000000FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
0000FF0000FFFF0000FFFFFF0000FFFFFF0000FFFFFF0000FFFFFF0000FFFFFFFF0000FF
FF0000FFFFFF0000FFFFFF000000FFFFFFFF000000FFFFFF0000FFFFFFFFFFFFFFFF0000
FFFFFF000000FFFFFFFF0000FFFFFF0000FFFF0000FFFFFFFF0000FFFFFF000000FF0000
00FFFFFFFF0000FFFF000000FFFFFFFF000000FFFFFF0000FFFFFF00FFFFFFFFFFFF0000
00FFFFFFFF00FFFFFFFFFFFF0000FFFFFFFFFFFF00000000FFFFFFFF00FFFF000000FFFF
FFFF000000FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF0000FFFF0000FFFFFF0000FFFFFF0000FFFFFF0000FFFFFF0000FFFFFFFF0000FF
FF0000FFFFFF0000FFFFFF0000FFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFF0000
FFFFFF0000FFFFFFFFFF0000FFFFFF0000FFFF0000FFFFFFFF0000FFFFFF000000FF00FF
00FFFFFFFF0000FFFF0000FFFFFFFFFFFF0000FFFFFF0000FFFFFF00000000FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FF00FFFF
FFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFF0000FF0000FFFFFF0000FFFFFF0000FFFFFF0000FFFFFF0000FFFFFFFFFF0000
FF0000FFFFFF0000FFFFFF0000FFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFF0000
FFFF0000FFFFFFFFFFFF0000FFFFFF0000FFFF0000FFFFFFFF0000FFFF0000FF000000FF
0000FFFFFF0000FFFF0000FFFFFFFFFFFF0000FFFFFF0000FFFF0000FFFF0000FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FF0000FF
FFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFF000000FFFFFF0000FFFFFF0000FFFFFF0000FFFFFF0000FFFFFFFFFFFFFF
000000FFFFFF0000FFFFFF00000000000000000000FFFFFF0000FFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFF0000FFFFFF0000FFFF0000FFFFFFFF0000FFFF0000FF0000FFFF
0000FFFFFF0000FFFF00000000000000000000FFFFFF0000FFFF0000FFFFFF00FFFF0000
000000000000FFFFFFFFFFFF0000FFFFFFFFFFFFFF0000000000000000FF0000FFFF00FF
FFFF0000000000000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFF0000FFFF0000FFFFFF0000FFFFFF0000FFFFFF0000FFFFFF000000FFFFFF0000FF
FF0000FFFFFF0000FFFFFF0000FFFFFFFF00000000FFFFFF0000FFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF000000FFFF0000FFFF0000FFFFFFFF0000FF0000FFFFFF00FFFF
0000FFFFFF0000FFFF0000FFFFFFFF00000000FFFFFF0000FFFF0000FFFFFF00FFFF0000
FFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFF00000000FFFFFF00FF
FFFF0000FFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFF0000FFFF0000FFFFFF0000FFFFFF0000FFFFFF0000FFFFFF0000FF0000FF0000FF
FF0000FFFFFF0000FFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF0000FF00000000FFFFFF0000FFFF0000FFFF0000FFFF0000FFFF
FF0000FFFF0000FFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFF00
00FFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FF0000FFFFFF0000
FFFFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFF00000000FFFFFF0000000000000000FFFF000000FFFF000000FF0000FFFF0000
0000FFFFFF0000000000FFFFFF00000000FFFFFFFF0000000000FFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFF000000FFFF0000FFFFFFFFFF00000000FFFF000000FFFF000000FF
FF000000FF0000FFFFFFFF00000000FFFFFFFF0000000000FFFFFFFF0000000000FFFFFF
00000000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF00000000FF00000000FFFF0000
00FFFFFF00000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF0000
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF0000
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF0000
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000
00FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFF000000FFFFFFFF00000000FFFF00000000000000000000FF0000
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF0000FF0000FFFF0000FFFF0000FFFFFF0000FFFFFF0000FFFF0000
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF0000FF0000FFFF0000FFFF0000FFFFFF0000FFFFFF0000FFFF0000
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFFFF0000FFFFFF0000FFFF0000
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFFFF0000FFFFFF000000FF0000
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFF0000FFFFFF00000000FFFF00000000FFFF0000FF000000FF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FF00FF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF000000FF000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF000000FFFF0000FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF000000FFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF0000000000FFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF0000
0000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFF
FFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF0000
0000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFF
FFFF00000000FFFFFFFF000000000000FFFF00000000FFFFFFFF00000000FFFFFFFF0000
0000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFF
FFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF0000
0000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFF
FFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF0000
0000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFF
FFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF0000
0000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFF
FFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF0000
0000FFFFFFFF00000000FFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF0000
00FFFF0000FFFF00000000FFFFFF0000FF00FF00000000FF000000000000FF0000FFFF00
000000FFFFFF0000FF00FFFF000000000000FFFF00000000FFFFFF000000000000FF0000
000000FFFF00000000FFFF00000000FFFFFF0000000000FFFFFF00000000FF000000FF00
FF00FFFF00000000FFFFFF0000FF00FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00
FFFFFF0000FF0000FFFF0000FFFF00000000FFFF0000FFFF0000FF0000FFFF0000FF0000
FFFF0000FFFF00000000FFFFFFFF0000FFFFFF0000FFFF0000FF0000FFFF0000FF0000FF
FF0000FF0000FFFF0000FFFF0000FFFFFFFFFF0000FFFFFFFF0000FFFF0000FF0000FF00
FF00FFFFFF0000FFFFFFFF00000000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00
FFFF000000FF0000FFFFFFFFFF00000000FF00FF0000FF0000FFFF0000FFFF0000FF0000
FFFF0000FF00000000FF00FFFFFF0000FFFFFF0000FFFFFFFFFF0000FFFF0000FF0000FF
FF0000FF0000FFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFF0000FFFF0000FF0000FF00
FF00FFFFFF0000FFFFFF00000000FF00FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00
FF00000000FF000000000000FF0000FF00FF00FF00000000FFFFFF0000FFFF0000FF0000
FFFF0000FF0000FF00FF00FFFFFF0000FFFFFF000000000000FF0000FFFF0000FF0000FF
FF0000FF000000000000FFFF0000FF00FFFFFF0000FFFFFFFF0000FFFF0000FF0000FF00
FF00FFFFFF0000FFFFFF0000FF00FF00FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00
000000FF00FF0000FFFF0000FF0000FFFFFF00FF000000FFFFFFFF000000FF0000FF0000
FFFF0000FF0000FFFFFF00FFFFFF0000FFFFFF0000FFFF0000FF0000FFFF0000FF0000FF
FF0000FF0000FFFF0000FFFF00000000FFFFFF000000FF00FF0000FFFF0000FF00000000
0000FFFFFF0000FFFFFF0000FFFFFF00FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00
0000FFFF00FFFF00000000FF00000000FF0000000000FF00FFFF0000FF000000FFFFFF00
000000FF00000000FF000000FFFF0000FFFFFFFF00000000FFFFFF0000000000FFFF0000
00FF0000FF00000000FFFFFF0000FFFFFFFF0000FF000000FFFF00000000FF0000FF00FF
00FFFFFFFF0000FFFF00000000FF000000FF00000000FFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF0000
00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFF
00000000FFFFFF0000FF00FF00000000FF000000000000FF0000FFFF00000000FFFFFF00
00FF00FFFF000000000000FFFF00000000FFFFFF000000000000FF0000000000FFFF0000
0000FFFF00000000FFFFFF0000000000FFFFFF00000000FF000000FF00FF00FFFF000000
00FF00000000FF0000FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFF000000FFFF0000FFFF00000000FFFFFF0000FF00FF0000000000FFFFFFFF00000000
0000000000000000FF0000000000FFFFFF00000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00
00FFFF0000FFFF00000000FFFF0000FFFF0000FF0000FFFF0000FF0000FFFF0000FFFF00
000000FFFFFFFF0000FFFFFF0000FFFF0000FF0000FFFF0000FF0000FFFF0000FF0000FF
FF0000FFFF0000FFFFFFFFFF0000FFFFFFFF0000FFFF0000FF0000FF00FF00FF0000FFFF
0000FF0000FFFF0000FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFF00FFFFFF0000FF0000FFFF0000FFFF00000000FFFF0000FFFFFFFFFF0000FFFF00
00FFFFFF0000FFFFFFFF0000FFFFFFFF0000FFFF0000FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FF00
00FFFFFFFFFF00000000FF00FF0000FF0000FFFF0000FFFF0000FF0000FFFF0000FF0000
0000FF00FFFFFF0000FFFFFF0000FFFFFFFFFF0000FFFF0000FF0000FFFF0000FF0000FF
FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFF0000FFFF0000FF0000FF00FF00FF0000FFFF
0000FF0000FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFF00FFFF000000FF0000FFFFFFFFFF00000000FF00FF0000FFFFFFFFFF0000FFFF00
00FFFFFF0000FFFFFFFF0000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FF00
0000000000FF0000FF00FF00FF00000000FFFFFF0000FFFF0000FF0000FFFF0000FF0000
FF00FF00FFFFFF0000FFFFFF000000000000FF0000FFFF0000FF0000FFFF0000FF000000
000000FFFF0000FF00FFFFFF0000FFFFFFFF0000FFFF0000FF0000FF00FF00FF0000FFFF
0000FF0000FFFF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFF00FF00000000FF000000000000FF0000FF00FF00FF0000000000FFFFFF00000000
00FFFFFF0000FFFFFFFF0000FFFFFFFFFF00000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FF00
00FFFF0000FF0000FFFFFF00FF000000FFFFFFFF000000FF0000FF0000FFFF0000FF0000
FFFFFF00FFFFFF0000FFFFFF0000FFFF0000FF0000FFFF0000FF0000FFFF0000FF0000FF
FF0000FFFF00000000FFFFFF000000FF00FF0000FFFF0000FF000000000000FF0000FFFF
0000FF000000FF0000FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFF00000000FF00FF0000FFFF0000FF0000FFFFFF00FF0000FFFF0000FFFFFFFFFF00
00FFFFFF0000FFFFFFFF000000FF00FF000000FFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFF
00000000FF00000000FF0000000000FF00FFFF0000FF000000FFFFFF00000000FF000000
00FF000000FFFF0000FFFFFFFF00000000FFFFFF0000000000FFFF000000FF0000FF0000
0000FFFFFF0000FFFFFFFF0000FF000000FFFF00000000FF0000FF00FF00FFFF0000FFFF
00000000FF000000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFF000000FFFF00FFFF00000000FF00000000FF0000000000FFFF0000FFFF00000000
FFFF00000000FFFFFF0000FF000000FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFF000000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00
000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FF
FFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00
000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FF
FFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00
000000FFFFFFFF00000000FFFFFFFF00000000FFFFFF0000000000FFFFFFFF00000000FF
FFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00
000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FF
FFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00
000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FF00FFFF00000000FF
FFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00
000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FF
FFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00
000000FFFFFFFF00000000FFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00000000000000
0000FF00FF00FF0000000000FFFF000000000000FF000000000000FF000000000000FF00
0000000000FFFF00000000FFFFFF0000000000000000FFFF000000FF00000000FFFFFF00
000000FFFFFF000000FF00000000FF00FF00FF0000000000FFFFFFFF000000FFFF000000
000000FFFF00000000FF00000000FF0000FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFF0000FFFFFF
0000FF00FF00FF0000FFFF0000FFFFFF0000FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFF
FF0000FFFFFF0000FFFF0000FF0000FFFF0000FF0000FFFF0000FF0000FFFF0000FF0000
FFFF0000FF0000FFFF0000FF0000FF00FF00FF0000FFFF0000FFFF0000FFFF00FFFFFF00
00FFFFFF0000FFFF0000FF0000FFFF0000FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFF
0000FF00FF00FF0000FFFF0000FFFFFF0000FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFF
FF0000FFFFFF0000FFFFFFFFFF0000FFFF0000FF0000FFFF0000FFFFFFFF000000FFFFFF
FF000000FF0000FFFF0000FF0000FF00FF00FF0000FFFF0000FFFF0000FFFFFFFFFFFF00
00FFFFFF0000FFFF0000FF0000FFFF0000FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FFFFFF
0000FF00FF00FF0000FFFF0000FFFFFF0000FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFF
FF0000FFFFFF000000000000FF0000FFFF0000FFFF00000000FFFFFF00000000FFFFFF00
000000FFFF0000FFFF0000FF0000FF00FF00FF0000FFFF0000FFFF0000FFFFFFFFFFFF00
00FFFFFF0000FFFF0000FF0000FFFF0000FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF0000FFFFFF
000000000000FF0000FFFF0000FFFFFF0000FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFF
FF0000FFFFFF0000FFFF0000FF0000FFFF0000FFFF0000FF00FFFF000000FFFF00FF0000
00FFFF00FF0000FFFF0000FF000000000000FF0000FFFF0000FFFF0000FFFFFFFFFFFF00
00FFFFFF0000FFFF0000FF000000FF0000FF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00000000FFFF00
00FF00FF00FF0000FF000000FFFFFFFF0000FFFFFF00000000FFFFFF000000000000FF00
000000FFFFFFFF00000000FFFFFF0000000000FFFF0000FF00FFFFFF0000000000FFFF00
00000000000000FF0000000000FF00FF00FF0000FF000000FFFF000000000000FF000000
00FFFFFFFF00000000FF0000FF000000FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF0000FFFFFFFFFFFF00000000FF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFF
FF00000000FFFFFFFF00000000FFFFFF0000000000FFFFFFFF00000000FFFFFFFF000000
00FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFF
FF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF000000
00FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFF
FF00000000FFFFFFFF00000000FFFFFFFF00000000FF00FFFF00000000FFFFFFFF000000
00FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFF
FF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF000000
00FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFF
FF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF000000
00FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFF
FF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF000000
00FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFF
FF00000000FFFFFFFF00000000FFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF000000000000FF000000FFFFFFFFFF00
00000000FF000000FFFF00000000FFFFFFFFFF00FF0000FFFF000000FFFFFFFF00000000
FFFFFFFF00FFFFFF000000FFFF000000FFFFFFFF0000FF0000FF000000FFFFFFFFFFFF00
0000FFFFFFFF000000FF00FFFF0000FFFF0000FF0000000000FFFFFFFF000000FF00FFFF
0000000000FFFF000000FFFF000000FF000000FFFFFF000000FFFFFFFF0000FF00000000
00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFFFFFFFF00FF
FFFF00FFFFFF00FFFF0000FFFFFF00FFFFFFFF0000FF0000FFFF00FFFFFFFF0000FFFFFF
00FFFFFF00FFFFFFFF00FFFF0000FF0000FFFF0000FF0000FFFF00FFFF00FFFFFFFFFF00
FFFF00FFFF0000FFFF00FFFF00FFFFFF0000FF0000FFFF00FFFFFFFF0000FFFF00FFFF00
FFFFFF00FFFF0000FF0000FFFF00FFFFFF00FFFFFFFFFF00FFFFFFFF0000FF0000FFFF00
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFFFFFFFF00FF
FFFF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00FFFFFFFF00FFFFFFFF
FFFFFF00FF00FFFFFF00FFFF00FFFFFF00FFFF00FFFFFF00FFFFFFFF0000FFFFFFFFFFFF
FF0000FFFF00FFFFFF00FFFF00FFFFFF00FFFFFF00FFFF00FFFFFFFF00FFFFFF00FFFF00
FFFFFF00FFFF00FFFFFF00FFFF00FFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFF00FFFF00
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFFFFFFFF00FF
FFFF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00FFFFFFFF00FFFFFFFF
FFFFFF00FF00FFFFFF00FFFF00FFFFFF00FFFF00FFFFFF00FFFFFF0000FFFFFFFFFFFFFF
0000FFFFFFFF0000FF00FFFF00FFFFFF00FFFFFF00FFFF00FFFFFFFFFF0000FF00FFFF00
FFFFFF00FFFF00FFFFFF00FFFF00FFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFF00FFFF00
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFFFFFFFF00FF
FFFF00FFFFFF00FFFF0000000000FFFFFFFFFF00FFFFFF00FFFF00FFFFFFFF0000000000
FFFF00FFFFFF00FFFF00FFFF00FFFFFF00FFFF00FFFFFF00FFFF0000FFFFFFFFFFFFFF00
00FFFFFFFFFFFFFF0000FFFF00FFFFFF00FFFFFF00FFFF00FFFFFFFFFFFFFF0000FFFF00
FFFFFF00FFFF00FFFFFF00FFFF00FFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFF00FFFF00
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF0000FFFFFFFFFF00FF
FFFF0000FF0000FFFF00FFFFFF00FFFFFFFFFF0000FF0000FFFF0000FF00FF00FFFFFF00
FFFF00FFFFFF00FFFF00FFFF0000FF0000FFFF00FFFFFF00FFFF00FFFF00FFFFFFFFFF00
FFFF00FFFF0000FFFF00FFFF00FFFFFF00FFFFFF00FFFF0000FF00FF0000FFFF00FFFF00
FFFFFF00FFFF0000FF0000FFFF0000FF0000FFFFFFFFFF0000FF00FF00FFFFFF00FFFF00
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFF000000FF00000000FFFF000000FFFFFF00000000FFFFFFFFFFFF
00FFFFFF00FFFFFFFF00000000FFFFFF00000000FFFFFFFF000000000000FFFF00000000
000000FFFF00000000FFFFFFFFFFFFFF0000000000000000FFFFFFFF0000FFFF0000FF00
FF0000FFFFFFFFFF00000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000FF0000FF0000FFFFFFFFFF000000
00FF00FF0000FFFFFFFF000000FFFFFFFFFF0000FF0000FFFF00FF000000FFFF000000FF
FF000000FF0000000000FFFFFF000000FFFF0000FFFF0000FFFFFF000000FFFFFFFFFFFF
000000FFFFFF000000FFFF000000000000FFFF0000FF00FF000000FFFF000000FFFF0000
00000000FFFFFF000000FFFF0000FF0000FFFFFFFFFF00FF0000000000FFFF0000FF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF000000FFFFFF0000FFFFFF0000FFFFFF0000FFFF0000FFFFFFFFFF
00FFFFFF00FFFFFFFFFF0000FFFFFF000000FF0000FFFF0000FFFF0000FFFFFF00000000
00FFFFFF000000FF0000FFFFFFFFFFFFFF0000FFFFFFFF0000FFFF000000000000FFFF00
00FF0000FFFFFF000000FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00FFFFFFFF00000000FFFFFFFF
00FFFFFF00FFFFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFF000000FFFF000000FF00
0000FF000000FFFF0000FF0000000000FFFF000000FF00FFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFF000000FFFFFFFF0000FFFFFF0000FFFF0000FFFFFFFF0000FFFFFF00
0000FF000000FFFFFFFF0000FFFF000000FFFFFFFF000000FFFFFF0000FFFFFF00FFFFFF
FFFFFF000000FFFFFFFF00FFFFFFFFFFFF0000FFFFFFFFFF0000FF0000FFFF0000FFFF00
FFFF0000FFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFF0000FFFFFF00FFFFFF
00FFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FF0000FFFF00FFFFFFFF00FFFFFF
00FFFFFF00FFFF0000FF0000FFFF00FFFF0000FFFF00FFFF0000FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFF0000FFFFFFFFFF0000FFFFFF0000FFFF0000FFFFFFFF0000FFFFFF00
0000FF00FF00FFFFFFFF0000FFFF0000FFFFFFFFFFFF0000FFFFFF0000FFFFFF00000000
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FF0000FFFF0000FFFFFF
FF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFF00
0000FF000000FFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFF00FFFF00FFFFFFFF00FFFFFF
00FFFFFF00FFFF00FFFFFF00FFFF00FFFF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF0000FFFFFFFFFFFF0000FFFFFF0000FFFF0000FFFFFFFF0000FFFF0000
FF000000FF0000FFFFFF0000FFFF0000FFFFFFFFFFFF0000FFFFFF0000FFFF0000FFFF00
00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFF0000FF0000FFFFFF
000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFF00
FFFF00FFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFF00FFFF00FFFFFFFF00FFFFFF
00FFFFFF00FFFF00FFFFFF00FFFF00FFFFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FFFFFFFFFFFFFF0000FFFFFF0000FFFF0000FFFFFFFF0000FFFF0000
FF0000FFFF0000FFFFFF0000FFFF00000000000000000000FFFFFF0000FFFF0000FFFFFF
00FFFF0000000000000000FFFFFFFFFFFF0000FFFFFFFF000000FFFFFFFF000000FFFF00
0000FFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF00FFFFFF0000000000FFFF00FF
FFFF00FFFFFF00FFFFFFFFFFFF00FFFFFF00FFFF00FFFFFF00FFFF00FFFFFFFF00FFFFFF
00FFFFFF00FFFF00FFFFFF00FFFF00FFFFFFFFFF0000FFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFF000000FFFF0000FFFF0000FFFFFFFF0000FF0000FF
FFFF00FFFF0000FFFFFF0000FFFF0000FFFFFFFF00000000FFFFFF0000FFFF0000FFFFFF
00FFFF0000FFFFFFFF0000FFFFFFFFFFFF0000000000000000FFFF0000FFFF0000FFFF00
00FFFF00FFFF0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFF00FFFFFF00FFFF00FF
FFFF00FFFFFF00FFFFFFFFFFFF0000000000FFFF0000FF0000FFFF0000FF00FF0000FF00
0000FF0000FFFF00FFFFFF00FFFF00FFFF0000FFFF00FFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFF0000FF00000000FFFFFF0000FFFF0000FFFF0000FF
FF0000FFFFFF0000FFFF0000FFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00
00FFFFFF0000FFFF0000FFFFFFFFFFFFFF0000FFFFFF0000FFFFFF0000FFFF0000FFFF00
00FF0000FFFFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF00FFFFFFFF000000FFFF000000
FF000000FF000000FFFFFFFFFF00FFFFFF00FFFFFF000000FFFF00FF0000000000FF0000
FF000000FFFF0000FFFF0000FFFF00FFFFFF000000FFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FFFFFFFFFFFF000000FFFF0000FFFFFFFFFF00000000FFFF000000FF
FF000000FFFF000000FF0000FFFFFFFF00000000FFFFFFFF0000000000FFFFFFFF000000
0000FFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFF00000000FFFFFFFF
0000FF00FFFFFFFF00000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFF00
0000FFFF000000FF000000FF000000FFFF0000FF0000000000FFFF000000FF00FFFF0000
0000FFFFFFFFFFFF000000FF00000000000000FFFFFFFF00000000FFFFFF000000FF00FF
FF000000FF00FFFF0000FFFFFFFFFFFF000000FF000000FFFF000000FF00000000FF0000
00FFFF000000FF00000000FFFF00000000FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FF0000FFFF
00FFFFFFFF00FFFFFF00FFFFFF00FFFF0000FF0000FFFF00FFFF0000FFFF00FFFF0000FF
FFFF00FFFFFFFF0000FFFF00FFFF00FFFF00FFFFFFFF0000FFFFFF00FF0000FFFF00FFFF
0000FF0000FFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFF0000FFFF00FFFF00FFFFFF00
FFFF0000FF0000FFFF00FFFF0000FFFFFF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFF00FFFF
00FFFFFFFF00FFFFFF00FFFFFF00FFFF00FFFFFF00FFFF00FFFF00FFFFFF00FFFF00FFFF
FFFFFFFFFFFFFF00FFFFFF00FFFF00FFFF00FFFFFFFF00FFFFFFFFFFFF00FFFFFF00FFFF
00FFFFFF00FFFFFF00FF00FFFFFFFFFFFF00FFFFFF00FFFF00FFFFFF00FFFF00FFFFFF00
FFFF00FFFFFF00FFFF00FFFF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFF00FFFF
00FFFFFFFF00FFFFFF00FFFFFF00FFFF00FFFFFF00FFFF00FFFFFF0000FF00FFFF00FFFF
FFFFFFFFFFFFFFFF0000FF00FFFF00FFFF00FFFFFFFF00FFFFFFFFFFFFFF0000FF00FFFF
00FFFFFF00FFFFFF00FF00FFFFFFFFFFFF00FFFFFF00FFFFFF0000FF00FFFF00FFFFFF00
FFFF00FFFFFF00FFFF00FFFF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00FFFFFF00FFFF
00FFFFFFFF00FFFFFF00FFFFFF00FFFF00FFFFFF00FFFF00FFFFFFFFFF0000FFFF000000
0000FFFFFFFFFFFFFFFF0000FFFF00FFFF00FFFFFFFF0000000000FFFFFFFFFF0000FFFF
00FFFFFF00FFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFF0000FFFF00FFFFFF00
FFFF00FFFFFF00FFFF00FFFF0000000000FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000000000FFFF0000FF0000FFFF
0000FF00FF0000FF000000FF0000FFFF00FFFFFF00FFFF00FFFF0000FFFF00FFFF00FFFF
FF00FFFFFFFFFF0000FFFF00FFFF00FFFF0000FF00FF00FFFFFF00FFFF0000FFFF00FFFF
0000FFFF00FFFF00FFFFFF00FFFFFFFFFF0000FF0000FFFF0000FFFF00FFFF0000FF0000
FFFF0000FFFF00FFFF00FFFF00FFFFFF00FFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF000000FFFF00
FF0000000000FF0000FF000000FFFF0000FFFF0000FFFF00FFFFFF000000FFFFFFFF0000
00FFFFFFFFFFFFFF000000FFFFFF00FF00FF000000FFFF000000FFFFFFFF000000FFFFFF
FF00000000FF000000FF000000FFFFFFFF00FF0000FFFFFFFF000000FFFF0000FF0000FF
FFFFFF00000000FFFF00FFFFFF000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CounterIncrements->"Figure",
  ImageSize->{286, 298.812},
  ImageMargins->{{0, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004N0001:R000`400?l00000o`00003oo`3Vi^HO
0>KViP00o`3Vi^HO0>KViP00o`3Vi^HO0>KViP00o`3Vi^HO0>KViP00o`3Vi^HO0>KViP00o`3Vi^HO
0>KViP00o`3Vi^HO0>KViP00o`3Vi^HO0>KViP001P3Vi^Ko0?oooa80oooo1`3Vi^H000H0i^KVQ`3o
ool2000008P0oooo1`3Vi^H000H0i^KVQ`3oool01@000000oooo0?ooo`3oool0000008D0oooo1`3V
i^H000H0i^KV>@3oool400000080oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`00
0000oooo00@000000`3oool00`000000oooo000000020?ooo`030000003oool0oooo008000000P3o
ool4000000<0oooo0P0000030?ooo`050000003oool000000000003oool00P000000103oool00000
0000000000030?ooo`030000003oool000000080oooo0P0000020?ooo`8000000P3oool400000003
0?ooo`00000000000080000000<0oooo000000000000103oool6000000030?ooo`000000000000L0
oooo0P0000020?ooo`800000J03oool70>KViP001P3Vi^Hi0?ooo`040000003oool0oooo0?ooo`80
000000D0oooo000000000000oooo000000020?ooo`040000003oool0oooo00000080oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3o
ool000001@3oool010000000oooo0000000000020?ooo`060000003oool0oooo0000003oool00000
0`3oool01P000000oooo000000000000oooo000000<0oooo00@000000?ooo`00000000000P3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo
0P0000040?ooo`8000000P3oool200000080oooo0P00001Y0?ooo`L0i^KV00060>KViS`0oooo0P00
00001P3oool00000000000000000oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`3oool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0000000<0oooo00H000000?ooo`3oool000000?ooo`0000030?oo
o`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00H0
00000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo06L0oooo1`3Vi^H000H0i^KV>P3oool3000000030?ooo`000000oooo00800000
00D0oooo0000003oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool00`000000oooo0?ooo`03
0?ooo`800000103oool2000000040?ooo`000000oooo000000<0oooo0P0000020?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000P3oool200000080oooo00<000000?ooo`0000000P3o
ool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3oool00`00001Y0?ooo`L0i^KV0006
0>KViSX0oooo0P0000020?ooo`060000003oool000000000003oool000000P3oool010000000oooo
0?ooo`0000020?ooo`80000000@0oooo0000003oool000000P3oool010000000oooo0?ooo`000002
0?ooo`050000003oool000000?ooo`0000001@3oool2000000@0oooo00@000000?ooo`0000000000
0P3oool01@000000oooo0000003oool000000080oooo00L000000?ooo`00000000000?ooo`000000
oooo0080000000P0oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000P0000020?ooo`080000003oool0oooo0000003oool000000?ooo`00001Y0?ooo`L0i^KV0006
0>KViST0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000E0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo06L0oooo1`3Vi^H000H0i^KV>P3oool00`000000oooo0000000Q0?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1W0?ooo`L0i^KV00060>KV
i_l0oooo4P3oool70>KViP001P3Vi^Ko0?oooa80oooo1`3Vi^H000H0i^KVo`3ooolB0?ooo`L0i^KV
00060>KViW40oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^I`0?ooo`800000W`3oool7
0>KViP001P3Vi^I`0?ooo`<00000WP3oool70>KViP001P3Vi^I_0?ooo`@00000WP3oool70>KViP00
1P3Vi^Ia0?ooo`030000003oool0oooo09d0oooo1`3Vi^H000H0i^KVL@3oool00`000000oooo0?oo
o`2M0?ooo`L0i^KV00060>KViW40oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^Ia0?oo
o`030000003oool0oooo09d0oooo1`3Vi^H000H0i^KVL@3oool00`000000oooo0?ooo`2M0?ooo`L0
i^KV00060>KViW40oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^Ia0?ooo`030000003o
ool0oooo09d0oooo1`3Vi^H000H0i^KVL@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV00060>KV
iW40oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^Ia0?ooo`030000003oool0oooo09d0
oooo1`3Vi^H000H0i^KVL@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV00060>KViW40oooo00<0
00000?ooo`3oool0W@3oool70>KViP001P3Vi^Ia0?ooo`030000003oool0oooo09d0oooo1`3Vi^H0
00H0i^KVL@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV00060>KViW40oooo00<000000?ooo`3o
ool0W@3oool70>KViP001P3Vi^Ia0?ooo`030000003oool0oooo09d0oooo1`3Vi^H000H0i^KVL@3o
ool00`000000oooo0?ooo`2M0?ooo`L0i^KV00060>KViVH0oooo5`00002D0?ooo`L0i^KV00060>KV
iVH0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2B0?ooo`L0i^KV00060>KViVH0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2B0?ooo`L0i^KV00060>KViVH0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2B0?ooo`L0i^KV00060>KViVH0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`2B0?ooo`L0i^KV00060>KViVH0oooo00@00000
0?ooo`3oool0oooo0`000000103oool000000?ooo`0000020?ooo`060000003oool000000000003o
ool000000`3oool00`000000oooo0?ooo`2B0?ooo`L0i^KV00060>KViVH0oooo00<000000?ooo`3o
ool00P3oool2000000040?ooo`000000oooo00000080oooo00H000000?ooo`00000000000?ooo`00
00030?ooo`030000003oool0oooo0980oooo1`3Vi^H000H0i^KVIP3oool00`000000oooo0?ooo`02
0?ooo`80000000<0oooo0000000000000P3oool2000000040?ooo`000000oooo000000@0oooo00<0
00000?ooo`3oool0TP3oool70>KViP001P3Vi^IV0?ooo`040000003oool0oooo0?ooo`<000003`3o
ool00`000000oooo0?ooo`2B0?ooo`L0i^KV00060>KViVH0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0980oooo1`3Vi^H000H0i^KVIP3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0980oooo1`3Vi^H000H0i^KVIP3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0980oooo1`3Vi^H000H0i^KVo`3ooolB0?ooo`L0i^KV
00060>KViVh0oooo0P0000000`3oool0000000000002000009`0oooo1`3Vi^H000H0i^KVK@3oool3
000000030?ooo`000000000000800000W03oool70>KViP001P3Vi^I^0?ooo`@0000000<0oooo0000
003oool00P00002J0?ooo`L0i^KV00060>KViV`0oooo00@000000?ooo`3oool0oooo0`0000050?oo
o`030000003oool0oooo09H0oooo1`3Vi^H000H0i^KVJ`3oool010000000oooo0?ooo`3oool40000
00L0oooo00<000000?ooo`3oool0U03oool70>KViP001P3Vi^Ia0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0TP3oool70>KViP001P3Vi^IY0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2A0?ooo`L0i^KV00060>KViVP0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08h0oooo1`3V
i^H000H0i^KVIP3oool2000000T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2<
0?ooo`L0i^KV00060>KViVD0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?oo
o`800000S03oool70>KViP001P3Vi^IT0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`280?ooo`L0i^KV00060>KViW40oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`270?ooo`L0i^KV00060>KViW40oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`250?ooo`L0i^KV00060>KViV40oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo08<0oooo1`3Vi^H000H0i^KVH03oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo0P0000220?ooo`L0i^KV00060>KViUl0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo07h0
oooo1`3Vi^H000H0i^KVGP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0O@3oool70>KViP001P3Vi^Ia0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0N`3oool70>KViP001P3Vi^Ia0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0N@3oool70>KViP001P3Vi^IJ0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`1g0?ooo`L0i^KV00060>KViUT0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo07D0oooo1`3Vi^H000H0i^KV
00@0oooo00000000000000000P3oool200000080oooo0`0000020?ooo`8000000P3oool2000000<0
oooo0P0000020?ooo`8000000`3oool200000080oooo0P0000030?ooo`8000000P3oool200000080
oooo0`0000020?ooo`8000000P3oool300000080oooo0P0000020?ooo`<000000P3oool200000080
oooo0`0000020?ooo`8000000P3oool4000000030?ooo`00000000000080oooo0P0000030?ooo`80
00000P3oool2000000<0oooo0P0000020?ooo`8000000P3oool300000080oooo0P0000020?ooo`<0
00000P3oool200000080oooo0`0000020?ooo`8000000P3oool300000080oooo0P0000020?ooo`80
00000`3oool200000080oooo0P0000030?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`80
00000P3oool300000080oooo0P0000020?ooo`<000000P3oool200000080oooo0`0000020?ooo`80
00000P3oool300000080oooo0P0000020?ooo`8000000`3oool200000080oooo0P0000030?ooo`80
00000P3oool2000000<0oooo0P0000020?ooo`8000000P3oool300000080oooo0P0000020?ooo`<0
00000P3oool200000080oooo00@000000?ooo`3oool0oooo1`3Vi^H000H0i^KVE`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0L@3oool70>KViP00
1P3Vi^IF0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`1_0?ooo`L0i^KV00060>KViUD0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo06d0oooo1`3Vi^H000H0i^KVD`3oool2000001`0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`1[0?ooo`L0i^KV00060>KViU<0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo06X0oooo1`3Vi^H000H0
i^KVL@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo06P0oooo1`3Vi^H000H0i^KV
L@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo06H0oooo1`3Vi^H000H0i^KVC`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0H`3o
ool70>KViP001P3Vi^I>0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`1Q0?ooo`L0i^KV00060>KViTd0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo0600oooo1`3Vi^H000H0i^KVC03oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0GP3oool70>KViP00
1P3Vi^I;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`1L0?ooo`L0i^KV00060>KViTT0oooo0P00000V0?ooo`030000003oool0oooo0400oooo0P00
001K0?ooo`L0i^KV00060>KViTP0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo05P0oooo1`3Vi^H000H0i^KVA`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo04@0oooo0P00001G0?ooo`L0i^KV00060>KViW40oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`1D0?ooo`L0i^KV00060>KViTD0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0580oooo1`3Vi^H000H0i^KVA03o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0D03o
ool70>KViP001P3Vi^I30?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`1>0?ooo`L0i^KV00060>KViT80oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo04/0oooo1`3Vi^H000H0i^KV@@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo04l0oooo0P00001<0?ooo`L0i^KV00060>KViW40oooo
00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0N0?ooo`L0i^KV00060>KViW40oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`0N0?ooo`L0i^KV00060>KViSd0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`1D0?ooo`8000009P3oool00`000000oooo0?ooo`0N
0?ooo`L0i^KV00060>KViS`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool07P3oool70>KViP001P3Vi^Hk0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0;03oool2000000030?ooo`000000oooo0080
00000P3oool00`000000oooo0?ooo`0700000080oooo0P0000001@3oool00000000000000000oooo
00<0000000D0oooo00000000000000000?ooo`07000000040?ooo`00000000000?ooo`<0000000@0
oooo00000000000000000P3oool2000000030?ooo`000000oooo00<0oooo0P0000001@3oool00000
000000000000oooo00<000001P3oool00`000000oooo0?ooo`0N0?ooo`L0i^KV00060>KViSX0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0000000800000
0`3oool50000000;0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00P00
00030?ooo`040000003oool0oooo000000<0oooo00H000000?ooo`000000oooo0000003oool30000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0000000800000103oool0
0`000000oooo0?ooo`0200000080oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0N
0?ooo`L0i^KV00060>KViST0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0/0?oo
o`D000000P3oool200000080oooo0`0000020?ooo`<0000000H0oooo0000003oool000000?ooo`00
00040?ooo`0=0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`03000000030?ooo`000000oooo008000000P3oool4000000030?ooo`000000000000<000000P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0
7P3oool70>KViP001P3Vi^Hh0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0;03o
ool2000000030?ooo`000000oooo00L0oooo00<000000?ooo`0000003P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000303oool2000000l0oooo00<0
00000?ooo`3oool07P3oool70>KViP001P3Vi^Hf0?ooo`800000>@3oool00`000000oooo0?ooo`18
0?ooo`8000001`3oool2000002T0oooo00<000000?ooo`3oool07P3oool70>KViP001P3Vi^Hf0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0N0?oo
o`L0i^KV00060>KViW40oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0N0?ooo`L0
i^KV00060>KViW40oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0N0?ooo`L0i^KV
00060>KViS80oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2M0?ooo`L0i^KV0006
0>KViS40oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1@0?ooo`800000B`3oool7
0>KViP001P3Vi^H`0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0D03oool20000
04/0oooo1`3Vi^H000H0i^KV;`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0500
oooo0P00001;0?ooo`L0i^KV00060>KViRh0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`1?0?ooo`<00000B`3oool70>KViP001P3Vi^H/0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0W@3oool70>KViP001P3Vi^H[0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool0W@3oool70>KViP001P3Vi^H[0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0W@3oool70>KViP001P3Vi^Ia0?ooo`030000003oool0oooo09d0oooo1`3Vi^H000H0i^KV
:03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo09d0oooo1`3Vi^H000H0i^KV9`3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo09d0oooo1`3Vi^H000H0i^KV9P3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo09d0oooo1`3Vi^H000H0i^KV9@3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo09d0oooo1`3Vi^H000H0i^KV903oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo09d0oooo1`3Vi^H000H0i^KVL@3oool00`000000oooo
0?ooo`2M0?ooo`L0i^KV00060>KViW40oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HP
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HP0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HN0?ooo`03
0000003oool0oooo0500oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<00000
0?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3o
ool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool7
0>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KV
iP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP00
1P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3V
i^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0KP3ooolX000003L0oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0e0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0a
0?ooo`800000>`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo1`3Vi^H0
00H0i^KV7@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo00D000000?oo
o`00000000000?ooo`0200000080oooo200000000`3oool000000?ooo`03000000030?ooo`000000
oooo0080oooo0`0000000`3oool00000000000020?ooo`<0000000D0oooo00000000000000000?oo
o`02000000030?ooo`00000000000080oooo0`0000000`3oool000000000000400000080oooo0P00
00001P3oool000000000003oool000000?ooo`8000007@3oool010000000oooo0?ooo`3oool20000
00030?ooo`000000oooo00<0000000@0oooo0000003oool0oooo0`0000020?ooo`X000000P3oool2
000000@0oooo00<000000?ooo`3oool0=@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0203oool00`000000oooo00000002000000040?ooo`000000oooo
0?ooo`80000000d0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo008000000`3oool01@000000oooo000000000000oooo008000000P3oool2000000050?ooo`00
000000000000003oool00P0000000`3oool000000?ooo`020?ooo`070000003oool0oooo0000003o
ool000000?ooo`0200000080oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000000L0?ooo`030000003oool0oooo00@0oooo00H000000?ooo`000000oooo0000003oool2
00000080oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`0200000080oooo00D00000
0?ooo`3oool000000?ooo`02000000<0oooo00<000000?ooo`3oool0=@3oool70>KViP001P3Vi^HM
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0203oool7000000030?ooo`000000
oooo0080oooo0P0000020?ooo`080000003oool000000?ooo`000000oooo0000003oool300000080
oooo00<000000?ooo`000000100000020?ooo`80000000<0oooo000000000000100000000`3oool0
0000000000020?ooo`070000003oool0oooo0000003oool000000?ooo`0200000080oooo00P00000
0?ooo`000000oooo0000003oool000000?ooo`<00000703oool00`000000oooo0?ooo`030?ooo`80
000000D0oooo00000000000000000?ooo`03000000030?ooo`00000000000080oooo0`0000000`3o
ool00000000000020?ooo`040000003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`0e
0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`080?oo
o`80000000<0oooo0000003oool0200000020?ooo`050000003oool000000000003oool01@000000
1@3oool000000000003oool000000080oooo0P0000020?ooo`<0000000D0oooo0000003oool00000
0?ooo`0200000080oooo00L000000?ooo`3oool000000?ooo`000000oooo00@000000P3oool01000
0000oooo0000003oool2000000040?ooo`000000oooo0?ooo`8000007@3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo0?ooo`D0000000L0oooo00000000000000000?ooo`000000oooo
0080000000L0oooo00000000000000000?ooo`000000oooo0080000000@0oooo0000000000000000
0`3oool00`000000oooo0?ooo`0e0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`080?ooo`040000003oool00000000000L0oooo1000000>0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool3000000d0oooo0P00000U0?ooo`040000
003oool0oooo0?ooo`80000000<0oooo0000000000001`3oool3000001@0oooo00<000000?ooo`3o
ool0=@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
KP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo1`3Vi^H000H0i^KV7@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0e0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`3=0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`1>0?ooo`<00000C03oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0500
oooo0P00001?0?ooo`D00000B`3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0500oooo
0P00001=0?ooo`030000003oool0oooo0080oooo0P00001;0?ooo`L0i^KV00060>KViQd0oooo00<0
00000?ooo`3oool0D03oool3000004/0oooo00<000000?ooo`3oool00`3oool2000004/0oooo1`3V
i^H000H0i^KV7@3oool00`000000oooo0?ooo`1?0?ooo`@00000B@3oool00`000000oooo0?ooo`1B
0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo05@0oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?ooo`1A0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0EP3oool70>KViP001P3Vi^HM0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`L0i^KV
00060>KViQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo05T0oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool0G03oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool0?03oool2000005l0oooo1`3Vi^H000H0i^KV7@3oool00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo03X0oooo0P00001Q0?ooo`L0i^KV00060>KViQd0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0680oooo
1`3Vi^H000H0i^KV7@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0I03oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`1U0?ooo`L0i^KV00060>KViQd0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo06L0oooo1`3Vi^H000H0
i^KV7@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0J@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`1[0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`0/0?ooo`800000K`3oool70>KViP001P3Vi^HM0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1_0?ooo`L0i^KV00060>KV
iQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0700oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02L0
oooo0P00001d0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo07D0oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0M`3oool70>KViP001P3Vi^HM
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1h
0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo07X0oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?ooo`1A0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0O03oool70>KViP001P3Vi^HM0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1n0?ooo`L0i^KV
00060>KViQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0I0?ooo`800000PP3o
ool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0603oool2
000008<0oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0P`3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0503oool2000008L0oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0R03oool70>KViP001P3V
i^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`2:0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0?
0?ooo`800000S03oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`2=0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo08l0oooo1`3Vi^H000H0i^KV
7@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
T@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`2C0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`050?ooo`800000UP3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2F0?ooo`L0i^KV00060>KViQd0
oooo00<000000?ooo`3oool0D@3oool010000000oooo0?ooo`3oool2000009X0oooo1`3Vi^H000H0
i^KV7@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0000009d0oooo1`3Vi^H000H0i^KV
7@3oool00`000000oooo0?ooo`0Q0?ooof400000K`3oool70>KViP001P3Vi^HM0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1]0?ooo`L0i^KV0006
0>KViQd0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo06d0oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0100oooo0P00000]0?ooo`800000703oool00`000000oooo0?ooo`1]0?ooo`L0i^KV00060>KViQd0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02/0
oooo0P00000L0?ooo`030000003oool0oooo06d0oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`03000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P0000020?ooo`80
00000P3oool06`000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`05
000000080?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool000000080
000000H0oooo0000003oool000000?ooo`0000070?ooo`030000003oool0oooo06d0oooo1`3Vi^H0
00H0i^KV7@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00@000000?oo
o`3oool000000P3oool3000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P00
00020?ooo`8000000P3oool010000000oooo0?ooo`0000030?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`8000000P3oool2000000050?ooo`000000oooo0000003oool01@000000
103oool000000?ooo`0000030?ooo`050000003oool0oooo0000003oool00`0000000`3oool00000
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0K@3oool70>KViP001P3V
i^HM0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<0
00000?ooo`3oool00`000000103oool000000?ooo`0000020?ooo`030000003oool0oooo00800000
0P3oool200000080oooo00/000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`03000000030?ooo`000000oooo0080oooo00P000000?ooo`3oool0oooo0000003oool000000?oo
o`D0000000@0oooo0000003oool000000`3oool01@000000oooo0?ooo`000000oooo00D0000000<0
oooo000000000000203oool00`000000oooo0?ooo`1]0?ooo`L0i^KV00060>KViQd0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000h0oooo00<00000
0?ooo`3oool0103oool2000000/0oooo00@000000?ooo`3oool000005P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo06d0oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool300000080oooo0P000003
0?ooo`80000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0K@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1]0?ooo`L0i^KV00060>KViQd0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo06d0
oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?ooo`0Q0?ooof400000K`3oool70>KViP001P3V
i^HM0?ooo`030000003oool0oooo0?40oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?ooo`3a
0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool0l@3oool70>KViP001P3Vi^HM0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000
003oool0oooo0500oooo0P00002O0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool0D03o
ool2000009l0oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?ooo`1@0?ooo`<00000WP3oool7
0>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KV
iP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP00
1P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3V
i^HM0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?oo
o`030000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool0W@3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool0W@3oool70>KViP001P3Vi^H30?ooo`8000000`3oool200000080oooo0P000002
0?ooo`<000000P3oool200000080oooo0`000000103oool000000000000000020?ooo`<000000P3o
ool200000080oooo0P0000030?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`8000000`3o
ool200000080oooo0P0000030?ooo`8000000P3oool200000080oooo0`0000020?ooo`8000000P3o
ool300000080oooo0P0000020?ooo`<000000P3oool200000080oooo0P0000000`3oool000000?oo
o`0200000080oooo0P0000030?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`8000000P3o
ool300000080oooo0P0000020?ooo`<000000P3oool200000080oooo0`0000020?ooo`8000000P3o
ool300000080oooo0P0000020?ooo`8000000`3oool200000080oooo0P0000030?ooo`8000000P3o
ool2000000<0oooo0P0000020?ooo`8000000P3oool300000080oooo0P0000020?ooo`<000000P3o
ool200000080oooo0`0000020?ooo`8000000P3oool300000080oooo0P0000020?ooo`8000000`3o
ool200000080oooo0P0000030?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`030000003o
ool0i^KV00H0i^KV00060>KViQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2M
0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2M0?oo
o`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2M0?ooo`L0
i^KV00060>KViQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV
00060>KViQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV0006
0>KViQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV00060>KV
iQd0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV00060>KViQd0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV00060>KViQd0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV00060>KViQd0oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV00060>KViQd0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV00060>KViQd0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`2M0?ooo`L0i^KV00060>KViQd0oooo00<000000?ooo`3oool0;03o
oond00000140oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0?0?ooo`L0i^KV00060>KV
iQd0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool03`3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00l0
oooo1`3Vi^H000H0i^KV7@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0?0?ooo`L0i^KV00060>KViQd0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool03`3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00l0oooo1`3Vi^H0
00H0i^KV7@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0;00oooo00<000000?oo
o`3oool03`3oool70>KViP001P3Vi^HM0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0G03oool200000580oooo00<000000?ooo`3oool03`3oool70>KViP001P3Vi^HM0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0?0?ooo`L0i^KV
00060>KViQd0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`000000oooo000000050?ooo`800000103oool01P000000oooo
0?ooo`000000oooo00000080oooo00H000000?ooo`000000oooo0000003oool300000080oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00@000000?ooo`00000000001`3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0?0?ooo`L0i^KV00060>KViRH0oooo00@000000?ooo`3oool000008P3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`000000oooo0000000;0?ooo`030000
003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000000@0
oooo00@000000?ooo`3oool0oooo0P0000030?ooo`050000003oool000000?ooo`0000000P3oool3
000000<0oooo00<000000?ooo`3oool0203oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`L0i^KV00060>KViRT0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1;0?ooo`030000003oool0000000D0oooo00L0
00000?ooo`000000oooo0000003oool0000000<0oooo0P0000020?ooo`<000000`3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool0oooo000000@0oooo
00D000000?ooo`000000oooo000000030?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo000000030?ooo`040000003oool0000000000080oooo0P0000030?ooo`0:0000003oool0
oooo0000003oool000000?ooo`000000oooo000000/0oooo00<000000?ooo`3oool03`3oool70>KV
iP001P3Vi^H20?ooo`030000003oool0oooo008000000P3oool01`000000oooo000000000000oooo
0000003oool00P0000020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`3oool000000?oo
o`000000oooo0000003oool00P000000103oool000000000000000020?ooo`030000003oool00000
00@0oooo00@000000?ooo`3oool000000P3oool3000000050?ooo`000000oooo0000003oool00P00
0000103oool000000?ooo`0000060?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0
00000P3oool3000000@0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`80000000@0oooo0000
00000000oooo100000001@3oool000000?ooo`000000oooo00<0000000D0oooo0000000000000000
0?ooo`02000001T0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0?0?ooo`L0i^KV
00060>KViP80oooo00@000000?ooo`3oool000000`3oool01P000000oooo000000000000oooo0000
0080oooo00D000000?ooo`3oool000000?ooo`0200000080oooo00@000000?ooo`00000000000P3o
ool2000000050?ooo`00000000000?ooo`0000000`3oool200000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`0:0000003oool000000?ooo`000000oooo0000003oool000000?ooo`800000
2P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo00000008
0?ooo`030000003oool00000008000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0?0?ooo`L0i^KV00060>KViP80oooo00<00000
0?ooo`000000103oool01P000000oooo000000000000oooo00000080oooo00@000000?ooo`000000
oooo0`0000020?ooo`030000003oool0000000@0oooo00X000000?ooo`00000000000?ooo`000000
oooo0000003oool000001`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000002
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool010000000oooo0000
000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00001h0?oo
o`030000003oool0oooo00l0oooo1`3Vi^H000H0i^KV0P3oool2000000D0oooo00H000000?ooo`00
000000000?ooo`0000020?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000
003oool0000000<0oooo0P0000002@3oool000000000003oool000000?ooo`000000oooo00000002
0?ooo`8000000`3oool400000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`<0000000D0oooo
0000003oool000000?ooo`02000000060?ooo`00000000000000003oool000000`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0000007H0oooo00<000000?ooo`3oool03`3oool70>KV
iP001P3Vi^H20?ooo`030000003oool0000000<0oooo0P0000000`3oool000000?ooo`020?ooo`80
000000@0oooo000000000000oooo0P000000103oool000000?ooo`0000020?ooo`<000000P3oool3
00000080oooo0`0000000`3oool00000000000050?ooo`040000003oool0oooo00000080oooo0P00
00030?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0;0?ooo`80000000<0oooo0000003oool03@3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool03`3oool70>KViP001P3Vi^H20?ooo`040000003oool0
oooo000001@0oooo00<000000?ooo`3oool01P3oool2000000d0oooo00@000000?ooo`3oool00000
5P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00800000303oool400000140oooo
00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0?0?ooo`L0i^KV00060>KViP80oooo00@0
00000?ooo`3oool00000503oool00`000000oooo0?ooo`060?ooo`8000003@3oool010000000oooo
0?ooo`00000F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool00P3oool01@000000
oooo000000000000oooo00@0000000@0oooo0000003oool0oooo100000001@3oool0000000000000
0000oooo00800000103oool00`000000oooo0000000300000080oooo0P0000020?ooo`<0000000H0
oooo0000003oool000000?ooo`0000030?ooo`@0000000<0oooo0000000000001@0000000`3oool0
00000000000200000080oooo0P0000000`3oool000000000000E0?ooo`030000003oool0oooo00l0
oooo1`3Vi^H000H0i^KVC03oool00`000000oooo0?ooo`1:0?ooo`090000003oool0oooo0?ooo`00
0000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool01P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00l0oooo1`3Vi^H000H0i^KVC03oool00`000000oooo0?ooo`1:0?ooo`090000003oool0
00000?ooo`000000oooo0000003oool0000000@0oooo00L000000?ooo`000000oooo0000003oool0
000000@0oooo00<000000?ooo`0000000P0000050?ooo`030000003oool0000000<0oooo0`000003
0?ooo`090000003oool000000?ooo`000000oooo0000003oool0000000D0oooo00@000000?ooo`3o
ool000001@3oool01P000000oooo0?ooo`3oool000000?ooo`<000000`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00l0oooo1`3Vi^H000H0i^KVC03oool00`000000oooo0?ooo`1:
0?ooo`030000003oool000000080oooo00@000000?ooo`000000oooo0P0000001@3oool000000?oo
o`000000oooo0080000000<0oooo0000003oool00P3oool200000080oooo0P0000040?ooo`030000
003oool0oooo00@0000000<0oooo0000000000000P3oool200000080oooo0P000000103oool00000
0?ooo`0000040?ooo`030000003oool0oooo0080000000@0oooo0000003oool000000P3oool20000
00050?ooo`000000oooo0?ooo`0000000P3oool3000001@0oooo00<000000?ooo`3oool03`3oool7
0>KViP001P3Vi^I<0?ooo`030000003oool0oooo04X0oooo00@000000?ooo`3oool00000803oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo1`3Vi^H000H0i^KVC03oool00`00
0000oooo0?ooo`1:0?ooo`@00000403oool00`000000oooo0?ooo`0<0?ooo`8000003@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000001`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo1`3Vi^H000H0i^KVC03oool00`000000
oooo0?ooo`2`0?ooo`030000003oool0oooo00l0oooo1`3Vi^H000H0i^KVC03oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0oooo00l0oooo1`3Vi^H000H0i^KVC03oool00`000000oooo0?oo
o`2`0?ooo`030000003oool0oooo00l0oooo1`3Vi^H000H0i^KVC03oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo00l0oooo1`3Vi^H000H0i^KVC03oool00`000000oooo0?ooo`2`0?oo
o`030000003oool0oooo00l0oooo1`3Vi^H000H0i^KVC03oool00`000000oooo0?ooo`2`0?ooo`03
0000003oool0oooo00l0oooo1`3Vi^H000H0i^KVC03oool00`000000oooo0?ooo`2`0?ooo`030000
003oool0oooo00l0oooo1`3Vi^H000H0i^KVC03ooond00000140oooo1`3Vi^H00?l0i^KV7`3Vi^H0
0?l0i^KV7`3Vi^H00?l0i^KV7`3Vi^H00?l0i^KV7`3Vi^H00?l0i^KV7`3Vi^H00?l0i^KV7`3Vi^H0
0?l0i^KV7`3Vi^H00?l0i^KV7`3Vi^H00001\
\>"],
  ImageRangeCache->{{{117.188, 402.188}, {691.812, 394}} -> {-222.946, \
695.705, 1.79811, 1.79811}}],

Cell[TextData[{
  "Figure ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Figure"],
  ". Schematic flow of the STKBR level saturation (Include/STKBR.gif)"
}], "TableHead",
  CellTags->"Fig:STKBR"],

Cell[TextData[{
  "Phase one is accomplished by calling the function ",
  StyleBox["SimplifiedAssumptions[kb,handled]", "MathematicaInput"],
  ", where ",
  StyleBox["kb", "MathematicaInput"],
  " is the entire knowledge base and ",
  StyleBox["handled", "MathematicaInput"],
  " is the list of labels of assumptions that have already been used in the \
previous saturation phase, which has been stored in the local proof context. \
All formulae from the knowledge base, whose labels is not among the handled \
labels, are sent to the function ",
  StyleBox["EvaluateFromProve", "MathematicaInput"],
  ", which computes a simplified version of the formulae w.r.t. the knowledge \
bases as initialized from the knowledge bases specified in the ",
  StyleBox["Prove", "MathematicaInput"],
  " call. EvaluateFromProve is the function used also in the STC module, see \
Section ",
  
  CounterBox["Section", "Sec:STC"],
  ", for goal simplification by computation. Note, that EvaluateFromProve is \
based on the function EvaluateStandard, which is the basic evaluation \
function for computations using ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " semantics, which is used also by ",
  StyleBox["Compute", "MathematicaInput"],
  ". This guarantees utmost coherence between all computations happening in \
the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " systems, be it on the user level by calling Compute, be it on the prover \
level by doing simplifications on the goal or on the knowledge base. Again it \
should be mentioned that this coherence in the computational behavior is \
surely the reward for the clear language design on the basis of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system."
}], "FirstParagraph"],

Cell[TextData[{
  "Phase two is covered in the implementation by the function ",
  StyleBox["AugmentedKnowledgeBase[kb,handled]", "MathematicaInput"],
  ", where ",
  StyleBox["kb", "MathematicaInput"],
  " is the simplified knowledge base resulting from phase one. First, all ",
  StyleBox["new assumptions",
    FontSlant->"Italic"],
  " are identified by selecting those elements from the simplified knowledge \
base whose label does not occur in ",
  StyleBox["handled", "MathematicaInput"],
  ", and then ",
  StyleBox["all new pairs",
    FontSlant->"Italic"],
  ", where at least one component is a new formula,",
  " ",
  "are formed from ",
  StyleBox["kb", "MathematicaInput"],
  ". Group One of inference rules is implemented as separate definitions for \
a function ",
  StyleBox["NewKnowledgeFromOne", "MathematicaInput"],
  ", which is applied componentwise to the new assumptions. Likewise is Group \
Two of inference rules represented by the definitions for the function ",
  StyleBox["NewKnowledgeFromTwo", "MathematicaInput"],
  ", which is applied to all new pairs.\nIn the subsequent sections, we will \
again list all the inference rules that are applied in the two phases. We \
will demonstrate the effect of each inference rule by an example call of \
NewKnowledgeFromOne or NewKnowledgeFromTwo, respectively. We will ",
  StyleBox["not",
    FontSlant->"Italic"],
  " show the resulting proof text for each rule, because we supply ",
  StyleBox["one standard phrase",
    FontSlant->"Italic"],
  " for all rules, which reads as follows: Suppose, we have two formulae in \
the knowledge base, from which we can infer some new knowledge. Then STKBR \
produces ",
  StyleBox["one new node",
    FontSlant->"Italic"],
  " in the proof tree with a saturated knowledge base that contains ",
  StyleBox["all new formulae",
    FontSlant->"Italic"],
  " generated by NewKnowledgeFromOne and NewKnowledgeFromTwo."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STKBR", "[", 
      RowBox[{\(\[Bullet]lf[]\), ",", 
        RowBox[{"\[Bullet]asml", "[", 
          RowBox[{
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\"\<a1\>\"", ",", 
                StyleBox[\(a \[Element] {x\( | \+x\)P[x]}\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], ",",
             
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\"\<a2\>\"", ",", 
                StyleBox[\(b \[Element] {T[x]\( | \+x\)P[x]}\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}]}], 
          "]"}], ",", \(\[Bullet]lkTab[{{"\<QR\>", \
\[Bullet]lkTab[{{"\<SimplifBy\>", {}}, {"\<Combined\>", {}}, \
{"\<Instantiation\>", {}}}]}, {"\<STKBR\>", \
\[Bullet]lkTab[{{"\<augmentedAssums\>", \[Bullet]asml[]}, \
{"\<rewriteExceptions\>", \[Bullet]lkTab[{}]}}]}}]\)}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"NewKnowledge\"\>", 
            ",", \(\[Bullet]usedFormulae["a1", "a2"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{\(\[Bullet]lf["a1'", P[a], \[Bullet]finfo[]]\), ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"a2[1]\"\>", ",", 
                    RowBox[{"P", "[", 
                      StyleBox[\(x1\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "]"}], ",", \(\[Bullet]finfo[]\)}],
                   "]"}], ",", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"a2[2]\"\>", ",", 
                    RowBox[{"b", "=", 
                      RowBox[{"T", "[", 
                        StyleBox[\(x1\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "]"}]}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}]}], "]"}], 
            ",", \(\[Bullet]asml[]\), ",", 
            RowBox[{"\[Bullet]asml", "[", 
              
              RowBox[{\({\[Bullet]asml[\[Bullet]lf["a1'", 
                      P[a], \[Bullet]finfo[]]], "a1"}\), ",", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"\[Bullet]asml", "[", 
                      RowBox[{
                        RowBox[{"\[Bullet]lf", "[", 
                          RowBox[{"\<\"a2[1]\"\>", ",", 
                            RowBox[{"P", "[", 
                              StyleBox[\(x1\_0\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "]"}], 
                            ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                        RowBox[{"\[Bullet]lf", "[", 
                          RowBox[{"\<\"a2[2]\"\>", ",", 
                            RowBox[{"b", "=", 
                              RowBox[{"T", "[", 
                                StyleBox[\(x1\_0\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "]"}]}], 
                            ",", \(\[Bullet]finfo[]\)}], "]"}]}], "]"}], 
                    ",", "\<\"a2\"\>", ",", "\<\"\!\(\*
StyleBox[\\\"KBMembershipAbstractionTerm\\\",\\n\\\"HighlightedText\\\"]\)\"\>\
"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", \(\[Bullet]lf[]\), ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"a1'\"\>", ",", 
                      StyleBox[\(P[a]\),
                        "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", 
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"a2[1]\"\>", ",", 
                      RowBox[{
                        StyleBox["P",
                          "HighlightedText"], 
                        StyleBox["[",
                          "HighlightedText"], 
                        StyleBox[\(x1\_0\),
                          "HighlightedText",
                          FontSlant->"Italic",
                          Background->None], 
                        StyleBox["]",
                          "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                    "]"}], ",", 
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"a2[2]\"\>", ",", 
                      RowBox[{
                        StyleBox["b",
                          "HighlightedText"], 
                        StyleBox["=",
                          "HighlightedText"], 
                        RowBox[{
                          StyleBox["T",
                            "HighlightedText"], 
                          StyleBox["[",
                            "HighlightedText"], 
                          StyleBox[\(x1\_0\),
                            "HighlightedText",
                            FontSlant->"Italic",
                            Background->None], 
                          StyleBox["]",
                            "HighlightedText"]}]}], 
                      ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"a1\"\>", ",", 
                      RowBox[{"a", "\[Element]", 
                        RowBox[{"{", 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], 
                            UnderscriptBox["\[VerticalSeparator]", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], " "}]], 
                            RowBox[{"P", "[", 
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "]"}]}], "}"}]}], 
                      ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
                  RowBox[{"\[Bullet]lf", "[", 
                    RowBox[{"\<\"a2\"\>", ",", 
                      RowBox[{"b", "\[Element]", 
                        RowBox[{"{", 
                          RowBox[{
                            RowBox[{"T", "[", 
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "]"}], 
                            UnderscriptBox["\[VerticalSeparator]", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], " "}]], 
                            RowBox[{"P", "[", 
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "]"}]}], "}"}]}], 
                      ",", \(\[Bullet]finfo[]\)}], "]"}]}], "]"}], 
              ",", \(\[Bullet]lkTab[{{"QR", \[Bullet]lkTab[{{"SimplifBy", \
{}}, {"Combined", {}}, {"Instantiation", {}}}]}, {"STKBR", \
\[Bullet]lkTab[{{"augmentedAssums", \[Bullet]asml["a1", 
                            "a2"]}, {"rewriteExceptions", \
\[Bullet]lkTab[{}]}}]}}]\)}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
        ",", "\<\"pending\"\>"}], "}"}]], "Output",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["\<\
The proof information in the second position of the new node is \
used for actually generating the proof text. In addition to the keyword \"New \
Knowledge\", which indicates the name of the proof header to be used for this \
node, it contains the new formulae that have been inferred during this \
saturation step in a structured way, from which a structured text can be \
generated as follows:\
\>", "SingleParagraph"],

Cell["From what we already know follows:", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["a1",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a1"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we can infer"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(P[a]\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1'"],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["a2",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a2"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we know by definition of ",
  Cell[BoxData[
      \(TraditionalForm\`{T\_x\( | \+x\)P}\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " that we can choose an appropriate value such that"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a2[1])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(P[x1\_0]\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a2[1]"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a2[2])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(b = T[x1\_0]\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a2[2]"],

Cell[TextData[{
  "The first new formula is explained by a standard text, for the new \
formulae obtained from (a2) we provide a special text, which is indicated by \
putting the ",
  StyleBox["name of the inference rule",
    FontSlant->"Italic"],
  " (KBMembershipAbstractionTerm), which justifies this step, into the proof \
information. We do not go further into details of the data structure here, we \
will explain some aspects in the demonstrations of individual rules below."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell["Rule Locking", "Subsubsection",
  CellTags->"c:14"],

Cell["Consider the two inference rules", "SingleParagraph"],

Cell[TextData[{
  "if we know ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] A \[Intersection] B\)]],
  " then we know also ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] B\)]],
  " and"
}], "ItemizedText"],

Cell[TextData[{
  "if we know both  ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] B\)]],
  " then we can infer ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] A \[Intersection] B\)]],
  "."
}], "ItemizedText"],

Cell[TextData[{
  "We call such rules ",
  StyleBox["inverse",
    FontSlant->"Italic"],
  " to each other, and always i",
  "f both a rule and its inverse are available without further restrictions, \
they immediately produce a cycle in the proof search. Therefore, we \
implemented a mechanism of ",
  StyleBox["rule locking",
    FontSlant->"Italic"],
  ", which prevents inverse rules from introducing cycles.",
  " Rule locking means that the application of an inference rule \
\[ScriptCapitalI], that generates new formulae ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", from then on prevents the inverse of \[ScriptCapitalI] to be applied to \
the formulae ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". It uses an entry in the local proof context to store so\[Dash]called ",
  StyleBox["rewrite exceptions",
    FontSlant->"Italic"],
  ", which contain pairs ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]\[ScriptCapitalI], \
\[ScriptCapitalL]\[RightAngleBracket]\)]],
  " of rule names and rule locks (list of formula labels) telling that the \
application of rule \[ScriptCapitalI] is locked for any of the formulae in \
\[ScriptCapitalL]. As an example, the rewrite exceptions"
}], "SingleParagraph"],

Cell[BoxData[
    \(\[Bullet]lkTab[{{\[Cent]KBComposeIntersection, \[Bullet]asml[{"\<5\>", \
"\<7\>"}, {"\<1\>", "\<2\>"}]}, \
\[IndentingNewLine]{\[Cent]KBInferExistsMember, \[Bullet]asml["\<3\>", \
"\<4\>"]}}]\)], "Input"],

Cell["\<\
prevents the rule named \[Cent]KBComposeIntersection from being \
applied to formulae \"5\" together with \"7\" and to \"1\" together with \
\"2\" and it locks the rule \[Cent]KBInferExistsMember for the formulae \"3\" \
and \"4\". Of course, we must take care of rule locking when simplifying \
formulae in phase one of level saturation: if locks exist for some formula \
and we simplify this formula, then all locks have to be adapted to the \
simplified formula.\
\>", "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["STKBR Inference Rules", "Subsection",
  CellTags->"c:15"],

Cell[TextData[{
  "In this section, we will list the inference rules used by the STKBR prover \
grouped by the outermost set theoretic predicate occurring in one of the \
assumptions. As in the case of the STP prover, the correctness of these rules \
follows in most cases directly from the definitions of the respective notions \
in set theory. We will prove the correctness of the rules only when it does \
",
  StyleBox["not follow immediately",
    FontSlant->"Italic"],
  " from the definition. We shall demonstrate the effect of each rule by \
calling NewKnowledgeFromOne or NewKnowledgeFromTwo with appropriate \
arguments."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell["Set Membership", "Subsubsection",
  CellTags->"Sec:STKBRMembership"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipAbstraction",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[GothicCapitalP]\_\(x \[Rule] \[GothicT]\), \[CapitalLambda], \
\[GothicT] \[Element] {x\( | \+x\)\[GothicCapitalP]\_x}, \[CapitalDelta]\), 
            "\[RightTee]", "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[GothicT] \[Element] {x\( | \+x\)\
\[GothicCapitalP]\_x}, \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[Element] {x\( | \+x\)x < 10}\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1'\"\>", ",", 
                StyleBox[\(a < 10\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"\!\(\*
StyleBox[\\\"a1\\\",\\n\\\"HighlightedText\\\"]\)\"\>"}], "}"}], 
      "}"}]], "Output",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["\<\
Basically, this means that formula (a1') can be inferred from (a1). \
Since no inference rule name is put into the data structure, this inference \
step will be explained using the default text template.\
\>", \
"SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBNonMembershipAbstraction",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[Not] \[GothicCapitalP]\_\(x \[Rule] \[GothicT]\), \
\[CapitalLambda], \[GothicT] \[NotElement] {x\( | \+x\)\[GothicCapitalP]\_x}, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[GothicT] \[NotElement] {x\( | \+x\)\
\[GothicCapitalP]\_x}, \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[NotElement] {x\( | \+x\)x < 10}\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1'1\"\>", ",", 
                StyleBox[\(a \[NotLess] 10\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["\<\
This rule can be deactivated by the prover option UseNonMembership\
\[Rule]False. In future versions, this option may be superseded by the option \
DisableInferenceRule.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipAbstractionTerm",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicCapitalP]\_\(x \[Rule] x\_1\), \[GothicT] = \
\[GothicCapitalT]\_\(x \[Rule] x\_1\), \[CapitalLambda], \[GothicT] \
\[Element] {\[GothicCapitalT]\_x\( | \+x\)\[GothicCapitalP]\_x}, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[Element] \
{\[GothicCapitalT]\_x\( | \+x\)\[GothicCapitalP]\_x}, \[CapitalDelta]\), 
              "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((where\ \(x\_1\) 
            is\ some\ new\ constant)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[Element] {3  x\( | \+x\)x < 10}\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1[1]\"\>", ",", 
                  RowBox[{
                    StyleBox[\(x1\_0\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None], 
                    StyleBox["<",
                      "HighlightedText"], 
                    StyleBox["10",
                      "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                "]"}], ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1[2]\"\>", ",", 
                  RowBox[{
                    StyleBox["a",
                      "HighlightedText"], 
                    StyleBox["=",
                      "HighlightedText"], 
                    RowBox[{
                      StyleBox["3",
                        "HighlightedText"], 
                      StyleBox["*",
                        "HighlightedText"], 
                      StyleBox[\(x1\_0\),
                        "HighlightedText",
                        FontSlant->"Italic",
                        Background->None]}]}], ",", \(\[Bullet]finfo[]\)}], 
                "]"}]}], "]"}], ",", "\<\"a1\"\>", ",", "\<\"\!\(\*
StyleBox[\\\"KBMembershipAbstractionTerm\\\",\\n\\\"HighlightedText\\\"]\)\"\>\
"}], "}"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell["\<\
This means that two new formulae, (a1[1]) and (a1[2]), can be \
inferred from formula (a1), and special text for the inference rule \
\[Cent]KBMembershipAbstractionTerm will be used in the proof \
presentation.\
\>", "SingleParagraph"],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["a1",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a1"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we know by definition of ",
  Cell[BoxData[
      \(TraditionalForm\`{T\_x\( | \+x\)P}\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " that we can choose an appropriate value such that"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1[1])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(x1\_0 < 10\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1[1]"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1[2])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a = 3*x1\_0\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1[2]"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipFinite",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\((\[GothicT] = \(\[GothicCapitalT]\_1 \[Or] \[Ellipsis] \[Or] \
\[GothicT] = \[GothicCapitalT]\_n\))\), \[CapitalLambda], \[GothicT] \
\[Element] {\[GothicCapitalT]\_1, \[Ellipsis], \[GothicCapitalT]\_n}, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[Element] {\[GothicCapitalT]\_1, \
\[Ellipsis], \[GothicCapitalT]\_n}, \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((if\ n \[GreaterEqual] 1)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[Element] {3}\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1.\[Or]\"\>", ",", 
                StyleBox[\(a = 3\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[Element] {3, 4}\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1.\[Or]\"\>", ",", 
                StyleBox[\(\((a = 3)\) \[Or] \((a = 4)\)\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBNonMembershipFinite",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicT] \[NotEqual] \[GothicCapitalT]\_1, \[Ellipsis], \
\[GothicT] \[NotEqual] \[GothicCapitalT]\_n, \[CapitalLambda], \[GothicT] \
\[NotElement] {\[GothicCapitalT]\_1, \[Ellipsis], \[GothicCapitalT]\_n}, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[NotElement] \
{\[GothicCapitalT]\_1, \[Ellipsis], \[GothicCapitalT]\_n}, \[CapitalDelta]\), 
              "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((if\ n \[GreaterEqual] 1)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[NotElement] {3}\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1[1]\"\>", ",", 
                StyleBox[\(a \[NotEqual] 3\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[NotElement] {3, 4}\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1[1]\"\>", ",", 
                  StyleBox[\(a \[NotEqual] 3\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1[2]\"\>", ",", 
                  StyleBox[\(a \[NotEqual] 4\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}]}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipFiniteUnion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicT] \[Element] \[GothicCapitalS]\_1 \[Or] \[Ellipsis] \
\[Or] \[GothicT] \[Element] \[GothicCapitalS]\_n, \[CapitalLambda], \
\[GothicT] \[Element] \[GothicCapitalS]\_1 \[Union] \[Ellipsis] \[Union] \
\[GothicCapitalS]\_n, \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[Element] \[GothicCapitalS]\_1 \
\[Union] \[Ellipsis] \[Union] \[GothicCapitalS]\_n, \[CapitalDelta]\), 
              "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((if\ n \[GreaterEqual] 2)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[Element] A \[Union] B\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1.\[Union]\"\>", ",", 
                StyleBox[\(a \[Element] A \[Or] a \[Element] B\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBNonMembershipFiniteUnion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicT] \[NotElement] \[GothicCapitalS]\_1, \[Ellipsis], \
\[GothicT] \[NotElement] \[GothicCapitalS]\_n, \[CapitalLambda], \[GothicT] \
\[NotElement] \[GothicCapitalS]\_1 \[Union] \[Ellipsis] \[Union] \
\[GothicCapitalS]\_n, \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[NotElement] \
\[GothicCapitalS]\_1 \[Union] \[Ellipsis] \[Union] \[GothicCapitalS]\_n, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((if\ n \[GreaterEqual] 2)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[NotElement] A \[Union] B\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[Union].[1]\"\>", ",", 
                  StyleBox[\(a \[NotElement] A\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[Union].[2]\"\>", ",", 
                  StyleBox[\(a \[NotElement] B\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}]}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipUnaryUnion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicS] \[Element] \[GothicCapitalS], \[GothicT] \[Element] \
\[GothicS], \[CapitalLambda], \[GothicT] \[Element] \(\[Union]\
\[GothicCapitalS]\), \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[Element] \(\[Union]\
\[GothicCapitalS]\), \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((where\ \[GothicS]\ is\ some\ new\ constant)\)}]}]], \
"InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[Element] \(\[Union]A\)\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[Union].[1]\"\>", ",", 
                  RowBox[{
                    StyleBox[\(A3\_0\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None], 
                    StyleBox["\[Element]",
                      "HighlightedText"], 
                    StyleBox["A",
                      "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                "]"}], ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[Union].[2]\"\>", ",", 
                  RowBox[{
                    StyleBox["a",
                      "HighlightedText"], 
                    StyleBox["\[Element]",
                      "HighlightedText"], 
                    StyleBox[\(A3\_0\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None]}], ",", \(\[Bullet]finfo[]\)}], 
                "]"}]}], "]"}], ",", "\<\"a1\"\>", ",", "\<\"\!\(\*
StyleBox[\\\"KBMembershipUnaryUnion\\\",\\n\\\"HighlightedText\\\"]\)\"\>"}], 
        "}"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["a1",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a1"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we know by definition of the big ",
  Cell[BoxData[
      \(TraditionalForm\`"\[Union]"\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "-operator that we can choose an appropriate value such that"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1\[Union].[1])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A3\_0 \[Element] A\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1\[Union].[1]"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1\[Union].[2])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] A3\_0\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1\[Union].[2]"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipUnionOf",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicT] \[Element] \[GothicCapitalS]\_\(x \[Rule] x\_1\), \
\[GothicCapitalC]\_\(x \[Rule] x\_1\), \[CapitalLambda], \[GothicT] \
\[Element] \(\(\[Union]\+x\)\+\(\[GothicCapitalC]\_x\)\[GothicCapitalS]\_x\), \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[Element] \(\(\[Union]\+x\)\+\(\
\[GothicCapitalC]\_x\)\[GothicCapitalS]\_x\), \[CapitalDelta]\), 
              "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "    ", \((where\ x\_1\ is\ some\ new\ constant)\),
         Cell[""]}]}]], "InferenceRule"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipUnionOf",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicT] \[Element] \[GothicCapitalS]\_\(x \[Rule] x\_1\), \
\[CapitalLambda], \[GothicT] \[Element] \(\[Union]\+x \[GothicCapitalS]\_x\), \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[Element] \(\[Union]\+x \
\[GothicCapitalS]\_x\), \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((special\ case, \ no\ condition)\)}]}]], "InferenceRule"],

Cell["Proof (Correctness of \[Cent]KBMembershipUnionOf, general case)", \
"SingleParagraph",
  FontWeight->"Bold"],

Cell[TextData[{
  "By definition of the union quantifier, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] \(\(\[Union]\+x\)\+\(\
\[GothicCapitalC]\_x\)\[GothicCapitalS]\_x\)\)]],
  " stands for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[GothicT]", "\[Element]", 
          RowBox[{
            StyleBox["\[Union]",
              
              SpanMaxSize->
                2], \({\[GothicCapitalS]\_x\( | \
\+x\)\[GothicCapitalC]\_x}\)}]}], TraditionalForm]]],
  ", thus"
}], "SingleParagraph"],

Cell[BoxData[
    \(z\_1 \[Element] {\[GothicCapitalS]\_x\( | \
\+x\)\[GothicCapitalC]\_x}\ \ and\)], "NumberedEquation",
  CellTags->"zElemAbstr"],

Cell[BoxData[
    \(\[GothicT] \[Element] z\_1\)], "NumberedEquation",
  CellTags->"tElemZ"],

Cell[TextData[{
  "for some new constant ",
  Cell[BoxData[
      \(TraditionalForm\`z\_1\)]],
  ". Expanding the set quantifier in (",
  
  CounterBox["NumberedEquation", "zElemAbstr"],
  ") leads to"
}], "SingleParagraph"],

Cell[BoxData[
    \(z\_1 = \[GothicCapitalS]\_\(x \[Rule] x\_1\)\ \ and\)], \
"NumberedEquation",
  CellTags->"zEqSx"],

Cell[BoxData[
    \(\[GothicCapitalC]\_\(x \[Rule] x\_1\)\)], "DisplayFormula",
  CellTags->"Cx"],

Cell[TextData[{
  "for some new constant ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  ". Substituting (",
  
  CounterBox["NumberedEquation", "zEqSx"],
  ") in (",
  
  CounterBox["NumberedEquation", "tElemZ"],
  ") delivers ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] \[GothicCapitalS]\_\(x \[Rule] \
x\_1\)\)]],
  ", thus ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] \[GothicCapitalS]\_\(x \[Rule] \
x\_1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalC]\_\(x \[Rule] x\_1\)\)]],
  " can be derived as new formulae."
}], "SingleParagraph"],

Cell["\[EmptySquare]", "Text",
  CellMargins->{{Inherited, Inherited}, {Inherited, -6}},
  TextAlignment->Right,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[
            RowBox[{"a", "\[Element]", 
              RowBox[{
                UnderscriptBox[
                  UnderscriptBox[
                    StyleBox["\[Union]",
                      "HighlightedText"], 
                    "x"], \(x \[Element] \[DoubleStruckCapitalN]\)], 
                RowBox[{"{", 
                  RowBox[{"x", ",", 
                    FractionBox[
                      StyleBox["x",
                        "HighlightedText"], "2"]}], "}"}]}]}],
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1.\[Union]\"\>", ",", 
                  StyleBox[
                    RowBox[{"a", "\[Element]", 
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox[\(x\_0\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], ",", 
                          FractionBox[
                            StyleBox[\(x\_0\),
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "2"]}], "}"}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1.C\"\>", ",", 
                  RowBox[{
                    StyleBox[\(x\_0\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None], 
                    StyleBox["\[Element]",
                      "HighlightedText"], 
                    StyleBox["\[DoubleStruckCapitalN]",
                      "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                "]"}]}], "]"}], ",", "\<\"a1\"\>", ",", "\<\"\!\(\*
StyleBox[\\\"KBMembershipUnionOf\\\",\\n\\\"HighlightedText\\\"]\)\"\>"}], 
        "}"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["a1",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a1"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we know by definition of the ",
  Cell[BoxData[
      \(TraditionalForm\`"\[Union]"\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "-quantifier that we can choose an appropriate value such that"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1.\[Union])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] {x\_0, x\_0\/2}\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1.\[Union]"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1.C)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(x\_0 \[Element] \[DoubleStruckCapitalN]\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1.C"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[
            RowBox[{"a", "\[Element]", 
              RowBox[{
                UnderscriptBox[
                  StyleBox["\[Union]",
                    "HighlightedText"], "x"], 
                RowBox[{"{", 
                  RowBox[{"x", ",", 
                    FractionBox[
                      StyleBox["x",
                        "HighlightedText"], "2"]}], "}"}]}]}],
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1.\[Union]\"\>", ",", 
                StyleBox[
                  RowBox[{"a", "\[Element]", 
                    RowBox[{"{", 
                      RowBox[{
                        StyleBox[\(x\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], ",", 
                        FractionBox[
                          StyleBox[\(x\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "2"]}], "}"}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>", ",", 
          StyleBox["\<\"KBMembershipUnionOf\"\>",
            "HighlightedText"]}], "}"}], "}"}]], "Output",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["a1",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a1"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we know by definition of the ",
  Cell[BoxData[
      \(TraditionalForm\`"\[Union]"\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "-quantifier that we can choose an appropriate value such that"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1.\[Union])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] {x\_1, x\_1\/2}\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1.\[Union]"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBSplitIntersection",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicT] \[Element] \[GothicCapitalS]\_1, \[Ellipsis], \
\[GothicT] \[Element] \[GothicCapitalS]\_n, \[GothicCapitalS]\_1 \
\[Intersection] \[Ellipsis] \[Intersection] \[GothicCapitalS]\_n \[NotEqual] \
\[EmptySet], \[CapitalLambda], \[GothicT] \[Element] \[GothicCapitalS]\_1 \
\[Intersection] \[Ellipsis] \[Intersection] \[GothicCapitalS]\_n, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[Element] \[GothicCapitalS]\_1 \
\[Intersection] \[Ellipsis] \[Intersection] \[GothicCapitalS]\_n, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((if\ n \[GreaterEqual] 2)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[Element] A \[Intersection] B\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[Intersection].[1]\"\>", ",", 
                  StyleBox[\(a \[Element] A\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[Intersection].[2]\"\>", ",", 
                  StyleBox[\(a \[Element] B\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[NotEqual]\[EmptySet]\"\>", ",", 
                  StyleBox[\(A \[Intersection] B \[NotEqual] {}\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}]}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output",
  CellEditDuplicate->False]
}, Open  ]],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["a1",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a1"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we can infer"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1\[Intersection].[1])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] A\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1\[Intersection].[1]"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1\[Intersection].[2])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] B\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1\[Intersection].[2]"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1\[NotEqual]\[EmptySet])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A \[Intersection] B \[NotEqual] {}\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1\[NotEqual]\[EmptySet]"],

Cell["\<\
Since non\[Dash]empty intersection is a property that is often used \
and often needed, we deduce this formula immediately from the membership in \
the intersection. For the other specialized membership assumptions we did not \
yet add this case due to lacking applications. We only infer \
non\[Dash]emptiness for general sets, which do not match any of the \
specialized syntactic patterns listed in this section, see the rule \
\[Cent]KBInferNonEmpty below. Furthermore, since inferring the membership in \
the individual sets is inverse to the rule \[Cent]KBComposeIntersection and \
deducing non\[Dash]emptiness is inverse to \[Cent]KBInferExistsMember, the \
rule locking mechanism stores the following rewrite exceptions:\
\>", \
"SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \($RewriteExceptions\)], "Input"],

Cell[BoxData[
    \(\[Bullet]lkTab[{{"KBComposeIntersection", \[Bullet]asml[{"a1\
\[Intersection].[1]", "a1\[Intersection].[2]"}, {"a1\[Intersection].[1]", 
              "a1"}, {"a1\[Intersection].[2]", 
              "a1"}]}, {"KBInferExistsMember", \[Bullet]asml[
            "a1\[NotEqual]\[EmptySet]"]}}]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This information should read as: for this branch of the proof, the rule \
\[Cent]KBComposeIntersection should ",
  StyleBox["not",
    FontSlant->"Italic"],
  " be applied to the assumptions \"",
  "a1\[Intersection].[1]\" and \"a1\[Intersection].[2]\", which would produce \
the \"new\" formula ",
  Cell[BoxData[
      \(TraditionalForm\`a \[Element] A \[Intersection] B\)]],
  ". Similarly, it should ",
  StyleBox["not",
    FontSlant->"Italic"],
  " apply to ",
  "\"a1\[Intersection].[1]\" and \"a1\" and to \"a1\[Intersection].[2]\" \
together with \"a1\", since no valuable knowledge can be gained. Furthermore, \
\[Cent]KBInferExistsMember should ",
  StyleBox["not",
    FontSlant->"Italic"],
  " be applied to \"a1\[NotEqual]\[EmptySet]\"."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBComposeIntersection",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[GothicT] \[Element] \[GothicCapitalS]\_1 \[Intersection] \
\[GothicCapitalS]\_2, \[CapitalLambda], \[GothicT] \[Element] \
\[GothicCapitalS]\_1, \[CapitalGamma], \[GothicT] \[Element] \
\[GothicCapitalS]\_2, \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[GothicT] \[Element] \[GothicCapitalS]\_1, \
\[CapitalGamma], \[GothicT] \[Element] \[GothicCapitalS]\_2, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromTwo", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<a1\>\"", ",", 
            StyleBox[\(a \[Element] \[Bullet]var[A]\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<a2\>\"", ",", 
            StyleBox[\(a \[Element] \[Bullet]var[B]\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}]}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1\[Intersection]a2\"\>", ",", 
                RowBox[{"a", "\[Element]", 
                  RowBox[{
                    StyleBox["A",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[Intersection]", 
                    StyleBox["B",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ",", \(\[Bullet]finfo[]\)}], 
              "]"}], "]"}], ",", "\<\"a1\"\>", ",", "\<\"a2\"\>"}], "}"}], 
      "}"}]], "Output"]
}, Open  ]],

Cell["\<\
As in the previous rule, the inverse rule \
\[Cent]KBSplitIntersection is locked for the resulting formula. Moreover, the \
rule locks itself for the resulting formula together with one of the input \
formulae.\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \($RewriteExceptions\)], "Input"],

Cell[BoxData[
    \(\[Bullet]lkTab[{{"KBSplitIntersection", \[Bullet]asml[
            "a1\[Intersection]a2"]}, {"KBComposeIntersection", \
\[Bullet]asml[{"a1\[Intersection]a2", "a1"}, {"a1\[Intersection]a2", 
              "a2"}]}}]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In the current version, this rule is restricted to the case, where both ",
  Cell[BoxData[
      \(\[GothicCapitalS]\_1\)]],
  " and ",
  Cell[BoxData[
      \(\[GothicCapitalS]\_2\)]],
  " are variables or constants introduced by the system. (This explains the \
\[Bullet]var tags in the input above.) Allowing this rule for more general \
cases, for instance for the case where ",
  Cell[BoxData[
      \(\[GothicCapitalS]\_1\)]],
  " and ",
  Cell[BoxData[
      \(\[GothicCapitalS]\_2\)]],
  "are expressions involving the set quantifier, would demand a simplifier \
for set expressions in order to simplify the resulting intersection \
expression. It is a task for future investigations to enhance the prover \
towards that aspect."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBNonMembershipFiniteIntersection",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicT] \[NotElement] \[GothicCapitalS]\_1 \[Or] \
\[Ellipsis] \[Or] \[GothicT] \[NotElement] \[GothicCapitalS]\_n, \
\[CapitalLambda], \[GothicT] \[NotElement] \[GothicCapitalS]\_1 \
\[Intersection] \[Ellipsis] \[Intersection] \[GothicCapitalS]\_n, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[NotElement] \
\[GothicCapitalS]\_1 \[Intersection] \[Ellipsis] \[Intersection] \
\[GothicCapitalS]\_n, \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((if\ n \[GreaterEqual] 2)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[NotElement] A \[Intersection] B\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1.\[Intersection]\"\>", ",", 
                StyleBox[\(a \[NotElement] A \[Or] a \[NotElement] B\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipUnaryIntersection",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[ForAll] \+s 
                    s \[Element] \[GothicCapitalS] \[Implies] \[GothicT] \
\[Element] 
                  s, \[CapitalLambda], \[GothicT] \[Element] \
\(\[Intersection]\[GothicCapitalS]\), \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[Element] \(\[Intersection]\
\[GothicCapitalS]\), \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((where\ \[GothicT]\ and\ \[GothicCapitalS]\ are\ free\ of\ \
s)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[Element] \(\[Intersection]A\)\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1.\[Intersection]\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["A1",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["A1",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", "A"}], 
                        "\[Implies]", 
                        RowBox[{"a", "\[Element]", 
                          StyleBox["A1",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipIntersectionOf",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[ForAll] \+x \[GothicCapitalC]\_x \[Implies] \[GothicT] \
\[Element] \[GothicCapitalS]\_x, \[CapitalLambda], \[GothicT] \[Element] \(\(\
\[Intersection]\+x\)\+\(\[GothicCapitalC]\_x\)\[GothicCapitalS]\_x\), \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[GothicT] \[Element] \(\(\[Intersection]\+x\)\
\+\(\[GothicCapitalC]\_x\)\[GothicCapitalS]\_x\), \[CapitalDelta]\), 
            "\[RightTee]", "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipIntersectionOf",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[ForAll] \+x \[GothicT] \[Element] \[GothicCapitalS]\_x, \
\[CapitalLambda], \[GothicT] \[Element] \(\[Intersection]\+x \
\[GothicCapitalS]\_x\), \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[Element] \(\[Intersection]\+x \
\[GothicCapitalS]\_x\), \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((special\ case, \ no\ condition)\)}]}]], "InferenceRule"],

Cell["\<\
Proof (Correctness of \[Cent]KBMembershipIntersectionOf, general \
case)\
\>", "SingleParagraph",
  FontWeight->"Bold"],

Cell[TextData[{
  "Assume we know ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] \(\(\[Intersection]\+x\)\+\(\
\[GothicCapitalC]\_x\)\[GothicCapitalS]\_x\)\)]],
  ". We have to show ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \+x \[GothicCapitalC]\_x \[Implies] \
\[GothicT] \[Element] \[GothicCapitalS]\_x\)]],
  ", so we assume ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalC]\_\(x \[Rule] x\_1\)\)]],
  " for some new constant ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  " and show ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[GothicT]", "\[Element]", 
          SubscriptBox["\[GothicCapitalS]", 
            RowBox[{
              StyleBox["x",
                FontSlant->"Italic"], "\[Rule]", 
              SubscriptBox[
                StyleBox["x",
                  FontSlant->"Italic"], "1"]}]]}], TraditionalForm]]],
  ". By definition of the intersection quantifier, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] \(\(\[Intersection]\+x\)\+\(\
\[GothicCapitalC]\_x\)\[GothicCapitalS]\_x\)\)]],
  " stands for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[GothicT]", "\[Element]", 
          RowBox[{
            StyleBox["\[Intersection]",
              
              SpanMaxSize->
                2], \({\[GothicCapitalS]\_x\( | \
\+x\)\[GothicCapitalC]\_x}\)}]}], TraditionalForm]]],
  ", thus"
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        FormBox[\(\[ForAll] \+s 
                s \[Element] {\[GothicCapitalS]\_x\( | \+x\)\[GothicCapitalC]\
\_x} \[Implies] \[GothicT] \[Element] s\),
          "TraditionalForm"], "."}]}]], "NumberedEquation",
  CellTags->"UniAssum"],

Cell[TextData[{
  "From ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalC]\_\(x \[Rule] x\_1\)\)]],
  " we know  ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalS]\_\(x \[Rule] x\_1\) \[Element] {\
\[GothicCapitalS]\_x\( | \+x\)\[GothicCapitalC]\_x}\)]],
  " and, by (",
  
  CounterBox["NumberedEquation", "UniAssum"],
  "), ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] \[GothicCapitalS]\_\(x \[Rule] \
x\_1\)\)]],
  "."
}], "SingleParagraph"],

Cell["\[EmptySquare]", "Text",
  CellMargins->{{Inherited, Inherited}, {Inherited, -6}},
  TextAlignment->Right,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[
            RowBox[{"a", "\[Element]", 
              RowBox[{
                UnderscriptBox[
                  UnderscriptBox[
                    StyleBox["\[Intersection]",
                      "HighlightedText"], 
                    "x"], \(x \[Element] \[DoubleStruckCapitalN]\)], 
                RowBox[{"{", 
                  RowBox[{"x", ",", 
                    FractionBox[
                      StyleBox["x",
                        "HighlightedText"], "2"]}], "}"}]}]}],
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1.\[Intersection]\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", 
                          "\[DoubleStruckCapitalN]"}], "\[Implies]", 
                        RowBox[{"a", "\[Element]", 
                          RowBox[{"{", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], ",", 
                              FractionBox[
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "2"]}], "}"}]}]}], 
                      ")"}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[
            RowBox[{"a", "\[Element]", 
              RowBox[{
                UnderscriptBox[
                  StyleBox["\[Intersection]",
                    "HighlightedText"], "x"], 
                RowBox[{"{", 
                  RowBox[{"x", ",", 
                    FractionBox[
                      StyleBox["x",
                        "HighlightedText"], "2"]}], "}"}]}]}],
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1.\[Intersection]\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{"a", "\[Element]", 
                        RowBox[{"{", 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], ",", 
                            FractionBox[
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "2"]}], "}"}]}], ")"}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipDifference",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[GothicT] \[Element] \[GothicCapitalS]\_1, \[GothicT] \
\[NotElement] \[GothicCapitalS]\_2, \[CapitalLambda], \[GothicT] \[Element] \
\[GothicCapitalS]\_1\[Backslash]\[GothicCapitalS]\_2, \[CapitalDelta]\), 
            "\[RightTee]", "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[GothicT] \[Element] \[GothicCapitalS]\_1\
\[Backslash]\[GothicCapitalS]\_2, \[CapitalDelta]\), "\[RightTee]", 
            "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[Element] A\[Backslash]B\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1[1]\"\>", ",", 
                  StyleBox[\(a \[Element] A\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1[2]\"\>", ",", 
                  StyleBox[\(a \[NotElement] B\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}]}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBNonMembershipDifference",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[GothicT] \[NotElement] \[GothicCapitalS]\_1 \[Or] \[GothicT] \
\[Element] \[GothicCapitalS]\_2, \[CapitalLambda], \[GothicT] \[NotElement] \
\[GothicCapitalS]\_1\[Backslash]\[GothicCapitalS]\_2, \[CapitalDelta]\), 
            "\[RightTee]", "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[GothicT] \[NotElement] \[GothicCapitalS]\_1\
\[Backslash]\[GothicCapitalS]\_2, \[CapitalDelta]\), "\[RightTee]", 
            "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[NotElement] A\[Backslash]B\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1[1]\"\>", ",", 
                StyleBox[\(a \[NotElement] A \[Or] a \[Element] B\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipComplement",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[GothicT] \[NotElement] \[GothicCapitalS], \[CapitalLambda], \
\[GothicT] \[Element] \[GothicCapitalS]\^c, \[CapitalDelta]\), "\[RightTee]", 
            "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[GothicT] \[Element] \[GothicCapitalS]\^c, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[
            RowBox[{"a", "\[Element]", 
              SuperscriptBox[
                StyleBox["A",
                  "HighlightedText"], "c"]}],
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"\[ScriptCapitalC] a1\"\>", ",", 
                StyleBox[\(a \[NotElement] A\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBNonMembershipComplement",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[GothicT] \[Element] \[GothicCapitalS], \[CapitalLambda], \
\[GothicT] \[NotElement] \[GothicCapitalS]\^c, \[CapitalDelta]\), 
            "\[RightTee]", "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[GothicT] \[NotElement] \[GothicCapitalS]\^c, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[NotElement] A\^c\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"\[ScriptCapitalC] a1\"\>", ",", 
                StyleBox[\(a \[Element] A\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipPowerset",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[GothicS] \[SubsetEqual] \[GothicCapitalS], \[CapitalLambda], \
\[GothicS] \[Element] \[ScriptCapitalP][\[GothicCapitalS]], \[CapitalDelta]\),
             "\[RightTee]", "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[GothicS] \[Element] \[ScriptCapitalP][\
\[GothicCapitalS]], \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[Element] \[ScriptCapitalP][A]\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"\[ScriptCapitalP] a1\"\>", ",", 
                StyleBox[\(a \[SubsetEqual] A\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipCrossProduct",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicT] = \[LeftAngleBracket]\[GothicT]\_1, \[Ellipsis], \
\[GothicT]\_n\[RightAngleBracket], \[GothicT]\_1 \[Element] \[GothicCapitalS]\
\_1, \[Ellipsis], \[GothicT]\_n \[Element] \[GothicCapitalS]\_n, \
\[CapitalLambda], \[GothicT] \[Element] \[GothicCapitalS]\_1\[Cross]\
\[Ellipsis]\[Cross]\[GothicCapitalS]\_n, \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[Element] \[GothicCapitalS]\_1\
\[Cross]\[Ellipsis]\[Cross]\[GothicCapitalS]\_n, \[CapitalDelta]\), 
              "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((if\ n \[GreaterEqual] 2)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[Element] A\[Cross]B\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"\[Cross] a1\"\>", ",", 
                  
                  StyleBox[\(a = \[LeftAngleBracket]a\_1, 
                        a\_2\[RightAngleBracket]\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1.1\"\>", ",", 
                  StyleBox[\(a\_1 \[Element] A\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1.2\"\>", ",", 
                  StyleBox[\(a\_2 \[Element] B\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}]}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Introducing the equality ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] = \[LeftAngleBracket]\[GothicT]\_1, \
\[Ellipsis], \[GothicT]\_n\[RightAngleBracket]\)]],
  " is important because it gives a ",
  StyleBox["structural representation",
    FontSlant->"Italic"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT]\)]],
  ", which is very useful in most of the proofs. On the other hand, of \
course, it makes no sense to substitute this representation into the formula, \
which it was derived from. Since substitution is handled by a different \
prover, namely QR, we must communicate this fact to the QR module. This is \
accomplished, as expected, through an entry in QR's proof context. We \
introduced a mechanism similar to rule locking in the QR prover by again \
maintaining a list of ",
  StyleBox["rewrite exceptions",
    FontSlant->"Italic"],
  " in the proof context. In \[Cent]KBMembershipCrossProduct, the rewrite \
exceptions for QR are expanded by an entry that prevents rewriting the \
original cross product formula using the new equation, in the example"
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GetElem[
      GetProofContextElem["\<QR\>"], "\<RewriteException\>"]\)], "Input"],

Cell[BoxData[
    \({{"a1", {"\[Cross] a1"}}}\)], "Output"]
}, Open  ]],

Cell["\<\
the formula \"a1\" should not be rewritten by a rule derived from \
formula \"\[Cross] a1\".\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBInferNonEmpty",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicCapitalS] \[NotEqual] \[EmptySet], \[CapitalLambda], \
\[GothicT] \[Element] \[GothicCapitalS], \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicT] \[Element] \[GothicCapitalS], \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((if\ \[GothicCapitalS]\ is\ ont\ one\ of\ the\ known\ number\ \
sets)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[Element] A\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1\[NotEqual]\[EmptySet]\"\>", ",", 
                StyleBox[\(A \[NotEqual] {}\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The inverse of this rule, which becomes locked for the rest of the \
proof, is \[Cent]KBInferExistsMember\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \($RewriteExceptions\)], "Input"],

Cell[BoxData[
    \(\[Bullet]lkTab[{{"KBInferExistsMember", \[Bullet]asml[
            "a1\[NotEqual]\[EmptySet]"]}}]\)], "Output"]
}, Open  ]],

Cell["\<\
The number sets recognized by the rule are: \
\[DoubleStruckCapitalN], \[DoubleStruckCapitalI], \[DoubleStruckCapitalZ], \
\[DoubleStruckCapitalQ], \[DoubleStruckCapitalR], \[DoubleStruckCapitalC], \
and \[DoubleStruckCapitalP].\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(a \[Element] \[DoubleStruckCapitalR]\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    \(Sequence[]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBInferExistsMember",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(a \[Element] \[GothicCapitalS], \[CapitalLambda], \
\[GothicCapitalS] \[NotEqual] \[EmptySet], \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicCapitalS] \[NotEqual] \[EmptySet], \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((where\ a\ is\ some\ new\ constant)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<A\>\"", ",", 
          StyleBox[\(A \[NotEqual] \[EmptySet]\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"A\[NotEqual]\[EmptySet]\"\>", ",", 
                RowBox[{
                  StyleBox[\(A1\_0\),
                    "HighlightedText",
                    FontSlant->"Italic",
                    Background->None], 
                  StyleBox["\[Element]",
                    "HighlightedText"], 
                  StyleBox["A",
                    "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"A\"\>", ",", "\<\"KBNonEmpty\"\>"}], "}"}], 
      "}"}]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["A",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "A"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we know that we can choose an appropriate value such that"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(A\[NotEqual]\[EmptySet])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A1\_0 \[Element] A\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"A\[NotEqual]\[EmptySet]"],

Cell["Conversely, this rule locks its inverse \[Cent]KBInferNonEmpty.", \
"SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \($RewriteExceptions\)], "Input"],

Cell[BoxData[
    \(\[Bullet]lkTab[{{"KBInferExistsMember", \[Bullet]asml[
            "a1\[NotEqual]\[EmptySet]"]}, {"KBInferNonEmpty", \[Bullet]asml[
            "A\[NotEqual]\[EmptySet]"]}}]\)], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<A\[NotEqual]\[EmptySet]\>\"", ",", 
          RowBox[{
            StyleBox[\(A1\_0\),
              "HighlightedText",
              FontSlant->"Italic",
              Background->None], 
            StyleBox["\[Element]",
              "HighlightedText"], 
            StyleBox["A",
              "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    \(Sequence[]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set Inclusion", "Subsubsection",
  CellTags->"c:17"],

Cell["\<\
Like with the inference rules for reducing set inclusion in the \
goal, we provide special rules for expanding inclusion properties containing \
set abstractions.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBInclusion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[ForAll] \+z \[GothicCapitalP]\_\(x \[Rule] z\) \[Implies] \
\[GothicCapitalQ]\_\(x \[Rule] z\), \[CapitalLambda], {x\( | \+x\)\
\[GothicCapitalP]\_x} \[SubsetEqual] {x\( | \+x\)\[GothicCapitalQ]\_x}, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], {x\( | \+x\)\[GothicCapitalP]\_x} \
\[SubsetEqual] {x\( | \+x\)\[GothicCapitalQ]\_x}, \[CapitalDelta]\), 
              "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((where\ \[GothicCapitalP]\_x\ and\ \[GothicCapitalQ]\_x\ are\
\ free\ of\ z)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\({x\( | \+x\)x < k} \[SubsetEqual] {x\( | \+x\)x < l}\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1\[SubsetEqual]\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["x1",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["x1",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "<", "k"}], "\[Implies]", 
                        RowBox[{
                          StyleBox["x1",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "<", "l"}]}], ")"}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell["Weaker forms of this rule are:", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBInclusion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[ForAll] \+z \[GothicCapitalP]\_\(x \[Rule] z\) \[Implies] 
                z \[Element] \[GothicCapitalS]\_2, \[CapitalLambda], {x\( | \
\+x\)\[GothicCapitalP]\_x} \[SubsetEqual] \[GothicCapitalS]\_2, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], {x\( | \+x\)\[GothicCapitalP]\_x} \
\[SubsetEqual] \[GothicCapitalS]\_2, \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "    ", \((where\ \[GothicCapitalP]\_x\ and\ \[GothicCapitalS]\_2\ \
are\ free\ of\ z)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\({x\( | \+x\)x < k} \[SubsetEqual] B\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1\[SubsetEqual]\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["x5",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["x5",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "<", "k"}], "\[Implies]", 
                        RowBox[{
                          StyleBox["x5",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", "B"}]}], ")"}]}],
                  
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBInclusion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[ForAll] \+z 
                    z \[Element] \[GothicCapitalS]\_1 \[Implies] \
\[GothicCapitalQ]\_\(x \[Rule] z\), \[CapitalLambda], \[GothicCapitalS]\_1 \
\[SubsetEqual] {x\( | \+x\)\[GothicCapitalQ]\_x}, \[CapitalDelta]\), 
              "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicCapitalS]\_1 \[SubsetEqual] {x\( | \
\+x\)\[GothicCapitalQ]\_x}, \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((where\ \[GothicCapitalQ]\_x\ and\ \[GothicCapitalS]\_1\ are\
\ free\ of\ z)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(A \[SubsetEqual] {x\( | \+x\)x < l}\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1\[SubsetEqual]\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["x6",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["x6",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", "A"}], 
                        "\[Implies]", 
                        RowBox[{
                          StyleBox["x6",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "<", "l"}]}], ")"}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["For general sets, the rule is:", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBInclusion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[ForAll] \+z z \[Element] \[GothicCapitalS]\_1 \[Implies] 
                z \[Element] \[GothicCapitalS]\_2, \[CapitalLambda], \
\[GothicCapitalS]\_1 \[SubsetEqual] \[GothicCapitalS]\_2, \[CapitalDelta]\), 
              "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicCapitalS]\_1 \[SubsetEqual] \
\[GothicCapitalS]\_2, \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "    ", \((where\ \[GothicCapitalS]\_1\ and\ \[GothicCapitalS]\_2\ \
are\ free\ of\ z)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(A \[SubsetEqual] B\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1\[SubsetEqual]\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["A3",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["A3",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", "A"}], 
                        "\[Implies]", 
                        RowBox[{
                          StyleBox["A3",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", "B"}]}], ")"}]}],
                  
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBProperInclusion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[ForAll] \+z z \[Element] \[GothicCapitalS]\_1 \[Implies] 
                z \[Element] \[GothicCapitalS]\_2, 
              a \[Element] \[GothicCapitalS]\_2, 
              a \[NotElement] \[GothicCapitalS]\_1, \[CapitalLambda], \
\[GothicCapitalS]\_1 \[SubsetEqual] \[GothicCapitalS]\_2, \[CapitalDelta]\), 
              "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicCapitalS]\_1 \[Subset] \
\[GothicCapitalS]\_2, \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "    ", \((where\ \[GothicCapitalS]\_1\ and\ \[GothicCapitalS]\_2\ \
are\ free\ of\ z, \ a\ some\ new\ constant)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(A \[Subset] B\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[SubsetEqual]\"\>", ",", 
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["A5",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["A5",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", "A"}], 
                        "\[Implies]", 
                        RowBox[{
                          StyleBox["A5",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", "B"}]}], ")"}]}],
                   ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[Element]\"\>", ",", 
                  RowBox[{
                    StyleBox[\(A6\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[Element]", "B"}], 
                  ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[NotElement]\"\>", ",", 
                  RowBox[{
                    StyleBox[\(A6\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[NotElement]", "A"}], 
                  ",", \(\[Bullet]finfo[]\)}], "]"}]}], "]"}], 
          ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["a1",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a1"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we can infer"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1\[SubsetEqual])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["A5",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["A5",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Element]", "A"}], "\[Implies]", 
            RowBox[{
              StyleBox["A5",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Element]", "B"}]}], ")"}]}]], 
    "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1\[SubsetEqual]"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1\[Element])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A6\_0 \[Element] B\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1\[Element]"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1\[NotElement])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(A6\_0 \[NotElement] A\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1\[NotElement]"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set Equality", "Subsubsection",
  CellTags->"c:18"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBSetEquality",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[GothicCapitalS]\_1 \[SubsetEqual] \[GothicCapitalS]\_2, \
\[GothicCapitalS]\_2 \[SubsetEqual] \[GothicCapitalS]\_1, \[CapitalLambda], \
\[GothicCapitalS]\_1 = \[GothicCapitalS]\_2, \[CapitalDelta]\), "\[RightTee]",
               "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicCapitalS]\_1 = \[GothicCapitalS]\_2, \
\[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "    ", \((if\ \[GothicCapitalS]\_1\ or\ \[GothicCapitalS]\_2\ can\ \
be\ recognized\ as\ set)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(A = {x\( | \+x\)x < l}\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[SubsetEqual]\"\>", ",", 
                  StyleBox[
                    RowBox[{"A", "\[SubsetEqual]", 
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], 
                          UnderscriptBox["\[VerticalSeparator]", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], " "}]], 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "<", "l"}]}], "}"}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[SupersetEqual]\"\>", ",", 
                  StyleBox[
                    RowBox[{
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], 
                          UnderscriptBox["\[VerticalSeparator]", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], " "}]], 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "<", "l"}]}], "}"}], 
                      "\[SubsetEqual]", "A"}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}]}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBSetEqualityProperty",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\((y \[Element] \[GothicCapitalS]\_2)\)\_u, \[CapitalLambda], \
\[GothicCapitalS]\_1 = \[GothicCapitalS]\_2, \[CapitalGamma], \[ForAll] \+y 
                  y \[Element] \[GothicCapitalR]\_y, \[CapitalDelta]\), 
              "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[GothicCapitalS]\_1 = \[GothicCapitalS]\_2, \
\[CapitalGamma], \[ForAll] \+y 
                  y \[Element] \[GothicCapitalR]\_y, \[CapitalDelta]\), 
              "\[RightTee]", "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "    ", 
        RowBox[{"(", 
          RowBox[{"if", " ", "u", " ", "is", " ", 
            StyleBox["a",
              FontSlant->"Plain"], " ", "unifier", " ", "for", 
            "  ", \(\[GothicCapitalS]\_1\), " ", "and", 
            " ", \(\[GothicCapitalR]\_y\)}], ")"}]}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromTwo", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<a1\>\"", ",", 
            StyleBox[\({a} = {b}\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<a2\>\"", ",", 
            StyleBox[\(\[ForAll] \+x x \[Element] {x}\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}]}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1+a2\"\>", ",", 
                StyleBox[\(a \[Element] {b}\),
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a2\"\>", 
          ",", \(\[Bullet]lf["a2\[Dagger]", 
            a \[Element] {a}, \[Bullet]finfo[]]\), ",", "\<\"a1\"\>"}], "}"}],
       "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(Theorema`Provers`SetTheory`Header`English`Private`InferredNewKnowledge[{\
\[Bullet]asml[\[Bullet]lf["\<a1+a2\>", 
              a \[Element] {b}, \[Bullet]finfo[]]], "\<a2\>", \
\[Bullet]lf["\<a2\[Dagger]\>", 
            a \[Element] {a}, \[Bullet]finfo[]], "\<a1\>"}] // 
      CellPrint\)], "Input"],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["a2",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a2"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we know in particular"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a2\[Dagger])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] {a}\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a2\[Dagger]"],

Cell[TextData[{
  "and, together with ",
  StyleBox["(", "Label"],
  ButtonBox["a1",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a1"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ", we can deduce"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1+a2)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] {b}\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1+a2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cardinality of Sets", "Subsubsection",
  CellTags->"c:19"],

Cell["\<\
The following two rules rely on the axiom of choice. In the \
standard setting of the prover options they are deactivated.\
\>", \
"SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBFiniteChoice",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(a \[Element] \[GothicCapitalS], \[CapitalLambda], \
\[LeftBracketingBar]\[GothicCapitalS]\[RightBracketingBar] = 
                1, \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[LeftBracketingBar]\[GothicCapitalS]\
\[RightBracketingBar] = 1, \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((where\ a\ is\ some\ new\ constant)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(\[LeftBracketingBar]A\[RightBracketingBar] = 1\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1#1\"\>", ",", 
                RowBox[{
                  StyleBox[\(A7\_0\),
                    "HighlightedText",
                    FontSlant->"Italic",
                    Background->None], 
                  StyleBox["\[Element]",
                    "HighlightedText"], 
                  StyleBox["A",
                    "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBFiniteChoice",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(a \[Element] \[GothicCapitalS], 
              b \[Element] \[GothicCapitalS], 
              a \[NotEqual] 
                b, \[CapitalLambda], \[LeftBracketingBar]\[GothicCapitalS]\
\[RightBracketingBar] = 2, \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[LeftBracketingBar]\[GothicCapitalS]\
\[RightBracketingBar] = 2, \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((where\ a\ and\ b\ are\ some\ new\ constants)\)}]}]], \
"InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(\[LeftBracketingBar]A\[RightBracketingBar] = 2\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1#1\"\>", ",", 
                  RowBox[{
                    StyleBox[\(A8\_0\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None], 
                    StyleBox["\[Element]",
                      "HighlightedText"], 
                    StyleBox["A",
                      "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                "]"}], ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1#2\"\>", ",", 
                  RowBox[{
                    StyleBox[\(A8\_1\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None], 
                    StyleBox["\[Element]",
                      "HighlightedText"], 
                    StyleBox["A",
                      "HighlightedText"]}], ",", \(\[Bullet]finfo[]\)}], 
                "]"}], ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[NotEqual]\"\>", ",", 
                  RowBox[{
                    StyleBox[\(A8\_0\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None], 
                    StyleBox["\[NotEqual]",
                      "HighlightedText"], 
                    StyleBox[\(A8\_1\),
                      "HighlightedText",
                      FontSlant->"Italic",
                      Background->None]}], ",", \(\[Bullet]finfo[]\)}], 
                "]"}]}], "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The Such\[Dash]A and the Such\[Dash]A\[Dash]Unique Quantifier\
\>", \
"Subsubsection",
  CellTags->"c:20"],

Cell[TextData[{
  "As already introduced in Part 1, Section ",
  ButtonBox["2.1",
    ButtonData:>{"Part1.nb", "Sec:MathLanguage"},
    ButtonStyle->"Hyperlink"],
  " on special quantifiers in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language, the system supports two special quantifiers, which are intended \
to be used on the right\[Dash]hand side of definitions, the such\[Dash]a \
quantifier \[SuchThat] and the such\[Dash]a\[Dash]unique quantifier \
\[SuchThat]!. The STKBR prover contains inference rules for expanding \
definitions involving these quantifiers, based on the following conventions:\n\
A definition for a ",
  StyleBox["new",
    FontSlant->"Italic"],
  " function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " in the form"
}], "SingleParagraph"],

Cell[BoxData[
    \(\(\[ForAll] \+x\)\+\(\[GothicCapitalC]\_x\)f[
          x] := \(\( \[SuchThat] \+y\)\(\[GothicCapitalP]\_\(x, 
            y\)\)\)\)], "NumberedEquation",
  CellTags->"defST"],

Cell["expresses one of the equivalent facts that", "SingleParagraph"],

Cell[BoxData[
    \(\(\[ForAll] \+x\)\+\(\[GothicCapitalC]\_x\)\(\[Exists] \+y \
\[GothicCapitalP]\_\(x, y\)\)\)], "NumberedEquation",
  CellTags->"charPropST1"],

Cell[BoxData[
    RowBox[{\(\(\[ForAll] \+x\)\+\(\[GothicCapitalC]\_x\)\), 
      RowBox[{\(\[GothicCapitalP]\_\(x, f[x]\)\), "  ", 
        RowBox[{"(", 
          RowBox[{"where", " ", "f", " ", "is", " ", 
            StyleBox["a",
              FontSlant->"Plain"], " ", "new", " ", "function", " ", 
            "symbol"}], ")"}]}]}]], "NumberedEquation",
  CellTags->"charPropST2"],

Cell[BoxData[
    RowBox[{\(\(\[ForAll] \+\(x, y\)\)\+\(\[GothicCapitalC]\_x\)f[x]\), "=", 
      RowBox[{"y", "\[Implies]", 
        RowBox[{\(\[GothicCapitalP]\_\(x, y\)\), "  ", 
          RowBox[{"(", 
            RowBox[{"where", " ", "f", " ", "is", " ", 
              StyleBox["a",
                FontSlant->"Plain"], " ", "new", " ", "function", " ", 
              "symbol"}], ")"}]}]}]}]], "NumberedEquation",
  CellTags->"charPropST3"],

Cell["\<\
Proof (Equivalence of the three characterizations for \
\[SuchThat])\
\>", "SingleParagraph",
  FontWeight->"Bold"],

Cell[TextData[{
  "For showing the equivalence of (",
  
  CounterBox["NumberedEquation", "charPropST1"],
  "), (",
  
  CounterBox["NumberedEquation", "charPropST2"],
  "), and (",
  
  CounterBox["NumberedEquation", "charPropST3"],
  "), we show the following implications: (",
  
  CounterBox["NumberedEquation", "charPropST1"],
  ")\[Implies](",
  
  CounterBox["NumberedEquation", "charPropST2"],
  "), (",
  
  CounterBox["NumberedEquation", "charPropST2"],
  ")\[Implies](",
  
  CounterBox["NumberedEquation", "charPropST3"],
  "), and (",
  
  CounterBox["NumberedEquation", "charPropST3"],
  ")\[Implies](",
  
  CounterBox["NumberedEquation", "charPropST1"],
  ")."
}], "SingleParagraph"],

Cell[TextData[{
  "(",
  
  CounterBox["NumberedEquation", "charPropST1"],
  ")\[Implies](",
  
  CounterBox["NumberedEquation", "charPropST2"],
  "): From ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ForAll] \+x\)\+\(\[GothicCapitalC]\_x\)\(\
\[Exists] \+y \[GothicCapitalP]\_\(x, y\)\)\)]],
  " we know by skolemization, that we can introduce a new Skolem function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", such that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ForAll] \+x\)\+\(\[GothicCapitalC]\_x\)\
\[GothicCapitalP]\_\(x, f[x]\)\)]],
  "."
}], "SingleParagraph"],

Cell[TextData[{
  "(",
  
  CounterBox["NumberedEquation", "charPropST2"],
  ")\[Implies](",
  
  CounterBox["NumberedEquation", "charPropST3"],
  "): For proving (",
  
  CounterBox["NumberedEquation", "charPropST3"],
  "), we take ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0\)]],
  " arbitrary but fixed and assume ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalC]\_\(x\_0\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f[x\_0] = y\_0\)]],
  ". From (",
  
  CounterBox["NumberedEquation", "charPropST2"],
  ") we know in particular ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_\(x\_0, f[x\_0]\)\)]],
  ", hence ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_\(x\_0, y\_0\)\)]],
  "."
}], "SingleParagraph"],

Cell[TextData[{
  "(",
  
  CounterBox["NumberedEquation", "charPropST3"],
  ")\[Implies](",
  
  CounterBox["NumberedEquation", "charPropST1"],
  "): For proving (",
  
  CounterBox["NumberedEquation", "charPropST1"],
  "), we take ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  "arbitrary but fixed and assume ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalC]\_\(x\_0\)\)]],
  ". From ",
  Cell[BoxData[
      \(TraditionalForm\`f[x\_0] = f[x\_0]\)]],
  " we know, by (",
  
  CounterBox["NumberedEquation", "charPropST3"],
  "), ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_\(x\_0, f[x\_0]\)\)]],
  ", hence ",
  Cell[BoxData[
      \(TraditionalForm\`\[Exists] \+y \[GothicCapitalP]\_\(x\_0, y\)\)]],
  "."
}], "SingleParagraph"],

Cell["\[EmptySquare]", "Text",
  CellMargins->{{Inherited, Inherited}, {Inherited, -6}},
  TextAlignment->Right,
  TextJustification->0],

Cell[TextData[{
  "In order to guarantee that no contradiction is introduced by introducing a \
new function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", it is obligatory to ",
  StyleBox["prove",
    FontSlant->"Italic"],
  " one of the three properties listed above ",
  StyleBox["before",
    FontSlant->"Italic"],
  " giving a function definition using the \[SuchThat]\[Dash]quantifier. \
Property (",
  
  CounterBox["NumberedEquation", "charPropST1"],
  ") is most commonly used as justification for the definition and it is \
addressed as showing that the function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is ",
  StyleBox["well\[Dash]defined",
    FontSlant->"Italic"],
  ". There is also the \"dual\" position to view the \
\[SuchThat]\[Dash]quantifier as a possibility to make skolemization explicit. \
Suppose we already know ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \+x\(\[Exists] \+y P[x, y]\)\)]],
  ", then, by skolemization, we can introduce a new function ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ", such that ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \+x P[x, S[x]]\)]],
  ", which is an ",
  StyleBox["implicit definition",
    FontSlant->"Italic"],
  " for the function ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ". The \[SuchThat]\[Dash]quantifier can be used to turn the implicit \
definition of ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " into an explicit definition ",
  Cell[BoxData[
      \(TraditionalForm\`S[x] := \(\( \[SuchThat] \+y\)\(P[x, y]\)\)\)]],
  ". Of course, another possibility would be to provide a mechanism for \
handling implicit definitions. Instead, we provide a mechanism for handling \
definitions involving the \[SuchThat]\[Dash]quantifier, which, in its current \
version, infers a formula in the style of (",
  
  CounterBox["NumberedEquation", "charPropST2"],
  ") from a definition like (",
  
  CounterBox["NumberedEquation", "defST"],
  "). It is not necessary to add a formula of type (",
  
  CounterBox["NumberedEquation", "charPropST3"],
  ") to the knowledge base, because formula (",
  
  CounterBox["NumberedEquation", "charPropST2"],
  ") together with substitution done in the QR module has exactly the same \
effect. In addition, we delete the definition from the knowledge base in \
order to prevent the QR prover from using the definition for rewriting."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBSuchThatExpansion",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[ForAll] \+x \[GothicCapitalC]\_x \[Implies] \
\[GothicCapitalP]\_\(x, f[x]\), \[CapitalLambda], \[CapitalDelta]\), 
            "\[RightTee]", "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[ForAll] \+x \[GothicCapitalC]\_x \[Implies] \
\((f[x] := \(\( \[SuchThat] \+y\)\(\[GothicCapitalP]\_\(x, 
                        y\)\)\))\), \[CapitalDelta]\), "\[RightTee]", 
            "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBSuchThatExpansion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[ForAll] \+x \[GothicCapitalP]\_\(x, f[x]\), \
\[CapitalLambda], \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[ForAll] \+x\((f[
                      x] := \(\( \[SuchThat] \+y\)\(\[GothicCapitalP]\_\(x, 
                          y\)\)\))\), \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "  ", \((special\ case, \ no\ condition)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          
          StyleBox[\(\[ForAll] \+x\((\@x := \(\( \[SuchThat] \+y\)\((y\^2 = 
                        x)\)\))\)\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1\[SuchThat]\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        SuperscriptBox[
                          RowBox[{"(", 
                            SqrtBox[
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]], ")"}], "2"], "=", 
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>", ",", "\<\"\!\(\*
StyleBox[\\\"KBSuchThatExpansion\\\",\\n\\\"HighlightedText\\\"]\)\"\>"}], 
        "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["a1",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a1"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we can infer by expansion of the \"such that\"\[Dash]quantifier"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1\[SuchThat])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                SqrtBox[
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]], ")"}], "2"], "=", 
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1\[SuchThat]"],

Cell[TextData[{
  "Note that, before giving the above definition, the user should provide a \
proof of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \+x\(\[Exists] \+y\((y\^2 = x)\)\)\)]],
  ". However, the system does not force the user to give this prove, we leave \
it to the responsibility of the user to apply the \
\[SuchThat]\[Dash]quantifier correctly. For this example, if ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " ranges over the real numbers and ",
  Cell[BoxData[
      \(TraditionalForm\`y\^2\)]],
  " means ",
  Cell[BoxData[
      \(TraditionalForm\`y*y\)]],
  " with \"",
  Cell[BoxData[
      \(TraditionalForm\`*\)]],
  "\" denoting \"usual multiplication\", then this statement can't be proven. \
It is, in fact, false, since for negative ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " there is no such ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ", thus, the definition will introduce a contradiction. Restricting the \
range of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " to the non\[Dash]negative real numbers, for instance, would make a true \
statement out of it, and it would be safe to give the definition for non\
\[Dash]negative reals."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          
          StyleBox[\(\[ForAll] \+x\((x \[GreaterEqual] 
                    0 \[Implies] \((\@x := \(\( \[SuchThat] \+y\)\((y\^2 = 
                            x)\)\))\))\)\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1\[SuchThat]\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[GreaterEqual]", "0"}], 
                        "\[Implies]", 
                        RowBox[{"(", 
                          RowBox[{
                            SuperscriptBox[
                              RowBox[{"(", 
                                SqrtBox[
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None]], ")"}], "2"], "=", 
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], ")"}]}], ")"}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>", ",", "\<\"\!\(\*
StyleBox[\\\"KBSuchThatExpansion\\\",\\n\\\"HighlightedText\\\"]\)\"\>"}], 
        "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["a1",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a1"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we can infer by expansion of the \"such that\"\[Dash]quantifier"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1\[SuchThat])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", "0"}], "\[Implies]", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", 
                    SqrtBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]], ")"}], "2"], "=", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}]}]], "Assumption"],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1\[SuchThat]"],

Cell[TextData[{
  "There is also a stronger variant of this quantifier, the such\[Dash]a\
\[Dash]unique quantifier denoted by \[SuchThat]!. A definition of a ",
  StyleBox["new",
    FontSlant->"Italic"],
  " function using the \[SuchThat]!\[Dash]quantifier in the form"
}], "SingleParagraph"],

Cell[BoxData[
    \(\(\[ForAll] \+x\)\+\(\[GothicCapitalC]\_x\)f[
          x] := \(\(\[SuchThat]\)\(\[NegativeThickSpace]\)\(!\)\)\+y\ \
\[GothicCapitalP]\_\(x, y\)\)], "NumberedEquation",
  CellTags->"defSTun"],

Cell["is meant to express one of the equivalent properties", "SingleParagraph"],

Cell[BoxData[
    \(\(\[ForAll] \+x\)\+\(\[GothicCapitalC]\_x\)\(\(\[Exists] \
\[NegativeThickSpace]\[NegativeThinSpace]! \)\+y\) \[GothicCapitalP]\_\(x, \
y\)\)], "NumberedEquation",
  CellTags->"charPropSTun1"],

Cell[BoxData[
    RowBox[{\(\(\[ForAll] \
\+x\)\+\(\[GothicCapitalC]\_x\)\[GothicCapitalP]\_\(x, f[x]\)\  \[And] \(\
\[ForAll] \+\(x, y\)\)\+\(\[GothicCapitalC]\_x\)\[GothicCapitalP]\_\(x, y\) \
\[Implies] f[x]\), "=", 
      RowBox[{"y", "   ", 
        RowBox[{"(", 
          RowBox[{"where", " ", "f", " ", "is", " ", 
            StyleBox["a",
              FontSlant->"Plain"], " ", "new", " ", "function", " ", 
            "symbol"}], ")"}]}]}]], "NumberedEquation",
  CellTags->"charPropSTun2"],

Cell[BoxData[
    RowBox[{\(\(\[ForAll] \+\(x, y\)\)\+\(\[GothicCapitalC]\_x\)f[x]\), "=", 
      RowBox[{"y", "\[DoubleLeftRightArrow]", 
        RowBox[{\(\[GothicCapitalP]\_\(x, y\)\), "  ", 
          RowBox[{"(", 
            RowBox[{"where", " ", "f", " ", "is", " ", 
              StyleBox["a",
                FontSlant->"Plain"], " ", "new", " ", "function", " ", 
              "symbol"}], ")"}]}]}]}]], "NumberedEquation",
  CellTags->"charPropSTun3"],

Cell["\<\
Proof (Equivalence of the three characterizations for \[SuchThat]!)\
\
\>", "SingleParagraph",
  FontWeight->"Bold"],

Cell[TextData[{
  "As in the proof for the characterizations we show the implications (",
  
  CounterBox["NumberedEquation", "charPropSTun1"],
  ")\[Implies](",
  
  CounterBox["NumberedEquation", "charPropSTun2"],
  "), (",
  
  CounterBox["NumberedEquation", "charPropSTun2"],
  ")\[Implies](",
  
  CounterBox["NumberedEquation", "charPropSTun3"],
  "), and (",
  
  CounterBox["NumberedEquation", "charPropSTun3"],
  ")\[Implies](",
  
  CounterBox["NumberedEquation", "charPropSTun1"],
  ")."
}], "SingleParagraph"],

Cell[TextData[{
  "(",
  
  CounterBox["NumberedEquation", "charPropSTun1"],
  ")\[Implies](",
  
  CounterBox["NumberedEquation", "charPropSTun2"],
  "): Part 1 of (",
  
  CounterBox["NumberedEquation", "charPropSTun2"],
  ") follows from (",
  
  CounterBox["NumberedEquation", "charPropSTun1"],
  ") again by skolemization. For proving part 2, we assume ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalC]\_\(x\_0\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_\(x\_0, y\_0\)\)]],
  "for arbitrary constants ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0\)]],
  ". From part 1, we know ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_\(x\_0, f[x\_0]\)\)]],
  ", from which we get ",
  Cell[BoxData[
      \(TraditionalForm\`f[x\_0] = y\_0\)]],
  " by the uniqueness property of (",
  
  CounterBox["NumberedEquation", "charPropSTun1"],
  ")."
}], "SingleParagraph"],

Cell[TextData[{
  "(",
  
  CounterBox["NumberedEquation", "charPropSTun2"],
  ")\[Implies](",
  
  CounterBox["NumberedEquation", "charPropSTun3"],
  "): The implication from left to right follows from part 1 of (",
  
  CounterBox["NumberedEquation", "charPropSTun2"],
  ") as in the proof above. The implication from right to left coincides with \
part 2 from (",
  
  CounterBox["NumberedEquation", "charPropSTun2"],
  ")."
}], "SingleParagraph"],

Cell[TextData[{
  "(",
  
  CounterBox["NumberedEquation", "charPropSTun3"],
  ")\[Implies](",
  
  CounterBox["NumberedEquation", "charPropSTun1"],
  "): We only need to proof the part concerning  the uniqueness of (",
  
  CounterBox["NumberedEquation", "charPropSTun1"],
  "). Suppose ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_\(x\_0, y\_0\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_\(x\_0, y\_1\)\)]],
  ", which, by (",
  
  CounterBox["NumberedEquation", "charPropSTun3"],
  ") leads to ",
  Cell[BoxData[
      \(TraditionalForm\`f[x\_0] = y\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f[x\_0] = y\_1\)]],
  ", thus ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0 = y\_1\)]],
  "."
}], "SingleParagraph"],

Cell["\[EmptySquare]", "Text",
  CellMargins->{{Inherited, Inherited}, {Inherited, -6}},
  TextAlignment->Right,
  TextJustification->0],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBSuchThatUniqueExpansion",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[ForAll] \+x \[GothicCapitalC]\_x \[Implies] \
\[GothicCapitalP]\_\(x, f[x]\), \[ForAll] \+\(x, y\)\[GothicCapitalC]\_x \
\[Implies] \((\[GothicCapitalP]\_\(x, y\) \[Implies] \((f[x] = 
                      y)\))\), \[CapitalLambda], \[CapitalDelta]\), 
            "\[RightTee]", "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[ForAll] \+x \[GothicCapitalC]\_x \[Implies] \
\((f[x] := \(\(\[SuchThat]\)\(\[NegativeThickSpace]\)\(!\)\)\+y\ \
\[GothicCapitalP]\_\(x, y\))\), \[CapitalDelta]\), "\[RightTee]", 
            "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBSuchThatUniqueExpansion",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[ForAll] \+x \[GothicCapitalP]\_\(x, f[x]\), \[ForAll] \+\(x, \
y\)\[GothicCapitalP]\_\(x, y\) \[Implies] \((f[x] = 
                    y)\), \[CapitalLambda], \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"},
            {\(\[CapitalLambda], \[ForAll] \+x f[
                    x] := \(\(\[SuchThat]\)\(\[NegativeThickSpace]\)\(!\)\)\+\
y\ \[GothicCapitalP]\_\(x, y\), \[CapitalDelta]\), "\[RightTee]", 
              "\[GothicCapitalG]"}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], 
        "   ", \((special\ case, \ no\ condition)\)}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          
          StyleBox[\(\[ForAll] \+x\((x \[GreaterEqual] 
                    0 \[Implies] \((\@x := \(\(\[SuchThat]\)\(\
\[NegativeThickSpace]\)\(!\)\)\+y\ \((y \[GreaterEqual] 0 \[And] y\^2 = 
                            x)\))\))\)\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[SuchThat].1\"\>", ",", 
                  StyleBox[
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[GreaterEqual]", "0"}], 
                          "\[Implies]", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                RowBox[{
                                  RowBox[{"(", 
                                    SqrtBox[
                                      StyleBox["x",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None]], ")"}], 
                                  "\[GreaterEqual]", "0"}], "\[And]", 
                                SuperscriptBox[
                                  RowBox[{"(", 
                                    SqrtBox[
                                      StyleBox["x",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None]], ")"}], "2"]}], 
                              "=", 
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], ")"}]}], ")"}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"a1\[SuchThat].2\"\>", ",", 
                  StyleBox[
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], ",", 
                          StyleBox["y",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[GreaterEqual]", "0"}], 
                          "\[Implies]", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{
                                    RowBox[{
                                      StyleBox["y",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "\[GreaterEqual]", 
                                      "0"}], "\[And]", 
                                    SuperscriptBox[
                                      StyleBox["y",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "2"]}], "=", 
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None]}], ")"}], "\[Implies]", 
                              
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{"(", 
                                    SqrtBox[
                                      StyleBox["x",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None]], ")"}], "=", 
                                  StyleBox["y",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None]}], ")"}]}], ")"}]}], 
                        ")"}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}]}], 
            "]"}], ",", "\<\"a1\"\>", ",", "\<\"\!\(\*
StyleBox[\\\"KBSuchThatExpansion\\\",\\n\\\"HighlightedText\\\"]\)\"\>"}], 
        "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["a1",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a1"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we can infer by expansion of the \"such that\"\[Dash]quantifier"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1\[SuchThat].1)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", "0"}], "\[Implies]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      SqrtBox[
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]], ")"}], "\[GreaterEqual]", "0"}],
                   "\[And]", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      SqrtBox[
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]], ")"}], "2"]}], "=", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}]}]], "Assumption"],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1\[SuchThat].1"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a1\[SuchThat].2)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["y",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", "0"}], "\[Implies]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{
                        StyleBox["y",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "\[GreaterEqual]", "0"}], 
                      "\[And]", 
                      SuperscriptBox[
                        StyleBox["y",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "2"]}], "=", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "\[Implies]", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      SqrtBox[
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]], ")"}], "=", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}]}], ")"}]}]], 
    "Assumption"],
  Cell[".", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a1\[SuchThat].2"],

Cell[TextData[{
  "Some authors would allow a such\[Dash]a or a similar construct in a \
definition ",
  StyleBox["only",
    FontSlant->"Italic"],
  " when ",
  StyleBox["unique existence",
    FontSlant->"Italic"],
  " is guaranteed, i.e. only ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \+x\(\(\[Exists] \[NegativeThickSpace]\
\[NegativeThinSpace]! \)\+y\) \[GothicCapitalP]\_\(x, y\)\)]],
  " justifies the use of a such\[Dash]a construct in a definition. We have \
already pointed out the correspondence between the \[SuchThat]\[Dash]related \
quantifiers and implicit definitions. Allowing both types of quantifiers \
follows the spirit of allowing ",
  StyleBox["implicit definitions",
    FontSlant->"Italic"],
  " and ",
  StyleBox["implicit unique definitions",
    FontSlant->"Italic"],
  " as described in [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Buch91",
            ButtonData:>"Buch91",
            ButtonStyle->"RefLink",
            ButtonNote->"B. Buchberger, 1991, Logic for Computer Science"],
          "Text"], TraditionalForm]]],
  "]. Of course, using the strong \[SuchThat]!\[Dash]quantifier ",
  StyleBox["without proving unique existence",
    FontSlant->"Italic"],
  " may introduce a contradiction! To be precise, using the quantifier is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " the problem per se, but using then a ",
  StyleBox["prover",
    FontSlant->"Italic"],
  " that applies the inference rules given in this section may cause the \
troubles, since the inference rules add formulae equivalent to the unique \
existence property to the assumptions."
}], "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generalizations and Variants of Notation", "Subsubsection",
  CellTags->"c:21"],

Cell["\<\
All of the rules are generalized in such a way that they apply even \
in cases, where the respective set theoretic formula occurs inside a \
universal quantifier. All those inference rules that silently expand the \
existential quantifier that is introduced by the definition of the respective \
notion in set theory need special care, because the existential quantifier \
must be kept in those cases.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipAbstractionTerm",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[ForAll] \+t\(\[Exists] \+x\((\[GothicCapitalP]\_x \[And] 
                      t = \[GothicCapitalT]\_x)\)\), \[CapitalLambda], \
\[ForAll] \+t 
                t \[Element] {\[GothicCapitalT]\_x\( | \+x\)\[GothicCapitalP]\
\_x}, \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[ForAll] \+t 
                t \[Element] {\[GothicCapitalT]\_x\( | \+x\)\[GothicCapitalP]\
\_x}, \[CapitalDelta]\), "\[RightTee]", "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(\[ForAll] \+a a \[Element] {3  x\( | \+x\)x < 10}\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1'\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["a",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "<", "10"}], "\[And]", 
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox["a",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "=", 
                              RowBox[{"3", "*", 
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}]}], ")"}]}], ")"}]}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipUnaryUnion",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[ForAll] \+t\(\[Exists] \+s\((s \[Element] \[GothicCapitalS] \
\[And] t \[Element] s)\)\), \[CapitalLambda], \[ForAll] \+t 
                t \[Element] \(\[Union]\[GothicCapitalS]\), \[CapitalDelta]\),
             "\[RightTee]", "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[ForAll] \+t 
                t \[Element] \(\[Union]\[GothicCapitalS]\), \[CapitalDelta]\),
             "\[RightTee]", "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[\(\[ForAll] \+a a \[Element] \(\[Union]A\)\),
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1\[Union].\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["a",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["a6",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["a",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[Element]", 
                            StyleBox["a6",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], "\[And]", 
                          RowBox[{
                            StyleBox["a6",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[Element]", "A"}]}], 
                        ")"}]}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]KBMembershipUnionOf",
        FontWeight->"Bold"], ":", GridBox[{
          {\(\[ForAll] \+t\(\[Exists] \+x\((\[GothicCapitalC]\_x \[And] 
                    t \[Element] \[GothicCapitalS]\_x)\)\), \[CapitalLambda], \
\[ForAll] \+t 
                t \[Element] \(\(\[Union]\+x\)\+\(\[GothicCapitalC]\_x\)\
\[GothicCapitalS]\_x\), \[CapitalDelta]\), "\[RightTee]", 
            "\[GothicCapitalG]"},
          {\(\[CapitalLambda], \[ForAll] \+t 
                t \[Element] \(\(\[Union]\+x\)\+\(\[GothicCapitalC]\_x\)\
\[GothicCapitalS]\_x\), \[CapitalDelta]\), "\[RightTee]", 
            "\[GothicCapitalG]"}
          },
        ColumnSpacings->0.4,
        ColumnAlignments->{Right, Center, Left},
        RowLines->True]}]], "InferenceRule"],

Cell["\<\
The resulting quantified expression is simplified immediately, in \
order to cover the case where the condition in the union quantifier is \
missing. \
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[
            RowBox[{\(\[ForAll] \+a\), 
              RowBox[{"a", "\[Element]", 
                RowBox[{
                  UnderscriptBox[
                    UnderscriptBox[
                      StyleBox["\[Union]",
                        "HighlightedText"], 
                      "x"], \(x \[Element] \[DoubleStruckCapitalN]\)], 
                  RowBox[{"{", 
                    RowBox[{"x", ",", 
                      FractionBox[
                        StyleBox["x",
                          "HighlightedText"], "2"]}], "}"}]}]}]}],
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1.\[Union]\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["a",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[Element]", 
                            "\[DoubleStruckCapitalN]"}], "\[And]", 
                          RowBox[{
                            StyleBox["a",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[Element]", 
                            RowBox[{"{", 
                              RowBox[{
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], ",", 
                                FractionBox[
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "2"]}], "}"}]}]}], 
                        ")"}]}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[
            RowBox[{\(\[ForAll] \+a\), 
              RowBox[{"a", "\[Element]", 
                RowBox[{
                  UnderscriptBox[
                    StyleBox["\[Union]",
                      "HighlightedText"], "x"], 
                  RowBox[{"{", 
                    RowBox[{"x", ",", 
                      FractionBox[
                        StyleBox["x",
                          "HighlightedText"], "2"]}], "}"}]}]}]}],
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1.\[Union]\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["a",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox["a",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", 
                          RowBox[{"{", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], ",", 
                              FractionBox[
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "2"]}], "}"}]}], 
                        ")"}]}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["\<\
 All other rules simply apply inside the universal quantifier, for \
example:\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"NewKnowledgeFromOne", "[", 
      RowBox[{"\[Bullet]lf", "[", 
        RowBox[{"\"\<a1\>\"", ",", 
          StyleBox[
            RowBox[{
              UnderscriptBox[
                StyleBox["\[ForAll]",
                  "HighlightedText"], "a"], 
              RowBox[{"a", "\[Element]", 
                RowBox[{
                  UnderscriptBox[
                    StyleBox["\[Intersection]",
                      "HighlightedText"], "x"], 
                  RowBox[{"{", 
                    RowBox[{"x", ",", 
                      FractionBox[
                        StyleBox["x",
                          "HighlightedText"], "2"]}], "}"}]}]}]}],
            "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Bullet]asml", "[", 
            RowBox[{"\[Bullet]lf", "[", 
              RowBox[{"\<\"a1.\[Intersection]\"\>", ",", 
                StyleBox[
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["a",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox["a",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", 
                          RowBox[{"{", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], ",", 
                              FractionBox[
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "2"]}], "}"}]}], 
                        ")"}]}]}],
                  "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
            "]"}], ",", "\<\"a1\"\>"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Negated membership is implemented by separate rules as mentioned above, \
negations of other predicates is not yet covered in the current status of the \
prover. Other variants of set theoretic notation, such as ",
  Cell[BoxData[
      \(TraditionalForm\`a \[ReverseElement] A\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`B \[SupersetEqual] A\)]],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`B \[Superset] A\)]],
  " are converted to regular notation silently. Extended quantifier syntax \
using special ranges and conditions in the such\[Dash]a quantifier and the \
such\[Dash]a\[Dash]unique quantifier may be used in the input, it is \
converted to standard quantifier syntax during ",
  StyleBox["SimplifyQuantifier", "MathematicaInput"],
  ", see also Section ",
  
  CounterBox["Section", "Sec:STPVariants"],
  ".",
  
  CounterBox["Subsection", "Sec:STPVariants"],
  ".",
  
  CounterBox["Subsubsection", "Sec:STPVariants"],
  "."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["STC: The Set Theory Computing Module", "Section",
  CellTags->"Sec:STC"],

Cell[TextData[{
  "In this section, we present the STC module for performing simplifications \
on the proof goal based on computations using set theory semantics provided \
by the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language. "
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell["Semantics for Sets Provided by the Language", "Subsection",
  CellTags->"c:23"],

Cell[TextData[{
  "The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language ",
  "essentially",
  " contains semantics for finite sets, namely"
}], "SingleParagraph"],

Cell["\<\
sets that are constructed using the set braces \"{\" and \"}\" as \
set constructor applied to finitely many arguments, and\
\>", "ItemizedText"],

Cell[TextData[{
  "sets that are constructed using ",
  StyleBox["algorithmic versions",
    FontSlant->"Italic"],
  " of the set quantifier, see also [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Buch96",
            ButtonData:>"Buch96",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "B. Buchberger, 1996, Mathematics: An Introduction to \
Mathematics Integrating the Pure and  ..."],
          "Text"], TraditionalForm]]],
  "], i.e. set quantifiers with finite and computable range specifications, \
see Section ",
  ButtonBox["2.1",
    ButtonData:>{"Part1.nb", "Sec:MathLanguage"},
    ButtonStyle->"Hyperlink"],
  " in Part 1 on the quantifier language. In particular, integer ranges and \
set ranges for finite sets are algorithmic ranges, which lead to finite sets \
when used in combination with the set quantifier."
}], "ItemizedText"],

Cell[TextData[{
  "For finite sets, the language semantics also provides implementations for \
membership, the subset relation, set equality, and set operations such as \
union, intersection, set difference, power set, and cartesian product. We \
give an impression of the type of simplifications that can be done using the \
knowledge built into the language semantics by doing some computations on the \
",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " user level."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[{3, 1, 2}, 
      built\[Dash]in \[Rule] Built\[Dash]in["\<Sets\>"]]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[{3, 1, 2} \[Union] {3, 5}, 
      built\[Dash]in \[Rule] Built\[Dash]in["\<Sets\>"]]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 5}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[{3, 1, 2} \[Intersection] {3, 5}, 
      built\[Dash]in \[Rule] Built\[Dash]in["\<Sets\>"]]\)], "Input"],

Cell[BoxData[
    \({3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[{3, 1, 2}\[Backslash]{3, 5}, 
      built\[Dash]in \[Rule] Built\[Dash]in["\<Sets\>"]]\)], "Input"],

Cell[BoxData[
    \({1, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[{x\( | \+\(x = 1, \[Ellipsis], 10\)\)x < 3}, 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], 
          Built\[Dash]in["\<Quantifiers\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \({1, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[{3  x\( | \+\(x \[Element] {1, 2, 3, 4}\)\)is\[Dash]prime[x]}, 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], 
          Built\[Dash]in["\<Quantifiers\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \({6, 9}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[\[ScriptCapitalP][{x\( | \+\(x = 1, \[Ellipsis], 10\)\)x < 
                3}\[Cross]{3  
                x\( | \+\(x \[Element] {1, 2, 3, 4}\)\)is\[Dash]prime[x]}], 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], 
          Built\[Dash]in["\<Quantifiers\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \({{}, {\[LeftAngleBracket]1, 
          6\[RightAngleBracket]}, {\[LeftAngleBracket]1, 
          9\[RightAngleBracket]}, {\[LeftAngleBracket]2, 
          6\[RightAngleBracket]}, {\[LeftAngleBracket]2, 
          9\[RightAngleBracket]}, {\[LeftAngleBracket]1, 
          6\[RightAngleBracket], \[LeftAngleBracket]1, 
          9\[RightAngleBracket]}, {\[LeftAngleBracket]1, 
          6\[RightAngleBracket], \[LeftAngleBracket]2, 
          6\[RightAngleBracket]}, {\[LeftAngleBracket]1, 
          6\[RightAngleBracket], \[LeftAngleBracket]2, 
          9\[RightAngleBracket]}, {\[LeftAngleBracket]1, 
          9\[RightAngleBracket], \[LeftAngleBracket]2, 
          6\[RightAngleBracket]}, {\[LeftAngleBracket]1, 
          9\[RightAngleBracket], \[LeftAngleBracket]2, 
          9\[RightAngleBracket]}, {\[LeftAngleBracket]2, 
          6\[RightAngleBracket], \[LeftAngleBracket]2, 
          9\[RightAngleBracket]}, {\[LeftAngleBracket]1, 
          6\[RightAngleBracket], \[LeftAngleBracket]1, 
          9\[RightAngleBracket], \[LeftAngleBracket]2, 
          6\[RightAngleBracket]}, {\[LeftAngleBracket]1, 
          6\[RightAngleBracket], \[LeftAngleBracket]1, 
          9\[RightAngleBracket], \[LeftAngleBracket]2, 
          9\[RightAngleBracket]}, {\[LeftAngleBracket]1, 
          6\[RightAngleBracket], \[LeftAngleBracket]2, 
          6\[RightAngleBracket], \[LeftAngleBracket]2, 
          9\[RightAngleBracket]}, {\[LeftAngleBracket]1, 
          9\[RightAngleBracket], \[LeftAngleBracket]2, 
          6\[RightAngleBracket], \[LeftAngleBracket]2, 
          9\[RightAngleBracket]}, {\[LeftAngleBracket]1, 
          6\[RightAngleBracket], \[LeftAngleBracket]1, 
          9\[RightAngleBracket], \[LeftAngleBracket]2, 
          6\[RightAngleBracket], \[LeftAngleBracket]2, 
          9\[RightAngleBracket]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      3*2 \[Element] {3  
              x\( | \+\(x \[Element] {1, 2, 3, 4}\)\)is\[Dash]prime[x]}, 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], 
          Built\[Dash]in["\<Quantifiers\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[{6} \[SubsetEqual] {3  
              x\( | \+\(x \[Element] {1, 2, 3, 4}\)\)is\[Dash]prime[x]}, 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], 
          Built\[Dash]in["\<Quantifiers\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[{6} = {3  x\( | \+\(x \[Element] {1, 2, 3, 4}\)\)is\[Dash]prime[
              x]}, built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\
\<Sets\>"], Built\[Dash]in["\<Numbers\>"], 
          Built\[Dash]in["\<Quantifiers\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[{6, 
          9} = {3  x\( | \+\(x \[Element] {1, 2, 3, 4}\)\)is\[Dash]prime[x]}, 
      built\[Dash]in \[Rule] \[LeftAngleBracket]Built\[Dash]in["\<Sets\>"], 
          Built\[Dash]in["\<Numbers\>"], 
          Built\[Dash]in["\<Quantifiers\>"]\[RightAngleBracket]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Design of the STC Prover", "Subsection",
  CellTags->"c:24"],

Cell[TextData[{
  "It is the intention of the STC prove module to integrate the knowledge \
available for computations seamlessly into the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " proving machinery. Otherwise, all algorithmic knowledge about finite sets \
needed to be re\[Dash]implemented inside the set theory prover, which would \
make it next to impossible to guarantee identical behavior in proving and \
computing. In order to avoid this duplication of code and knowledge, the STC \
prover simplifies the goal by sending the formula to the same evaluation \
function that is also used in the ",
  StyleBox["Compute", "MathematicaInput"],
  " command. Again, the STC prover  hides its global variables in the private \
context of the package, access is provided through the global variable \
handling procedure ",
  StyleBox["SetSTCGlobals", "MathematicaInput"],
  ". As it was already mentioned in Section ",
  
  CounterBox["Section", "Sec:STKBR"],
  " for the STKBR module, the knowledge bases given in the ",
  StyleBox["Prove", "MathematicaInput"],
  " call must be passed further to the global variable handler, since the \
knowledge, with respect to which computations should be performed, must be \
kept in global variables. This has its reason in the current mechanism of the \
proof search, which does not allow the user prover to pass parameters to the \
special provers, hence, the direct communication through parameters must be \
circumvented by a communication through global variables. From the point of \
view of software design, this use of global variables need not be condemned, \
because the global variables are carefully encapsulated in the private \
context of the prover package, which makes them inaccessible from outside the \
package. It is one of the strengths of the Mathematica programming \
environment that it allows data encapsulation within so\[Dash]called ",
  StyleBox["packages",
    FontSlant->"Italic"],
  " so that package related global data need not be global in the entire \
session. The global knowledge bases used for computations are initialized by \
calling ",
  StyleBox["InitSTKnowledgeBase", "MathematicaInput"],
  ", which stores the knowledge bases in three global variables:"
}], "SingleParagraph"],

Cell[TextData[{
  StyleBox["$TmaSTUserDefKnowledgeBase", "MathematicaInput"],
  " is designed to contain the user knowledge base, see Section ",
  ButtonBox["2.3.2",
    ButtonData:>{"Part1.nb", "Sec:Computing"},
    ButtonStyle->"Hyperlink"],
  ". In the current version, however, it is initialized to contain an empty \
knowledge base, instead of the user knowledge base given in the \
using\[Dash]option of Prove, because simplifications based on explicit \
knowledge is the task of the Simplifier prover. It will be task for future \
research to investigate the interplay between computation and simplification \
as done in the Simplifier prover."
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["$TmaSTUserDefHiddenKnowledgeBase", "MathematicaInput"],
  " contains the user hidden knowledge, see Section ",
  ButtonBox["2.3.2",
    ButtonData:>{"Part1.nb", "Sec:Computing"},
    ButtonStyle->"Hyperlink"],
  "."
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["$TmaSTKnowledgeBase", "MathematicaInput"],
  " contains the union of the built\[Dash]in knowledge base as specified by \
the user with the built\[Dash]in knowledge about sets and connectives, i.e. \
even if no built\[Dash]in knowledge is given in the Prove call, it will at \
least contain semantic knowledge about sets and logical connectives. All the \
built\[Dash]in knowledge carries a trace threshold of 95, meaning that in the \
trace of computations, built\[Dash]in knowledge enters only if the global \
trace level is higher than 95."
}], "ItemizedText"],

Cell[TextData[{
  "In addition to these parameters, SetSTCGlobals may receive prover options \
relevant for the STC prover, which are listed in Table ",
  
  CounterBox["Section", "Tab:STCGlobals"],
  ".",
  
  CounterBox["TableHead", "Tab:STCGlobals"],
  "."
}], "SingleParagraph"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(Option\ Name\),
              "ColumnHead"], \(Default\ Value\)},
          {"ApplyBuiltIns", "True"},
          {
            StyleBox["SimplifyFormula",
              "TableText"], "True"}
          }], NullForm]], "Table",
  GridBoxOptions->{RowLines->{0.5, False},
  ColumnLines->0.5},
  CellTags->"Tab:STCGlobals"],

Cell[TextData[{
  "Table ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["TableHead"],
  ". ",
  StyleBox["Options and global variables of the STC prover module", 
    "TableHeadText"]
}], "TableHead"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ApplyBuiltIns\)\)], "Input"],

Cell[BoxData[
    \("Option for STC and STKBR deciding whether built\[Dash]in semantics \
knowledge should be applied for simplifications in the knowledge base."\)], \
"Print",
  CellTags->"Info3197979294-9280556"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?SimplifyFormula\)\)], "Input"],

Cell[BoxData[
    \("Option for STC deciding whether formulae obtained by computation are \
simplified further using Mathematica's FullSimplify function. Be aware, that \
the semantics of using Mathematica's FullSimplify cannot be defined exactly \
because it is not known which simplification rules are implemented inside \
FullSimplify. However, it might be convenient to use FullSimplify, for \
instance, for doing simplification on arithmetic terms."\)], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellTags->"Info3197979311-7956398"]
}, Open  ]],

Cell[TextData[{
  "Basically, when the STC prover applies to a proof situation, i.e. a goal, \
a knowledge base, and the additional facts, one step of the STC prover \
consists of calling the evaluation function ",
  StyleBox["EvaluateFromProve", "MathematicaInput"],
  " with the goal and the assumptions as parameters and, in case the result \
differs from the original form, of adding a node to the proof object, from \
which the effect and the trace of the computation can be displayed. As an \
administrative task, the label of a computed goal is stored in the additional \
facts together with the labels of the current knowledge base, so that, as \
long as neither the goal nor the assumptions change, we are able to avoid \
unnecessary computations."
}], "FirstParagraph"],

Cell[TextData[{
  "The evaluation function EvaluateFromProve now calls the function ",
  StyleBox["EvaluateStandard", "MathematicaInput"],
  " with the global knowledge base variables as described above as \
parameters. EvaluateStandard implements the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " standard evaluation mechanism, used also by Compute. Owing to the fact \
that the mechanism for computation during proving is identical to the \
computation mechanism applied on the user level by Compute, we can guarantee \
consistent behavior of computation on all system levels. Due to reasons \
already explained above, the actual knowledge base of the current proof \
situation does not enter the computation process. Depending on the prover \
option SimplifyFormula, the Mathematica function ",
  ButtonBox["FullSimplify",
    ButtonStyle->"RefGuideLink"],
  " is applied to the result of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "'s semantic simplification. Additional arithmetic knowledge, which can be \
handled by the optional second argument of FullSimplify, is extracted from \
the assumptions and, if present, passed on to FullSimplify. Note, however, \
that one leaves save ground, when letting FullSimplify do parts of a proof, \
because we neither have any control over what simplifications are actually \
applied nor do we even know, which assumptions justify the simplifications \
done in FullSimplify. It is certainly difficult to guarantee, that the \
assumptions in the current proof situation do not contradict an implicit \
assumption from FullSimplify. On the other hand, when doing proofs involving \
formulae containing some arithmetic terms, it is convenient to let ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " do the logic parts of the proof and then pass the \"boring arithmetic\" \
tasks finally to Mathematica. Of course, whether the arithmetic tasks of a \
proof are considered as boring or not depends heavily on the context, in \
which the proof is done. Since ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " is targeted also towards users who definitely consider basic arithmetic \
as the uninteresting part of a proof, we want to offer the possibility to \
employ Mathematica for this. In any case, FullSimplify leaves its trace in \
the trace of the simplification, and the user can the decide whether to trust \
the result or, alternatively, turn off FullSimplify by setting the prover \
option ",
  Cell[BoxData[
      \(TraditionalForm\`SimplifyFormula \[Rule] False\)]],
  ".\nFor displaying computations that happened during a proof, the recent \
development of the so\[Dash]called ",
  StyleBox["computation object",
    FontSlant->"Italic"],
  " is absolutely crucial, see also Section ",
  ButtonBox["2.3.2",
    ButtonData:>{"Part1.nb", "Sec:Computing"},
    ButtonStyle->"Hyperlink"],
  ". The computation object is the counterpart on the computational side of \
what the proof object represents on the proof side, it contains a \
justification, how the result has been obtained from the input. In the first \
versions of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system, the trace of a computation consisted simply of screen output, \
where each computational rule printed one line of notification of its \
application to the screen. In the current version, nothing is printed to the \
screen anymore, but all information is collected in a global data structure \
named $TmaCompObj."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \($TmaCompObject\)], "Input"],

Cell[BoxData[
    RowBox[{"CObj", "[", 
      RowBox[{
        RowBox[{\({6, 9}\), "=", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"3", "*", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], 
              UnderscriptBox["\[VerticalSeparator]", 
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "\[Element]", \({1, 2, 3, 4}\)}]], 
              RowBox[{"IsPrime", "[", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}]}], "}"}]}], ",", "True"}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The granularity of information packed into the computation object depends \
on the trace level globally set in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system at the time of computation. We explained the mechanism in all \
detail in Section ",
  ButtonBox["2.3.2",
    ButtonData:>{"Part1.nb", "Sec:Computing"},
    ButtonStyle->"Hyperlink"],
  StyleBox[". When a computation is performed during a proof, the resulting \
computation object is put into the resulting node of the proof object, so \
that the ProofHeader can display the computation trace when displaying the \
proof step in natural language. We implemented the display of the trace in \
such a manner that it goes into a closed cell in the resulting proof \
notebook, which can be opened on demand by the reader of the proof.",
    Background->None]
}], "FirstParagraph"],

Cell[TextData[{
  "Another interesting aspect of the STC's open design is, that, by giving \
the prover access to the knowledge bases specified by the user in the Prove \
call, its domain of applicability is not by any means limited to \
simplifications using semantics about sets only. Any built\[Dash]in knowledge \
specified in the built\[Dash]in option of Prove is used during the \
computations, e.g. Built\[Dash]in[\"Numbers\"] can be passed in the prover \
options to enable arithmetic simplifications on numbers or \
Built\[Dash]in[\"Quantifiers\"] can be used to enable semantics on \
algorithmic versions of the logical quantifiers. When intending the treatment \
of algorithmic quantifiers by STC, it is important to set the prover option \
",
  Cell[BoxData[
      \(TraditionalForm\`TransformRanges \[Rule] False\)]],
  ", see Section ",
  
  CounterBox["Section", "Sec:UserProver"],
  ", because otherwise an algorithmic range as in ",
  Cell[BoxData[
      \(TraditionalForm\`{3  
            x\( | \+\(x \[Element] {1, 2, 3, 4}\)\)is\[Dash]prime[x]}\)]],
  " will be converted into ",
  Cell[BoxData[
      \(TraditionalForm\`{3  x\( | \+x\)x \[Element] {1, 2, 3, 4} \[And] 
            is\[Dash]prime[x]}\)]],
  ", which is not anymore an algorithmic range, ",
  StyleBox["before",
    FontSlant->"Italic"],
  " any special prover is called. From the generality of its design, the STC \
module is a general interface between proving and computing rather than a \
\"Set Theory Computation\" module, as its name wants to express. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples of Proof Steps with Computation", "Subsection",
  CellTags->"c:25"],

Cell["\<\
For the examples in this section, the global variables for STC have \
been initialized such that Built\[Dash]in[\"Numbers\"] and \
Built\[Dash]in[\"Quantifiers\"] are available for computation in the proof \
step.\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STC", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[
              RowBox[{"a", "\[Element]", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"3", "*", 
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], 
                    UnderscriptBox["\[VerticalSeparator]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], 
                        "\[Element]", \({1, 2, 3, 4}\)}]], 
                    RowBox[{"IsPrime", "[", 
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "]"}]}], "}"}]}],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[]\), 
        ",", \(\[Bullet]lkTab[{{"\<STC\>", \
\[Bullet]lkTab[{{"\<computedFormulae\>", \[Bullet]asml[]}}]}}]\)}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"SetComputation\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal\[MathematicaIcon]\"\>", ",", 
                  StyleBox[\(a \[Element] {6, 9}\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              "]"}], ",", 
            StyleBox[
              RowBox[{"CObj", "[", 
                RowBox[{
                  RowBox[{"a", "\[Element]", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"3", "*", 
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], 
                        UnderscriptBox["\[VerticalSeparator]", 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], 
                            "\[Element]", \({1, 2, 3, 4}\)}]], 
                        RowBox[{"IsPrime", "[", 
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "]"}]}], "}"}]}], 
                  ",", \(a \[Element] {6, 9}\)}], "]"}],
              "HighlightedText"]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            
            RowBox[{"\<\"ProofSituation\"\>", 
              ",", \(\[Bullet]lf["goal\[MathematicaIcon]", 
                a \[Element] {6, 9}, \[Bullet]finfo[]]\), 
              ",", \(\[Bullet]asml[]\), ",", 
              RowBox[{"\[Bullet]lkTab", "[", 
                RowBox[{"{", 
                  RowBox[{"{", 
                    
                    StyleBox[\("STC", \[Bullet]lkTab[{{"computedFormulae", \
\[Bullet]asml[{"goal\[MathematicaIcon]", \[Bullet]asml[]}]}}]\),
                      "HighlightedText"], "}"}], "}"}], "]"}]}], "}"}], "}"}],
         ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output",\

  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "Using available computation rules we evaluate ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ":"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"a", "\[Element]", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"3", "*", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], 
            UnderscriptBox["\[VerticalSeparator]", 
              RowBox[{
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[Element]", \({1, 2, 3, 4}\)}]], 
            RowBox[{"IsPrime", "[", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}]}], "}"}]}]], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " \[RightTriangle]"
}], "ProofText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(a \[Element] {6, 9}\)], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "."
}], "ProofText"],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal\[MathematicaIcon])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] {6, 9}\)], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[0.305882, 0.815686, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal\[MathematicaIcon]"],

Cell["\<\
In a standard proof notebook, the inner two cells are grouped in a \
closed cell group, so that the trace of the computation is by default \
invisible. The proof node generated by STC contains the computation object in \
as well as an entry in the additional facts in which the prover memorizes the \
fact that formula \"goal\[MathematicaIcon]\" has been retrieved by a \
computation w.r.t. the empty knowledge base. Using this information, the \
prover can avoid recomputing the same result in future applications to the \
same goal and identical knowledge base.\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STC", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(\(a - b\)\/2 = a\/2 - b + b\/2\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[]\), 
        ",", \(\[Bullet]lkTab[{{"\<STC\>", \
\[Bullet]lkTab[{{"\<computedFormulae\>", \[Bullet]asml[]}}]}}]\)}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"SetComputation\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal\[MathematicaIcon]\"\>", ",", 
                  StyleBox["True",
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              "]"}], ",", 
            
            StyleBox[\(CObj[\(a - b\)\/2 = \((a\/2 - b)\) + b\/2, 
                1\/2*\((a + \((\(-1\))\)*b)\) = 1\/2*a + \((\(-1\)\/2)\)*b, 
                "FullSimplify", True]\),
              "HighlightedText"]}], "}"}], 
        ",", \({{"ProofSituation", \[Bullet]lf["goal\[MathematicaIcon]", 
              True, \[Bullet]finfo[]], \[Bullet]asml[], \
\[Bullet]lkTab[{{"STC", \[Bullet]lkTab[{{"computedFormulae", \
\[Bullet]asml[{"goal\[MathematicaIcon]", \[Bullet]asml[]}]}}]}}]}}\), 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Using available computation rules we evaluate ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ":"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(a - b\)\/2 = \((a\/2 - b)\) + b\/2\)], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " \[RightTriangle]"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(1\/2*\((a + \((\(-1\))\)*b)\) = 1\/2*a + \(-1\)\/2*b\)], "Expression",
    
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " \[RightTriangle]  (by Mathematica's ",
  StyleBox["FullSimplify",
    FontColor->RGBColor[0.0470588, 0.823529, 1]],
  ")"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(True\)], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "."
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal\[MathematicaIcon])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(True\)], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[0.305882, 0.815686, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal\[MathematicaIcon]"],

Cell[TextData[{
  "In case one does not trust the FullSimplify implementation in Mathematica \
(one could give reasons for this in several cases \[Ellipsis]), one can \
abandon it from proving by setting the prover option ",
  Cell[BoxData[
      \(TraditionalForm\`SimplifyFormula \[Rule] False\)]],
  "."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STC", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[\(\(a - b\)\/2 = a\/2 - b + b\/2\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[]\), 
        ",", \(\[Bullet]lkTab[{{"\<STC\>", \
\[Bullet]lkTab[{{"\<computedFormulae\>", \[Bullet]asml[]}}]}}]\)}], 
      "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"SetComputation\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal\[MathematicaIcon]\"\>", ",", 
                  
                  StyleBox[\(1\/2*\((a + \((\(-1\))\)*b)\) = 
                      1\/2*a + \((\(-1\)\/2)\)*b\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              "]"}], ",", 
            
            StyleBox[\(CObj[\(a - b\)\/2 = \((a\/2 - b)\) + b\/2, 
                1\/2*\((a + \((\(-1\))\)*b)\) = 1\/2*a + \((\(-1\)\/2)\)*b]\),
              
              "HighlightedText"]}], "}"}], 
        ",", \({{"ProofSituation", \[Bullet]lf["goal\[MathematicaIcon]", 
              1\/2*\((a + \((\(-1\))\)*b)\) = 
                1\/2*a + \((\(-1\)\/2)\)*
                    b, \[Bullet]finfo[]], \[Bullet]asml[], \
\[Bullet]lkTab[{{"STC", \[Bullet]lkTab[{{"computedFormulae", \
\[Bullet]asml[{"goal\[MathematicaIcon]", \[Bullet]asml[]}]}}]}}]}}\), 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Using available computation rules we evaluate ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ":"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(a - b\)\/2 = \((a\/2 - b)\) + b\/2\)], "Expression",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " \[RightTriangle]"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(1\/2*\((a + \((\(-1\))\)*b)\) = 1\/2*a + \(-1\)\/2*b\)], "Expression",
    
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "."
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal\[MathematicaIcon])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(1\/2*\((a + \((\(-1\))\)*b)\) = 1\/2*a + \(-1\)\/2*b\)], "Conclusion",
    
    CellBracketOptions->{"Color"->RGBColor[0.305882, 0.815686, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal\[MathematicaIcon]"],

Cell[TextData[{
  "In this setting, STC is restricted to simplification rules implemented in \
the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language semantics, in the example it applies symbolic computation on the \
terms on the left\[Dash]hand and the right\[Dash]hand side of the equality. \
Without Mathematica's simplification, however, the computation does not \
continue. For the example above, a solution not depending on Mathematica's \
FullSimplify would be to setup computation rules in such a fashion that they \
result in canonical forms. Rather, for basic arithmetic such as + and *, we \
again use Mathematica's built\[Dash]in arithmetic. Unfortunately, the \
Mathematica term evaluator does not produce canonical forms. It will be topic \
for future investigations whether to switch to an evaluation mechanism that \
guarantees a canonical form."
}], "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["STS: The Set Theory Solving Module", "Section",
  CellTags->"Sec:STS"],

Cell["\<\
The STS module collects inference rules for existentially \
quantified goals. When structuring proofs into phases of proving (\"P\"), \
computing (\"C\"), and solving (\"S\") according to the PCS paradigm it is \
near at hand to structure also provers according to the same scheme. We \
followed this principle in the Set Theory prover by grouping the inference \
rules for different prove phases in different prover modules, from which, \
finally, the SetTheoryPCSProver is composed. \"Solving\" typically refers to \
proof situations, where concrete values have to be found to be substituted \
for variables such that certain properties are fulfilled. Proof situation of \
that kind are usually characterized by an existential quantifier as the \
outermost symbol, and the STS module contains appropriate rules for handling \
proof situations of that flavor. \
\>", "FirstParagraph"],

Cell["\<\
Unlike the other provers discussed so far, the STS prover's \
behavior does not depend on global variables adjustable by the user, thus, no \
prover options relevant for STS need to be handled. Still there are some \
global entities that influence the STS inference rules, they are used mainly \
for administrative purposes:\
\>", "Text"],

Cell[TextData[{
  StyleBox["unsolvableGoals", "MathematicaInput"],
  ": an entry in the ",
  StyleBox["local proof context",
    FontSlant->"Italic"],
  ", in which existential goals are stored, for which an attempt to solve \
them has already failed, so that repeated failures can be avoided. This entry \
in the additional facts is used to decide on applicability of the STS prover \
as a whole."
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["instantiations", "MathematicaInput"],
  ": an entry in the ",
  StyleBox["local proof context",
    FontSlant->"Italic"],
  ", in which instantiations of particular formulae are stored. It avoids \
repeated identical instantiations of an existential goal, when a certain \
instantiation has already proved unsuccessful in a previous solution attempt. \
Some book\[Dash]keeping effort pays off in this case, because in some cases, \
instantiation is done by unification, which can be rather expensive. This \
entry in the additional facts is used to decide on applicability of certain \
inference rules in certain proof situations."
}], "ItemizedText"],

Cell[TextData[{
  StyleBox["$TmaProofPhase", "MathematicaInput"],
  ": a global variable containing an indication of the current proof phase. \
The default value is \"P\" for the proving phase, a value of \"S\" stands for \
 the solving phase. This variable is used",
  " in the user prover",
  " to decide on applicability of ",
  StyleBox["other special provers",
    FontSlant->"Italic"],
  ", because some rules in the STS prover only reduce one solve situation to \
another solve situation, which can be indicated by turning $TmaProofPhase to \
\"S\", and other provers apply only when $TmaProofPhase is different from \"S\
\"."
}], "ItemizedText"],

Cell[TextData[{
  "Methods used for instantiating existential goals range from ",
  StyleBox["matching",
    FontSlant->"Italic"],
  " against formulae in the knowledge base, over ",
  StyleBox["unification",
    FontSlant->"Italic"],
  " and introduction of ",
  StyleBox["solve constants",
    FontSlant->"Italic"],
  " (what we call solve constants is sometimes in the literature referred to \
as ",
  StyleBox["meta variable",
    FontSlant->"Italic"],
  ") until employing the Mathematica Solve function to obtain solutions of \
equational goals."
}], "Text"],

Cell[CellGroupData[{

Cell["STS Inference Rules", "Subsection",
  CellTags->"c:27"],

Cell["\<\
For reasons of completeness, we mention two rules that could \
equally well be rules of the STP prover, namely rules for expanding the set \
quantifier inside an existential quantifier. We grouped them together with \
the rules of STS because of the outermost existential quantifier in the goal \
formula. An argument for placing them in the STP prover would be that they do \
not eliminate the existential quantifier.\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STS", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[
              RowBox[{\(\[Exists] \+a\), 
                RowBox[{"a", "\[Element]", 
                  RowBox[{"{", 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], 
                      StyleBox[\( \[VerticalSeparator] \+x\),
                        "HighlightedText"], 
                      RowBox[{
                        StyleBox["IsPrime",
                          "HighlightedText"], 
                        StyleBox["[",
                          "HighlightedText"], 
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], 
                        StyleBox["]",
                          "HighlightedText"]}]}], "}"}]}]}],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"MembershipAbstraction\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  RowBox[{
                    UnderscriptBox["\[Exists]", 
                      RowBox[{
                        StyleBox["a",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"IsPrime", "[", 
                      StyleBox["a",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "]"}]}], 
                  ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  RowBox[{
                    StyleBox[
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["a",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]],
                      "HighlightedText"], 
                    RowBox[{
                      StyleBox["IsPrime",
                        "HighlightedText"], 
                      StyleBox["[",
                        "HighlightedText"], 
                      StyleBox["a",
                        "HighlightedText",
                        FontSlant->"Italic",
                        Background->None], 
                      StyleBox["]",
                        "HighlightedText"]}]}], ",", \(\[Bullet]finfo[]\)}], 
                "]"}], ",", \(\[Bullet]asml[]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In order to prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we have to show:"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"IsPrime", "[", 
          StyleBox["a",
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "]"}]}]], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STS", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[
              RowBox[{\(\[Exists] \+a\), 
                RowBox[{"t", "\[Element]", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        RowBox[{
                          StyleBox["3",
                            "HighlightedText"], 
                          StyleBox["*",
                            "HighlightedText"], 
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], 
                        StyleBox["+",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], 
                        StyleBox["a",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], 
                      StyleBox[\( \[VerticalSeparator] \+x\),
                        "HighlightedText"], 
                      RowBox[{
                        StyleBox["IsPrime",
                          "HighlightedText"], 
                        StyleBox["[",
                          "HighlightedText"], 
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], 
                        StyleBox["]",
                          "HighlightedText"]}]}], "}"}]}]}],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"MembershipAbstractionTerm\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  RowBox[{
                    UnderscriptBox["\[Exists]", 
                      RowBox[{
                        StyleBox["a",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"IsPrime", "[", 
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "]"}], "\[And]", 
                          RowBox[{"(", 
                            RowBox[{"t", "=", 
                              RowBox[{
                                RowBox[{"3", "*", 
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None]}], "+", 
                                StyleBox["a",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}]}], ")"}]}], ")"}]}]}], 
                  ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal'\"\>", ",", 
                  StyleBox[
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["a",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{
                        UnderscriptBox["\[Exists]", 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], " "}]], 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{"IsPrime", "[", 
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "]"}], "\[And]", 
                            RowBox[{"(", 
                              RowBox[{"t", "=", 
                                RowBox[{
                                  RowBox[{"3", "*", 
                                    StyleBox["x",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}], "+", 
                                  StyleBox["a",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None]}]}], ")"}]}], ")"}]}]}],
                    
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In order to prove ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we have to show"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal')", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"IsPrime", "[", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "\[And]", 
              RowBox[{"(", 
                RowBox[{"t", "=", 
                  RowBox[{
                    RowBox[{"3", "*", 
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox["a",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}]}]}]], 
    "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal'"],

Cell[TextData[{
  "Now we will come to those inference rules that really ",
  StyleBox["eliminate an existential quantifier",
    FontSlant->"Italic"],
  "."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]IntroSolveConstant",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicCapitalQ]\_\(y \[Rule] \(y\^*\)\) \
\[And] \[Exists] \+x\((\[GothicCapitalP]\_x \[And] \(y\^*\) = \
\[GothicCapitalT]\_x)\) \[And] \[GothicCapitalR]\_\(y \[Rule] \(y\^*\)\)\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[Exists] \+y\((\[GothicCapitalQ]\_y \[And] 
                    y \[Element] {\[GothicCapitalT]\_x\( | \+x\)\
\[GothicCapitalP]\_x} \[And] \[GothicCapitalR]\_y)\)\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", 
        RowBox[{"(", 
          RowBox[{
          "where", " ", \(\[GothicCapitalQ]\_y\), " ", "and", 
            " ", \(\[GothicCapitalR]\_y\), " ", "are", " ", "possibly", " ", 
            "empty", " ", "conjunctions", " ", "of", " ", "formulae", " ", 
            "and", " ", \(y\^*\), " ", "is", " ", 
            StyleBox["a",
              FontSlant->"Plain"], " ", "solve", " ", "constant"}], 
          ")"}]}]}]], "InferenceRule"],

Cell[TextData[{
  "A ",
  StyleBox["solve constant",
    FontSlant->"Italic"],
  " is some constant, which we still have to assign a concrete value. Solve \
constants are introduced in order to eliminate existential quantifiers by \
substituting a constant for the quantified variable, where at the moment of \
introducing the constant, its concrete value can not yet be determined. For \
the proof to succeed, ",
  StyleBox["all solve constants",
    FontSlant->"Italic"],
  " that have been introduced must be eliminated by substituting appropriate \
ground terms in such a manner that the resulting formula can be proven. \
Substitution is usually done for variables only, and the fact that solve \
constants finally need to be ",
  StyleBox["instantiated",
    FontSlant->"Italic"],
  " makes them somewhat similar to variables. Due to this, what we call solve \
constant is often addressed as ",
  StyleBox["meta variable",
    FontSlant->"Italic"],
  " by other authors. The technique of meta variables is well known and used \
also in other systems and it imitates what is done mostly in human analysis \
proofs on boundedness, limits, and continuity. Unfortunately, even within the \
",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " group there is no coherent treatment of this issue, see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Konev99a",
            ButtonData:>"Konev99a",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "B. Konev, 1999, Metavariable Method for Natural Deduction \
Within Theorema"],
          "Text"], TraditionalForm]]],
  "], [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["JeKo00a",
            ButtonData:>"JeKo00a",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "T. Jebelean and B. Konev, 2000, Using Meta-variables for \
Natural Deduction in Theorema"],
          "Text"], TraditionalForm]]],
  "], [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["JeKo00b",
            ButtonData:>"JeKo00b",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "B. Konev and T. Jebelean, 2000, Combining Level-Saturation \
Strategies and Meta-Variables f ..."],
          "Text"], TraditionalForm]]],
  "], and [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Vasa00PhD",
            ButtonData:>"Vasa00PhD",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "D. Vasaru-Dupr\[EGrave], 2000, Automated Theorem Proving by \
Integrating Proving, Solving and Compu ..."],
          "Text"], TraditionalForm]]],
  "], which even led to the fact that internally the representation of a \
\"solve constant\" ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\^*\)\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Bullet]meta[y, n]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is used to distinguish between multiple constants that may be \
introduced."
}], "FirstParagraph"],

Cell[TextData[{
  "At first glance, it might not be obvious at all what one might benefit \
from introducing solve constants, because still the values for the constants \
need to be found. The point  is just that the instantiation is ",
  StyleBox["delayed",
    FontSlant->"Italic"],
  " to a later stage of the proof, and, in the meantime, the existential \
quantifier is eliminated so that different inference rules might apply in \
order to modify the proof goal containing the solve constants. Of course, the \
strategy after introducing solve constants must always be to isolate the \
solve constants, which is typically done by ",
  StyleBox["solving",
    FontSlant->"Italic"],
  ", using methods depending on the nature of the remaining formula. In case \
inequalities over the reals are involved, it is tried to identify \
subformulae, from which solve constants can be isolated using Collins' CAD \
method, see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Coll75",
            ButtonData:>"Coll75",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "G. E. Collins, 1975, Quantifier Elimination for Real Closed \
Fields by Cylindrical Algebrai ..."],
          "Text"], TraditionalForm]]],
  "]. This approach is implemented in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " PCS prover for proofs in elementary analysis, see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Vasa00PhD",
            ButtonData:>"Vasa00PhD",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "D. Vasaru-Dupr\[EGrave], 2000, Automated Theorem Proving by \
Integrating Proving, Solving and Compu ..."],
          "Text"], TraditionalForm]]],
  "]. In case algebraic equations are involved, it might be useful to apply \
known solving techniques for algebraic equations. If no special structure can \
be recognized, the solve constants may still be instantiated by matching or, \
in a more general setting, by unification. Applying this strategy reduces \
proving to solving over various domains, and it offers the possibility to \
benefit from the great advances that have been accomplished in developing \
powerful solution methods in computer algebra.\nThe proof situation, for \
which the above inference rule is applicable, might appear random, but it is \
exactly the pattern of a proof situation that is left after expanding \
membership in a union, i.e. every proof situation of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[GothicT]", "\[Element]", 
          RowBox[{
            StyleBox["\[Union]",
              
              SpanMaxSize->
                2], \({\[GothicCapitalT]\_x\( | \
\+x\)\[GothicCapitalP]\_x}\)}]}], TraditionalForm]]],
  " leads to a proof situation that can be processed by introducing a solve \
constant, namely ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Exists] \+y a \[Element] y\), 
          StyleBox["\[And]",
            
            SpanMaxSize->
              1.5], \(y \[Element] {\[GothicCapitalT]\_x\( | \+x\)\
\[GothicCapitalP]\_x}\)}], TraditionalForm]]],
  ". This is the motivation to consider the above rule as a \"solve rule\" \
for set theory.\nAfter introducing the solve constant, the inference rule \
sets $TmaProofPhase to \"S\" as an indication for the prover to stay in \
\"solve mode\" in order to isolate the solve constants. The remaining rules \
of STS maintain $TmaProofPhase in such a way that the prover remains in solve \
mode until no more solve constants appear in the proof goal. For the \
following examples, we refer to the notion of equivalence class, which we \
have already introduced in earlier sections when presenting the capabilities \
for defining new notions, doing computations, and the interplay between \
proving and computing."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STS", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[
              RowBox[{
                UnderscriptBox["\[Exists]", 
                  RowBox[{
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], " "}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"a", "\[Element]", 
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "\[And]", 
                    RowBox[{
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[Element]", 
                      RowBox[{"{", 
                        RowBox[{
                          RowBox[{\(class\_\(A, R\)\), "[", 
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "]"}], 
                          UnderscriptBox["\[VerticalSeparator]", 
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], " "}]], 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[Element]", "A"}]}], 
                        "}"}]}]}], ")"}]}],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"IntroSolveConstant\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal*\"\>", ",", 
                  RowBox[{\(a \[Element] y\^"*"\), "\[And]", 
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[Element]", "A"}], 
                          "\[And]", 
                          RowBox[{"(", 
                            RowBox[{\(y\^"*"\), "=", 
                              RowBox[{\(class\_\(A, R\)\), "[", 
                                StyleBox["x",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "]"}]}], ")"}]}], 
                        ")"}]}]}], ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}], 
            ",", \(y\^"*"\)}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal*\"\>", ",", 
                  StyleBox[
                    RowBox[{\(a \[Element] y\^"*"\), "\[And]", 
                      RowBox[{
                        UnderscriptBox["\[Exists]", 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], " "}]], 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["x",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "\[Element]", "A"}], 
                            "\[And]", 
                            RowBox[{"(", 
                              RowBox[{\(y\^"*"\), "=", 
                                RowBox[{\(class\_\(A, R\)\), "[", 
                                  StyleBox["x",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "]"}]}], ")"}]}], 
                          ")"}]}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In order to solve ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we have to find ",
  Cell[BoxData[
      \(TraditionalForm\`y\^"*"\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " such that"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal*)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{\(a \[Element] y\^"*"\), "\[And]", 
        RowBox[{
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[Element]", "A"}], "\[And]", 
              RowBox[{"(", 
                RowBox[{\(y\^"*"\), "=", 
                  RowBox[{\(class\_\(A, R\)\), "[", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}]}], ")"}]}], ")"}]}]}]], 
    "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal*"],

Cell["\<\
As already motivated above, we must now provide some rules to \
isolate solve constants in order to succeed with the proof.\
\>", \
"SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]SolveConstant",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicCapitalQ]\_\(\(y\^*\) \[Rule] \
\[GothicCapitalT]\_\(x \[Rule] a\)\) \[And] \[GothicCapitalP]\_\(x \[Rule] \
a\) \[And] \[GothicCapitalR]\_\(\(y\^*\) \[Rule] \[GothicCapitalT]\_\(x \
\[Rule] a\)\)\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicCapitalQ]\_\(y\^*\) \[And] \[Exists] \
\+x\((\[GothicCapitalP]\_x \[And] \(y\^*\) = \[GothicCapitalT]\_x)\) \[And] \
\[GothicCapitalR]\_\(y\^*\)\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", 
        RowBox[{"(", 
          
          RowBox[{\(where\ \[GothicCapitalQ]\_\(y\^*\)\ and\ \
\[GothicCapitalR]\_\(y\^*\)\ are\ possibly\ empty\ conjunctions\ of\ formulae\
\), ",", " ", 
            RowBox[{\(y\^*\), " ", "is", " ", 
              StyleBox["a",
                FontSlant->"Plain"], " ", "solve", " ", "constant"}], 
            ",", \(and\ a\ is\ some\ constant\)}], ")"}]}]}]], "InferenceRule"],

Cell[TextData[{
  "We try to find an appropriate constant ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " by matching subformulae in the goal ",
  StyleBox["not containing",
    FontSlant->"Italic"],
  " solve constants against ground formulae in the assumptions ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalKappa]\)]],
  ". If an instantiation of the existential variable ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is possible by ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", then the solve constant can immediately be assigned from the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\^*\) = \[GothicCapitalT]\_x\)]],
  ". In the remaining formulae, we substitute the solve constant ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\^*\)\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalT]\_\(x \[Rule] a\)\)]],
  " (we use the notation for variable substitutions also for substitution of \
solve constants since, having in mind what has just been said on the notion \
of solve constants, this should not lead to any confusions). We try to find \
all possible instantiations for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " in one stroke, if more than one instantiation is possible, we initiate a \
split into alternative proof branches."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STS", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal*\>\"", ",", 
            StyleBox[
              RowBox[{\(a \[Element] \[Bullet]meta[y, 0]\), "\[And]", 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], " "}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "\[Element]", "A"}], "\[And]", 
                      RowBox[{"(", 
                        RowBox[{\(\[Bullet]meta[y, 0]\), "=", 
                          RowBox[{\(class\_\(A, R\)\), "[", 
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "]"}]}], ")"}]}], ")"}]}]}],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
        RowBox[{"\[Bullet]asml", "[", 
          RowBox[{"\[Bullet]lf", "[", 
            RowBox[{"\"\<ab\>\"", ",", 
              StyleBox[\(b \[Element] A \[Or] a \[Element] A\),
                "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}],
         ",", \(\[Bullet]lkTab[{{"\<PND\>", \[Bullet]lkTab[{{"\<MatchingFacts\
\>", \[Bullet]lkTab[{}]}}]}}]\)}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"\!\(\*
StyleBox[\\\"OrNode\\\",\\n\\\"HighlightedText\\\"]\)\"\>", 
        ",", \({"MatchExistGoal", \[Bullet]usedFormulae["goal*", "ab", 
            "ab"], \[Bullet]generatedFormulae[]}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"\<\"AndNode\"\>", ",", 
                RowBox[{"{", 
                  
                  RowBox[{"\<\"SolveConstant\"\>", 
                    ",", \(\[Bullet]usedFormulae["goal*", "ab"]\), 
                    ",", \(\[Bullet]generatedFormulae[\[Bullet]lf[
                        "goal**(1)", 
                        b \[Element] A \[And] 
                          a \[Element] 
                            class\_\(A, R\)[b], \[Bullet]finfo[]]]\), ",", 
                    StyleBox[
                      RowBox[{"{", 
                        RowBox[{
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[RuleDelayed]", "b"}], 
                          ",", \(y\^"*" \[Rule] class\_\(A, R\)[b]\)}], "}"}],
                      
                      "HighlightedText"]}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"{", 
                    RowBox[{"\<\"ProofSituation\"\>", ",", 
                      
                      StyleBox[\(\[Bullet]lf["goal**(1)", 
                          b \[Element] A \[And] 
                            a \[Element] 
                              class\_\(A, R\)[b], \[Bullet]finfo[]]\),
                        "HighlightedText"], 
                      ",", \(\[Bullet]asml[\[Bullet]lf["ab", 
                          b \[Element] A \[Or] 
                            a \[Element] A, \[Bullet]finfo[]]]\), 
                      ",", \(\[Bullet]lkTab[{{"PND", \
\[Bullet]lkTab[{{"MatchingFacts", \[Bullet]lkTab[{}]}}]}}]\)}], "}"}], "}"}], 
                ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}], 
            ",", 
            RowBox[{"{", 
              RowBox[{"\<\"AndNode\"\>", ",", 
                RowBox[{"{", 
                  
                  RowBox[{"\<\"SolveConstant\"\>", 
                    ",", \(\[Bullet]usedFormulae["goal*", "ab"]\), 
                    ",", \(\[Bullet]generatedFormulae[\[Bullet]lf[
                        "goal**(2)", 
                        a \[Element] A \[And] 
                          a \[Element] 
                            class\_\(A, R\)[a], \[Bullet]finfo[]]]\), ",", 
                    StyleBox[
                      RowBox[{"{", 
                        RowBox[{
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[RuleDelayed]", "a"}], 
                          ",", \(y\^"*" \[Rule] class\_\(A, R\)[a]\)}], "}"}],
                      
                      "HighlightedText"]}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"{", 
                    RowBox[{"\<\"ProofSituation\"\>", ",", 
                      
                      StyleBox[\(\[Bullet]lf["goal**(2)", 
                          a \[Element] A \[And] 
                            a \[Element] 
                              class\_\(A, R\)[a], \[Bullet]finfo[]]\),
                        "HighlightedText"], 
                      ",", \(\[Bullet]asml[\[Bullet]lf["ab", 
                          b \[Element] A \[Or] 
                            a \[Element] A, \[Bullet]finfo[]]]\), 
                      ",", \(\[Bullet]lkTab[{{"PND", \
\[Bullet]lkTab[{{"MatchingFacts", \[Bullet]lkTab[{}]}}]}}]\)}], "}"}], "}"}], 
                ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]}], 
          "}"}], ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], 
      "}"}]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["\<\
The or\[Dash]node represents the following alternatives, which will \
be tried in sequence:\
\>", "SingleParagraph"],

Cell[TextData[{
  "Since ",
  StyleBox["(", "Label"],
  ButtonBox["ab",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "ab"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " matches a part of ",
  StyleBox["(", "Label"],
  ButtonBox["goal*",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal*"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we try to instantiate, i.e. let know ",
  Cell[BoxData[
      \(TraditionalForm\`x := b\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "."
}], "ProofText"],

Cell[TextData[{
  "Thus, by ",
  StyleBox["(", "Label"],
  ButtonBox["goal*",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal*"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ", we choose ",
  Cell[BoxData[
      \(TraditionalForm\`y\^"*" := class\_\(A, R\)[b]\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "."
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Now, it suffices to show", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal**(1))", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(b \[Element] A \[And] a \[Element] class\_\(A, R\)[b]\)], 
    "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal**(1)"],

Cell["\<\
If the attempt to prove formula \"goal**(1)\" does not succeed, the \
proof search will continue as follows:\
\>", "SingleParagraph"],

Cell[TextData[{
  "Since ",
  StyleBox["(", "Label"],
  ButtonBox["ab",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "ab"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " matches a part of ",
  StyleBox["(", "Label"],
  ButtonBox["goal*",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal*"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we try to instantiate, i.e. let know ",
  Cell[BoxData[
      \(TraditionalForm\`x := a\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "."
}], "ProofText"],

Cell[TextData[{
  "Thus, by ",
  StyleBox["(", "Label"],
  ButtonBox["goal*",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal*"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ", we choose ",
  Cell[BoxData[
      \(TraditionalForm\`y\^"*" := class\_\(A, R\)[a]\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "."
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Now, it suffices to show", "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal**(2))", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] A \[And] a \[Element] class\_\(A, R\)[a]\)], 
    "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal**(2)"],

Cell[TextData[{
  "The following rule is a specialization of the previous one. It appears, \
when expanding membership in unions of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[GothicT]", "\[Element]", 
          RowBox[{
            StyleBox["\[Union]",
              SpanMaxSize->2], \({\(\[GothicCapitalT]\_x\)\( | \+x\)}\)}]}], 
        TraditionalForm]]],
  "."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]SolveConstant",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[Exists] \+x\((\[GothicCapitalQ]\_\(\(y\^*\) \
\[Rule] \[GothicCapitalT]\_x\) \[And] \[GothicCapitalR]\_\(\(y\^*\) \[Rule] \
\[GothicCapitalT]\_x\))\)\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicCapitalQ]\_\(y\^*\) \[And] \[Exists] \
\+x\( y\^*\) = \[GothicCapitalT]\_x \[And] \[GothicCapitalR]\_\(y\^*\)\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", 
        RowBox[{"(", 
          
          RowBox[{\(where\ \[GothicCapitalQ]\_\(y\^*\)\ and\ \
\[GothicCapitalR]\_\(y\^*\)\ are\ possibly\ empty\ conjunctions\ of\ formulae\
\), ",", " ", 
            RowBox[{\(y\^*\), " ", "is", " ", 
              StyleBox["a",
                FontSlant->"Plain"], " ", "solve", " ", "constant"}]}], 
          ")"}]}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STS", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal*\>\"", ",", 
            StyleBox[
              RowBox[{\(a \[Element] \[Bullet]meta[y, 0]\), "\[And]", 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], " "}]], 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(\[Bullet]meta[y, 0]\),
                        "HighlightedText"], 
                      StyleBox["=",
                        "HighlightedText"], 
                      RowBox[{
                        StyleBox[\(class\_\(A, R\)\),
                          "HighlightedText"], 
                        StyleBox["[",
                          "HighlightedText"], 
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], 
                        StyleBox["]",
                          "HighlightedText"]}]}], ")"}]}]}],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[a]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"SolveConstant\"\>", 
            ",", \(\[Bullet]usedFormulae["goal*"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal**\"\>", ",", 
                  RowBox[{
                    UnderscriptBox["\[Exists]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{"a", "\[Element]", 
                        RowBox[{\(class\_\(A, R\)\), "[", 
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "]"}]}], ")"}]}], 
                  ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}], ",", 
            RowBox[{
              StyleBox[\(y\^"*"\),
                "HighlightedText"], 
              StyleBox["\[Rule]",
                "HighlightedText"], 
              RowBox[{
                StyleBox[\(class\_\(A, R\)\),
                  "HighlightedText"], 
                StyleBox["[",
                  "HighlightedText"], 
                StyleBox["x",
                  "HighlightedText",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox["]",
                  "HighlightedText"]}]}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal**\"\>", ",", 
                  StyleBox[
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{"a", "\[Element]", 
                          RowBox[{\(class\_\(A, R\)\), "[", 
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "]"}]}], ")"}]}],
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[a]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Let know ",
  Cell[BoxData[
      \(TraditionalForm\`y\^"*" := class\_\(A, R\)[x]\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "."
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Thus, for proving ",
  StyleBox["(", "Label"],
  ButtonBox["goal*",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal*"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " it remains to show"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal**)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{"a", "\[Element]", 
            RowBox[{\(class\_\(A, R\)\), "[", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}]}], ")"}]}]], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal**"],

Cell["\<\
In some odd situations, the existential quantifier vanishes due to \
cancellation of the quantified variables, still leaving some solve constants \
around. In fact, these situations are particularly easy to handle for the \
case where the formula originates again from expanding membership in a union, \
because then the solve constants appear again in a form, where an assignment \
can easily be read off.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]SolveConstant",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicCapitalQ]\_\(\(y\^*\) \[Rule] \
\[GothicCapitalT]\) \[And] \[GothicCapitalR]\_\(\(y\^*\) \[Rule] \
\[GothicCapitalT]\)\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[GothicCapitalQ]\_\(y\^*\) \[And] \(y\^*\) = \
\[GothicCapitalT] \[And] \[GothicCapitalR]\_\(y\^*\)\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", 
        RowBox[{"(", 
          
          RowBox[{\(where\ \[GothicCapitalQ]\_\(y\^*\)\ and\ \
\[GothicCapitalR]\_\(y\^*\)\ are\ possibly\ empty\ conjunctions\ of\ formulae\
\), ",", " ", 
            RowBox[{\(y\^*\), " ", "is", " ", 
              StyleBox["a",
                FontSlant->"Plain"], " ", "solve", " ", "constant"}]}], 
          ")"}]}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STS", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal*\>\"", ",", 
            
            StyleBox[\(a \[Element] \[Bullet]meta[y, 
                    0] \[And] \((\[Bullet]meta[y, 0] = 
                    class\_\(A, R\)[t])\)\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[a]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"SolveConstant\"\>", 
            ",", \(\[Bullet]usedFormulae["goal*"]\), 
            ",", \(\[Bullet]generatedFormulae[\[Bullet]lf["goal**", 
                a \[Element] class\_\(A, R\)[t], \[Bullet]finfo[]]]\), ",", 
            StyleBox[\({y\^"*" \[Rule] class\_\(A, R\)[t]}\),
              "HighlightedText"]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal**\"\>", ",", 
                  StyleBox[\(a \[Element] class\_\(A, R\)[t]\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[a]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Let know ",
  Cell[BoxData[
      \(TraditionalForm\`y\^"*" := class\_\(A, R\)[t]\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  "."
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Thus, for proving ",
  StyleBox["(", "Label"],
  ButtonBox["goal*",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal*"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " it remains to show"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal**)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] class\_\(A, R\)[t]\)], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal**"],

Cell[TextData[{
  "The remaining two rules in STS try to solve an existential goal ",
  StyleBox["directly",
    FontSlant->"Italic"],
  ", i.e. without introducing solve constants. A first attempt is to try ",
  StyleBox["unification",
    FontSlant->"Italic"],
  " of parts of the goal with universally quantified formulae from the \
assumptions. "
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]PartiallySolved",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[CapitalLambda], \[ForAll] \+x \[GothicCapitalP]\_x, \
\[CapitalDelta]\), "\[RightTee]", \(\[GothicCapitalR]\_u\)},
            {\(\[CapitalLambda], \[ForAll] \+x \[GothicCapitalP]\_x, \
\[CapitalDelta]\), 
              "\[RightTee]", \(\[Exists] \+z\((\[GothicCapitalQ]\_z \[And] \
\[GothicCapitalR]\_z)\)\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", 
        RowBox[{"(", 
          RowBox[{"if", " ", "u", " ", "is", " ", 
            StyleBox["a",
              FontSlant->"Plain"], " ", "unifier", " ", "for", 
            " ", \(\[GothicCapitalP]\_x\), " ", "and", 
            " ", \(\[GothicCapitalQ]\_z\), " ", "and", 
            " ", \(\[GothicCapitalR]\_u\), " ", "is", " ", "free", " ", "of", 
            " ", "x"}], ")"}]}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STS", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            
            StyleBox[\(\[Exists] \+y\((y \[Element] A \[And] 
                    a \[Element] class\_\(A, R\)[y])\)\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
        RowBox[{"\[Bullet]asml", "[", 
          RowBox[{"\[Bullet]lf", "[", 
            RowBox[{"\"\<a\>\"", ",", 
              StyleBox[\(\[ForAll] \+x x \[Element] class\_\(A, R\)[x]\),
                "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}],
         ",", \(\[Bullet]lkTab[{{"\<STS\>", \
\[Bullet]lkTab[{{"\<instantiations\>", {}}}]}}]\)}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"PartiallySolved\"\>", 
            ",", \(\[Bullet]usedFormulae["goal", "a"]\), 
            ",", \(\[Bullet]generatedFormulae[\[Bullet]lf["a\[Dagger]", 
                a \[Element] 
                  class\_\(A, R\)[a], \[Bullet]finfo[]], \[Bullet]lf["goal*", 
                a \[Element] A, \[Bullet]finfo[]]]\), ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[Rule]", "a"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              
              StyleBox[\(\[Bullet]lf["goal*", 
                  a \[Element] A, \[Bullet]finfo[]]\),
                "HighlightedText"], ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"a\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Element]", 
                          RowBox[{\(class\_\(A, R\)\), "[", 
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "]"}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}], ",", 
              RowBox[{"\[Bullet]lkTab", "[", 
                RowBox[{"{", 
                  RowBox[{"{", 
                    RowBox[{"\<\"STS\"\>", ",", 
                      RowBox[{"\[Bullet]lkTab", "[", 
                        RowBox[{"{", 
                          StyleBox[
                            RowBox[{"{", 
                              RowBox[{"\<\"instantiations\"\>", ",", 
                                RowBox[{"{", 
                                  RowBox[{"{", 
                                    RowBox[{"\<\"goal\"\>", ",", 
                                      RowBox[{"a", "\[Element]", 
                                        RowBox[{\(class\_\(A, R\)\), "[", 
                                        StyleBox["y",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "]"}]}], 
                                      ",", "\<\"a\"\>", ",", 
                                      RowBox[{"{", 
                                        RowBox[{
                                        StyleBox["y",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "\[Rule]", "a"}], 
                                        "}"}]}], "}"}], "}"}]}], "}"}],
                            "HighlightedText"], "}"}], "]"}]}], "}"}], "}"}], 
                "]"}]}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
        ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["a",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we know in particular"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(a\[Dagger])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] class\_\(A, R\)[a]\)], "Assumption",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[",", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"a\[Dagger]"],

Cell[TextData[{
  "which is an instance of a subformula in ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ". Thus, we choose ",
  Cell[BoxData[
      \(TraditionalForm\`y := a\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  ". For proving ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " it now suffices to show "
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal*)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(a \[Element] A\)], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal*"],

Cell[TextData[{
  "For efficiency reasons, we store the fact that formula \"goal\" has been \
instantiated using its subformula ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "\[Element]", 
          RowBox[{\(class\_\(A, R\)\), "[", 
            StyleBox["y",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "]"}]}], TraditionalForm]]],
  " and assumption \"a\" by the substitution ",
  Cell[BoxData[
      \(TraditionalForm\`{y \[Rule] a}\)]],
  ". In future proof situations, we apply this rule only if another \
assumption from the knowledge base is used ",
  StyleBox["and",
    FontSlant->"Italic"],
  " a different substitution results from unification. This method can be \
enhanced to check for unifiability even in more complicated constellations of \
goal and assumptions."
}], "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]PartiallySolved",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {\(\[CapitalLambda], \[ForAll] \+x \[GothicCapitalP]\_x, \
\[CapitalDelta]\), "\[RightTee]", \(\[Exists] \+x \[GothicCapitalR]\_u\)},
            {\(\[CapitalLambda], \[ForAll] \+x \[GothicCapitalP]\_x, \
\[CapitalDelta]\), 
              "\[RightTee]", \(\[Exists] \+z\((\[GothicCapitalQ]\_z \[And] \
\[GothicCapitalR]\_z)\)\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", 
        RowBox[{"(", 
          RowBox[{"if", " ", "u", " ", "is", " ", 
            StyleBox["a",
              FontSlant->"Plain"], " ", "unifier", " ", "for", 
            " ", \(\[GothicCapitalP]\_x\), " ", "and", 
            " ", \(\[GothicCapitalQ]\_z\), " ", "and", 
            " ", \(\[GothicCapitalR]\_u\), " ", "is", " ", "not", " ", "free",
             " ", "of", " ", "x"}], ")"}]}]}]], "InferenceRule"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STS", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            
            StyleBox[\(\[Exists] \+y\((y \[Element] A \[And] 
                    a \[Element] y)\)\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
        RowBox[{"\[Bullet]asml", "[", 
          RowBox[{"\[Bullet]lf", "[", 
            RowBox[{"\"\<a\>\"", ",", 
              StyleBox[\(\[ForAll] \+x f[x] \[Element] A\),
                "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}],
         ",", \(\[Bullet]lkTab[{{"\<STS\>", \
\[Bullet]lkTab[{{"\<instantiations\>", {}}}]}}]\)}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"PartiallySolved\"\>", 
            ",", \(\[Bullet]usedFormulae["goal", "a"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal*\"\>", ",", 
                  RowBox[{
                    UnderscriptBox["\[Exists]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"(", 
                      RowBox[{"a", "\[Element]", 
                        RowBox[{"f", "[", 
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "]"}]}], ")"}]}], 
                  ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}], ",", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[Rule]", 
                RowBox[{"f", "[", 
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "]"}]}], "}"}], ",", 
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              StyleBox[
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"goal*\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[Exists]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{"a", "\[Element]", 
                          RowBox[{"f", "[", 
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "]"}]}], ")"}]}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}],
                "HighlightedText"], ",", 
              RowBox[{"\[Bullet]asml", "[", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\<\"a\"\>", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"f", "[", 
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "]"}], "\[Element]", "A"}], 
                        ")"}]}], ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}], 
              ",", 
              RowBox[{"\[Bullet]lkTab", "[", 
                RowBox[{"{", 
                  RowBox[{"{", 
                    RowBox[{"\<\"STS\"\>", ",", 
                      RowBox[{"\[Bullet]lkTab", "[", 
                        RowBox[{"{", 
                          StyleBox[
                            RowBox[{"{", 
                              RowBox[{"\<\"instantiations\"\>", ",", 
                                RowBox[{"{", 
                                  RowBox[{"{", 
                                    RowBox[{"\<\"goal\"\>", ",", 
                                      RowBox[{
                                        StyleBox["y",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "\[Element]", 
                                        "A"}], ",", "\<\"a\"\>", ",", 
                                      RowBox[{"{", 
                                        RowBox[{
                                        StyleBox["y",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "\[Rule]", 
                                        RowBox[{"f", "[", 
                                        StyleBox["x",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "]"}]}], "}"}]}], 
                                    "}"}], "}"}]}], "}"}],
                            "HighlightedText"], "}"}], "]"}]}], "}"}], "}"}], 
                "]"}]}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
        ",", "\<\"pending\"\>"}], "}"}]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "Formula ",
  StyleBox["(", "Label"],
  ButtonBox["a",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "a"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " indicates to choose ",
  Cell[BoxData[
      \(TraditionalForm\`y := f[x]\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " (for some still to be determined ",
  Cell[BoxData[
      \(TraditionalForm\`x\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  ") for the existential variable in ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ". For proving ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " it now remains to show "
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal*)", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{"a", "\[Element]", 
            RowBox[{"f", "[", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}]}], ")"}]}]], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal*"],

Cell["\<\
 Finally, in some cases we can try to solve an existential goal by \
known solving techniques from computer algebra.\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]PartiallySolved",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {"\[CapitalKappa]", "\[RightTee]", \(\[GothicCapitalP]\_s\)},
            {"\[CapitalKappa]", 
              "\[RightTee]", \(\[Exists] \+\(x\+_\)\((\[GothicCapitalE]\_x\+_ \
\[And] \[GothicCapitalP]\_x\+_)\)\)}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Right, Center, Left},
          RowLines->True], "   ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
            "where", " ", \(\[GothicCapitalE]\_x\+_\), " ", "is", " ", 
              StyleBox["a",
                FontSlant->"Plain"], " ", "conjunction", " ", "of", " ", 
              "equations"}], ",", 
            RowBox[{"s", " ", 
              StyleBox["a",
                FontSlant->"Plain"], " ", "solution", " ", "of", 
              " ", \(\[GothicCapitalE]\_x\+_\)}]}], 
          ")"}]}]}]], "InferenceRule"],

Cell[TextData[{
  "We use the built\[Dash]in Solve function from Mathematica to obtain the \
solutions for ",
  Cell[BoxData[
      \(TraditionalForm\`x\+_\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalE]\_x\+_\)]],
  ". Similar to the situation when using FullSimplify during computations, a \
user might decide not to trust what Mathematica's Solve function returns as a \
solution. In this case, this inference rule ought to be deactivated. On the \
other hand, since one might often agree with the implicit assumptions taken \
by Solve, it is convenient to use this function, in particular, when dealing \
with algebraic equations. In the current implementation, we analyze the \
structure of ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalE]\_x\+_\)]],
  " and then decide, whether it is appropriate to call Mathematica's Solve \
function (we consider Solve as \"appropriate\" when ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalE]\_x\+_\)]],
  " is a conjunction of arithmetic expressions). For future versions, we can \
employ at this stage our own solvers or solvers available for special \
application domains developed by others. "
}], "FirstParagraph"],

Cell[TextData[{
  "Again, the proof situation, for which the rule applies might appear \
random, but, in fact, it is exactly the type of proof situation that is left \
after expanding membership in a set abstraction of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicT] \[Element] {\[GothicCapitalT]\_x\( | \
\+x\)\[GothicCapitalQ]\_x}\)]],
  ". Tuple equations, as they appear when proving membership in a cartesian \
product, are translated, by tuple equality, into a conjunction of single \
equations for the individual components. When translating a formula into the \
syntax that is expected by the Solve function, we use semantic knowledge \
stored in the STC prover's global variable $TmaSTKnowledgeBase for \
translating operators occurring in the formula, i.e. appropriate \
built\[Dash]in knowledge (e.g. Built\[Dash]in[\"Numbers\"]) must be specified \
in the Prove call in order to translate \"+\", \"*\", and \"^\" into the \
respective Mathematica built\[Dash]in operators. For future versions, we will \
provide a separate knowledge base for STS in order to make the provers \
independent of each other."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STS", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            StyleBox[
              RowBox[{
                UnderscriptBox["\[Exists]", 
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Plain",
                      Background->None], " "}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Plain",
                        Background->None], 
                      StyleBox["<",
                        "HighlightedText"], 
                      StyleBox["10",
                        "HighlightedText"]}], 
                    StyleBox["\[And]",
                      "HighlightedText"], 
                    StyleBox[
                      RowBox[{"(", 
                        RowBox[{"a", "=", 
                          RowBox[{"3", "*", 
                            StyleBox["x",
                              FontWeight->"Plain",
                              Background->None]}]}], ")"}],
                      "HighlightedText"]}], ")"}]}],
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"PartiallySolved\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), 
            ",", \(\[Bullet]generatedFormulae[\[Bullet]lf["goal*(1)", 
                1\/3*a < 10, \[Bullet]finfo[]]]\), ",", 
            StyleBox[
              RowBox[{"{", 
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "\[Rule]", \(1\/3*a\)}], "}"}],
              "HighlightedText"]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"\<\"ProofSituation\"\>", ",", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"goal*(1)\"\>", ",", 
                  StyleBox[\(1\/3*a < 10\),
                    "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
              ",", \(\[Bullet]asml[]\), ",", "af"}], "}"}], "}"}], 
        ",", \({}\), ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`x := a\/3\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " solves the equational part of ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " it suffices to show "
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal*(1))", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(1\/3*a < 10\)], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal*(1)"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STS", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            
            StyleBox[\(\[Exists] \+\(\(x\)\(\ \)\)\((x < 
                      0 \[And] \((10  a = 
                        3*x\^3 + 3  a\ x\^2 - x\^2 - a\ x - 10  x)\))\)\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"\!\(\*
StyleBox[\\\"OrNode\\\",\\n\\\"HighlightedText\\\"]\)\"\>", 
        ",", \({"TrySeveralSolutions", \[Bullet]usedFormulae[
            "goal"], \[Bullet]generatedFormulae["goal*(1)", "goal*(2)", 
            "goal*(3)"]}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"\<\"AndNode\"\>", ",", 
                RowBox[{"{", 
                  
                  RowBox[{"\<\"PartiallySolved\"\>", 
                    ",", \(\[Bullet]usedFormulae["goal"]\), 
                    ",", \(\[Bullet]generatedFormulae[\[Bullet]lf[
                        "goal*(1)", \((\(-5\)\/3)\) < 0, \[Bullet]finfo[]]]\),
                     ",", 
                    StyleBox[
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Rule]", \(\(-5\)\/3\)}], 
                        "}"}],
                      "HighlightedText"]}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"{", 
                    RowBox[{"\<\"ProofSituation\"\>", ",", 
                      
                      StyleBox[\(\[Bullet]lf[
                          "goal*(1)", \((\(-5\)\/3)\) < 
                            0, \[Bullet]finfo[]]\),
                        "HighlightedText"], ",", \(\[Bullet]asml[]\), ",", 
                      "af"}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
                ",", "\<\"pending\"\>"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"\<\"AndNode\"\>", ",", 
                RowBox[{"{", 
                  
                  RowBox[{"\<\"PartiallySolved\"\>", 
                    ",", \(\[Bullet]usedFormulae["goal"]\), 
                    ",", \(\[Bullet]generatedFormulae[\[Bullet]lf["goal*(2)", 
                        2 < 0, \[Bullet]finfo[]]]\), ",", 
                    StyleBox[
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[Rule]", "2"}], "}"}],
                      "HighlightedText"]}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"{", 
                    RowBox[{"\<\"ProofSituation\"\>", ",", 
                      
                      StyleBox[\(\[Bullet]lf["goal*(2)", 
                          2 < 0, \[Bullet]finfo[]]\),
                        "HighlightedText"], ",", \(\[Bullet]asml[]\), ",", 
                      "af"}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
                ",", "\<\"pending\"\>"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"\<\"AndNode\"\>", ",", 
                RowBox[{"{", 
                  
                  RowBox[{"\<\"PartiallySolved\"\>", 
                    ",", \(\[Bullet]usedFormulae["goal"]\), 
                    ",", \(\[Bullet]generatedFormulae[\[Bullet]lf[
                        "goal*(3)", \((\(-1\))\)*a < 0, \[Bullet]finfo[]]]\), 
                    ",", 
                    StyleBox[
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], 
                          "\[Rule]", \(\((\(-1\))\)*a\)}], "}"}],
                      "HighlightedText"]}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"{", 
                    RowBox[{"\<\"ProofSituation\"\>", ",", 
                      
                      StyleBox[\(\[Bullet]lf[
                          "goal*(3)", \((\(-1\))\)*a < 0, \[Bullet]finfo[]]\),
                        
                        "HighlightedText"], ",", \(\[Bullet]asml[]\), ",", 
                      "af"}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
                ",", "\<\"pending\"\>"}], "}"}]}], "}"}], ",", \({}\), 
        ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The or\[Dash]node represents the following alternatives:\
\>", \
"SingleParagraph"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`x := \(-5\)\/3\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " solves the equational part of ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " it suffices to show "
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal*(1))", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\(-5\)\/3 < 0\)], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal*(1)"],

Cell["\<\
If the attempt to prove formula \"goal*(1)\" fails, the proof \
search will continue as follows:\
\>", "SingleParagraph"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`x := 2\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " solves the equational part of ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " it suffices to show "
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal*(2))", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(2 < 0\)], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal*(2)"],

Cell["\<\
If also the attempt to prove formula \"goal*(2)\" fails, the proof \
search will continue with:\
\>", "SingleParagraph"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`x := \(-a\)\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " solves the equational part of ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " it suffices to show "
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal*(3))", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\((\(-1\))\)*a < 0\)], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal*(3)"],

Cell["\<\
In the next example, we solve a tuple equation with additional \
restrictions, where the individual components of the tuple are \
multi\[Dash]variate non\[Dash]linear polynomials, hence, in the background a \
Gr\[ODoubleDot]bner bases computation eliminates the existential \
quantifier.\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"STS", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            
            StyleBox[\(\[Exists] \+\(x, y\)\((x > 0 \[And] 
                    y > 0 \[And] \((\[LeftAngleBracket]x\^2 + y\^2, 
                          x\[RightAngleBracket] = \[LeftAngleBracket]1, 
                          y\[RightAngleBracket])\))\)\),
              "HighlightedText"], ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"OrNode\"\>", ",", 
        RowBox[{"{", 
          RowBox[{"\<\"\!\(\*
StyleBox[\\\"TrySeveralSolutions\\\",\\n\\\"HighlightedText\\\"]\)\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), 
            ",", \(\[Bullet]generatedFormulae["goal*(1)", "goal*(2)"]\)}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"\<\"AndNode\"\>", ",", 
                RowBox[{"{", 
                  
                  RowBox[{"\<\"PartiallySolved\"\>", 
                    ",", \(\[Bullet]usedFormulae["goal"]\), 
                    ",", \(\[Bullet]generatedFormulae[\[Bullet]lf[
                        "goal*(1)", \((\(-1\))\)*2\^\(\(-1\)\/2\) > 
                            0 \[And] \((\(-1\))\)*2\^\(\(-1\)\/2\) > 
                            0, \[Bullet]finfo[]]]\), ",", 
                    StyleBox[
                      RowBox[{"{", 
                        RowBox[{
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], 
                            "\[Rule]", \(\((\(-1\))\)*2\^\(\(-1\)\/2\)\)}], 
                          ",", 
                          RowBox[{
                            StyleBox["y",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], 
                            "\[Rule]", \(\((\(-1\))\)*2\^\(\(-1\)\/2\)\)}]}], 
                        "}"}],
                      "HighlightedText"]}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"{", 
                    RowBox[{"\<\"ProofSituation\"\>", ",", 
                      
                      StyleBox[\(\[Bullet]lf[
                          "goal*(1)", \((\(-1\))\)*2\^\(\(-1\)\/2\) > 
                              0 \[And] \((\(-1\))\)*2\^\(\(-1\)\/2\) > 
                              0, \[Bullet]finfo[]]\),
                        "HighlightedText"], ",", \(\[Bullet]asml[]\), ",", 
                      "af"}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
                ",", "\<\"pending\"\>"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"\<\"AndNode\"\>", ",", 
                RowBox[{"{", 
                  
                  RowBox[{"\<\"PartiallySolved\"\>", 
                    ",", \(\[Bullet]usedFormulae["goal"]\), 
                    ",", \(\[Bullet]generatedFormulae[\[Bullet]lf["goal*(2)", 
                        2\^\(\(-1\)\/2\) > 0 \[And] 
                          2\^\(\(-1\)\/2\) > 0, \[Bullet]finfo[]]]\), ",", 
                    StyleBox[
                      RowBox[{"{", 
                        RowBox[{
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], 
                            "\[Rule]", \(2\^\(\(-1\)\/2\)\)}], ",", 
                          RowBox[{
                            StyleBox["y",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], 
                            "\[Rule]", \(2\^\(\(-1\)\/2\)\)}]}], "}"}],
                      "HighlightedText"]}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"{", 
                    RowBox[{"\<\"ProofSituation\"\>", ",", 
                      
                      StyleBox[\(\[Bullet]lf["goal*(2)", 
                          2\^\(\(-1\)\/2\) > 0 \[And] 
                            2\^\(\(-1\)\/2\) > 0, \[Bullet]finfo[]]\),
                        "HighlightedText"], ",", \(\[Bullet]asml[]\), ",", 
                      "af"}], "}"}], "}"}], ",", \({}\), ",", \({}\), 
                ",", "\<\"pending\"\>"}], "}"}]}], "}"}], ",", \({}\), 
        ",", \({}\), ",", "\<\"pending\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell["Branch 1:", "SingleParagraph"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`x := \(-1\)\/2\^\(1\/2\)\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y := \(-1\)\/2\^\(1\/2\)\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " solves the equational part of ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " it suffices to show "
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal*(1))", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\((\(-1\))\)*2\^\(\(-1\)\/2\) > 
          0 \[And] \((\(-1\))\)*2\^\(\(-1\)\/2\) > 0\)], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal*(1)"],

Cell["Branch 2:", "SingleParagraph"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`x := 2\^\(\(-1\)\/2\)\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y := 2\^\(\(-1\)\/2\)\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " solves the equational part of ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " it suffices to show "
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(goal*(2))", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(2\^\(\(-1\)\/2\) > 0 \[And] 2\^\(\(-1\)\/2\) > 0\)], "Conclusion",
    CellBracketOptions->{"Color"->RGBColor[1, 0.647059, 0]}],
  Cell[".", "ProofText"]
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"goal*(2)"],

Cell["\<\
Omitting the additional restrictions, the equation can be solved \
completely.\
\>", "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(STS[\[Bullet]lf["\<goal\>", \[Exists] \+\(x, y\)\((\[LeftAngleBracket]x\
\^2 + y\^2, x\[RightAngleBracket] = \[LeftAngleBracket]1, 
                y\[RightAngleBracket])\), \[Bullet]finfo[]], \[Bullet]asml[], 
      af]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          RowBox[{"\<\"\!\(\*
StyleBox[\\\"CompletelySolved\\\",\\n\\\"HighlightedText\\\"]\)\"\>", 
            ",", \(\[Bullet]usedFormulae["goal"]\), 
            ",", \(\[Bullet]generatedFormulae[]\), ",", 
            StyleBox[
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], 
                    "\[Rule]", \(\((\(-1\))\)*2\^\(\(-1\)\/2\)\)}], ",", 
                  RowBox[{
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], 
                    "\[Rule]", \(\((\(-1\))\)*2\^\(\(-1\)\/2\)\)}]}], "}"}],
              "HighlightedText"]}], "}"}], ",", \({}\), ",", \({}\), 
        ",", \({}\), ",", "\<\"\!\(\*
StyleBox[\\\"proved\\\",\\n\\\"HighlightedText\\\"]\)\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`x := \(-1\)\/2\^\(1\/2\)\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y := \(-1\)\/2\^\(1\/2\)\)],
    CellBracketOptions->{"Color"->RGBColor[0.705882, 0.054902, 0.611765]}],
  " solves the equational part of ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we are done."
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Modifications in the Existing PCS Components", "Section",
  CellTags->"c:28"],

Cell[CellGroupData[{

Cell["TerminalND", "Subsection",
  CellTags->"Sec:TerminalND"],

Cell[TextData[{
  "TerminalND is a new special prover, which consists exactly of all terminal\
\[Dash]proved inference rules of the predicate logic prover, i.e. those \
inference rules that detect terminal\[Dash]proved proof situations. It \
contains at the one hand a strict subset of the BasicND prover (Basic Natural \
Deduction prover) developed by Daniela Vasaru for the PCS prover, which was \
in turn derived from ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "'s standard PND prover (Predicate Logic by Natural Deduction prover) \
developed by Tudor Jebelean. It is enriched by just one inference rule for \
detecting, by unification, that an existential goal can be instantiated by an \
appropriate instance of a universally quantified assumption. The simplest \
example for the necessity of this rule is when it is to prove ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Exists] \+z\), 
          RowBox[{"P", "[", 
            RowBox[{"z", ",", 
              StyleBox["t",
                FontSlant->"Plain"]}], 
            StyleBox["]",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "  for some arbitrary constant ",
  Cell[BoxData[
      FormBox[
        StyleBox["t",
          FontSlant->"Plain"], TraditionalForm]]],
  ", and among the assumptions there is ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \+x P[x, x]\)]],
  ". The trivial check, as it exists as an inference rule from PND, whether \
the goal is an instance of the universal assumption, fails, but a human would \
immediately \"see\" that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"P", "[", 
          StyleBox[\(t, t\),
            FontSlant->"Plain"], 
          StyleBox["]",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " is the appropriate instance, by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", "\[Rule]", 
          StyleBox["t",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ", of the universal assumption, from which the existential goal can be \
instantiated with ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "\[Rule]", 
          StyleBox["t",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ", as symbolized in Figure ",
  
  CounterBox["Section", "Fig:CommonInstance1"],
  ".",
  
  CounterBox["Figure", "Fig:CommonInstance1"],
  ". "
}], "SingleParagraph"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{\(\[ForAll] \+x\), 
              RowBox[{"P", "[", 
                StyleBox[\(x, x\),
                  GridBoxOptions->{ColumnAlignments->{Left}}], 
                StyleBox["]",
                  GridBoxOptions->{ColumnAlignments->{Left}}]}], 
              StyleBox["      ",
                FontSlant->"Plain"]}], "  ", 
            RowBox[{"       ", 
              RowBox[{\(\[Exists] \+z\), 
                RowBox[{"P", "[", 
                  RowBox[{"z", ",", 
                    StyleBox["t",
                      FontSlant->"Plain"]}], 
                  StyleBox["]",
                    FontSlant->"Plain"]}]}]}]},
          {GridBox[{
                {
                  RowBox[{" ", 
                    SubscriptBox["", 
                      RowBox[{"x", "\[Rule]", 
                        StyleBox["t",
                          FontSlant->"Plain"]}]]}], 
                  StyleBox["\[LowerRightArrow]",
                    FontSize->24]}
                },
              ColumnSpacings->-0.5], " ", 
            StyleBox[GridBox[{
                  {
                    StyleBox["\[LowerLeftArrow]",
                      FontSize->24], 
                    RowBox[{" ", 
                      SubscriptBox["", 
                        RowBox[{"z", "\[Rule]", 
                          StyleBox["t",
                            FontSlant->"Plain"]}]]}]}
                  },
                ColumnSpacings->-0.6],
              GridBoxOptions->{ColumnAlignments->{Left}}]},
          {" ", 
            RowBox[{"P", "[", 
              StyleBox[\(t, t\),
                FontSlant->"Plain"], 
              StyleBox["]",
                FontSlant->"Plain"]}], " "}
          },
        RowSpacings->0.1,
        ColumnSpacings->0,
        ColumnAlignments->{Right, Center, Left}], 
      TraditionalForm]], "DisplayFormula",
  CounterIncrements->"Figure"],

Cell[TextData[{
  "Figure ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Figure"],
  ". ",
  StyleBox["Detecting an instance of ", "TableHeadText"],
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(\[Exists] \+z\),
            "TableHead"], 
          RowBox[{
            StyleBox["P",
              "TableHead"], 
            StyleBox["[",
              "TableHead"], 
            RowBox[{
              StyleBox["z",
                "TableHead"], 
              StyleBox[",",
                "TableHead"], 
              StyleBox["t",
                "TableHead",
                FontSlant->"Plain"]}], 
            StyleBox["]",
              "TableHead",
              FontSlant->"Plain"]}]}], TraditionalForm]], "TableHeadText"], 
    "TableHeadText"],
  StyleBox[" from ", "TableHeadText"],
  StyleBox[Cell[BoxData[
      FormBox[
        StyleBox[\(\[ForAll] \+x P[x, x]\),
          "TableHead"], TraditionalForm]], "TableHeadText"], 
    "TableHeadText"],
  StyleBox[".", "TableHeadText"]
}], "TableHead",
  CellTags->"Fig:CommonInstance1"],

Cell[TextData[{
  "An algorithmic approach to detecting the instance ",
  Cell[BoxData[
      FormBox[
        RowBox[{"P", "[", 
          StyleBox[\(t, t\),
            FontSlant->"Plain"], 
          StyleBox["]",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " in the above example is to try to find again a ",
  StyleBox["common instance",
    FontSlant->"Italic"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`P[x, x]\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"P", "[", 
          RowBox[{"z", ",", 
            StyleBox["t",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " by unification using ",
  StyleBox["CommonInstance", "MathematicaInput"],
  " from Section ",
  
  CounterBox["Section", "Sec:Terminology"],
  "."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CommonInstance[P[\[Bullet]var[x], \[Bullet]var[x]], 
      P[\[Bullet]var[z], t]]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(P[t, t]\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              StyleBox["z",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Rule]", "t"}], ",", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Rule]", "t"}]}], "}"}]}], 
      "}"}]], "Output"]
}, Open  ]],

Cell["\<\
In general, this rule can be formulated even for universal formulae \
with more than one quantified variable. In our notation for inference rules, \
this is written as\
\>", "SingleParagraph"],

Cell[BoxData[
    RowBox[{
      StyleBox["\[Cent]InstanceOfUniversal",
        FontWeight->"Bold"], ":", 
      RowBox[{GridBox[{
            {"proved"},
            {
              RowBox[{
                RowBox[{
                  UnderscriptBox["\[ForAll]", 
                    StyleBox[\(x\+_\),
                      SpanMaxSize->0]], \(\[GothicCapitalP]\_x\+_\)}], 
                "\[RightTee]", 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    StyleBox[\(z\+_\),
                      SpanMaxSize->0.5]], \(\[GothicCapitalQ]\_z\+_\)}]}]}
            },
          ColumnSpacings->0.4,
          ColumnAlignments->{Center},
          RowLines->True], "  ", 
        RowBox[{"(", 
          RowBox[{
          "if", " ", \(\[GothicCapitalP]\_r\+_\), " ", "and", 
            " ", \(\[GothicCapitalQ]\_z\+_\), " ", "are", " ", "unifiable", 
            " ", "by", " ", "u", " ", "and", " ", \(\[GothicCapitalP]\_x\+_\),
             "\[NegativeThickSpace]", 
            
            OverscriptBox[\(\(\[LowerRightArrow]\)\(\[NegativeThickSpace]\
\[NegativeThickSpace]\)\(\[LowerLeftArrow]\)\), 
              AdjustmentBox["u",
                BoxMargins->{{0.3, -0.3}, {-1, 1}},
                BoxBaselineShift->1]], \(\[GothicCapitalQ]\_z\+_\), " ", "is",
             " ", "free", " ", "of", " ", \(z\+_\)}], 
          ")"}]}]}]], "InferenceRule"],

Cell["Proof (Correctness of \[Cent]InstanceOfUniversal)", "SingleParagraph",
  FontWeight->"Bold"],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " be a unifier for ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_x\+_\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalQ]\_z\+_\)]],
  " and let ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[GothicCapitalU]", "=", 
          RowBox[{\(\[GothicCapitalP]\_x\+_\), "\[NegativeThickSpace]", 
            
            OverscriptBox[\(\(\[LowerRightArrow]\)\(\[NegativeThickSpace]\
\[NegativeThickSpace]\)\(\[LowerLeftArrow]\)\), 
              AdjustmentBox["u",
                BoxMargins->{{0.3, -0.3}, {-1, 1}},
                BoxBaselineShift->1]], \(\[GothicCapitalQ]\_z\+_\)}]}], 
        TraditionalForm]]],
  ". From the assumptions we know that ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP]\_u\ \((\(=\)\(\[GothicCapitalU]\))\
\)\)]],
  " is free of ",
  Cell[BoxData[
      \(TraditionalForm\`z\+_\)]],
  ", but it may still contain some of the variables ",
  Cell[BoxData[
      \(TraditionalForm\`x\+_\)]],
  ", say ",
  Cell[BoxData[
      \(TraditionalForm\`v\+_\)]],
  ".\nCase 1 (",
  Cell[BoxData[
      \(TraditionalForm\`v\+_\)]],
  " is empty): In this case, we can infer ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalU]\)]],
  " from ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            StyleBox[\(x\+_\),
              SpanMaxSize->0]], \(\[GothicCapitalP]\_x\+_\)}], 
        TraditionalForm]]],
  " by \[ForAll] elimination. Since ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalU] = \[GothicCapitalQ]\_u\)]],
  " is free of ",
  Cell[BoxData[
      \(TraditionalForm\`z\+_\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalQ]\_u\)]],
  " is obtained from ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalQ]\_z\+_\)]],
  " by substituting all free occurrences of ",
  Cell[BoxData[
      \(TraditionalForm\`z\+_\)]],
  ", we can conclude ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[Exists]", 
            StyleBox[\(z\+_\),
              SpanMaxSize->0.5]], \(\[GothicCapitalQ]\_z\+_\)}], 
        TraditionalForm]]],
  " by \[Exists] introduction.\nCase 2 (",
  Cell[BoxData[
      \(TraditionalForm\`v\+_\)]],
  " is not empty): In this case, we can infer from ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            StyleBox[\(x\+_\),
              SpanMaxSize->0]], \(\[GothicCapitalP]\_x\+_\)}], 
        TraditionalForm]]],
  " by \[ForAll] elimination only ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            StyleBox[\(v\+_\),
              SpanMaxSize->0]], \(\[GothicCapitalP]\_v\+_\)}], 
        TraditionalForm]]],
  ", which can also be written as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            StyleBox[\(v\+_\),
              SpanMaxSize->0]], "\[GothicCapitalU]"}], TraditionalForm]]],
  ". Again by \[ForAll] elimination, we can infer from this ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalU]\_\(v\+_ \[Rule] c\+_\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`c\+_\)]],
  " denotes a sequence new of constants such that ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalU]\_\(v\+_ \[Rule] c\+_\)\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`\(\(=\)\(\[GothicCapitalV]\)\)\)]],
  ") stays free of ",
  Cell[BoxData[
      \(TraditionalForm\`z\+_\)]],
  " (this can always be achieved because we know from the assumption that ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalU]\)]],
  " must be free of ",
  Cell[BoxData[
      \(TraditionalForm\`z\+_\)]],
  "). We can write ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalV]\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[GothicCapitalQ]\_u)\)\_\(v\+_ \[Rule] \
c\+_\)\)]],
  " in order to see that ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalV]\)]],
  " is obtained from ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalQ]\_z\+_\)]],
  " by substituting all free occurrences of ",
  Cell[BoxData[
      \(TraditionalForm\`z\+_\)]],
  ", thus, we can conclude ",
  Cell[BoxData[
      \(TraditionalForm\`\[Exists] \+\(z\+_\)\[GothicCapitalQ]\_z\+_\)]],
  " again by \[Exists] introduction."
}], "FirstParagraph"],

Cell["\[EmptySquare]", "Text",
  TextAlignment->Right],

Cell[TextData[{
  "We come back to the motivating example for developing this inference rule. \
The task was to detect that ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Exists] \+z\), 
          RowBox[{"P", "[", 
            RowBox[{"z", ",", 
              StyleBox["t",
                FontSlant->"Plain"]}], "]"}]}], TraditionalForm]]],
  " can be inferred from ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \+x P[x, x]\)]],
  ". As we have already seen before, the common instance of ",
  Cell[BoxData[
      \(TraditionalForm\`P[x, x]\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"P", "[", 
          RowBox[{"z", ",", 
            StyleBox["t",
              FontSlant->"Plain"]}], "]"}], TraditionalForm]]],
  " is free of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", which corresponds to case 1 of the correctness proof. This justifies the \
argument \[LeftGuillemet]from ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \+x P[x, x]\)]],
  " we know in particular ",
  Cell[BoxData[
      FormBox[
        RowBox[{"P", "[", 
          RowBox[{
            StyleBox["t",
              FontSlant->"Plain"], ",", 
            StyleBox["t",
              FontSlant->"Plain"]}], "]"}], TraditionalForm]]],
  ", which is an instance of the existential goal ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Exists] \+z\), 
          RowBox[{"P", "[", 
            RowBox[{"z", ",", 
              StyleBox["t",
                FontSlant->"Plain"]}], "]"}]}], TraditionalForm]]],
  "\[RightGuillemet]."
}], "FirstParagraph"],

Cell[TextData[{
  "A slightly modified example for an application of this inference rule is \
to detect that ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Exists] \+z\), 
          RowBox[{"P", "[", 
            RowBox[{"z", ",", 
              StyleBox["t",
                FontSlant->"Plain"]}], "]"}]}], TraditionalForm]]],
  " can be proven from ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[ForAll] \+\(x, y\)\), 
          RowBox[{"P", "[", 
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontSlant->"Plain"], "[", "x", "]"}], ",", "y"}], "]"}]}], 
        TraditionalForm]]],
  ". According to the inference rule, we check for unifiability of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"P", "[", 
          RowBox[{"z", ",", 
            StyleBox["t",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"P", "[", 
          RowBox[{
            RowBox[{
              StyleBox["f",
                FontSlant->"Plain"], "[", "x", "]"}], ",", "y"}], "]"}], 
        TraditionalForm]]],
  " using"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CommonInstance[P[f[\[Bullet]var[x]], \[Bullet]var[y]], 
      P[\[Bullet]var[z], t]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"P", "[", 
          RowBox[{
            RowBox[{"f", "[", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], ",", "t"}], "]"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Rule]", "t"}], ",", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Rule]", 
              RowBox[{"f", "[", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The expressions are unifiable and their common instance is free of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", thus, the inference rule is applicable, but since not all variables of \
the universal assumption have been instantiated the argument must be \
different, which can be extracted directly from case 2 of the correctness \
proof: \[LeftGuillemet]From ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[ForAll] \+\(x, y\)\), 
          RowBox[{"P", "[", 
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontSlant->"Plain"], "[", "x", "]"}], ",", "y"}], "]"}]}], 
        TraditionalForm]]],
  " we can infer ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[ForAll] \+x\), 
          RowBox[{"P", "[", 
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontSlant->"Plain"], "[", "x", "]"}], ",", 
              StyleBox["t",
                FontSlant->"Plain"]}], "]"}]}], TraditionalForm]]],
  ", and any instance of this is an instance of the existential goal ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Exists] \+z\), 
          RowBox[{"P", "[", 
            RowBox[{"z", ",", 
              StyleBox["t",
                FontSlant->"Plain"]}], "]"}]}], TraditionalForm]]],
  "\[RightGuillemet], as shown in Figure ",
  
  CounterBox["Section", "Fig:CommonInstance2"],
  ".",
  
  CounterBox["Figure", "Fig:CommonInstance2"],
  "."
}], "SingleParagraph"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{\(\[ForAll] \+\(x, y\)\), 
              RowBox[{"P", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox["f",
                      FontSlant->"Plain"], "[", 
                    StyleBox["x",
                      GridBoxOptions->{ColumnAlignments->{Left}}], 
                    StyleBox["]",
                      GridBoxOptions->{ColumnAlignments->{Left}}]}], 
                  StyleBox[",",
                    GridBoxOptions->{ColumnAlignments->{Left}}], 
                  StyleBox["y",
                    GridBoxOptions->{ColumnAlignments->{Left}}]}], 
                StyleBox["]",
                  GridBoxOptions->{ColumnAlignments->{Left}}]}], 
              StyleBox["      ",
                FontSlant->"Plain"]}], "  ", 
            RowBox[{"       ", 
              RowBox[{\(\[Exists] \+z\), 
                RowBox[{"P", "[", 
                  RowBox[{"z", ",", 
                    StyleBox["t",
                      FontSlant->"Plain"]}], 
                  StyleBox["]",
                    FontSlant->"Plain"]}]}]}]},
          {GridBox[{
                {
                  RowBox[{" ", 
                    SubscriptBox["", 
                      RowBox[{"y", "\[Rule]", 
                        StyleBox["t",
                          FontSlant->"Plain"]}]]}], 
                  StyleBox["\[LowerRightArrow]",
                    FontSize->24]}
                },
              ColumnSpacings->-0.5], " ", 
            StyleBox[GridBox[{
                  {
                    StyleBox["\[LowerLeftArrow]",
                      FontSize->24], 
                    RowBox[{" ", 
                      SubscriptBox["", 
                        RowBox[{"z", "\[Rule]", 
                          RowBox[{
                            StyleBox["f",
                              FontSlant->"Plain"], "[", "x", "]"}]}]]}]}
                  },
                ColumnSpacings->-0.6],
              GridBoxOptions->{ColumnAlignments->{Left}}]},
          {" ", 
            RowBox[{\(\[ForAll] \+x\), 
              RowBox[{"P", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox["f",
                      FontSlant->"Plain"], "[", "x", "]"}], 
                  StyleBox[",",
                    FontSlant->"Plain"], 
                  StyleBox["t",
                    FontSlant->"Plain"]}], 
                StyleBox["]",
                  FontSlant->"Plain"]}]}], " "},
          {" ", GridBox[{
                {
                  SubscriptBox["     ", 
                    RowBox[{\(e . g . \ x\), "\[Rule]", 
                      StyleBox["c",
                        FontSlant->"Plain"]}]], 
                  StyleBox["\[LowerRightArrow]",
                    FontSize->24]}
                },
              ColumnSpacings->-0.5], " "},
          {" ", " ", 
            RowBox[{"P", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontSlant->"Plain"], "[", 
                  StyleBox["c",
                    FontSlant->"Plain"], "]"}], ",", 
                StyleBox["t",
                  FontSlant->"Plain"]}], "]"}]}
          },
        RowSpacings->{0.5, 1},
        ColumnSpacings->0,
        ColumnAlignments->{Right, Center, Left}], 
      TraditionalForm]], "DisplayFormula",
  CounterIncrements->"Figure"],

Cell[TextData[{
  "Figure ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Figure"],
  ". ",
  StyleBox["Detecting an instance of ", "TableHeadText"],
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(\[Exists] \+z\),
            "TableHead"], 
          RowBox[{
            StyleBox["P",
              "TableHead"], 
            StyleBox["[",
              "TableHead"], 
            RowBox[{
              StyleBox["z",
                "TableHead"], 
              StyleBox[",",
                "TableHead"], 
              StyleBox["t",
                "TableHead",
                FontSlant->"Plain"]}], 
            StyleBox["]",
              "TableHead",
              FontSlant->"Plain"]}]}], TraditionalForm]], "TableHeadText"], 
    "TableHeadText"],
  StyleBox[" from ", "TableHeadText"],
  StyleBox[Cell[BoxData[
      FormBox[
        StyleBox[\(\[ForAll] \+\(x, y\)P[f[x], y]\),
          "TableHead"], TraditionalForm]], "TableHeadText"], 
    "TableHeadText"],
  StyleBox[".", "TableHeadText"]
}], "TableHead",
  CellTags->"Fig:CommonInstance2"],

Cell[TextData[{
  "The variation in the proof argument is reflected in the implementation of \
TerminalND in that the ",
  StyleBox["proof header",
    FontSlant->"Italic"],
  " for the inference rule \[Cent]InstanceOfUniversal is aware of the two \
possible cases and prints the justification accordingly. We show the concrete \
calls for the two examples, note the difference in the final proof argument."
}], "SingleParagraph"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TerminalND", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            RowBox[{\(\[Exists] \+z\), 
              RowBox[{"P", "[", 
                RowBox[{"z", ",", 
                  StyleBox["t",
                    FontSlant->"Plain"]}], "]"}]}], 
            ",", \(\[Bullet]finfo[]\)}], "]"}], 
        ",", \(\[Bullet]asml[\[Bullet]lf["\<assum\>", \[ForAll] \+x P[x, 
                x], \[Bullet]finfo[]]]\), ",", "af"}], "]"}]], "Input"],

Cell[BoxData[
    \({"AndNode", {"InstanceOfUniversal", \[Bullet]usedFormulae["goal", 
          "assum"], \[Bullet]generatedFormulae[\[Bullet]lf[
            "assum\[LightBulb]", P[t, t], \[Bullet]finfo[]]]}, {}, {}, {}, 
      "proved"}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(ProofHeader[{"\<InstanceOfUniversal\>", \
\[Bullet]usedFormulae["\<goal\>", "\<assum\>"], \[Bullet]generatedFormulae[\
\[Bullet]lf["\<assum\[LightBulb]\>", 
              P[t, t], \[Bullet]finfo[]]]}, "\<proved\>"] // 
      CellPrint\)], "Input"],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["assum",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "assum"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we know in particular"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(assum\[LightBulb])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      \(P[t, t]\)], "Assumption"],
  Cell["", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"assum\[LightBulb]"],

Cell[TextData[{
  "which is an instance of ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ", hence we are done."
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"TerminalND", "[", 
      RowBox[{
        RowBox[{"\[Bullet]lf", "[", 
          RowBox[{"\"\<goal\>\"", ",", 
            RowBox[{\(\[Exists] \+z\), 
              RowBox[{"P", "[", 
                RowBox[{"z", ",", 
                  StyleBox["t",
                    FontSlant->"Plain"]}], "]"}]}], 
            ",", \(\[Bullet]finfo[]\)}], "]"}], ",", 
        RowBox[{"\[Bullet]asml", "[", 
          RowBox[{"\[Bullet]lf", "[", 
            RowBox[{"\"\<assum\>\"", ",", 
              RowBox[{\(\[ForAll] \+\(x, y\)\), 
                RowBox[{"P", "[", 
                  RowBox[{
                    RowBox[{
                      StyleBox["f",
                        FontSlant->"Plain"], "[", "x", "]"}], ",", "y"}], 
                  "]"}]}], ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}], ",", 
        "af"}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"AndNode\"\>", ",", 
        RowBox[{"{", 
          
          RowBox[{"\<\"InstanceOfUniversal\"\>", 
            ",", \(\[Bullet]usedFormulae["goal", "assum"]\), ",", 
            RowBox[{"\[Bullet]generatedFormulae", "[", 
              RowBox[{"\[Bullet]lf", "[", 
                RowBox[{"\<\"assum\[LightBulb]\"\>", ",", 
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{"P", "[", 
                      RowBox[{
                        RowBox[{"f", "[", 
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "]"}], ",", "t"}], "]"}]}], 
                  ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}]}], "}"}], 
        ",", \({}\), ",", \({}\), ",", \({}\), ",", "\<\"proved\"\>"}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{"ProofHeader", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
            "\"\<InstanceOfUniversal\>\"", 
              ",", \(\[Bullet]usedFormulae["\<goal\>", "\<assum\>"]\), ",", 
              RowBox[{"\[Bullet]generatedFormulae", "[", 
                RowBox[{"\[Bullet]lf", "[", 
                  RowBox[{"\"\<assum\[LightBulb]\>\"", ",", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"P", "[", 
                        RowBox[{
                          RowBox[{"f", "[", 
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "]"}], ",", "t"}], "]"}]}], 
                    ",", \(\[Bullet]finfo[]\)}], "]"}], "]"}]}], "}"}], ",", 
          "\"\<proved\>\""}], "]"}], "//", "CellPrint"}]], "Input"],

Cell[TextData[{
  "From ",
  StyleBox["(", "Label"],
  ButtonBox["assum",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "assum"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  " we know in particular"
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  StyleBox["(assum\[LightBulb])", "Label",
    LineBreakWithin->False],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"P", "[", 
          RowBox[{
            RowBox[{"f", "[", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], ",", "t"}], "]"}]}]], 
    "Assumption"],
  Cell["", "ProofText"]
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"assum\[LightBulb]"],

Cell[TextData[{
  "and any instance of it is also an instance of ",
  StyleBox["(", "Label"],
  ButtonBox["goal",
    ButtonFunction:>(
      Theorema`Provers`Common`BasicProofCells`Private`ExtractTaggedCell[ 
      "goal"]&),
    ButtonEvaluator->Automatic,
    ButtonStyle->"Hyperlink"],
  StyleBox[")", "Label"],
  ", hence we are done."
}], "ProofText",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic Natural Deduction", "Subsection",
  CellTags->"c:30"],

Cell[TextData[{
  "The BasicND prover used in the Set Theory prover just contains those \
inference rules from predicate logic, which are not terminal\[Dash]proved. \
The original PCS prover implemented by Daniela Vasaru contained an inference \
rule for instantiating existential goals by matching subformulae from the \
goal against ground literals contained in the assumptions. We modified this \
rule in its organization of ",
  StyleBox["multiple instantiations",
    FontSlant->"Italic"],
  ", i.e. the case where different instantiations for the same variables are \
possible: the original rule tried multiple instantiations ",
  StyleBox["sequentially",
    FontSlant->"Italic"],
  ", which, in situations, where not the first match leads to proof success, \
requires high search depth for the proof search procedure. In the new \
version, multiple instantiations initiate branching of the proof search, \
which allows to try multiple instantiations ",
  StyleBox["in parallel",
    FontSlant->"Italic"],
  ", thus not requiring higher search depth. The prover option ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(MatchExistential \[Rule] "\<TryAllAtOnce\>"\),
          ShowStringCharacters->True], TraditionalForm]]],
  " chooses the new methodology, whereas ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(MatchExistential \[Rule] "\<OneAtTheTime\>"\),
          ShowStringCharacters->True], TraditionalForm]]],
  "."
}], "FirstParagraph"],

Cell[TextData[{
  "The second rule that received a minor modification is the application of \
the \"modus ponens\" rule for extending the knowledge base. Modus ponens is \
part of natural deduction for predicate logic, on the other hand, using an \
implication in the assumptions for rewriting the knowledge base, as it is \
done in the QR prover, can also be viewed as an application of modus ponens. \
In some situations, one might therefore like to deactivate the rule in the \
BasicND prover, which can be accomplished by setting the prover option ",
  Cell[BoxData[
      \(TraditionalForm\`ModusPonensKB \[Rule] True\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Quantifier Rewriting", "Subsection",
  CellTags->"c:31"],

Cell["\<\
The QR prover also needed some enhancements in order to cooperate \
with set theory proving. New prover options were introduced in order to \
adjust the prover to the needs.\
\>", "SingleParagraph"],

Cell[TextData[{
  "AllowIntroduceQuantifiers: when set to True, rewrite rules are generated \
also for assumptions, where the right\[Dash]hand side contains a quantifier. \
We give two examples for its application: an assumption ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \+\(x, y\)\[GothicCapitalP]\_y \[Implies] \
\[GothicCapitalQ]\_\(x, y\)\)]],
  " generates a rewrite rule ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalP][
          y_] \[RuleDelayed] \[ForAll] \+x \[GothicCapitalQ]\_\(x, y\)\)]],
  " applicable for rewriting the knowledge base, an assumption ",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \+\(x, y\)\[GothicCapitalP]\_\(x, y\) \
\[Implies] \[GothicCapitalQ]\_y\)]],
  "generates a rewrite rule ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalQ][
          y_] := \[Exists] \+x \[GothicCapitalP]\_\(x, y\)\)]],
  " applicable for rewriting the goal. This leads, in some examples, to very \
natural proofs. When introducing quantifiers is activated together with \
allowing the rewrite process to rewrite inside quantifiers (the option \
RWInsideQuantifiers is responsible for this), some care must be taken to \
rename quantified variables eventually in order to avoid name clashes. By \
default, however, the value is False."
}], "ItemizedText"],

Cell["\<\
RWHigherOrder: when set to True, rewrite rules are generated for \
formulae containing function variables, too. The default value is \
False.\
\>", "ItemizedText"],

Cell["\<\
RWSetOperators: when set to True, formulae having a set operator as \
outermost symbol, are allowed to be rewritten. The default value is \
False.\
\>", "ItemizedText"],

Cell["\<\
RWExistentialGoal: when set to True, formulae having an existential \
quantifier as outermost symbol, are allowed to be rewritten. The default \
value is False.\
\>", "ItemizedText"],

Cell[TextData[ButtonBox["\[LowerRightArrow]",
  ButtonData:>{"Part3.nb", "c:1"},
  ButtonStyle->"Navigation",
  ButtonNote->"Part 3"]], "SingleParagraph",
  TextAlignment->Right,
  TextJustification->0]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{783, 694},
WindowMargins->{{172, Automatic}, {Automatic, 66}},
PrintingStartingPageNumber->49,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Part 2: The Set Theory Prover"}], "Header"]}, {Cell[ 
        TextData[ {
          CounterBox[ "Section"], ". ", 
          CounterBox[ 
          "Section", CounterFunction :> (
            Part[ {"", "", "", 
              "The Theoretical Basis of the Set Theory Prover", 
              "Preliminaries on Terminology", 
              "The Set Theory PCS User Prover", 
              "STP: The Set Theory Proving Module", 
              "STKBR: The Set Theory Knowledge Base Rewriting Module", 
              "STC: The Set Theory Computing Module", 
              "STS: The Set Theory Solving Module", 
              "Modifications in the Existing PCS Components"}, #]&)]}], 
        "Header"], Inherited, Inherited}},
PrintingOptions->{"PrintingMargins"->{{79.1875, 79.1875}, {108, 108}},
"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", \
"wwindste", "Diss", "Main"}, "Part2.nb.ps", CharacterEncoding -> \
"ISO8859-1"],
"Magnification"->1},
StyleDefinitions -> "TheoremaSmartColors.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1930, 59, 149, 5, 160, "Title",
      CounterAssignments->{{"Section", 3}, {"Subtitle", 0}, {
          "Subsubtitle", 0}},
      CellTags->"c:1"]},
  "Sec:TheoFoundSet"->{
    Cell[7533, 249, 97, 1, 59, "Section",
      CellTags->"Sec:TheoFoundSet"]},
  "Sec:Terminology"->{
    Cell[16591, 483, 78, 1, 59, "Section",
      CellTags->"Sec:Terminology"]},
  "ExInfRules"->{
    Cell[29430, 805, 273, 7, 45, "InferenceRule",
      CellTags->"ExInfRules"]},
  "Fig:CommonInstance"->{
    Cell[41577, 1143, 645, 24, 36, "TableHead",
      CellTags->"Fig:CommonInstance"]},
  "Fig:MostGeneralUnifier"->{
    Cell[44662, 1249, 737, 25, 37, "TableHead",
      CellTags->"Fig:MostGeneralUnifier"]},
  "Sec:UserProver"->{
    Cell[49360, 1405, 79, 1, 59, "Section",
      CellTags->"Sec:UserProver"]},
  "Info3196237144-6946228"->{
    Cell[50961, 1457, 194, 3, 41, "Print",
      CellTags->"Info3196237144-6946228"]},
  "Info3196237114-3277180"->{
    Cell[51403, 1473, 199, 3, 41, "Print",
      CellTags->"Info3196237114-3277180"]},
  "Info3196237162-7896388"->{
    Cell[51888, 1490, 306, 6, 41, "Print",
      CellTags->"Info3196237162-7896388"]},
  "Sec:STP"->{
    Cell[52536, 1509, 76, 1, 59, "Section",
      CellTags->"Sec:STP"]},
  "Tab:STPGlobals"->{
    Cell[55318, 1580, 830, 25, 113, "Table",
      CellTags->"Tab:STPGlobals"]},
  "Info3196244389-1095809"->{
    Cell[56432, 1624, 329, 5, 59, "Print",
      CellTags->"Info3196244389-1095809"]},
  "Info3196244399-7615058"->{
    Cell[56863, 1637, 180, 3, 23, "Print",
      CellTags->"Info3196244399-7615058"]},
  "Info3196244409-6537830"->{
    Cell[57142, 1648, 222, 4, 41, "Print",
      CellTags->"Info3196244409-6537830"]},
  "c:6"->{
    Cell[57401, 1657, 60, 1, 53, "Subsection",
      CellTags->"c:6"]},
  "Sec:STPMembership"->{
    Cell[58230, 1677, 81, 1, 44, "Subsubsection",
      CellTags->{"Sec:STPMembership", "c:7"}]},
  "c:7"->{
    Cell[58230, 1677, 81, 1, 44, "Subsubsection",
      CellTags->{"Sec:STPMembership", "c:7"}]},
  "goal'"->{
    Cell[60483, 1744, 282, 11, 25, "Conclusion",
      CellTags->"goal'"],
    Cell[64996, 1864, 965, 31, 31, "Conclusion",
      CellTags->"goal'"],
    Cell[67854, 1954, 282, 11, 25, "Conclusion",
      CellTags->"goal'"],
    Cell[71859, 2074, 281, 11, 25, "Conclusion",
      CellTags->"goal'"],
    Cell[76019, 2208, 281, 11, 70, "Conclusion",
      CellTags->"goal'"],
    Cell[80063, 2333, 290, 11, 25, "Conclusion",
      CellTags->"goal'"],
    Cell[84320, 2468, 290, 11, 25, "Conclusion",
      CellTags->"goal'"],
    Cell[89050, 2600, 903, 30, 70, "Conclusion",
      CellTags->"goal'"],
    Cell[98979, 2869, 1213, 37, 31, "Conclusion",
      CellTags->"goal'"],
    Cell[108124, 3136, 294, 11, 25, "Conclusion",
      CellTags->"goal'"],
    Cell[117696, 3404, 304, 11, 27, "Conclusion",
      CellTags->"goal'"],
    Cell[127281, 3679, 294, 11, 25, "Conclusion",
      CellTags->"goal'"],
    Cell[132090, 3802, 456, 13, 25, "Conclusion",
      CellTags->"goal'"],
    Cell[171732, 4899, 294, 11, 25, "Conclusion",
      CellTags->"goal'"],
    Cell[192975, 5430, 2260, 64, 34, "Conclusion",
      CellTags->"goal'"],
    Cell[1033099, 21184, 711, 23, 31, "Conclusion",
      CellTags->"goal'"],
    Cell[1040142, 21359, 1514, 45, 31, "Conclusion",
      CellTags->"goal'"]},
  "goal[1]"->{
    Cell[71478, 2057, 295, 11, 19, "Assumption",
      CellTags->"goal[1]"],
    Cell[75042, 2165, 295, 11, 70, "Assumption",
      CellTags->"goal[1]"],
    Cell[79680, 2316, 297, 11, 19, "Assumption",
      CellTags->"goal[1]"],
    Cell[83337, 2425, 297, 11, 19, "Assumption",
      CellTags->"goal[1]"],
    Cell[103023, 2982, 294, 11, 70, "Conclusion",
      CellTags->"goal[1]"],
    Cell[120570, 3484, 294, 11, 25, "Conclusion",
      CellTags->"goal[1]"],
    Cell[132640, 3821, 358, 12, 25, "Conclusion",
      CellTags->"goal[1]"]},
  "goal[2]"->{
    Cell[75340, 2178, 295, 11, 70, "Assumption",
      CellTags->"goal[2]"],
    Cell[83637, 2438, 297, 11, 19, "Assumption",
      CellTags->"goal[2]"],
    Cell[103411, 2999, 294, 11, 70, "Conclusion",
      CellTags->"goal[2]"],
    Cell[120867, 3497, 297, 11, 25, "Conclusion",
      CellTags->"goal[2]"],
    Cell[133092, 3839, 358, 12, 25, "Conclusion",
      CellTags->"goal[2]"]},
  "goal[3]"->{
    Cell[75638, 2191, 295, 11, 70, "Assumption",
      CellTags->"goal[3]"],
    Cell[83937, 2451, 297, 11, 19, "Assumption",
      CellTags->"goal[3]"],
    Cell[133544, 3857, 358, 12, 25, "Conclusion",
      CellTags->"goal[3]"]},
  "goal.A"->{
    Cell[107742, 3119, 296, 11, 19, "Assumption",
      CellTags->"goal.A"],
    Cell[117293, 3387, 317, 11, 19, "Assumption",
      CellTags->"goal.A"],
    Cell[126899, 3662, 296, 11, 19, "Assumption",
      CellTags->"goal.A"],
    Cell[164184, 4693, 295, 11, 25, "Conclusion",
      CellTags->"goal.A"],
    Cell[171350, 4882, 296, 11, 19, "Assumption",
      CellTags->"goal.A"]},
  "assum\[SubsetEqual]goal"->{
    Cell[139308, 4037, 330, 11, 25, "Conclusion",
      CellTags->"assum\[SubsetEqual]goal"]},
  "Sec:STPInclusion"->{
    Cell[144300, 4173, 70, 1, 44, "Subsubsection",
      CellTags->"Sec:STPInclusion"]},
  "goal.\[EmptySet]"->{
    Cell[150623, 4345, 1134, 35, 34, "Conclusion",
      CellTags->"goal.\[EmptySet]"]},
  "goal.A1"->{
    Cell[176712, 5040, 288, 11, 19, "Assumption",
      CellTags->"goal.A1"]},
  "goal'2"->{
    Cell[177086, 5057, 287, 11, 25, "Conclusion",
      CellTags->"goal'2"]},
  "goal.\[SubsetEqual]"->{
    Cell[191387, 5379, 1487, 45, 34, "Conclusion",
      CellTags->"goal.\[SubsetEqual]"],
    Cell[230194, 6360, 333, 11, 19, "Assumption",
      CellTags->"goal.\[SubsetEqual]"],
    Cell[231459, 6411, 334, 11, 25, "Conclusion",
      CellTags->"goal.\[SubsetEqual]"],
    Cell[237160, 6563, 323, 11, 19, "Assumption",
      CellTags->"goal.\[SubsetEqual]"],
    Cell[238397, 6614, 324, 11, 25, "Conclusion",
      CellTags->"goal.\[SubsetEqual]"]},
  "Sec:STPEquality"->{
    Cell[195272, 5499, 68, 1, 44, "Subsubsection",
      CellTags->"Sec:STPEquality"]},
  "goal'1"->{
    Cell[199868, 5620, 369, 12, 25, "Conclusion",
      CellTags->"goal'1"]},
  "goal.\[Not]\[EmptySet]"->{
    Cell[207394, 5812, 1703, 49, 34, "Conclusion",
      CellTags->"goal.\[Not]\[EmptySet]"]},
  "goal.\[SupersetEqual]"->{
    Cell[220772, 6117, 1614, 47, 34, "Conclusion",
      CellTags->"goal.\[SupersetEqual]"],
    Cell[230613, 6377, 326, 11, 25, "Conclusion",
      CellTags->"goal.\[SupersetEqual]"],
    Cell[231048, 6394, 325, 11, 19, "Assumption",
      CellTags->"goal.\[SupersetEqual]"],
    Cell[237569, 6580, 317, 11, 25, "Conclusion",
      CellTags->"goal.\[SupersetEqual]"],
    Cell[237995, 6597, 316, 11, 19, "Assumption",
      CellTags->"goal.\[SupersetEqual]"]},
  "Sec:STPFunctions"->{
    Cell[240058, 6665, 104, 1, 44, "Subsubsection",
      CellTags->"Sec:STPFunctions"]},
  "goalinj."->{
    Cell[255271, 7080, 300, 11, 19, "Assumption",
      CellTags->"goalinj."]},
  "goalinj.1"->{
    Cell[255574, 7093, 302, 11, 19, "Assumption",
      CellTags->"goalinj.1"]},
  "goalinj.2"->{
    Cell[255879, 7106, 307, 11, 19, "Assumption",
      CellTags->"goalinj.2"]},
  "goalinj.3"->{
    Cell[256271, 7123, 297, 11, 25, "Conclusion",
      CellTags->"goalinj.3"]},
  "goalsurj."->{
    Cell[264207, 7323, 368, 12, 19, "Assumption",
      CellTags->"goalsurj."]},
  "goalsurj.1"->{
    Cell[264660, 7341, 1119, 34, 31, "Conclusion",
      CellTags->"goalsurj.1"]},
  "Sec:STPVariants"->{
    Cell[266519, 7394, 76, 1, 44, "Subsubsection",
      CellTags->"Sec:STPVariants"]},
  "Sec:STKBR"->{
    Cell[268413, 7450, 97, 1, 59, "Section",
      CellTags->"Sec:STKBR"]},
  "Tab:STKBRGlobals"->{
    Cell[270142, 7491, 748, 22, 183, "Table",
      CellTags->"Tab:STKBRGlobals"]},
  "Info3197979294-9280556"->{
    Cell[271181, 7532, 214, 4, 41, "Print",
      CellTags->"Info3197979294-9280556"],
    Cell[1002376, 20396, 214, 4, 41, "Print",
      CellTags->"Info3197979294-9280556"]},
  "Info3197203038-7879917"->{
    Cell[271546, 7546, 214, 4, 41, "Print",
      CellTags->"Info3197203038-7879917"]},
  "Info3197203052-1146766"->{
    Cell[271900, 7560, 207, 4, 41, "Print",
      CellTags->"Info3197203052-1146766"]},
  "Info3197203066-5485046"->{
    Cell[272253, 7574, 211, 4, 41, "Print",
      CellTags->"Info3197203066-5485046"]},
  "Info3197203079-3105421"->{
    Cell[272562, 7586, 295, 6, 41, "Print",
      CellTags->"Info3197203079-3105421"]},
  "Info3197203086-6729534"->{
    Cell[272954, 7600, 315, 6, 41, "Print",
      CellTags->"Info3197203086-6729534"]},
  "c:13"->{
    Cell[273909, 7622, 63, 1, 53, "Subsection",
      CellTags->"c:13"]},
  "Fig:STKBR"->{
    Cell[823521, 15435, 203, 9, 35, "TableHead",
      CellTags->"Fig:STKBR"]},
  "a1'"->{
    Cell[836474, 15731, 351, 12, 19, "Assumption",
      CellTags->"a1'"]},
  "a2[1]"->{
    Cell[837394, 15764, 359, 12, 19, "Assumption",
      CellTags->"a2[1]"]},
  "a2[2]"->{
    Cell[837756, 15778, 363, 12, 19, "Assumption",
      CellTags->"a2[2]"]},
  "c:14"->{
    Cell[838653, 15805, 57, 1, 44, "Subsubsection",
      CellTags->"c:14"]},
  "c:15"->{
    Cell[841405, 15887, 63, 1, 53, "Subsection",
      CellTags->"c:15"]},
  "Sec:STKBRMembership"->{
    Cell[842150, 15906, 74, 1, 44, "Subsubsection",
      CellTags->"Sec:STKBRMembership"]},
  "a1[1]"->{
    Cell[848937, 16097, 361, 12, 19, "Assumption",
      CellTags->"a1[1]"]},
  "a1[2]"->{
    Cell[849301, 16111, 362, 12, 19, "Assumption",
      CellTags->"a1[2]"]},
  "a1\[Union].[1]"->{
    Cell[860707, 16428, 387, 12, 19, "Assumption",
      CellTags->"a1\[Union].[1]"]},
  "a1\[Union].[2]"->{
    Cell[861097, 16442, 387, 12, 19, "Assumption",
      CellTags->"a1\[Union].[2]"]},
  "zElemAbstr"->{
    Cell[863670, 16513, 147, 3, 70, "NumberedEquation",
      CellTags->"zElemAbstr"]},
  "tElemZ"->{
    Cell[863820, 16518, 92, 2, 70, "NumberedEquation",
      CellTags->"tElemZ"]},
  "zEqSx"->{
    Cell[864142, 16532, 118, 3, 70, "NumberedEquation",
      CellTags->"zEqSx"]},
  "Cx"->{
    Cell[864263, 16537, 97, 2, 27, "DisplayFormula",
      CellTags->"Cx"]},
  "a1.\[Union]"->{
    Cell[868080, 16651, 391, 12, 21, "Assumption",
      CellTags->"a1.\[Union]"],
    Cell[871174, 16747, 391, 12, 21, "Assumption",
      CellTags->"a1.\[Union]"]},
  "a1.C"->{
    Cell[868474, 16665, 388, 12, 19, "Assumption",
      CellTags->"a1.C"]},
  "a1\[Intersection].[1]"->{
    Cell[874164, 16830, 397, 12, 19, "Assumption",
      CellTags->"a1\[Intersection].[1]"]},
  "a1\[Intersection].[2]"->{
    Cell[874564, 16844, 397, 12, 70, "Assumption",
      CellTags->"a1\[Intersection].[2]"]},
  "a1\[NotEqual]\[EmptySet]"->{
    Cell[874964, 16858, 423, 12, 70, "Assumption",
      CellTags->"a1\[NotEqual]\[EmptySet]"]},
  "UniAssum"->{
    Cell[887799, 17199, 285, 7, 38, "NumberedEquation",
      CellTags->"UniAssum"]},
  "A\[NotEqual]\[EmptySet]"->{
    Cell[908469, 17776, 405, 12, 19, "Assumption",
      CellTags->"A\[NotEqual]\[EmptySet]"]},
  "c:17"->{
    Cell[909931, 17830, 58, 1, 44, "Subsubsection",
      CellTags->"c:17"]},
  "a1\[SubsetEqual]"->{
    Cell[923490, 18182, 1003, 31, 25, "Assumption",
      CellTags->"a1\[SubsetEqual]"]},
  "a1\[Element]"->{
    Cell[924496, 18215, 383, 12, 19, "Assumption",
      CellTags->"a1\[Element]"]},
  "a1\[NotElement]"->{
    Cell[924882, 18229, 392, 12, 19, "Assumption",
      CellTags->"a1\[NotElement]"]},
  "c:18"->{
    Cell[925311, 18246, 57, 1, 44, "Subsubsection",
      CellTags->"c:18"]},
  "a2\[Dagger]"->{
    Cell[931705, 18411, 379, 12, 19, "Assumption",
      CellTags->"a2\[Dagger]"]},
  "a1+a2"->{
    Cell[932461, 18440, 367, 12, 19, "Assumption",
      CellTags->"a1+a2"]},
  "c:19"->{
    Cell[932865, 18457, 64, 1, 44, "Subsubsection",
      CellTags->"c:19"]},
  "c:20"->{
    Cell[937726, 18592, 116, 4, 44, "Subsubsection",
      CellTags->"c:20"]},
  "defST"->{
    Cell[938643, 18620, 195, 4, 46, "NumberedEquation",
      CellTags->"defST"]},
  "charPropST1"->{
    Cell[938913, 18628, 161, 3, 46, "NumberedEquation",
      CellTags->"charPropST1"]},
  "charPropST2"->{
    Cell[939077, 18633, 387, 8, 46, "NumberedEquation",
      CellTags->"charPropST2"]},
  "charPropST3"->{
    Cell[939467, 18643, 448, 9, 48, "NumberedEquation",
      CellTags->"charPropST3"]},
  "a1\[SuchThat]"->{
    Cell[949048, 18942, 924, 30, 27, "Assumption",
      CellTags->"a1\[SuchThat]"],
    Cell[953829, 19079, 1225, 37, 27, "Assumption",
      CellTags->"a1\[SuchThat]"]},
  "defSTun"->{
    Cell[955353, 19126, 212, 4, 46, "NumberedEquation",
      CellTags->"defSTun"]},
  "charPropSTun1"->{
    Cell[955650, 19134, 212, 4, 46, "NumberedEquation",
      CellTags->"charPropSTun1"]},
  "charPropSTun2"->{
    Cell[955865, 19140, 503, 11, 51, "NumberedEquation",
      CellTags->"charPropSTun2"]},
  "charPropSTun3"->{
    Cell[956371, 19153, 463, 9, 48, "NumberedEquation",
      CellTags->"charPropSTun3"]},
  "a1\[SuchThat].1"->{
    Cell[967708, 19459, 1603, 46, 27, "Assumption",
      CellTags->"a1\[SuchThat].1"]},
  "a1\[SuchThat].2"->{
    Cell[969314, 19507, 2188, 61, 28, "Assumption",
      CellTags->"a1\[SuchThat].2"]},
  "c:21"->{
    Cell[973203, 19617, 85, 1, 44, "Subsubsection",
      CellTags->"c:21"]},
  "Sec:STC"->{
    Cell[989889, 20042, 78, 1, 59, "Section",
      CellTags->"Sec:STC"]},
  "c:23"->{
    Cell[990265, 20056, 85, 1, 53, "Subsection",
      CellTags->"c:23"]},
  "c:24"->{
    Cell[997535, 20276, 66, 1, 53, "Subsection",
      CellTags->"c:24"]},
  "Tab:STCGlobals"->{
    Cell[1001697, 20365, 390, 12, 87, "Table",
      CellTags->"Tab:STCGlobals"]},
  "Info3197979311-7956398"->{
    Cell[1002683, 20408, 557, 9, 95, "Print",
      CellTags->"Info3197979311-7956398"]},
  "c:25"->{
    Cell[1010922, 20585, 82, 1, 53, "Subsection",
      CellTags->"c:25"]},
  "goal\[MathematicaIcon]"->{
    Cell[1016456, 20736, 397, 12, 25, "Conclusion",
      CellTags->"goal\[MathematicaIcon]"],
    Cell[1020341, 20849, 382, 12, 25, "Conclusion",
      CellTags->"goal\[MathematicaIcon]"],
    Cell[1023752, 20951, 435, 13, 27, "Conclusion",
      CellTags->"goal\[MathematicaIcon]"]},
  "Sec:STS"->{
    Cell[1025138, 20987, 76, 1, 59, "Section",
      CellTags->"Sec:STS"]},
  "c:27"->{
    Cell[1028814, 21073, 61, 1, 53, "Subsection",
      CellTags->"c:27"]},
  "goal\[RawStar]"->{
    Cell[1055794, 21751, 1161, 34, 32, "Conclusion",
      CellTags->"goal\[RawStar]"],
    Cell[1087482, 22613, 351, 12, 25, "Conclusion",
      CellTags->"goal\[RawStar]"],
    Cell[1097055, 22852, 780, 25, 70, "Conclusion",
      CellTags->"goal\[RawStar]"]},
  "goal\[RawStar]\[RawStar](1)"->{
    Cell[1066914, 22038, 403, 13, 25, "Conclusion",
      CellTags->"goal\[RawStar]\[RawStar](1)"]},
  "goal\[RawStar]\[RawStar](2)"->{
    Cell[1068832, 22107, 403, 13, 25, "Conclusion",
      CellTags->"goal\[RawStar]\[RawStar](2)"]},
  "goal\[RawStar]\[RawStar]"->{
    Cell[1075483, 22288, 798, 25, 70, "Conclusion",
      CellTags->"goal\[RawStar]\[RawStar]"],
    Cell[1079776, 22411, 370, 12, 70, "Conclusion",
      CellTags->"goal\[RawStar]\[RawStar]"]},
  "a\[Dagger]"->{
    Cell[1086272, 22571, 378, 12, 19, "Assumption",
      CellTags->"a\[Dagger]"]},
  "goal\[RawStar](1)"->{
    Cell[1104330, 23040, 354, 12, 27, "Conclusion",
      CellTags->"goal\[RawStar](1)"],
    Cell[1110058, 23185, 356, 12, 70, "Conclusion",
      CellTags->"goal\[RawStar](1)"],
    Cell[1118254, 23411, 428, 13, 30, "Conclusion",
      CellTags->"goal\[RawStar](1)"]},
  "goal\[RawStar](2)"->{
    Cell[1111087, 23223, 348, 12, 25, "Conclusion",
      CellTags->"goal\[RawStar](2)"],
    Cell[1119429, 23451, 391, 12, 30, "Conclusion",
      CellTags->"goal\[RawStar](2)"]},
  "goal\[RawStar](3)"->{
    Cell[1112112, 23261, 361, 12, 25, "Conclusion",
      CellTags->"goal\[RawStar](3)"]},
  "c:28"->{
    Cell[1122076, 23533, 83, 1, 59, "Section",
      CellTags->"c:28"]},
  "Sec:TerminalND"->{
    Cell[1122184, 23538, 62, 1, 53, "Subsection",
      CellTags->"Sec:TerminalND"]},
  "Fig:CommonInstance1"->{
    Cell[1126558, 23659, 1087, 39, 42, "TableHead",
      CellTags->"Fig:CommonInstance1"]},
  "Fig:CommonInstance2"->{
    Cell[1144202, 24210, 1096, 39, 44, "TableHead",
      CellTags->"Fig:CommonInstance2"]},
  "assum\[LightBulb]"->{
    Cell[1147194, 24306, 306, 11, 19, "Assumption",
      CellTags->"assum\[LightBulb]"],
    Cell[1151540, 24431, 743, 25, 25, "Assumption",
      CellTags->"assum\[LightBulb]"]},
  "c:30"->{
    Cell[1152730, 24476, 65, 1, 53, "Subsection",
      CellTags->"c:30"]},
  "c:31"->{
    Cell[1154945, 24527, 62, 1, 53, "Subsection",
      CellTags->"c:31"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 1159280, 24637},
  {"Sec:TheoFoundSet", 1159462, 24642},
  {"Sec:Terminology", 1159565, 24645},
  {"ExInfRules", 1159663, 24648},
  {"Fig:CommonInstance", 1159771, 24651},
  {"Fig:MostGeneralUnifier", 1159889, 24654},
  {"Sec:UserProver", 1160003, 24657},
  {"Info3196237144-6946228", 1160113, 24660},
  {"Info3196237114-3277180", 1160230, 24663},
  {"Info3196237162-7896388", 1160347, 24666},
  {"Sec:STP", 1160449, 24669},
  {"Tab:STPGlobals", 1160544, 24672},
  {"Info3196244389-1095809", 1160655, 24675},
  {"Info3196244399-7615058", 1160772, 24678},
  {"Info3196244409-6537830", 1160889, 24681},
  {"c:6", 1160987, 24684},
  {"Sec:STPMembership", 1161084, 24687},
  {"c:7", 1161193, 24690},
  {"goal'", 1161304, 24693},
  {"goal[1]", 1162610, 24728},
  {"goal[2]", 1163168, 24743},
  {"goal[3]", 1163572, 24754},
  {"goal.A", 1163819, 24761},
  {"assum\[SubsetEqual]goal", 1164236, 24772},
  {"Sec:STPInclusion", 1164355, 24775},
  {"goal.\[EmptySet]", 1164468, 24778},
  {"goal.A1", 1164572, 24781},
  {"goal'2", 1164665, 24784},
  {"goal.\[SubsetEqual]", 1164770, 24787},
  {"Sec:STPEquality", 1165245, 24798},
  {"goal'1", 1165347, 24801},
  {"goal.\[Not]\[EmptySet]", 1165455, 24804},
  {"goal.\[SupersetEqual]", 1165579, 24807},
  {"Sec:STPFunctions", 1166065, 24818},
  {"goalinj.", 1166171, 24821},
  {"goalinj.1", 1166268, 24824},
  {"goalinj.2", 1166366, 24827},
  {"goalinj.3", 1166464, 24830},
  {"goalsurj.", 1166562, 24833},
  {"goalsurj.1", 1166661, 24836},
  {"Sec:STPVariants", 1166767, 24839},
  {"Sec:STKBR", 1166872, 24842},
  {"Tab:STKBRGlobals", 1166972, 24845},
  {"Info3197979294-9280556", 1167086, 24848},
  {"Info3197203038-7879917", 1167293, 24853},
  {"Info3197203052-1146766", 1167411, 24856},
  {"Info3197203066-5485046", 1167529, 24859},
  {"Info3197203079-3105421", 1167647, 24862},
  {"Info3197203086-6729534", 1167765, 24865},
  {"c:13", 1167865, 24868},
  {"Fig:STKBR", 1167956, 24871},
  {"a1'", 1168047, 24874},
  {"a2[1]", 1168136, 24877},
  {"a2[2]", 1168227, 24880},
  {"c:14", 1168317, 24883},
  {"c:15", 1168407, 24886},
  {"Sec:STKBRMembership", 1168509, 24889},
  {"a1[1]", 1168615, 24892},
  {"a1[2]", 1168706, 24895},
  {"a1\[Union].[1]", 1168806, 24898},
  {"a1\[Union].[2]", 1168915, 24901},
  {"zElemAbstr", 1169020, 24904},
  {"tElemZ", 1169122, 24907},
  {"zEqSx", 1169218, 24910},
  {"Cx", 1169311, 24913},
  {"a1.\[Union]", 1169407, 24916},
  {"a1.C", 1169586, 24921},
  {"a1\[Intersection].[1]", 1169692, 24924},
  {"a1\[Intersection].[2]", 1169815, 24927},
  {"a1\[NotEqual]\[EmptySet]", 1169941, 24930},
  {"UniAssum", 1170054, 24933},
  {"A\[NotEqual]\[EmptySet]", 1170171, 24936},
  {"c:17", 1170279, 24939},
  {"a1\[SubsetEqual]", 1170381, 24942},
  {"a1\[Element]", 1170491, 24945},
  {"a1\[NotElement]", 1170599, 24948},
  {"c:18", 1170699, 24951},
  {"a2\[Dagger]", 1170796, 24954},
  {"a1+a2", 1170893, 24957},
  {"c:19", 1170983, 24960},
  {"c:20", 1171073, 24963},
  {"defST", 1171165, 24966},
  {"charPropST1", 1171267, 24969},
  {"charPropST2", 1171375, 24972},
  {"charPropST3", 1171483, 24975},
  {"a1\[SuchThat]", 1171593, 24978},
  {"defSTun", 1171780, 24983},
  {"charPropSTun1", 1171886, 24986},
  {"charPropSTun2", 1171998, 24989},
  {"charPropSTun3", 1172111, 24992},
  {"a1\[SuchThat].1", 1172225, 24995},
  {"a1\[SuchThat].2", 1172337, 24998},
  {"c:21", 1172438, 25001},
  {"Sec:STC", 1172531, 25004},
  {"c:23", 1172618, 25007},
  {"c:24", 1172705, 25010},
  {"Tab:STCGlobals", 1172802, 25013},
  {"Info3197979311-7956398", 1172915, 25016},
  {"c:25", 1173017, 25019},
  {"goal\[MathematicaIcon]", 1173123, 25022},
  {"Sec:STS", 1173424, 25029},
  {"c:27", 1173512, 25032},
  {"goal\[RawStar]", 1173610, 25035},
  {"goal\[RawStar]\[RawStar](1)", 1173908, 25042},
  {"goal\[RawStar]\[RawStar](2)", 1174044, 25045},
  {"goal\[RawStar]\[RawStar]", 1174177, 25048},
  {"a\[Dagger]", 1174390, 25053},
  {"goal\[RawStar](1)", 1174499, 25056},
  {"goal\[RawStar](2)", 1174795, 25063},
  {"goal\[RawStar](3)", 1175001, 25068},
  {"c:28", 1175104, 25071},
  {"Sec:TerminalND", 1175199, 25074},
  {"Fig:CommonInstance1", 1175312, 25077},
  {"Fig:CommonInstance2", 1175432, 25080},
  {"assum\[LightBulb]", 1175550, 25083},
  {"c:30", 1175743, 25088},
  {"c:31", 1175831, 25091}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 200, 5, 42, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1930, 59, 149, 5, 160, "Title",
  CounterAssignments->{{"Section", 3}, {"Subtitle", 0}, {"Subsubtitle", 0}},
  CellTags->"c:1"],
Cell[2082, 66, 1946, 50, 152, "FirstParagraph"],
Cell[4031, 118, 293, 7, 50, "Text"],
Cell[4327, 127, 180, 6, 27, "ItemizedText"],
Cell[4510, 135, 253, 7, 46, "ItemizedText"],
Cell[4766, 144, 142, 5, 27, "ItemizedText"],
Cell[4911, 151, 366, 6, 69, "SingleParagraph"],
Cell[5280, 159, 413, 16, 46, "ItemizedText"],
Cell[5696, 177, 592, 23, 46, "ItemizedText"],
Cell[6291, 202, 452, 17, 46, "ItemizedText"],
Cell[6746, 221, 359, 14, 46, "ItemizedText"],
Cell[7108, 237, 400, 8, 69, "SingleParagraph"],

Cell[CellGroupData[{
Cell[7533, 249, 97, 1, 59, "Section",
  CellTags->"Sec:TheoFoundSet"],
Cell[7633, 252, 2468, 71, 180, "FirstParagraph"],
Cell[10104, 325, 2449, 55, 266, "Text"],
Cell[12556, 382, 223, 3, 38, "DisplayFormula"],
Cell[12782, 387, 220, 3, 59, "DisplayFormula"],
Cell[13005, 392, 85, 1, 38, "DisplayFormula"],
Cell[13093, 395, 189, 3, 38, "DisplayFormula"],
Cell[13285, 400, 304, 5, 38, "DisplayFormula"],
Cell[13592, 407, 161, 2, 54, "DisplayFormula"],
Cell[13756, 411, 132, 2, 43, "DisplayFormula"],
Cell[13891, 415, 311, 5, 38, "DisplayFormula"],
Cell[14205, 422, 267, 5, 54, "DisplayFormula"],
Cell[14475, 429, 87, 1, 31, "DisplayFormula"],
Cell[14565, 432, 146, 2, 43, "DisplayFormula"],
Cell[14714, 436, 293, 4, 33, "DisplayFormula"],
Cell[15010, 442, 308, 4, 33, "DisplayFormula"],
Cell[15321, 448, 131, 2, 38, "DisplayFormula"],
Cell[15455, 452, 203, 3, 38, "DisplayFormula"],
Cell[15661, 457, 401, 7, 40, "DisplayFormula"],
Cell[16065, 466, 217, 3, 25, "DisplayFormula"],
Cell[16285, 471, 269, 7, 50, "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16591, 483, 78, 1, 59, "Section",
  CellTags->"Sec:Terminology"],
Cell[16672, 486, 2028, 45, 183, "SingleParagraph"],
Cell[18703, 533, 251, 5, 25, "IndentedText"],
Cell[18957, 540, 427, 11, 25, "IndentedText"],
Cell[19387, 553, 1678, 47, 107, "SingleParagraph"],
Cell[21068, 602, 318, 7, 45, "InferenceRule"],
Cell[21389, 611, 2125, 56, 145, "SingleParagraph"],
Cell[23517, 669, 799, 16, 47, "InferenceRule"],
Cell[24319, 687, 1763, 40, 190, "FirstParagraph"],
Cell[26085, 729, 2984, 61, 354, "Text"],
Cell[29072, 792, 238, 6, 45, "InferenceRule"],
Cell[29313, 800, 114, 3, 31, "SingleParagraph"],
Cell[29430, 805, 273, 7, 45, "InferenceRule",
  CellTags->"ExInfRules"],
Cell[29706, 814, 462, 10, 45, "InferenceRule"],
Cell[30171, 826, 387, 9, 55, "InferenceRule"],
Cell[30561, 837, 2395, 60, 228, "FirstParagraph"],
Cell[32959, 899, 7700, 216, 450, "Text"],
Cell[40662, 1117, 912, 24, 69, "DisplayFormula",
  CounterIncrements->"Figure"],
Cell[41577, 1143, 645, 24, 36, "TableHead",
  CellTags->"Fig:CommonInstance"],
Cell[42225, 1169, 1578, 53, 92, "SingleParagraph"],
Cell[43806, 1224, 853, 23, 69, "DisplayFormula",
  CounterIncrements->"Figure"],
Cell[44662, 1249, 737, 25, 37, "TableHead",
  CellTags->"Fig:MostGeneralUnifier"],
Cell[45402, 1276, 1261, 34, 107, "SingleParagraph"],

Cell[CellGroupData[{
Cell[46688, 1314, 152, 3, 41, "Input",
  Evaluatable->False],
Cell[46843, 1319, 847, 25, 42, "Output"]
}, Open  ]],
Cell[47705, 1347, 1205, 36, 73, "SingleParagraph"],

Cell[CellGroupData[{
Cell[48935, 1387, 131, 3, 39, "Input",
  Evaluatable->False],
Cell[49069, 1392, 47, 1, 40, "Output"]
}, Open  ]],
Cell[49131, 1396, 192, 4, 50, "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49360, 1405, 79, 1, 59, "Section",
  CellTags->"Sec:UserProver"],
Cell[49442, 1408, 926, 22, 107, "SingleParagraph"],

Cell[CellGroupData[{
Cell[50393, 1434, 68, 1, 39, "Input"],
Cell[50464, 1437, 91, 1, 40, "Output"]
}, Open  ]],
Cell[50570, 1441, 139, 3, 31, "SingleParagraph"],
Cell[50712, 1446, 170, 4, 27, "ItemizedText"],

Cell[CellGroupData[{
Cell[50907, 1454, 51, 1, 39, "Input"],
Cell[50961, 1457, 194, 3, 41, "Print",
  CellTags->"Info3196237144-6946228"]
}, Open  ]],
Cell[51170, 1463, 153, 3, 27, "ItemizedText"],

Cell[CellGroupData[{
Cell[51348, 1470, 52, 1, 39, "Input"],
Cell[51403, 1473, 199, 3, 41, "Print",
  CellTags->"Info3196237114-3277180"]
}, Open  ]],
Cell[51617, 1479, 190, 4, 27, "ItemizedText"],

Cell[CellGroupData[{
Cell[51832, 1487, 53, 1, 39, "Input"],
Cell[51888, 1490, 306, 6, 41, "Print",
  CellTags->"Info3196237162-7896388"]
}, Open  ]],
Cell[52209, 1499, 290, 5, 69, "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52536, 1509, 76, 1, 59, "Section",
  CellTags->"Sec:STP"],
Cell[52615, 1512, 892, 22, 95, "FirstParagraph"],
Cell[53510, 1536, 1805, 42, 221, "Text"],
Cell[55318, 1580, 830, 25, 113, "Table",
  CellTags->"Tab:STPGlobals"],
Cell[56151, 1607, 207, 10, 36, "TableHead"],

Cell[CellGroupData[{
Cell[56383, 1621, 46, 1, 39, "Input"],
Cell[56432, 1624, 329, 5, 59, "Print",
  CellTags->"Info3196244389-1095809"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56798, 1634, 62, 1, 39, "Input"],
Cell[56863, 1637, 180, 3, 23, "Print",
  CellTags->"Info3196244399-7615058"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57080, 1645, 59, 1, 39, "Input"],
Cell[57142, 1648, 222, 4, 41, "Print",
  CellTags->"Info3196244409-6537830"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57401, 1657, 60, 1, 53, "Subsection",
  CellTags->"c:6"],
Cell[57464, 1660, 741, 13, 126, "SingleParagraph"],

Cell[CellGroupData[{
Cell[58230, 1677, 81, 1, 44, "Subsubsection",
  CellTags->{"Sec:STPMembership", "c:7"}],
Cell[58314, 1680, 135, 3, 31, "SingleParagraph"],
Cell[58452, 1685, 501, 12, 59, "InferenceRule"],
Cell[58956, 1699, 77, 0, 31, "SingleParagraph"],

Cell[CellGroupData[{
Cell[59058, 1703, 326, 7, 52, "Input"],
Cell[59387, 1712, 702, 14, 78, "Output"]
}, Open  ]],
Cell[60104, 1729, 376, 13, 25, "ProofText"],
Cell[60483, 1744, 282, 11, 25, "Conclusion",
  CellTags->"goal'"],
Cell[60768, 1757, 569, 13, 67, "InferenceRule"],
Cell[61340, 1772, 77, 0, 31, "SingleParagraph"],

Cell[CellGroupData[{
Cell[61442, 1776, 329, 7, 52, "Input"],
Cell[61774, 1785, 2829, 61, 112, "Output"]
}, Open  ]],
Cell[64618, 1849, 375, 13, 25, "ProofText"],
Cell[64996, 1864, 965, 31, 31, "Conclusion",
  CellTags->"goal'"],
Cell[65964, 1897, 451, 11, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[66440, 1912, 310, 7, 39, "Input"],
Cell[66753, 1921, 698, 14, 78, "Output"]
}, Open  ]],
Cell[67466, 1938, 385, 14, 25, "ProofText"],
Cell[67854, 1954, 282, 11, 25, "Conclusion",
  CellTags->"goal'"],
Cell[68139, 1967, 702, 15, 45, "InferenceRule"],
Cell[68844, 1984, 98, 1, 31, "SingleParagraph"],
Cell[68945, 1987, 569, 12, 50, "SingleParagraph"],
Cell[69517, 2001, 136, 3, 19, "Text"],

Cell[CellGroupData[{
Cell[69678, 2008, 313, 7, 39, "Input"],
Cell[69994, 2017, 1093, 22, 78, "Output"]
}, Open  ]],
Cell[71102, 2042, 373, 13, 25, "ProofText"],
Cell[71478, 2057, 295, 11, 19, "Assumption",
  CellTags->"goal[1]"],
Cell[71776, 2070, 80, 2, 25, "ProofText"],
Cell[71859, 2074, 281, 11, 25, "Conclusion",
  CellTags->"goal'"],
Cell[72143, 2087, 402, 13, 25, "ProofText"],

Cell[CellGroupData[{
Cell[72570, 2104, 319, 7, 39, "Input"],
Cell[72892, 2113, 1759, 34, 97, "Output"]
}, Open  ]],
Cell[74666, 2150, 373, 13, 70, "ProofText"],
Cell[75042, 2165, 295, 11, 70, "Assumption",
  CellTags->"goal[1]"],
Cell[75340, 2178, 295, 11, 70, "Assumption",
  CellTags->"goal[2]"],
Cell[75638, 2191, 295, 11, 70, "Assumption",
  CellTags->"goal[3]"],
Cell[75936, 2204, 80, 2, 70, "ProofText"],
Cell[76019, 2208, 281, 11, 70, "Conclusion",
  CellTags->"goal'"],
Cell[76303, 2221, 402, 13, 70, "ProofText"],
Cell[76708, 2236, 741, 16, 70, "InferenceRule"],
Cell[77452, 2254, 100, 1, 70, "SingleParagraph"],
Cell[77555, 2257, 242, 5, 70, "SingleParagraph"],

Cell[CellGroupData[{
Cell[77822, 2266, 319, 7, 39, "Input"],
Cell[78144, 2275, 1145, 23, 78, "Output"]
}, Open  ]],
Cell[79304, 2301, 373, 13, 25, "ProofText"],
Cell[79680, 2316, 297, 11, 19, "Assumption",
  CellTags->"goal[1]"],
Cell[79980, 2329, 80, 2, 25, "ProofText"],
Cell[80063, 2333, 290, 11, 25, "Conclusion",
  CellTags->"goal'"],
Cell[80356, 2346, 402, 13, 25, "ProofText"],

Cell[CellGroupData[{
Cell[80783, 2363, 341, 7, 39, "Input"],
Cell[81127, 2372, 1819, 35, 116, "Output"]
}, Open  ]],
Cell[82961, 2410, 373, 13, 25, "ProofText"],
Cell[83337, 2425, 297, 11, 19, "Assumption",
  CellTags->"goal[1]"],
Cell[83637, 2438, 297, 11, 19, "Assumption",
  CellTags->"goal[2]"],
Cell[83937, 2451, 297, 11, 19, "Assumption",
  CellTags->"goal[3]"],
Cell[84237, 2464, 80, 2, 25, "ProofText"],
Cell[84320, 2468, 290, 11, 25, "Conclusion",
  CellTags->"goal'"],
Cell[84613, 2481, 402, 13, 25, "ProofText"],
Cell[85018, 2496, 652, 16, 53, "InferenceRule"],

Cell[CellGroupData[{
Cell[85695, 2516, 320, 7, 45, "Input"],
Cell[86018, 2525, 2689, 59, 70, "Output"]
}, Open  ]],
Cell[88722, 2587, 325, 11, 70, "ProofText"],
Cell[89050, 2600, 903, 30, 70, "Conclusion",
  CellTags->"goal'"],
Cell[89956, 2632, 189, 4, 70, "SingleParagraph"],
Cell[90148, 2638, 569, 13, 70, "InferenceRule"],
Cell[90720, 2653, 190, 4, 50, "SingleParagraph"],
Cell[90913, 2659, 558, 13, 77, "InferenceRule"],
Cell[91474, 2674, 582, 15, 63, "InferenceRule"],
Cell[92059, 2691, 112, 2, 31, "SingleParagraph"],
Cell[92174, 2695, 1898, 50, 132, "SingleParagraph"],
Cell[94075, 2747, 136, 3, 19, "Text"],

Cell[CellGroupData[{
Cell[94236, 2754, 795, 19, 71, "Input"],
Cell[95034, 2775, 3553, 76, 120, "Output"]
}, Open  ]],
Cell[98602, 2854, 374, 13, 25, "ProofText"],
Cell[98979, 2869, 1213, 37, 31, "Conclusion",
  CellTags->"goal'"],
Cell[100195, 2908, 603, 13, 70, "InferenceRule"],

Cell[CellGroupData[{
Cell[100823, 2925, 326, 7, 70, "Input"],
Cell[101152, 2934, 1347, 26, 70, "Output"]
}, Open  ]],
Cell[102514, 2963, 415, 13, 70, "ProofText"],
Cell[102932, 2978, 88, 2, 70, "ProofText"],
Cell[103023, 2982, 294, 11, 70, "Conclusion",
  CellTags->"goal[1]"],
Cell[103320, 2995, 88, 2, 70, "ProofText"],
Cell[103411, 2999, 294, 11, 70, "Conclusion",
  CellTags->"goal[2]"],
Cell[103708, 3012, 595, 14, 45, "InferenceRule"],
Cell[104306, 3028, 246, 5, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[104577, 3037, 327, 7, 45, "Input"],
Cell[104907, 3046, 2454, 55, 97, "Output"]
}, Open  ]],
Cell[107376, 3104, 363, 13, 25, "ProofText"],
Cell[107742, 3119, 296, 11, 19, "Assumption",
  CellTags->"goal.A"],
Cell[108041, 3132, 80, 2, 25, "ProofText"],
Cell[108124, 3136, 294, 11, 25, "Conclusion",
  CellTags->"goal'"],
Cell[108421, 3149, 166, 4, 50, "SingleParagraph"],
Cell[108590, 3155, 597, 13, 45, "InferenceRule"],
Cell[109190, 3170, 179, 4, 50, "SingleParagraph"],
Cell[109372, 3176, 686, 15, 71, "InferenceRule"],
Cell[110061, 3193, 599, 15, 57, "InferenceRule"],
Cell[110663, 3210, 127, 4, 31, "SingleParagraph"],
Cell[110793, 3216, 2003, 54, 130, "SingleParagraph"],
Cell[112799, 3272, 136, 3, 19, "Text"],

Cell[CellGroupData[{
Cell[112960, 3279, 802, 19, 71, "Input"],
Cell[113765, 3300, 3147, 69, 149, "Output"]
}, Open  ]],
Cell[116927, 3372, 363, 13, 25, "ProofText"],
Cell[117293, 3387, 317, 11, 19, "Assumption",
  CellTags->"goal.A"],
Cell[117613, 3400, 80, 2, 25, "ProofText"],
Cell[117696, 3404, 304, 11, 27, "Conclusion",
  CellTags->"goal'"],
Cell[118003, 3417, 473, 10, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[118501, 3431, 321, 7, 39, "Input"],
Cell[118825, 3440, 1345, 26, 97, "Output"]
}, Open  ]],
Cell[120185, 3469, 382, 13, 25, "ProofText"],
Cell[120570, 3484, 294, 11, 25, "Conclusion",
  CellTags->"goal[1]"],
Cell[120867, 3497, 297, 11, 25, "Conclusion",
  CellTags->"goal[2]"],
Cell[121167, 3510, 337, 6, 69, "SingleParagraph"],
Cell[121507, 3518, 465, 11, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[121997, 3533, 443, 11, 39, "Input"],
Cell[122443, 3546, 753, 15, 78, "Output"]
}, Open  ]],
Cell[123211, 3564, 585, 15, 69, "SingleParagraph"],

Cell[CellGroupData[{
Cell[123821, 3583, 413, 9, 39, "Input"],
Cell[124237, 3594, 2281, 50, 97, "Output"]
}, Open  ]],
Cell[126533, 3647, 363, 13, 25, "ProofText"],
Cell[126899, 3662, 296, 11, 19, "Assumption",
  CellTags->"goal.A"],
Cell[127198, 3675, 80, 2, 25, "ProofText"],
Cell[127281, 3679, 294, 11, 25, "Conclusion",
  CellTags->"goal'"],
Cell[127578, 3692, 697, 14, 45, "InferenceRule"],
Cell[128278, 3708, 130, 3, 31, "SingleParagraph"],

Cell[CellGroupData[{
Cell[128433, 3715, 404, 9, 39, "Input"],
Cell[128840, 3726, 2752, 54, 155, "Output"]
}, Open  ]],
Cell[131607, 3783, 389, 13, 25, "ProofText"],
Cell[131999, 3798, 88, 2, 25, "ProofText"],
Cell[132090, 3802, 456, 13, 25, "Conclusion",
  CellTags->"goal'"],
Cell[132549, 3817, 88, 2, 25, "ProofText"],
Cell[132640, 3821, 358, 12, 25, "Conclusion",
  CellTags->"goal[1]"],
Cell[133001, 3835, 88, 2, 25, "ProofText"],
Cell[133092, 3839, 358, 12, 25, "Conclusion",
  CellTags->"goal[2]"],
Cell[133453, 3853, 88, 2, 25, "ProofText"],
Cell[133544, 3857, 358, 12, 25, "Conclusion",
  CellTags->"goal[3]"],
Cell[133905, 3871, 1623, 51, 126, "SingleParagraph"],
Cell[135531, 3924, 563, 13, 45, "InferenceRule"],
Cell[136097, 3939, 95, 1, 31, "SingleParagraph"],
Cell[136195, 3942, 406, 12, 31, "SingleParagraph"],
Cell[136604, 3956, 136, 3, 19, "Text"],
Cell[136743, 3961, 178, 5, 31, "SingleParagraph"],
Cell[136924, 3968, 85, 1, 39, "Input"],

Cell[CellGroupData[{
Cell[137034, 3973, 659, 15, 58, "Input"],
Cell[137696, 3990, 954, 20, 97, "Output"]
}, Open  ]],
Cell[138665, 4013, 640, 22, 25, "ProofText"],
Cell[139308, 4037, 330, 11, 25, "Conclusion",
  CellTags->"assum\[SubsetEqual]goal"],
Cell[139641, 4050, 331, 7, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[139997, 4061, 457, 10, 58, "Input"],
Cell[140457, 4073, 243, 4, 40, "Output"]
}, Open  ]],
Cell[140715, 4080, 423, 13, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[141163, 4097, 456, 10, 39, "Input"],
Cell[141622, 4109, 2629, 58, 97, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[144300, 4173, 70, 1, 44, "Subsubsection",
  CellTags->"Sec:STPInclusion"],
Cell[144373, 4176, 228, 4, 50, "SingleParagraph"],
Cell[144604, 4182, 281, 8, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[144910, 4194, 340, 7, 52, "Input"],
Cell[145253, 4203, 351, 8, 40, "Output"]
}, Open  ]],
Cell[145619, 4214, 400, 13, 25, "ProofText"],
Cell[146022, 4229, 452, 11, 47, "InferenceRule"],

Cell[CellGroupData[{
Cell[146499, 4244, 398, 9, 52, "Input"],
Cell[146900, 4255, 3328, 72, 117, "Output"]
}, Open  ]],
Cell[150243, 4330, 377, 13, 25, "ProofText"],
Cell[150623, 4345, 1134, 35, 34, "Conclusion",
  CellTags->"goal.\[EmptySet]"],
Cell[151760, 4382, 377, 9, 59, "InferenceRule"],

Cell[CellGroupData[{
Cell[152162, 4395, 388, 9, 52, "Input"],
Cell[152553, 4406, 354, 8, 40, "Output"]
}, Open  ]],
Cell[152922, 4417, 394, 13, 25, "ProofText"],
Cell[153319, 4432, 375, 9, 59, "InferenceRule"],

Cell[CellGroupData[{
Cell[153719, 4445, 596, 14, 52, "Input"],
Cell[154318, 4461, 354, 8, 40, "Output"]
}, Open  ]],
Cell[154687, 4472, 394, 13, 25, "ProofText"],
Cell[155084, 4487, 1094, 22, 145, "SingleParagraph"],
Cell[156181, 4511, 1219, 26, 84, "InferenceRule"],

Cell[CellGroupData[{
Cell[157425, 4541, 1437, 31, 87, "Input"],
Cell[158865, 4574, 4656, 92, 111, "Output"]
}, Open  ]],
Cell[163536, 4669, 645, 22, 25, "ProofText"],
Cell[164184, 4693, 295, 11, 25, "Conclusion",
  CellTags->"goal.A"],
Cell[164482, 4706, 152, 3, 19, "FirstParagraph"],
Cell[164637, 4711, 2384, 54, 259, "Text"],
Cell[167024, 4767, 725, 18, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[167774, 4789, 437, 10, 39, "Input"],
Cell[168214, 4801, 2755, 63, 97, "Output"]
}, Open  ]],
Cell[170984, 4867, 363, 13, 25, "ProofText"],
Cell[171350, 4882, 296, 11, 19, "Assumption",
  CellTags->"goal.A"],
Cell[171649, 4895, 80, 2, 25, "ProofText"],
Cell[171732, 4899, 294, 11, 25, "Conclusion",
  CellTags->"goal'"],
Cell[172029, 4912, 657, 17, 88, "SingleParagraph"],
Cell[172689, 4931, 764, 18, 61, "InferenceRule"],

Cell[CellGroupData[{
Cell[173478, 4953, 383, 9, 52, "Input"],
Cell[173864, 4964, 2467, 58, 97, "Output"]
}, Open  ]],
Cell[176346, 5025, 363, 13, 25, "ProofText"],
Cell[176712, 5040, 288, 11, 19, "Assumption",
  CellTags->"goal.A1"],
Cell[177003, 5053, 80, 2, 25, "ProofText"],
Cell[177086, 5057, 287, 11, 25, "Conclusion",
  CellTags->"goal'2"],
Cell[177376, 5070, 307, 5, 69, "SingleParagraph"],
Cell[177686, 5077, 750, 18, 61, "InferenceRule"],
Cell[178439, 5097, 750, 18, 61, "InferenceRule"],
Cell[179192, 5117, 85, 1, 31, "SingleParagraph"],
Cell[179280, 5120, 658, 14, 53, "InferenceRule"],

Cell[CellGroupData[{
Cell[179963, 5138, 342, 7, 52, "Input"],
Cell[180308, 5147, 10685, 214, 187, "Output"]
}, Open  ]],
Cell[191008, 5364, 376, 13, 25, "ProofText"],
Cell[191387, 5379, 1487, 45, 34, "Conclusion",
  CellTags->"goal.\[SubsetEqual]"],
Cell[192877, 5426, 95, 2, 25, "ProofText"],
Cell[192975, 5430, 2260, 64, 34, "Conclusion",
  CellTags->"goal'"]
}, Open  ]],

Cell[CellGroupData[{
Cell[195272, 5499, 68, 1, 44, "Subsubsection",
  CellTags->"Sec:STPEquality"],
Cell[195343, 5502, 380, 6, 69, "SingleParagraph"],
Cell[195726, 5510, 603, 16, 61, "InferenceRule"],

Cell[CellGroupData[{
Cell[196354, 5530, 784, 19, 52, "Input"],
Cell[197141, 5551, 2326, 51, 78, "Output"]
}, Open  ]],
Cell[199482, 5605, 383, 13, 25, "ProofText"],
Cell[199868, 5620, 369, 12, 25, "Conclusion",
  CellTags->"goal'1"],
Cell[200240, 5634, 103, 3, 31, "SingleParagraph"],
Cell[200346, 5639, 529, 13, 45, "InferenceRule"],
Cell[200878, 5654, 108, 3, 31, "SingleParagraph"],
Cell[200989, 5659, 576, 15, 53, "InferenceRule"],

Cell[CellGroupData[{
Cell[201590, 5678, 641, 16, 52, "Input"],
Cell[202234, 5696, 4761, 98, 117, "Output"]
}, Open  ]],
Cell[207010, 5797, 381, 13, 25, "ProofText"],
Cell[207394, 5812, 1703, 49, 34, "Conclusion",
  CellTags->"goal.\[Not]\[EmptySet]"],
Cell[209100, 5863, 553, 9, 88, "SingleParagraph"],
Cell[209656, 5874, 1272, 26, 84, "InferenceRule"],

Cell[CellGroupData[{
Cell[210953, 5904, 791, 16, 87, "Input"],
Cell[211747, 5922, 8362, 168, 152, "Output"]
}, Open  ]],
Cell[220124, 6093, 645, 22, 25, "ProofText"],
Cell[220772, 6117, 1614, 47, 34, "Conclusion",
  CellTags->"goal.\[SupersetEqual]"],
Cell[222389, 6166, 1205, 26, 152, "FirstParagraph"],
Cell[223597, 6194, 176, 4, 50, "Text"],
Cell[223776, 6200, 592, 13, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[224393, 6217, 436, 10, 45, "Input"],
Cell[224832, 6229, 4855, 107, 173, "Output"]
}, Open  ]],
Cell[229702, 6339, 389, 15, 25, "ProofText"],
Cell[230094, 6356, 97, 2, 25, "ProofText"],
Cell[230194, 6360, 333, 11, 19, "Assumption",
  CellTags->"goal.\[SubsetEqual]"],
Cell[230530, 6373, 80, 2, 25, "ProofText"],
Cell[230613, 6377, 326, 11, 25, "Conclusion",
  CellTags->"goal.\[SupersetEqual]"],
Cell[230942, 6390, 103, 2, 25, "ProofText"],
Cell[231048, 6394, 325, 11, 19, "Assumption",
  CellTags->"goal.\[SupersetEqual]"],
Cell[231376, 6407, 80, 2, 25, "ProofText"],
Cell[231459, 6411, 334, 11, 25, "Conclusion",
  CellTags->"goal.\[SubsetEqual]"],
Cell[231796, 6424, 590, 16, 69, "SingleParagraph"],
Cell[232389, 6442, 609, 14, 61, "InferenceRule"],

Cell[CellGroupData[{
Cell[233023, 6460, 344, 7, 52, "Input"],
Cell[233370, 6469, 3283, 70, 116, "Output"]
}, Open  ]],
Cell[236668, 6542, 389, 15, 25, "ProofText"],
Cell[237060, 6559, 97, 2, 25, "ProofText"],
Cell[237160, 6563, 323, 11, 19, "Assumption",
  CellTags->"goal.\[SubsetEqual]"],
Cell[237486, 6576, 80, 2, 25, "ProofText"],
Cell[237569, 6580, 317, 11, 25, "Conclusion",
  CellTags->"goal.\[SupersetEqual]"],
Cell[237889, 6593, 103, 2, 25, "ProofText"],
Cell[237995, 6597, 316, 11, 19, "Assumption",
  CellTags->"goal.\[SupersetEqual]"],
Cell[238314, 6610, 80, 2, 25, "ProofText"],
Cell[238397, 6614, 324, 11, 25, "Conclusion",
  CellTags->"goal.\[SubsetEqual]"],
Cell[238724, 6627, 71, 0, 31, "SingleParagraph"],
Cell[238798, 6629, 611, 15, 61, "InferenceRule"],
Cell[239412, 6646, 609, 14, 61, "InferenceRule"]
}, Open  ]],

Cell[CellGroupData[{
Cell[240058, 6665, 104, 1, 44, "Subsubsection",
  CellTags->"Sec:STPFunctions"],
Cell[240165, 6668, 393, 9, 69, "SingleParagraph"],
Cell[240561, 6679, 1012, 24, 61, "InferenceRule"],
Cell[241576, 6705, 151, 5, 31, "SingleParagraph"],
Cell[241730, 6712, 795, 27, 46, "ItemizedText"],
Cell[242528, 6741, 761, 27, 46, "ItemizedText"],
Cell[243292, 6770, 971, 24, 126, "SingleParagraph"],
Cell[244266, 6796, 159, 6, 27, "ItemizedText"],
Cell[244428, 6804, 164, 6, 27, "ItemizedText"],
Cell[244595, 6812, 160, 6, 27, "ItemizedText"],
Cell[244758, 6820, 690, 12, 107, "SingleParagraph"],
Cell[245451, 6834, 1485, 36, 63, "InferenceRule"],
Cell[246939, 6872, 891, 22, 53, "InferenceRule"],
Cell[247833, 6896, 743, 19, 69, "SingleParagraph"],

Cell[CellGroupData[{
Cell[248601, 6919, 607, 14, 47, "Input"],
Cell[249211, 6935, 5599, 124, 116, "Output"]
}, Open  ]],
Cell[254825, 7062, 443, 16, 25, "ProofText"],
Cell[255271, 7080, 300, 11, 19, "Assumption",
  CellTags->"goalinj."],
Cell[255574, 7093, 302, 11, 19, "Assumption",
  CellTags->"goalinj.1"],
Cell[255879, 7106, 307, 11, 19, "Assumption",
  CellTags->"goalinj.2"],
Cell[256189, 7119, 79, 2, 25, "ProofText"],
Cell[256271, 7123, 297, 11, 25, "Conclusion",
  CellTags->"goalinj.3"],
Cell[256571, 7136, 944, 22, 84, "InferenceRule"],
Cell[257518, 7160, 594, 15, 69, "SingleParagraph"],

Cell[CellGroupData[{
Cell[258137, 7179, 603, 15, 47, "Input"],
Cell[258743, 7196, 5002, 106, 170, "Output"]
}, Open  ]],
Cell[263760, 7305, 444, 16, 25, "ProofText"],
Cell[264207, 7323, 368, 12, 19, "Assumption",
  CellTags->"goalsurj."],
Cell[264578, 7337, 79, 2, 25, "ProofText"],
Cell[264660, 7341, 1119, 34, 31, "Conclusion",
  CellTags->"goalsurj.1"],
Cell[265782, 7377, 700, 12, 88, "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[266519, 7394, 76, 1, 44, "Subsubsection",
  CellTags->"Sec:STPVariants"],
Cell[266598, 7397, 1754, 46, 183, "SingleParagraph"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[268413, 7450, 97, 1, 59, "Section",
  CellTags->"Sec:STKBR"],
Cell[268513, 7453, 1626, 36, 202, "SingleParagraph"],
Cell[270142, 7491, 748, 22, 183, "Table",
  CellTags->"Tab:STKBRGlobals"],
Cell[270893, 7515, 209, 10, 36, "TableHead"],

Cell[CellGroupData[{
Cell[271127, 7529, 51, 1, 39, "Input"],
Cell[271181, 7532, 214, 4, 41, "Print",
  CellTags->"Info3197979294-9280556"]
}, Open  ]],

Cell[CellGroupData[{
Cell[271432, 7541, 111, 3, 39, "Input"],
Cell[271546, 7546, 214, 4, 41, "Print",
  CellTags->"Info3197203038-7879917"]
}, Open  ]],

Cell[CellGroupData[{
Cell[271797, 7555, 100, 3, 39, "Input"],
Cell[271900, 7560, 207, 4, 41, "Print",
  CellTags->"Info3197203052-1146766"]
}, Open  ]],

Cell[CellGroupData[{
Cell[272144, 7569, 106, 3, 39, "Input"],
Cell[272253, 7574, 211, 4, 41, "Print",
  CellTags->"Info3197203066-5485046"]
}, Open  ]],

Cell[CellGroupData[{
Cell[272501, 7583, 58, 1, 39, "Input"],
Cell[272562, 7586, 295, 6, 41, "Print",
  CellTags->"Info3197203079-3105421"]
}, Open  ]],

Cell[CellGroupData[{
Cell[272894, 7597, 57, 1, 39, "Input"],
Cell[272954, 7600, 315, 6, 41, "Print",
  CellTags->"Info3197203086-6729534"]
}, Open  ]],
Cell[273284, 7609, 600, 9, 107, "SingleParagraph"],

Cell[CellGroupData[{
Cell[273909, 7622, 63, 1, 53, "Subsection",
  CellTags->"c:13"],
Cell[273975, 7625, 1762, 42, 171, "FirstParagraph"],
Cell[275740, 7669, 611, 9, 107, "Text"],
Cell[276354, 7680, 282, 9, 46, "ItemizedText"],
Cell[276639, 7691, 256, 6, 46, "ItemizedText"],
Cell[276898, 7699, 306, 9, 27, "ItemizedText"],
Cell[277207, 7710, 304, 9, 27, "ItemizedText"],
Cell[277514, 7721, 575, 12, 84, "ItemizedText"],
Cell[278092, 7735, 678, 18, 88, "SingleParagraph"],
Cell[278773, 7755, 544745, 7678, 324, 505712, 7191, "GraphicsData", \
"PostScript", "Graphics",
  CounterIncrements->"Figure"],
Cell[823521, 15435, 203, 9, 35, "TableHead",
  CellTags->"Fig:STKBR"],
Cell[823727, 15446, 1756, 37, 209, "FirstParagraph"],
Cell[825486, 15485, 1940, 42, 259, "Text"],

Cell[CellGroupData[{
Cell[827451, 15531, 893, 18, 100, "Input"],
Cell[828347, 15551, 7213, 149, 216, "Output"]
}, Open  ]],
Cell[835575, 15703, 430, 7, 88, "SingleParagraph"],
Cell[836008, 15712, 105, 2, 25, "ProofText"],
Cell[836116, 15716, 355, 13, 25, "ProofText"],
Cell[836474, 15731, 351, 12, 19, "Assumption",
  CellTags->"a1'"],
Cell[836828, 15745, 563, 17, 34, "ProofText"],
Cell[837394, 15764, 359, 12, 19, "Assumption",
  CellTags->"a2[1]"],
Cell[837756, 15778, 363, 12, 19, "Assumption",
  CellTags->"a2[2]"],
Cell[838122, 15792, 506, 9, 88, "SingleParagraph"],

Cell[CellGroupData[{
Cell[838653, 15805, 57, 1, 44, "Subsubsection",
  CellTags->"c:14"],
Cell[838713, 15808, 59, 0, 31, "SingleParagraph"],
Cell[838775, 15810, 298, 11, 27, "ItemizedText"],
Cell[839076, 15823, 301, 11, 27, "ItemizedText"],
Cell[839380, 15836, 1246, 29, 145, "SingleParagraph"],
Cell[840629, 15867, 224, 4, 58, "Input"],
Cell[840856, 15873, 500, 8, 88, "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[841405, 15887, 63, 1, 53, "Subsection",
  CellTags->"c:15"],
Cell[841471, 15890, 654, 12, 107, "SingleParagraph"],

Cell[CellGroupData[{
Cell[842150, 15906, 74, 1, 44, "Subsubsection",
  CellTags->"Sec:STKBRMembership"],
Cell[842227, 15909, 604, 12, 75, "InferenceRule"],

Cell[CellGroupData[{
Cell[842856, 15925, 274, 6, 52, "Input"],
Cell[843133, 15933, 511, 14, 40, "Output"]
}, Open  ]],
Cell[843659, 15950, 240, 5, 50, "SingleParagraph"],
Cell[843902, 15957, 609, 12, 75, "InferenceRule"],

Cell[CellGroupData[{
Cell[844536, 15973, 277, 6, 52, "Input"],
Cell[844816, 15981, 460, 12, 40, "Output"]
}, Open  ]],
Cell[845291, 15996, 204, 4, 50, "SingleParagraph"],
Cell[845498, 16002, 802, 17, 99, "InferenceRule"],

Cell[CellGroupData[{
Cell[846325, 16023, 277, 6, 52, "Input"],
Cell[846605, 16031, 1503, 37, 59, "Output"]
}, Open  ]],
Cell[848123, 16071, 245, 5, 50, "SingleParagraph"],
Cell[848371, 16078, 563, 17, 34, "ProofText"],
Cell[848937, 16097, 361, 12, 19, "Assumption",
  CellTags->"a1[1]"],
Cell[849301, 16111, 362, 12, 19, "Assumption",
  CellTags->"a1[2]"],
Cell[849666, 16125, 786, 16, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[850477, 16145, 258, 6, 39, "Input"],
Cell[850738, 16153, 402, 10, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[851177, 16168, 261, 6, 39, "Input"],
Cell[851441, 16176, 426, 10, 40, "Output"]
}, Open  ]],
Cell[851882, 16189, 795, 16, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[852702, 16209, 261, 6, 39, "Input"],
Cell[852966, 16217, 409, 10, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[853412, 16232, 264, 6, 39, "Input"],
Cell[853679, 16240, 675, 16, 40, "Output"]
}, Open  ]],
Cell[854369, 16259, 827, 16, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[855221, 16279, 267, 6, 39, "Input"],
Cell[855491, 16287, 435, 10, 40, "Output"]
}, Open  ]],
Cell[855941, 16300, 819, 16, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[856785, 16320, 270, 6, 39, "Input"],
Cell[857058, 16328, 697, 16, 40, "Output"]
}, Open  ]],
Cell[857770, 16347, 711, 15, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[858506, 16366, 268, 6, 45, "Input"],
Cell[858777, 16374, 1339, 32, 40, "Output"]
}, Open  ]],
Cell[860131, 16409, 573, 17, 25, "ProofText"],
Cell[860707, 16428, 387, 12, 19, "Assumption",
  CellTags->"a1\[Union].[1]"],
Cell[861097, 16442, 387, 12, 19, "Assumption",
  CellTags->"a1\[Union].[2]"],
Cell[861487, 16456, 825, 16, 93, "InferenceRule"],
Cell[862315, 16474, 709, 15, 70, "InferenceRule"],
Cell[863027, 16491, 114, 2, 70, "SingleParagraph"],
Cell[863144, 16495, 523, 16, 70, "SingleParagraph"],
Cell[863670, 16513, 147, 3, 70, "NumberedEquation",
  CellTags->"zElemAbstr"],
Cell[863820, 16518, 92, 2, 70, "NumberedEquation",
  CellTags->"tElemZ"],
Cell[863915, 16522, 224, 8, 70, "SingleParagraph"],
Cell[864142, 16532, 118, 3, 70, "NumberedEquation",
  CellTags->"zEqSx"],
Cell[864263, 16537, 97, 2, 27, "DisplayFormula",
  CellTags->"Cx"],
Cell[864363, 16541, 622, 22, 50, "SingleParagraph"],
Cell[864988, 16565, 136, 3, 19, "Text"],

Cell[CellGroupData[{
Cell[865149, 16572, 719, 18, 71, "Input"],
Cell[865871, 16592, 1620, 37, 55, "Output"]
}, Open  ]],
Cell[867506, 16632, 571, 17, 25, "ProofText"],
Cell[868080, 16651, 391, 12, 21, "Assumption",
  CellTags->"a1.\[Union]"],
Cell[868474, 16665, 388, 12, 19, "Assumption",
  CellTags->"a1.C"],

Cell[CellGroupData[{
Cell[868887, 16681, 617, 16, 60, "Input"],
Cell[869507, 16699, 1078, 26, 55, "Output"]
}, Open  ]],
Cell[870600, 16728, 571, 17, 25, "ProofText"],
Cell[871174, 16747, 391, 12, 21, "Assumption",
  CellTags->"a1.\[Union]"],
Cell[871568, 16761, 943, 18, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[872536, 16783, 274, 6, 39, "Input"],
Cell[872813, 16791, 978, 21, 40, "Output"]
}, Open  ]],
Cell[873806, 16815, 355, 13, 25, "ProofText"],
Cell[874164, 16830, 397, 12, 19, "Assumption",
  CellTags->"a1\[Intersection].[1]"],
Cell[874564, 16844, 397, 12, 70, "Assumption",
  CellTags->"a1\[Intersection].[2]"],
Cell[874964, 16858, 423, 12, 70, "Assumption",
  CellTags->"a1\[NotEqual]\[EmptySet]"],
Cell[875390, 16872, 765, 12, 70, "SingleParagraph"],

Cell[CellGroupData[{
Cell[876180, 16888, 51, 1, 70, "Input"],
Cell[876234, 16891, 323, 5, 70, "Output"]
}, Open  ]],
Cell[876572, 16899, 793, 20, 70, "SingleParagraph"],
Cell[877368, 16921, 727, 14, 70, "InferenceRule"],

Cell[CellGroupData[{
Cell[878120, 16939, 501, 11, 70, "Input"],
Cell[878624, 16952, 756, 18, 70, "Output"]
}, Open  ]],
Cell[879395, 16973, 245, 5, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[879665, 16982, 51, 1, 39, "Input"],
Cell[879719, 16985, 247, 4, 59, "Output"]
}, Open  ]],
Cell[879981, 16992, 779, 19, 107, "SingleParagraph"],
Cell[880763, 17013, 866, 17, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[881654, 17034, 277, 6, 39, "Input"],
Cell[881934, 17042, 420, 9, 40, "Output"]
}, Open  ]],
Cell[882369, 17054, 810, 18, 75, "InferenceRule"],

Cell[CellGroupData[{
Cell[883204, 17076, 275, 6, 45, "Input"],
Cell[883482, 17084, 1264, 29, 51, "Output"]
}, Open  ]],
Cell[884761, 17116, 734, 14, 93, "InferenceRule"],
Cell[885498, 17132, 742, 16, 67, "InferenceRule"],
Cell[886243, 17150, 129, 4, 31, "SingleParagraph"],
Cell[886375, 17156, 1421, 41, 95, "SingleParagraph"],
Cell[887799, 17199, 285, 7, 38, "NumberedEquation",
  CellTags->"UniAssum"],
Cell[888087, 17208, 487, 16, 40, "SingleParagraph"],
Cell[888577, 17226, 136, 3, 19, "Text"],

Cell[CellGroupData[{
Cell[888738, 17233, 726, 18, 71, "Input"],
Cell[889467, 17253, 1726, 39, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[891230, 17297, 624, 16, 60, "Input"],
Cell[891857, 17315, 1343, 31, 55, "Output"]
}, Open  ]],
Cell[893215, 17349, 702, 14, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[893942, 17367, 269, 6, 39, "Input"],
Cell[894214, 17375, 648, 15, 40, "Output"]
}, Open  ]],
Cell[894877, 17393, 716, 14, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[895618, 17411, 272, 6, 39, "Input"],
Cell[895893, 17419, 404, 9, 40, "Output"]
}, Open  ]],
Cell[896312, 17431, 576, 12, 47, "InferenceRule"],

Cell[CellGroupData[{
Cell[896913, 17447, 383, 10, 39, "Input"],
Cell[897299, 17459, 398, 9, 40, "Output"]
}, Open  ]],
Cell[897712, 17471, 582, 12, 47, "InferenceRule"],

Cell[CellGroupData[{
Cell[898319, 17487, 262, 6, 39, "Input"],
Cell[898584, 17495, 395, 9, 40, "Output"]
}, Open  ]],
Cell[898994, 17507, 607, 12, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[899626, 17523, 275, 6, 39, "Input"],
Cell[899904, 17531, 399, 9, 40, "Output"]
}, Open  ]],
Cell[900318, 17543, 928, 18, 66, "InferenceRule"],

Cell[CellGroupData[{
Cell[901271, 17565, 265, 6, 39, "Input"],
Cell[901539, 17573, 972, 22, 40, "Output"]
}, Open  ]],
Cell[902526, 17598, 1138, 23, 145, "SingleParagraph"],

Cell[CellGroupData[{
Cell[903689, 17625, 102, 2, 39, "Input"],
Cell[903794, 17629, 59, 1, 40, "Output"]
}, Open  ]],
Cell[903868, 17633, 127, 3, 31, "SingleParagraph"],
Cell[903998, 17638, 683, 15, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[904706, 17657, 256, 6, 39, "Input"],
Cell[904965, 17665, 401, 9, 40, "Output"]
}, Open  ]],
Cell[905381, 17677, 140, 3, 31, "SingleParagraph"],

Cell[CellGroupData[{
Cell[905546, 17684, 51, 1, 39, "Input"],
Cell[905600, 17687, 131, 2, 40, "Output"]
}, Open  ]],
Cell[905746, 17692, 263, 5, 31, "SingleParagraph"],

Cell[CellGroupData[{
Cell[906034, 17701, 278, 6, 39, "Input"],
Cell[906315, 17709, 44, 1, 40, "Output"]
}, Open  ]],
Cell[906374, 17713, 646, 14, 47, "InferenceRule"],

Cell[CellGroupData[{
Cell[907045, 17731, 266, 6, 39, "Input"],
Cell[907314, 17739, 739, 19, 40, "Output"]
}, Open  ]],
Cell[908068, 17761, 398, 13, 25, "ProofText"],
Cell[908469, 17776, 405, 12, 19, "Assumption",
  CellTags->"A\[NotEqual]\[EmptySet]"],
Cell[908877, 17790, 92, 1, 31, "SingleParagraph"],

Cell[CellGroupData[{
Cell[908994, 17795, 51, 1, 39, "Input"],
Cell[909048, 17798, 259, 5, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[909344, 17808, 491, 13, 39, "Input"],
Cell[909838, 17823, 44, 1, 40, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[909931, 17830, 58, 1, 44, "Subsubsection",
  CellTags->"c:17"],
Cell[909992, 17833, 197, 4, 50, "SingleParagraph"],
Cell[910192, 17839, 830, 17, 75, "InferenceRule"],

Cell[CellGroupData[{
Cell[911047, 17860, 294, 6, 52, "Input"],
Cell[911344, 17868, 1219, 28, 51, "Output"]
}, Open  ]],
Cell[912578, 17899, 57, 0, 31, "SingleParagraph"],
Cell[912638, 17901, 819, 17, 75, "InferenceRule"],

Cell[CellGroupData[{
Cell[913482, 17922, 277, 6, 52, "Input"],
Cell[913762, 17930, 1247, 29, 51, "Output"]
}, Open  ]],
Cell[915024, 17962, 837, 18, 75, "InferenceRule"],

Cell[CellGroupData[{
Cell[915886, 17984, 277, 6, 52, "Input"],
Cell[916166, 17992, 1305, 31, 51, "Output"]
}, Open  ]],
Cell[917486, 18026, 57, 0, 31, "SingleParagraph"],
Cell[917546, 18028, 790, 16, 53, "InferenceRule"],

Cell[CellGroupData[{
Cell[918361, 18048, 260, 6, 39, "Input"],
Cell[918624, 18056, 1281, 30, 51, "Output"]
}, Open  ]],
Cell[919920, 18089, 920, 18, 75, "InferenceRule"],

Cell[CellGroupData[{
Cell[920865, 18111, 255, 6, 39, "Input"],
Cell[921123, 18119, 1994, 45, 80, "Output"]
}, Open  ]],
Cell[923132, 18167, 355, 13, 25, "ProofText"],
Cell[923490, 18182, 1003, 31, 25, "Assumption",
  CellTags->"a1\[SubsetEqual]"],
Cell[924496, 18215, 383, 12, 19, "Assumption",
  CellTags->"a1\[Element]"],
Cell[924882, 18229, 392, 12, 19, "Assumption",
  CellTags->"a1\[NotElement]"]
}, Open  ]],

Cell[CellGroupData[{
Cell[925311, 18246, 57, 1, 44, "Subsubsection",
  CellTags->"c:18"],
Cell[925371, 18249, 781, 16, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[926177, 18269, 264, 6, 52, "Input"],
Cell[926444, 18277, 2448, 54, 53, "Output"]
}, Open  ]],
Cell[928907, 18334, 1074, 22, 67, "InferenceRule"],

Cell[CellGroupData[{
Cell[930006, 18360, 484, 11, 50, "Input"],
Cell[930493, 18373, 505, 12, 40, "Output"]
}, Open  ]],
Cell[931013, 18388, 322, 6, 58, "Input"],
Cell[931338, 18396, 364, 13, 25, "ProofText"],
Cell[931705, 18411, 379, 12, 19, "Assumption",
  CellTags->"a2\[Dagger]"],
Cell[932087, 18425, 371, 13, 25, "ProofText"],
Cell[932461, 18440, 367, 12, 19, "Assumption",
  CellTags->"a1+a2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[932865, 18457, 64, 1, 44, "Subsubsection",
  CellTags->"c:19"],
Cell[932932, 18460, 159, 4, 31, "SingleParagraph"],
Cell[933094, 18466, 701, 15, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[933820, 18485, 288, 6, 39, "Input"],
Cell[934111, 18493, 635, 16, 40, "Output"]
}, Open  ]],
Cell[934761, 18512, 807, 19, 45, "InferenceRule"],

Cell[CellGroupData[{
Cell[935593, 18535, 288, 6, 39, "Input"],
Cell[935884, 18543, 1793, 43, 40, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[937726, 18592, 116, 4, 44, "Subsubsection",
  CellTags->"c:20"],
Cell[937845, 18598, 795, 20, 107, "SingleParagraph"],
Cell[938643, 18620, 195, 4, 46, "NumberedEquation",
  CellTags->"defST"],
Cell[938841, 18626, 69, 0, 31, "SingleParagraph"],
Cell[938913, 18628, 161, 3, 46, "NumberedEquation",
  CellTags->"charPropST1"],
Cell[939077, 18633, 387, 8, 46, "NumberedEquation",
  CellTags->"charPropST2"],
Cell[939467, 18643, 448, 9, 48, "NumberedEquation",
  CellTags->"charPropST3"],
Cell[939918, 18654, 125, 4, 31, "SingleParagraph"],
Cell[940046, 18660, 699, 29, 31, "SingleParagraph"],
Cell[940748, 18691, 589, 19, 50, "SingleParagraph"],
Cell[941340, 18712, 834, 32, 51, "SingleParagraph"],
Cell[942177, 18746, 772, 29, 60, "SingleParagraph"],
Cell[942952, 18777, 136, 3, 19, "Text"],
Cell[943091, 18782, 2428, 64, 239, "SingleParagraph"],
Cell[945522, 18848, 674, 14, 73, "InferenceRule"],
Cell[946199, 18864, 703, 15, 73, "InferenceRule"],

Cell[CellGroupData[{
Cell[946927, 18883, 342, 8, 70, "Input"],
Cell[947272, 18893, 1352, 31, 70, "Output"]
}, Open  ]],
Cell[948639, 18927, 406, 13, 25, "ProofText"],
Cell[949048, 18942, 924, 30, 27, "Assumption",
  CellTags->"a1\[SuchThat]"],
Cell[949975, 18974, 1236, 33, 135, "SingleParagraph"],

Cell[CellGroupData[{
Cell[951236, 19011, 404, 9, 56, "Input"],
Cell[951643, 19022, 1762, 39, 58, "Output"]
}, Open  ]],
Cell[953420, 19064, 406, 13, 25, "ProofText"],
Cell[953829, 19079, 1225, 37, 27, "Assumption",
  CellTags->"a1\[SuchThat]"],
Cell[955057, 19118, 293, 6, 50, "SingleParagraph"],
Cell[955353, 19126, 212, 4, 46, "NumberedEquation",
  CellTags->"defSTun"],
Cell[955568, 19132, 79, 0, 31, "SingleParagraph"],
Cell[955650, 19134, 212, 4, 46, "NumberedEquation",
  CellTags->"charPropSTun1"],
Cell[955865, 19140, 503, 11, 51, "NumberedEquation",
  CellTags->"charPropSTun2"],
Cell[956371, 19153, 463, 9, 48, "NumberedEquation",
  CellTags->"charPropSTun3"],
Cell[956837, 19164, 126, 4, 31, "SingleParagraph"],
Cell[956966, 19170, 521, 20, 31, "SingleParagraph"],
Cell[957490, 19192, 989, 35, 71, "SingleParagraph"],
Cell[958482, 19229, 450, 15, 50, "SingleParagraph"],
Cell[958935, 19246, 784, 29, 51, "SingleParagraph"],
Cell[959722, 19277, 136, 3, 19, "Text"],
Cell[959861, 19282, 821, 16, 75, "InferenceRule"],
Cell[960685, 19300, 815, 17, 90, "InferenceRule"],

Cell[CellGroupData[{
Cell[961525, 19321, 463, 10, 56, "Input"],
Cell[961991, 19333, 5293, 108, 98, "Output"]
}, Open  ]],
Cell[967299, 19444, 406, 13, 25, "ProofText"],
Cell[967708, 19459, 1603, 46, 27, "Assumption",
  CellTags->"a1\[SuchThat].1"],
Cell[969314, 19507, 2188, 61, 28, "Assumption",
  CellTags->"a1\[SuchThat].2"],
Cell[971505, 19570, 1661, 42, 154, "SingleParagraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[973203, 19617, 85, 1, 44, "Subsubsection",
  CellTags->"c:21"],
Cell[973291, 19620, 436, 7, 88, "SingleParagraph"],
Cell[973730, 19629, 747, 15, 75, "InferenceRule"],

Cell[CellGroupData[{
Cell[974502, 19648, 291, 6, 52, "Input"],
Cell[974796, 19656, 1846, 41, 51, "Output"]
}, Open  ]],
Cell[976657, 19700, 695, 14, 61, "InferenceRule"],

Cell[CellGroupData[{
Cell[977377, 19718, 282, 6, 50, "Input"],
Cell[977662, 19726, 1775, 40, 51, "Output"]
}, Open  ]],
Cell[979452, 19769, 798, 17, 93, "InferenceRule"],
Cell[980253, 19788, 185, 4, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[980463, 19796, 785, 19, 71, "Input"],
Cell[981251, 19817, 2203, 48, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[983491, 19870, 679, 17, 60, "Input"],
Cell[984173, 19889, 1877, 43, 55, "Output"]
}, Open  ]],
Cell[986065, 19935, 112, 3, 31, "SingleParagraph"],

Cell[CellGroupData[{
Cell[986202, 19942, 780, 20, 60, "Input"],
Cell[986985, 19964, 1832, 41, 55, "Output"]
}, Open  ]],
Cell[988832, 20008, 996, 27, 107, "SingleParagraph"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[989889, 20042, 78, 1, 59, "Section",
  CellTags->"Sec:STC"],
Cell[989970, 20045, 270, 7, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[990265, 20056, 85, 1, 53, "Subsection",
  CellTags->"c:23"],
Cell[990353, 20059, 178, 7, 31, "SingleParagraph"],
Cell[990534, 20068, 155, 3, 27, "ItemizedText"],
Cell[990692, 20073, 916, 24, 84, "ItemizedText"],
Cell[991611, 20099, 497, 10, 88, "SingleParagraph"],

Cell[CellGroupData[{
Cell[992133, 20113, 109, 2, 39, "Input"],
Cell[992245, 20117, 43, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[992325, 20123, 125, 2, 39, "Input"],
Cell[992453, 20127, 46, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[992536, 20133, 132, 2, 39, "Input"],
Cell[992671, 20137, 37, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[992745, 20143, 127, 2, 39, "Input"],
Cell[992875, 20147, 40, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[992952, 20153, 270, 4, 54, "Input"],
Cell[993225, 20159, 40, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[993302, 20165, 288, 4, 83, "Input"],
Cell[993593, 20171, 40, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[993670, 20177, 392, 6, 83, "Input"],
Cell[994065, 20185, 1860, 33, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[995962, 20223, 325, 6, 83, "Input"],
Cell[996290, 20231, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[996365, 20237, 322, 5, 83, "Input"],
Cell[996690, 20244, 38, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[996765, 20250, 293, 4, 83, "Input"],
Cell[997061, 20256, 39, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[997137, 20262, 308, 5, 83, "Input"],
Cell[997448, 20269, 38, 1, 40, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[997535, 20276, 66, 1, 53, "Subsection",
  CellTags->"c:24"],
Cell[997604, 20279, 2272, 39, 316, "SingleParagraph"],
Cell[999879, 20320, 671, 12, 103, "ItemizedText"],
Cell[1000553, 20334, 263, 7, 27, "ItemizedText"],
Cell[1000819, 20343, 590, 9, 84, "ItemizedText"],
Cell[1001412, 20354, 282, 9, 50, "SingleParagraph"],
Cell[1001697, 20365, 390, 12, 87, "Table",
  CellTags->"Tab:STCGlobals"],
Cell[1002090, 20379, 207, 10, 36, "TableHead"],

Cell[CellGroupData[{
Cell[1002322, 20393, 51, 1, 39, "Input"],
Cell[1002376, 20396, 214, 4, 41, "Print",
  CellTags->"Info3197979294-9280556"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1002627, 20405, 53, 1, 39, "Input"],
Cell[1002683, 20408, 557, 9, 95, "Print",
  CellTags->"Info3197979311-7956398"]
}, Open  ]],
Cell[1003255, 20420, 779, 12, 114, "FirstParagraph"],
Cell[1004037, 20434, 3500, 64, 468, "Text"],

Cell[CellGroupData[{
Cell[1007562, 20502, 47, 1, 39, "Input"],
Cell[1007612, 20505, 824, 22, 55, "Output"]
}, Open  ]],
Cell[1008451, 20530, 873, 17, 114, "FirstParagraph"],
Cell[1009327, 20549, 1558, 31, 222, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1010922, 20585, 82, 1, 53, "Subsection",
  CellTags->"c:25"],
Cell[1011007, 20588, 248, 5, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1011280, 20597, 1266, 30, 83, "Input"],
Cell[1012549, 20629, 2420, 55, 133, "Output"]
}, Open  ]],
Cell[1014984, 20687, 388, 13, 25, "ProofText"],
Cell[1015375, 20702, 877, 24, 36, "ProofText"],
Cell[1016255, 20728, 198, 6, 25, "ProofText"],
Cell[1016456, 20736, 397, 12, 25, "Conclusion",
  CellTags->"goal\[MathematicaIcon]"],
Cell[1016856, 20750, 598, 9, 107, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1017479, 20763, 430, 10, 86, "Input"],
Cell[1017912, 20775, 1094, 22, 135, "Output"]
}, Open  ]],
Cell[1019021, 20800, 388, 13, 25, "ProofText"],
Cell[1019412, 20815, 281, 8, 27, "ProofText"],
Cell[1019696, 20825, 406, 12, 27, "ProofText"],
Cell[1020105, 20839, 233, 8, 25, "ProofText"],
Cell[1020341, 20849, 382, 12, 25, "Conclusion",
  CellTags->"goal\[MathematicaIcon]"],
Cell[1020726, 20863, 329, 7, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1021080, 20874, 430, 10, 86, "Input"],
Cell[1021513, 20886, 1260, 26, 196, "Output"]
}, Open  ]],
Cell[1022788, 20915, 388, 13, 25, "ProofText"],
Cell[1023179, 20930, 281, 8, 27, "ProofText"],
Cell[1023463, 20940, 286, 9, 27, "ProofText"],
Cell[1023752, 20951, 435, 13, 27, "Conclusion",
  CellTags->"goal\[MathematicaIcon]"],
Cell[1024190, 20966, 899, 15, 145, "SingleParagraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1025138, 20987, 76, 1, 59, "Section",
  CellTags->"Sec:STS"],
Cell[1025217, 20990, 895, 13, 133, "FirstParagraph"],
Cell[1026115, 21005, 348, 6, 69, "Text"],
Cell[1026466, 21013, 418, 9, 65, "ItemizedText"],
Cell[1026887, 21024, 679, 12, 103, "ItemizedText"],
Cell[1027569, 21038, 653, 13, 103, "ItemizedText"],
Cell[1028225, 21053, 564, 16, 69, "Text"],

Cell[CellGroupData[{
Cell[1028814, 21073, 61, 1, 53, "Subsection",
  CellTags->"c:27"],
Cell[1028878, 21076, 453, 7, 88, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1029356, 21087, 1195, 28, 52, "Input"],
Cell[1030554, 21117, 2151, 49, 112, "Output"]
}, Open  ]],
Cell[1032720, 21169, 376, 13, 25, "ProofText"],
Cell[1033099, 21184, 711, 23, 31, "Conclusion",
  CellTags->"goal'"],

Cell[CellGroupData[{
Cell[1033835, 21211, 1813, 42, 52, "Input"],
Cell[1035651, 21255, 4098, 86, 112, "Output"]
}, Open  ]],
Cell[1039764, 21344, 375, 13, 25, "ProofText"],
Cell[1040142, 21359, 1514, 45, 31, "Conclusion",
  CellTags->"goal'"],
Cell[1041659, 21406, 180, 5, 31, "SingleParagraph"],
Cell[1041842, 21413, 1184, 25, 101, "InferenceRule"],
Cell[1043029, 21440, 3091, 87, 209, "FirstParagraph"],
Cell[1046123, 21529, 3888, 82, 430, "Text"],

Cell[CellGroupData[{
Cell[1050036, 21615, 1992, 45, 53, "Input"],
Cell[1052031, 21662, 3225, 67, 141, "Output"]
}, Open  ]],
Cell[1055271, 21732, 520, 17, 25, "ProofText"],
Cell[1055794, 21751, 1161, 34, 32, "Conclusion",
  CellTags->"goal\[RawStar]"],
Cell[1056958, 21787, 160, 4, 31, "SingleParagraph"],
Cell[1057121, 21793, 1165, 26, 106, "InferenceRule"],
Cell[1058289, 21821, 1338, 33, 126, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1059652, 21858, 1654, 35, 79, "Input"],
Cell[1061309, 21895, 4095, 86, 217, "Output"]
}, Open  ]],
Cell[1065419, 21984, 126, 3, 31, "SingleParagraph"],
Cell[1065548, 21989, 741, 24, 25, "ProofText"],
Cell[1066292, 22015, 521, 17, 25, "ProofText"],
Cell[1066816, 22034, 95, 2, 25, "ProofText"],
Cell[1066914, 22038, 403, 13, 25, "Conclusion",
  CellTags->"goal\[RawStar]\[RawStar](1)"],
Cell[1067320, 22053, 143, 3, 31, "SingleParagraph"],
Cell[1067466, 22058, 741, 24, 25, "ProofText"],
Cell[1068210, 22084, 521, 17, 25, "ProofText"],
Cell[1068734, 22103, 95, 2, 25, "ProofText"],
Cell[1068832, 22107, 403, 13, 25, "Conclusion",
  CellTags->"goal\[RawStar]\[RawStar](2)"],
Cell[1069238, 22122, 406, 11, 59, "SingleParagraph"],
Cell[1069647, 22135, 1038, 24, 92, "InferenceRule"],

Cell[CellGroupData[{
Cell[1070710, 22163, 1376, 32, 50, "Input"],
Cell[1072089, 22197, 2740, 63, 70, "Output"]
}, Open  ]],
Cell[1074844, 22263, 253, 8, 70, "ProofText"],
Cell[1075100, 22273, 380, 13, 70, "ProofText"],
Cell[1075483, 22288, 798, 25, 70, "Conclusion",
  CellTags->"goal\[RawStar]\[RawStar]"],
Cell[1076284, 22315, 441, 7, 70, "SingleParagraph"],
Cell[1076728, 22324, 996, 24, 70, "InferenceRule"],

Cell[CellGroupData[{
Cell[1077749, 22352, 435, 10, 70, "Input"],
Cell[1078187, 22364, 935, 19, 70, "Output"]
}, Open  ]],
Cell[1079137, 22386, 253, 8, 70, "ProofText"],
Cell[1079393, 22396, 380, 13, 70, "ProofText"],
Cell[1079776, 22411, 370, 12, 70, "Conclusion",
  CellTags->"goal\[RawStar]\[RawStar]"],
Cell[1080149, 22425, 373, 9, 50, "SingleParagraph"],
Cell[1080525, 22436, 992, 22, 61, "InferenceRule"],

Cell[CellGroupData[{
Cell[1081542, 22462, 725, 15, 81, "Input"],
Cell[1082270, 22479, 3622, 74, 130, "Output"]
}, Open  ]],
Cell[1085907, 22556, 362, 13, 25, "ProofText"],
Cell[1086272, 22571, 378, 12, 19, "Assumption",
  CellTags->"a\[Dagger]"],
Cell[1086653, 22585, 826, 26, 25, "ProofText"],
Cell[1087482, 22613, 351, 12, 25, "Conclusion",
  CellTags->"goal\[RawStar]"],
Cell[1087836, 22627, 870, 21, 88, "SingleParagraph"],
Cell[1088709, 22650, 1018, 22, 61, "InferenceRule"],

Cell[CellGroupData[{
Cell[1089752, 22676, 694, 15, 81, "Input"],
Cell[1090449, 22693, 5344, 115, 141, "Output"]
}, Open  ]],
Cell[1095808, 22811, 1244, 39, 70, "ProofText"],
Cell[1097055, 22852, 780, 25, 70, "Conclusion",
  CellTags->"goal\[RawStar]"],
Cell[1097838, 22879, 151, 3, 70, "SingleParagraph"],
Cell[1097992, 22884, 970, 24, 55, "InferenceRule"],
Cell[1098965, 22910, 1212, 24, 155, "FirstParagraph"],
Cell[1100180, 22936, 1144, 18, 173, "Text"],

Cell[CellGroupData[{
Cell[1101349, 22958, 1327, 33, 50, "Input"],
Cell[1102679, 22993, 1097, 25, 126, "Output"]
}, Open  ]],
Cell[1103791, 23021, 536, 17, 27, "ProofText"],
Cell[1104330, 23040, 354, 12, 27, "Conclusion",
  CellTags->"goal\[RawStar](1)"],

Cell[CellGroupData[{
Cell[1104709, 23056, 454, 10, 50, "Input"],
Cell[1105166, 23068, 4237, 90, 70, "Output"]
}, Open  ]],
Cell[1109418, 23161, 93, 3, 70, "SingleParagraph"],
Cell[1109514, 23166, 541, 17, 70, "ProofText"],
Cell[1110058, 23185, 356, 12, 70, "Conclusion",
  CellTags->"goal\[RawStar](1)"],
Cell[1110417, 23199, 131, 3, 70, "SingleParagraph"],
Cell[1110551, 23204, 533, 17, 70, "ProofText"],
Cell[1111087, 23223, 348, 12, 25, "Conclusion",
  CellTags->"goal\[RawStar](2)"],
Cell[1111438, 23237, 130, 3, 31, "SingleParagraph"],
Cell[1111571, 23242, 538, 17, 25, "ProofText"],
Cell[1112112, 23261, 361, 12, 25, "Conclusion",
  CellTags->"goal\[RawStar](3)"],
Cell[1112476, 23275, 322, 6, 69, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1112823, 23285, 537, 11, 52, "Input"],
Cell[1113363, 23298, 4126, 85, 263, "Output"]
}, Open  ]],
Cell[1117504, 23386, 36, 0, 31, "SingleParagraph"],
Cell[1117543, 23388, 708, 21, 36, "ProofText"],
Cell[1118254, 23411, 428, 13, 30, "Conclusion",
  CellTags->"goal\[RawStar](1)"],
Cell[1118685, 23426, 36, 0, 31, "SingleParagraph"],
Cell[1118724, 23428, 702, 21, 29, "ProofText"],
Cell[1119429, 23451, 391, 12, 30, "Conclusion",
  CellTags->"goal\[RawStar](2)"],
Cell[1119823, 23465, 113, 3, 31, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1119961, 23472, 253, 4, 52, "Input"],
Cell[1120217, 23478, 1095, 25, 80, "Output"]
}, Open  ]],
Cell[1121327, 23506, 700, 21, 36, "ProofText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1122076, 23533, 83, 1, 59, "Section",
  CellTags->"c:28"],

Cell[CellGroupData[{
Cell[1122184, 23538, 62, 1, 53, "Subsection",
  CellTags->"Sec:TerminalND"],
Cell[1122249, 23541, 2352, 61, 208, "SingleParagraph"],
Cell[1124604, 23604, 1951, 53, 63, "DisplayFormula",
  CounterIncrements->"Figure"],
Cell[1126558, 23659, 1087, 39, 42, "TableHead",
  CellTags->"Fig:CommonInstance1"],
Cell[1127648, 23700, 860, 30, 50, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1128533, 23734, 136, 3, 39, "Input",
  Evaluatable->False],
Cell[1128672, 23739, 499, 15, 40, "Output"]
}, Open  ]],
Cell[1129186, 23757, 202, 4, 50, "SingleParagraph"],
Cell[1129391, 23763, 1404, 34, 55, "InferenceRule"],
Cell[1130798, 23799, 98, 1, 31, "SingleParagraph"],
Cell[1130899, 23802, 4437, 139, 215, "FirstParagraph"],
Cell[1135339, 23943, 54, 1, 31, "Text"],
Cell[1135396, 23946, 1581, 48, 100, "FirstParagraph"],
Cell[1136980, 23996, 1205, 39, 65, "Text"],

Cell[CellGroupData[{
Cell[1138210, 24039, 117, 2, 39, "Input"],
Cell[1138330, 24043, 901, 26, 40, "Output"]
}, Open  ]],
Cell[1139246, 24072, 1499, 43, 103, "SingleParagraph"],
Cell[1140748, 24117, 3451, 91, 131, "DisplayFormula",
  CounterIncrements->"Figure"],
Cell[1144202, 24210, 1096, 39, 44, "TableHead",
  CellTags->"Fig:CommonInstance2"],
Cell[1145301, 24251, 430, 8, 69, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1145756, 24263, 525, 12, 50, "Input"],
Cell[1146284, 24277, 252, 4, 59, "Output"]
}, Open  ]],
Cell[1146551, 24284, 267, 5, 58, "Input"],
Cell[1146821, 24291, 370, 13, 25, "ProofText"],
Cell[1147194, 24306, 306, 11, 19, "Assumption",
  CellTags->"assum\[LightBulb]"],
Cell[1147503, 24319, 385, 13, 25, "ProofText"],

Cell[CellGroupData[{
Cell[1147913, 24336, 865, 21, 52, "Input"],
Cell[1148781, 24359, 1166, 26, 80, "Output"]
}, Open  ]],
Cell[1149962, 24388, 1202, 26, 79, "Input"],
Cell[1151167, 24416, 370, 13, 25, "ProofText"],
Cell[1151540, 24431, 743, 25, 25, "Assumption",
  CellTags->"assum\[LightBulb]"],
Cell[1152286, 24458, 407, 13, 25, "ProofText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1152730, 24476, 65, 1, 53, "Subsection",
  CellTags->"c:30"],
Cell[1152798, 24479, 1462, 30, 171, "FirstParagraph"],
Cell[1154263, 24511, 645, 11, 107, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1154945, 24527, 62, 1, 53, "Subsection",
  CellTags->"c:31"],
Cell[1155010, 24530, 208, 4, 50, "SingleParagraph"],
Cell[1155221, 24536, 1312, 25, 165, "ItemizedText"],
Cell[1156536, 24563, 173, 4, 46, "ItemizedText"],
Cell[1156712, 24569, 178, 4, 46, "ItemizedText"],
Cell[1156893, 24575, 192, 4, 46, "ItemizedText"],
Cell[1157088, 24581, 202, 5, 42, "SingleParagraph"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

