(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7796,        205]*)
(*NotebookOutlinePosition[      9427,        255]*)
(*  CellTagsIndexPosition[      9359,        249]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[ButtonBox["\[UpperLeftArrow]",
  ButtonData:>{"Part2.nb", "c:1"},
  ButtonStyle->"Navigation",
  ButtonNote->"Part 2"]], "SingleParagraph",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
Part 3
Case Studies\
\>", "Title",
  CounterAssignments->{{"Section", 11}, {"Subtitle", 0}, {"Subsubtitle", 0}},
  CellTags->"c:1"],

Cell[TextData[{
  "In this part of the thesis, we show some case studies that have been \
carried out using the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Set Theory prover. The emphasis in these case studies lies on performing \
",
  StyleBox["entire explorations",
    FontSlant->"Italic"],
  " (see Section ",
  ButtonBox["3.2",
    ButtonData:>{"Part1.nb", "Sec:ViewOnProving"},
    ButtonStyle->"Hyperlink"],
  ") of some mathematical domains that involve some portion of set theory in \
their formulation. An entire exploration consists of ",
  StyleBox["several exploration cycles",
    FontSlant->"Italic"],
  " each relating a newly introduced notion with previously available \
notions. However, few examples in the style of ",
  StyleBox["isolated theorem proving",
    FontSlant->"Italic"],
  " are also given in order "
}], "SingleParagraph"],

Cell["to demonstrate specific features of the prover or", "ItemizedText"],

Cell["\<\
to show the performance of the prover on known benchmark problems \
compared to existing automated theorem proving systems.\
\>", "ItemizedText"],

Cell[TextData[{
  "The second part of the case studies covers the theory of equivalence \
relations, equivalence classes, partitions, and induced relations. Different \
approaches to exploring these fields needing different proofs have been \
carried out, using an intensional concept of a relation as a predicate in the \
sense of predicate logic in one approach, and an extensional concept of a \
relation as a set of pairs in the alternative approach. In the thesis, we \
present a mixture of the two approaches, using the intensional concept of a \
relation on a ",
  StyleBox["variable",
    FontSlant->"Italic"],
  " set for the first part and the extensional concept for the second part. \
The complete explorations for both approaches and their proofs are collected \
in a separate technical report, see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Wind01c",
            ButtonData:>"Wind01c",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "W. Windsteiger, 2001, Exploring Equivalence Relations and \
Partitions using the Theorema Se ..."],
          "Text"], TraditionalForm]]],
  "]. The case study of the mutilated checkerboard has its origin in a \
project note by John McCarthy, see [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["McCarthy64",
            ButtonData:>"McCarthy64",
            ButtonStyle->"RefLink",
            
            ButtonNote->
              "J. McCarthy, 1964, A Tough Nut for Proof Procedures"],
          "Text"], TraditionalForm]]],
  "], and it has been characterized as a benchmark problem for set theory \
provers or proof checkers, thus, we want to demonstrate, how a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " approach to its solution can work out."
}], "FirstParagraph"],

Cell[TextData[{
  "In the printed version of the document all proofs are ",
  StyleBox["inlined",
    FontSlant->"Italic"],
  " in the sense that they follow immediately after the corresponding Prove \
call. In the electronic version of the document, the proofs are stored in \
separate notebooks that are hyperlinked from this notebook. This follows the \
default behavior of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system, in which proofs are displayed by default in separate documents \
offering some interactive features. In the proof notebooks all features \
supported by the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " proof display function are fully functional, such as hyperlinking \
formulae by their labels and cell grouping corresponding to the proof \
structure, which of course are lost in the printout."
}], "Text"],

Cell[TextData[StyleBox["The proofs in both the printed and the electronic \
version are displayed exactly in the form as they were produced by the \
Theorema system evaluating the Prove call as shown in this document. No \
editing in whatever manner has been done on the proofs! ",
  FontSlant->"Italic"]], "Note"],

Cell["\<\
Timings given in the following sections correspond to experiments \
carried out on a Linux PC (400MHz) with 256 MB RAM memory. We set some \
options for Prove in order to keep the actual call a little shorter:\
\>", \
"Text"],

Cell[BoxData[
    \(SetOptions[
      Prove, \[IndentingNewLine]transformBy \[Rule] 
        ProofSimplifier, \[IndentingNewLine]TransformerOptions \[Rule] \
{branches \[Rule] Proved, 
          steps \[Rule] Useful}, \[IndentingNewLine]by \[Rule] 
        SetTheoryPCSProver]\)], "Input"],

Cell[TextData[{
  "which will have the effect that, unless specified differently in the call \
to Prove, the SetTheoryPCSProver will be used and all proofs will be \
simplified keeping only the succeeding branch and within a branch only the \
useful steps. In case the online version of the thesis is viewed, proof \
phases during the proof are visualized by different colors of the cell \
brackets: red stands for proof phase \"P\", green for phase \"C\", and orange \
brackets mean proof phase \"S\". Timings listed refer to the ",
  StyleBox["total elapsed",
    FontSlant->"Italic"],
  " computation time needed for the generation of the proof object, \
simplification the proof object, and the final display of the proof in \
natural language in a Mathematica notebook."
}], "SingleParagraph"],

Cell[TextData[ButtonBox["\[LowerRightArrow]",
  ButtonFunction:>(NotebookLocate[ #2]&),
  ButtonData:>{"CaseStudies-IsolatedTheorems.nb", "c:1"},
  ButtonStyle->"Navigation",
  ButtonNote->"Isolated Theorems"]], "SingleParagraph",
  TextAlignment->Right]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowSize->{959, 707},
WindowMargins->{{Automatic, 78}, {78, Automatic}},
PrintingStartingPageNumber->103,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Part 3: Case Studies"}], "Header"]}, {Cell[ 
        TextData[ {"Part 3: Case Studies"}], "Header"], Inherited, 
      Inherited}},
PrintingOptions->{"PrintingMargins"->{{79.1875, 79.1875}, {108, 108}},
"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", \
"wwindste", "Diss", "Main"}, "Part3.nb.ps", CharacterEncoding -> \
"ISO8859-1"],
"Magnification"->1},
Magnification->1,
StyleDefinitions -> "TheoremaSmartColors.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1930, 59, 141, 5, 160, "Title",
      CounterAssignments->{{"Section", 11}, {"Subtitle", 0}, {
          "Subsubtitle", 0}},
      CellTags->"c:1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 9175, 240}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 200, 5, 42, "SingleParagraph"],

Cell[CellGroupData[{
Cell[1930, 59, 141, 5, 160, "Title",
  CounterAssignments->{{"Section", 11}, {"Subtitle", 0}, {"Subsubtitle", 0}},
  CellTags->"c:1"],
Cell[2074, 66, 868, 22, 88, "SingleParagraph"],
Cell[2945, 90, 73, 0, 27, "ItemizedText"],
Cell[3021, 92, 155, 3, 27, "ItemizedText"],
Cell[3179, 97, 1831, 42, 133, "FirstParagraph"],
Cell[5013, 141, 862, 18, 107, "Text"],
Cell[5878, 161, 314, 4, 60, "Note"],
Cell[6195, 167, 235, 5, 50, "Text"],
Cell[6433, 174, 289, 6, 96, "Input"],
Cell[6725, 182, 798, 13, 107, "SingleParagraph"],
Cell[7526, 197, 254, 5, 42, "SingleParagraph"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

