(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     67677,       2328]*)
(*NotebookOutlinePosition[     68309,       2350]*)
(*  CellTagsIndexPosition[     68265,       2346]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default \
appearance of all cells in a given style.  Make modifications to any \
definition using commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
  LineSpacing->{1, 4},
  ParagraphSpacing->{0, 0},
  ScriptMinSize->9,
  FontSize->14],

Cell[StyleData[All, "Presentation"],
  PageWidth->WindowWidth,
  ShowCellBracket->False,
  LineSpacing->{1, 8},
  ParagraphSpacing->{0, 8},
  ScriptMinSize->12,
  FontSize->24],

Cell[StyleData[All, "PrintoutColor"],
  PageWidth->PaperWidth,
  LineSpacing->{1, 3},
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}],

Cell[StyleData[All, "PrintoutGray"],
  PageWidth->PaperWidth,
  LineSpacing->{1, 3},
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
  The options defined for the style below will be used at \
the Notebook level.  \
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Notebook"],
  PrintingStyleEnvironment->"PrintoutGray",
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PrintingOptions->{"PrintingMargins"->{{122, 122}, {144, 144}},
  "FirstPageHeader"->False,
  "FacingPages"->True},
  CellMargins->{{15, 15}, {Inherited, Inherited}},
  CellFrameLabelMargins->6,
  AutoItalicWords->{"Theorema", "THEOREMA"},
  LimitsPositioningTokens->{},
  AnimationDisplayTime->1.5,
  StyleMenuListing->None,
  Background->GrayLevel[0.949996]],

Cell[StyleData["Notebook", "Presentation"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PrintingOptions->{"PrintingMargins"->{{122, 122}, {144, 144}},
  "FirstPageHeader"->False,
  "FacingPages"->True},
  CellMargins->{{20, 20}, {Inherited, Inherited}},
  CellFrameLabelMargins->6,
  LimitsPositioningTokens->{},
  AnimationDisplayTime->1.5,
  StyleMenuListing->None,
  Background->GrayLevel[0.949996]],

Cell[StyleData["Notebook", "PrintoutColor"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PrintingOptions->{"PrintingMargins"->{{122, 122}, {144, 144}},
  "FirstPageHeader"->False,
  "FacingPages"->True},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {Inherited, Inherited}},
  CellFrameLabelMargins->6,
  LimitsPositioningTokens->{},
  AnimationDisplayTime->1.5,
  StyleMenuListing->None,
  Background->GrayLevel[0.949996]],

Cell[StyleData["Notebook", "PrintoutGray"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PrintingOptions->{"PrintingMargins"->{{122, 122}, {144, 144}},
  "FirstPageHeader"->False,
  "FacingPages"->True},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {Inherited, Inherited}},
  CellFrameLabelMargins->6,
  LimitsPositioningTokens->{},
  AnimationDisplayTime->1.5,
  StyleMenuListing->None,
  Background->GrayLevel[1]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{Inherited, Inherited}, {40, 30}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  TextAlignment->Center,
  LineSpacing->{1.2, 0},
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Subtitle", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->30,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontColor->RGBColor[0.180392, 0.392157, 0.780392]],

Cell[StyleData["Title", "Presentation"],
  CellMargins->{{Inherited, Inherited}, {20, 30}},
  FontSize->44],

Cell[StyleData["Title", "PrintoutColor"],
  CellMargins->{{Inherited, Inherited}, {20, 80}},
  TextAlignment->Left,
  LineSpacing->{2, 0},
  FontSize->14],

Cell[StyleData["Title", "PrintoutGray"],
  CellMargins->{{Inherited, Inherited}, {20, 80}},
  TextAlignment->Left,
  LineSpacing->{2, 0},
  FontSize->14,
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{Inherited, Inherited}, {10, 2}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  TextAlignment->Center,
  LineSpacing->{1.2, 0},
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->24,
  FontColor->RGBColor[0.0627451, 0.588235, 0.6]],

Cell[StyleData["Subtitle", "Presentation"],
  CellMargins->{{Inherited, Inherited}, {15, 2}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  TextAlignment->Center,
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->34,
  FontColor->RGBColor[0.0627451, 0.588235, 0.6]],

Cell[StyleData["Subtitle", "PrintoutColor"],
  CellMargins->{{Inherited, Inherited}, {2, 4}},
  FontSize->12],

Cell[StyleData["Subtitle", "PrintoutGray"],
  CellMargins->{{Inherited, Inherited}, {2, 4}},
  FontSize->12,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{Inherited, Inherited}, {15, 12}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  TextAlignment->Center,
  LineSpacing->{1.2, 0},
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 0.6]],

Cell[StyleData["Subsubtitle", "Presentation"],
  CellMargins->{{Inherited, Inherited}, {30, 12}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  TextAlignment->Center,
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->24,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 0.6]],

Cell[StyleData["Subsubtitle", "PrintoutColor"],
  CellMargins->{{Inherited, Inherited}, {2, 8}},
  FontSize->12],

Cell[StyleData["Subsubtitle", "PrintoutGray"],
  CellMargins->{{Inherited, Inherited}, {2, 8}},
  FontSize->12,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellMargins->{{Inherited, 0}, {8, 18}},
  CellElementSpacings->{"ClosedGroupTopMargin"->12},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameLabels->{{Inherited, None}, {None, None}},
  CellFrameLabelMargins->6,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  LineSpacing->{1.2, 0},
  CounterIncrements->"Section",
  CounterAssignments->{{"TableHead", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->22,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Presentation"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{Inherited, Inherited}, {20, 20}},
  CellElementSpacings->{"ClosedGroupTopMargin"->0},
  CellFrameLabels->{{None, Inherited}, {Inherited, Inherited}},
  FontSize->32],

Cell[StyleData["Section", "PrintoutColor"],
  CellFrame->False,
  CellMargins->{{0, Inherited}, {8, 18}},
  CellFrameLabels->{{Cell[ 
          TextData[ {
            CounterBox[ "Section"]}]], Inherited}, {
      Inherited, Inherited}},
  FontSize->12],

Cell[StyleData["Section", "PrintoutGray"],
  CellFrame->False,
  CellMargins->{{0, Inherited}, {8, 18}},
  CellFrameLabels->{{Cell[ 
          TextData[ {
            CounterBox[ "Section"]}]], Inherited}, {
      Inherited, Inherited}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellMargins->{{Inherited, Inherited}, {8, 18}},
  CellElementSpacings->{"ClosedGroupTopMargin"->12},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CellFrameLabels->{{Inherited, None}, {None, None}},
  CellFrameLabelMargins->6,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  LineSpacing->{1.2, 0},
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Presentation"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{Inherited, Inherited}, {15, 15}},
  CellFrameLabels->{{None, Inherited}, {Inherited, Inherited}},
  FontSize->26],

Cell[StyleData["Subsection", "PrintoutColor"],
  CellMargins->{{0, Inherited}, {6, 16}},
  CellFrameLabels->{{Cell[ 
          TextData[ {
            CounterBox[ "Section"], ".", 
            CounterBox[ "Subsection"]}]], Inherited}, {
      Inherited, Inherited}},
  FontSize->11],

Cell[StyleData["Subsection", "PrintoutGray"],
  CellMargins->{{0, Inherited}, {6, 16}},
  CellFrameLabels->{{Cell[ 
          TextData[ {
            CounterBox[ "Section"], ".", 
            CounterBox[ "Subsection"]}]], Inherited}, {
      Inherited, Inherited}},
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellMargins->{{Inherited, Inherited}, {6, 18}},
  CellElementSpacings->{"ClosedGroupTopMargin"->12},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CellFrameLabels->{{Inherited, None}, {None, None}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  LineSpacing->{1.2, 0},
  CounterIncrements->"Subsubsection",
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Presentation"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{Inherited, Inherited}, {0, 15}},
  CellFrameLabels->{{None, Inherited}, {Inherited, Inherited}},
  FontSize->19],

Cell[StyleData["Subsubsection", "PrintoutColor"],
  CellMargins->{{0, Inherited}, {4, 14}},
  CellFrameLabels->{{Cell[ 
          TextData[ {
            CounterBox[ "Section"], ".", 
            CounterBox[ "Subsection"], ".", 
            CounterBox[ "Subsubsection"]}]], Inherited}, {
      Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["Subsubsection", "PrintoutGray"],
  CellMargins->{{0, Inherited}, {4, 14}},
  CellFrameLabels->{{Cell[ 
          TextData[ {
            CounterBox[ "Section"], ".", 
            CounterBox[ "Subsection"], ".", 
            CounterBox[ "Subsubsection"]}]], Inherited}, {
      Inherited, Inherited}},
  FontSize->10]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{Inherited, Inherited}, {6, 6}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  TextJustification->1,
  Hyphenation->True,
  ParagraphIndent->15,
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Presentation"],
  CellMargins->{{Inherited, Inherited}, {6, 6}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  TextJustification->1,
  Hyphenation->True,
  ParagraphIndent->0,
  CounterIncrements->"Text"],

Cell[StyleData["Text", "PrintoutColor"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["Text", "PrintoutGray"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{Inherited, Inherited}, {6, 10}},
  TextJustification->1,
  LineSpacing->{1, 2},
  ParagraphSpacing->{0, 4},
  CounterIncrements->"SmallText",
  FontFamily->"Helvetica",
  FontSize->10],

Cell[StyleData["SmallText", "Presentation"],
  CellMargins->{{Inherited, Inherited}, {8, 8}},
  TextJustification->1,
  LineSpacing->{1, 5},
  ParagraphSpacing->{0, 8},
  FontSize->16],

Cell[StyleData["SmallText", "PrintoutColor"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}},
  TextJustification->1,
  FontSize->8],

Cell[StyleData["SmallText", "PrintoutGray"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}},
  TextJustification->1,
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FirstParagraph"],
  CellMargins->{{Inherited, Inherited}, {-6, 6}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  TextJustification->1,
  Hyphenation->True,
  ParagraphIndent->0,
  CounterIncrements->"Text"],

Cell[StyleData["FirstParagraph", "Presentation"],
  CellMargins->{{Inherited, Inherited}, {-6, 18}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  TextJustification->1,
  Hyphenation->True,
  CounterIncrements->"Text"],

Cell[StyleData["FirstParagraph", "PrintoutColor"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["FirstParagraph", "PrintoutGray"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SingleParagraph"],
  CellMargins->{{Inherited, Inherited}, {6, 6}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  TextJustification->1,
  Hyphenation->True,
  ParagraphIndent->0,
  CounterIncrements->"Text"],

Cell[StyleData["SingleParagraph", "Presentation"],
  CellMargins->{{Inherited, Inherited}, {6, 6}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  TextJustification->1,
  Hyphenation->True,
  CounterIncrements->"Text"],

Cell[StyleData["SingleParagraph", "PrintoutColor"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["SingleParagraph", "PrintoutGray"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TextNoindent"],
  CellMargins->{{Inherited, Inherited}, {6, 6}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  TextJustification->1,
  Hyphenation->True,
  ParagraphIndent->0,
  CounterIncrements->"Text"],

Cell[StyleData["TextNoindent", "Presentation"],
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  TextJustification->1,
  Hyphenation->True,
  CounterIncrements->"Text"],

Cell[StyleData["TextNoindent", "PrintoutColor"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["TextNoindent", "PrintoutGray"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["HighlightedText"],
  CellMargins->{{Inherited, Inherited}, {6, 6}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  Hyphenation->True,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["HighlightedText", "Presentation"]],

Cell[StyleData["HighlightedText", "PrintoutColor"]],

Cell[StyleData["HighlightedText", "PrintoutGray"],
  FontWeight->"Bold",
  FontColor->GrayLevel[0.299992]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["UnHighlightedText"],
  FontSize->10,
  FontColor->GrayLevel[0.659998]],

Cell[StyleData["UnHighlightedText", "Presentation"],
  FontSize->11,
  FontColor->GrayLevel[0.659998]],

Cell[StyleData["UnHighlightedText", "PrintoutColor"],
  FontSize->8,
  FontColor->GrayLevel[0.659998]],

Cell[StyleData["UnHighlightedText", "PrintoutGray"],
  FontSize->8,
  FontColor->GrayLevel[0.659998]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and \
output to the kernel.  Be careful when modifying, renaming, or \
removing these styles, because the front end associates special \
meanings with these style names.    \
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellFrame->1,
  ShowCellBracket->True,
  CellMargins->{{80, Inherited}, {0, 4}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelPositioning->Left,
  CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0.180392, 0.392157, 0.780392],
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->StandardForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  Background->RGBColor[1, 1, 0.917647]],

Cell[StyleData["Input", "Presentation"],
  CellFrame->1,
  CellMargins->{{Inherited, Inherited}, {0, 10}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0.180392, 0.392157, 0.780392],
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->StandardForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  FontWeight->"Plain",
  Background->RGBColor[1, 1, 0.917647]],

Cell[StyleData["Input", "PrintoutColor"],
  ShowCellBracket->False,
  CellMargins->{{20, Inherited}, {Inherited, 1}},
  ShowCellLabel->False,
  CellFrameMargins->{{8, 8}, {2, 2}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->9],

Cell[StyleData["Input", "PrintoutGray"],
  ShowCellBracket->False,
  CellMargins->{{20, Inherited}, {0, 1}},
  ShowCellLabel->False,
  CellFrameMargins->{{8, 8}, {2, 2}},
  CellFrameColor->GrayLevel[0.749996],
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->9,
  Background->GrayLevel[0.980011]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellFrame->{{1, 1}, {1, 0}},
  ShowCellBracket->True,
  CellMargins->{{80, Inherited}, {7, -1}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelPositioning->Left,
  CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0.180392, 0.392157, 0.780392],
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->StandardForm,
  CounterIncrements->"Output",
  Background->RGBColor[1, 1, 0.917647]],

Cell[StyleData["Output", "Presentation"],
  CellFrame->{{1, 1}, {1, 0}},
  CellMargins->{{Inherited, Inherited}, {10, Inherited}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0.180392, 0.392157, 0.780392],
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->StandardForm,
  CounterIncrements->"Output",
  Background->RGBColor[1, 1, 0.917647]],

Cell[StyleData["Output", "PrintoutColor"],
  ShowCellBracket->False,
  CellMargins->{{20, Inherited}, {1, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{8, 8}, {2, 2}},
  FontSize->9],

Cell[StyleData["Output", "PrintoutGray"],
  ShowCellBracket->False,
  CellMargins->{{20, Inherited}, {1, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{8, 8}, {2, 2}},
  CellFrameColor->GrayLevel[0.749996],
  FontSize->9,
  Background->GrayLevel[0.980011]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellFrame->{{1, 1}, {0, 0}},
  ShowCellBracket->True,
  CellMargins->{{80, Inherited}, {0, -1}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  CellFrameMargins->{{8, 8}, {4, 4}},
  CellFrameColor->RGBColor[0.180392, 0.392157, 0.780392],
  DefaultFormatType->StandardForm,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontSize->12,
  FontColor->RGBColor[1, 0, 0],
  Background->RGBColor[0.666667, 0.835294, 0.776471]],

Cell[StyleData["Message", "Presentation"],
  LineSpacing->{1, 0},
  FontSize->14],

Cell[StyleData["Message", "PrintoutColor"],
  ShowCellBracket->False,
  CellMargins->{{20, Inherited}, {-1, Inherited}},
  CellFrameMargins->{{8, 8}, {2, 2}},
  FontSize->8],

Cell[StyleData["Message", "PrintoutGray"],
  ShowCellBracket->False,
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  CellFrameMargins->{{8, 8}, {2, 2}},
  CellFrameColor->GrayLevel[0.749996],
  FontSize->8,
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.850004]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellFrame->{{1, 1}, {0, 0}},
  ShowCellBracket->True,
  CellMargins->{{80, Inherited}, {0, -1}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  CellFrameMargins->{{8, 8}, {4, 4}},
  CellFrameColor->RGBColor[0.180392, 0.392157, 0.780392],
  DefaultFormatType->StandardForm,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontColor->GrayLevel[0.2],
  Background->RGBColor[0.666667, 0.835294, 0.776471]],

Cell[StyleData["Print", "Presentation"],
  LineSpacing->{1, 0},
  FontSize->14],

Cell[StyleData["Print", "PrintoutColor"],
  ShowCellBracket->False,
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  CellFrameMargins->{{8, 8}, {2, 2}},
  FontSize->8],

Cell[StyleData["Print", "PrintoutGray"],
  ShowCellBracket->False,
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  CellFrameMargins->{{8, 8}, {2, 2}},
  CellFrameColor->GrayLevel[0.749996],
  FontSize->8,
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.850004]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  ShowCellBracket->True,
  CellMargins->{{80, 80}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageSize->{588, 294},
  StyleMenuListing->None,
  Background->GrayLevel[0.900008]],

Cell[StyleData["Graphics", "Presentation"],
  ImageSize->{250, 250},
  FontSize->9],

Cell[StyleData["Graphics", "PrintoutColor"],
  ShowCellBracket->False,
  CellMargins->{{30, 30}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontSize->9],

Cell[StyleData["Graphics", "PrintoutGray"],
  ShowCellBracket->False,
  CellMargins->{{30, 30}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->9,
  FontColor->RGBColor[0, 0.2, 1]],

Cell[StyleData["CellLabel", "Presentation"]],

Cell[StyleData["CellLabel", "PrintoutColor"],
  FontSize->7,
  FontSlant->"Oblique"],

Cell[StyleData["CellLabel", "PrintoutGray"],
  FontSize->7,
  FontSlant->"Oblique",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unique Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Table"],
  CellMargins->{{40, 4}, {2, 20}},
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  ShowStringCharacters->True,
  LineIndent->0,
  CounterIncrements->"TableHead",
  FontFamily->"Times",
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnAlignments->{Left}}],

Cell[StyleData["Table", "PrintoutColor"],
  CellMargins->{{Inherited, 0}, {2, 16}}],

Cell[StyleData["Table", "PrintoutGray"],
  CellMargins->{{Inherited, 0}, {2, 16}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["TableHead"],
  CellMargins->{{40, Inherited}, {15, Inherited}},
  PageBreakAbove->False,
  FontSize->10],

Cell[StyleData["TableHead", "Presentation"],
  FontSize->12],

Cell[StyleData["TableHead", "PrintoutColor"],
  CellMargins->{{Inherited, Inherited}, {12, Inherited}},
  FontSize->9],

Cell[StyleData["TableHead", "PrintoutGray"],
  CellMargins->{{Inherited, Inherited}, {12, Inherited}},
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["TableHeadText"],
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["TableHeadText", "Presentation"],
  FontSize->14],

Cell[StyleData["TableHeadText", "PrintoutColor"],
  FontSize->9],

Cell[StyleData["TableHeadText", "PrintoutGray"],
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["ColumnHead"],
  CounterIncrements->"Table",
  FontFamily->"Times",
  FontSlant->"Plain"],

Cell[StyleData["ColumnHead", "PrintoutGray"]],

Cell[StyleData["ColumnHead", "PrintoutColor"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TableText"],
  TextAlignment->Left,
  LineSpacing->{1, 1},
  ShowStringCharacters->True,
  FontFamily->"Times"],

Cell[StyleData["TableText", "PrintoutColor"]],

Cell[StyleData["TableText", "PrintoutGray"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TableTextFormula"],
  TextAlignment->Left,
  LineSpacing->{1, 1},
  AutoSpacing->True,
  ShowStringCharacters->True,
  SingleLetterItalics->True],

Cell[StyleData["TableTextFormula", "PrintoutColor"]],

Cell[StyleData["TableTextFormula", "PrintoutGray"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TableNote"],
  CellMargins->{{20, 10}, {7, 1}},
  LineSpacing->{1, 1},
  ParagraphSpacing->{0.3, 0},
  FontFamily->"Times",
  FontSize->10],

Cell[StyleData["TableNote", "Presentation"],
  FontSize->12],

Cell[StyleData["TableNote", "PrintoutColor"],
  FontSize->9],

Cell[StyleData["TableNote", "PrintoutGray"],
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnTable"],
  CellMargins->{{10, 4}, {2, 8}},
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  FontFamily->"Times",
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->{0.3, 0.7},
  ColumnAlignments->{Right, Left}}],

Cell[StyleData["2ColumnTable", "PrintoutColor"],
  CellMargins->{{2, 0}, {2, 8}}],

Cell[StyleData["2ColumnTable", "PrintoutGray"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnTable"],
  CellMargins->{{10, 4}, {2, 8}},
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  FontFamily->"Times",
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.33,
  ColumnAlignments->{Right, Center, Left}}],

Cell[StyleData["3ColumnTable", "PrintoutColor"],
  CellMargins->{{2, 0}, {2, 8}}],

Cell[StyleData["3ColumnTable", "PrintoutGray"],
  CellMargins->{{2, 0}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedText"],
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{35, Inherited}, {4, 4}},
  TextJustification->1,
  Hyphenation->True,
  ParagraphIndent->0,
  CounterIncrements->"Text"],

Cell[StyleData["ItemizedText", "Presentation"],
  CellMargins->{{40, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["ItemizedText", "PrintoutColor"]],

Cell[StyleData["ItemizedText", "PrintoutGray"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedTextNote"],
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{35, 4}, {0, 4}},
  Hyphenation->True,
  CounterIncrements->"Text"],

Cell[StyleData["ItemizedTextNote", "Presentation"]],

Cell[StyleData["ItemizedTextNote", "PrintoutColor"]],

Cell[StyleData["ItemizedTextNote", "PrintoutGray"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndentedText"],
  CellMargins->{{42, 4}, {3, 3}},
  TextJustification->1,
  Hyphenation->True,
  ParagraphIndent->0,
  CounterIncrements->"Text"],

Cell[StyleData["IndentedText", "Presentation"]],

Cell[StyleData["IndentedText", "PrintoutColor"],
  CellMargins->{{34, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["IndentedText", "PrintoutGray"],
  CellMargins->{{34, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Note"],
  CellFrame->True,
  CellMargins->{{10, 4}, {4, 4}},
  CellHorizontalScrolling->True,
  TextJustification->1,
  CounterIncrements->"Text",
  FontFamily->"Helvetica",
  FontSize->11],

Cell[StyleData["Note", "Presentation"],
  CellMargins->{{2, 4}, {Inherited, Inherited}},
  FontSize->16],

Cell[StyleData["Note", "PrintoutColor"],
  CellMargins->{{2, 4}, {Inherited, Inherited}},
  FontSize->10],

Cell[StyleData["Note", "PrintoutGray"],
  CellMargins->{{2, 4}, {Inherited, Inherited}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Author"],
  CellMargins->{{20, 30}, {45, 5}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CellFrameMargins->{{0, 4}, {8, 4}},
  TextAlignment->Center,
  LineSpacing->{1, 3},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSlant->"Italic"],

Cell[StyleData["Author", "Presentation"],
  CellMargins->{{20, 30}, {45, 10}}],

Cell[StyleData["Author", "PrintoutColor"],
  CellMargins->{{18, 30}, {45, 5}},
  FontSize->10],

Cell[StyleData["Author", "PrintoutGray"],
  CellMargins->{{18, 30}, {45, 5}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Address"],
  CellMargins->{{20, 30}, {45, -40}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CellFrameMargins->{{0, 4}, {8, 4}},
  TextAlignment->Center,
  LineSpacing->{1, 3},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSlant->"Italic"],

Cell[StyleData["Address", "Presentation"],
  CellMargins->{{20, 30}, {45, -40}}],

Cell[StyleData["Address", "PrintoutColor"],
  CellMargins->{{18, 30}, {45, -40}},
  FontSize->9],

Cell[StyleData["Address", "PrintoutGray"],
  CellMargins->{{18, 30}, {45, -40}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Abstract"],
  CellMargins->{{22, 22}, {4, 30}},
  CellFrameLabels->{{
    Inherited, Inherited}, {
      Inherited, Cell[ 
        "Abstract", FontWeight -> "Bold", CellSize -> {100, 20}]}},
  TextJustification->1,
  Hyphenation->True,
  ParagraphSpacing->{0, 5},
  ParagraphIndent->0,
  FontFamily->"Times"],

Cell[StyleData["Abstract", "Presentation"],
  CellMargins->{{27, 27}, {Inherited, 30}}],

Cell[StyleData["Abstract", "PrintoutColor"]],

Cell[StyleData["Abstract", "PrintoutGray"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Picture"],
  CellMargins->{{10, Inherited}, {0, 8}},
  CellHorizontalScrolling->True],

Cell[StyleData["Picture", "Presentation"],
  CellMargins->{{2, Inherited}, {0, 8}}],

Cell[StyleData["Picture", "PrintoutColor"],
  CellMargins->{{2, Inherited}, {0, 8}}],

Cell[StyleData["Picture", "PrintoutGray"],
  CellMargins->{{2, Inherited}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Caption"],
  CellMargins->{{10, 50}, {0, 3}},
  PageBreakAbove->False,
  Hyphenation->True,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Caption", "Presentation"],
  CellMargins->{{2, 50}, {2, 4}},
  FontSize->12],

Cell[StyleData["Caption", "PrintoutColor"],
  CellMargins->{{2, 50}, {2, 4}},
  FontSize->8],

Cell[StyleData["Caption", "PrintoutGray"],
  CellMargins->{{2, 50}, {2, 4}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MathCaption"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{16, 16}, {0, 14}},
  PageBreakBelow->False,
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 8},
  FontColor->RGBColor[0, 0, 0.6]],

Cell[StyleData["MathCaption", "Presentation"],
  CellMargins->{{42, 42}, {0, 14}},
  FontColor->GrayLevel[0]],

Cell[StyleData["MathCaption", "PrintoutColor"],
  CellMargins->{{4, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["MathCaption", "PrintoutGray"],
  CellMargins->{{4, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Contents and Index", "Section"],

Cell[CellGroupData[{

Cell[StyleData["ContentsTitle"],
  ShowGroupOpenCloseIcon->False,
  CellMargins->{{10, 4}, {0, 18}},
  CellGroupingRules->{"SectionGrouping", 60},
  LineSpacing->{1, 11},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->26,
  FontWeight->"Bold"],

Cell[StyleData["ContentsTitle", "PrintoutColor"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->18],

Cell[StyleData["ContentsTitle", "PrintoutGray"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ContentsSection"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{35, 4}, {3, 18}},
  CellGroupingRules->{"SectionGrouping", 70},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["ContentsSection", "PrintoutColor"],
  CellMargins->{{20, 0}, {3, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->11],

Cell[StyleData["ContentsSection", "PrintoutGray"],
  CellMargins->{{20, 0}, {3, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndexSection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{20, 4}, {5, 20}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["IndexSection", "PrintoutColor"],
  CellMargins->{{12, 0}, {5, 20}},
  PageBreakBelow->False,
  FontSize->12],

Cell[StyleData["IndexSection", "PrintoutGray"],
  CellMargins->{{12, 0}, {5, 20}},
  PageBreakBelow->False,
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Contents"],
  ShowGroupOpenCloseIcon->False,
  CellMargins->{{50, 4}, {0, 5}},
  CellGroupingRules->{"SectionGrouping", 90},
  StyleMenuListing->None],

Cell[StyleData["Contents", "PrintoutColor"],
  CellMargins->{{40, 5}, {0, 5}},
  FontFamily->"Palatino",
  FontSize->11],

Cell[StyleData["Contents", "PrintoutGray"],
  CellMargins->{{40, 5}, {0, 5}},
  FontFamily->"Palatino",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Index"],
  CellMargins->{{21, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["Index", "PrintoutColor"],
  CellMargins->{{13, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["Index", "PrintoutGray"],
  CellMargins->{{13, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndexSubentry"],
  CellMargins->{{36, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["IndexSubentry", "PrintoutColor"],
  CellMargins->{{24, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["IndexSubentry", "PrintoutGray"],
  CellMargins->{{24, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Proof Cells", "Section"],

Cell[CellGroupData[{

Cell[StyleData["ProofText"],
  CellMargins->{{12, 10}, {3, 3}},
  LineSpacing->{1, 3},
  ParagraphIndent->0,
  CounterIncrements->"Text",
  FontColor->GrayLevel[0]],

Cell[StyleData["ProofText", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["ProofText", "PrintoutColor"],
  CellMargins->{{2, 2}, {0, 1}},
  FontSize->9],

Cell[StyleData["ProofText", "PrintoutGray"],
  CellMargins->{{2, 2}, {0, 1}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Label"],
  CellMargins->{{20, 30}, {7, 7}},
  LineSpacing->{1, 3},
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Label", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["Label", "PrintoutColor"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1},
  FontSize->9],

Cell[StyleData["Label", "PrintoutGray"],
  CellMargins->{{2, 2}, {6, 6}},
  FontSize->9,
  FontColor->GrayLevel[0.500008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Conclusion"],
  CellMargins->{{12, 10}, {3, 3}},
  LineSpacing->{1, 3},
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Conclusion", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["Conclusion", "PrintoutColor"],
  CellMargins->{{8, 10}, {0, 1}},
  LineSpacing->{1, 1},
  FontSize->9],

Cell[StyleData["Conclusion", "PrintoutGray"],
  CellMargins->{{2, 2}, {0, 1}},
  FontSize->9,
  FontColor->GrayLevel[0.100008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Assumption"],
  CellMargins->{{12, 10}, {0, 0}},
  LineSpacing->{1, 3},
  FontColor->RGBColor[0.270588, 0.545098, 0.454902]],

Cell[StyleData["Assumption", "Presentation"],
  CellMargins->{{24, 10}, {0, 0}},
  LineSpacing->{1, 5}],

Cell[StyleData["Assumption", "PrintoutColor"],
  CellMargins->{{8, 10}, {0, 1}},
  LineSpacing->{1, 1},
  FontSize->9],

Cell[StyleData["Assumption", "PrintoutGray"],
  CellMargins->{{2, 2}, {0, 1}},
  FontSize->9,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Expression"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3}],

Cell[StyleData["Expression", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["Expression", "PrintoutColor"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1},
  FontSize->9],

Cell[StyleData["Expression", "PrintoutGray"],
  CellMargins->{{2, 2}, {6, 6}},
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Indent"],
  CellSize->{25, Inherited}],

Cell[StyleData["Indent", "Presentation"],
  CellSize->{30, Inherited}],

Cell[StyleData["Indent", "PrintoutColor"],
  CellSize->{15, Inherited}],

Cell[StyleData["Indent", "PrintoutGray"],
  CellSize->{15, Inherited}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Blank"],
  CellSize->{15, Inherited}],

Cell[StyleData["Blank", "Presentation"],
  CellSize->{20, Inherited}],

Cell[StyleData["Blank", "PrintoutColor"],
  CellSize->{10, Inherited}],

Cell[StyleData["Blank", "PrintoutGray"],
  CellSize->{10, Inherited}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Formulas, Numbered Stuff, and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{42, 85}, {Inherited, Inherited}},
  CellHorizontalScrolling->True,
  CellFrameMargins->20,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->TraditionalForm,
  ScriptLevel->0,
  SingleLetterItalics->True,
  SpanMaxSize->Infinity,
  UnderoverscriptBoxOptions->{LimitsPositioning->True},
  GridBoxOptions->{ColumnWidths->Automatic}],

Cell[StyleData["DisplayFormula", "Presentation"],
  CellMargins->{{34, 10}, {Inherited, Inherited}}],

Cell[StyleData["DisplayFormula", "PrintoutColor"],
  CellMargins->{{34, 4}, {Inherited, Inherited}}],

Cell[StyleData["DisplayFormula", "PrintoutGray"],
  CellMargins->{{34, 4}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["InferenceRule"],
  CellFrame->{{2, 0}, {0, 0}},
  CellMargins->{{Inherited, 85}, {Inherited, Inherited}},
  CellHorizontalScrolling->True,
  CellFrameMargins->{{10, 4}, {8, 8}},
  CellFrameColor->RGBColor[0, 0, 0.788235],
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->TraditionalForm,
  ScriptLevel->0,
  SingleLetterItalics->True,
  SpanMaxSize->Infinity,
  UnderoverscriptBoxOptions->{LimitsPositioning->True},
  GridBoxOptions->{ColumnWidths->Automatic}],

Cell[StyleData["InferenceRule", "Presentation"],
  CellMargins->{{Inherited, 10}, {Inherited, Inherited}}],

Cell[StyleData["InferenceRule", "PrintoutColor"],
  CellMargins->{{0, 4}, {Inherited, Inherited}}],

Cell[StyleData["InferenceRule", "PrintoutGray"],
  CellMargins->{{0, 4}, {Inherited, Inherited}},
  CellFrameColor->GrayLevel[0.500008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellMargins->{{42, 4}, {8, 8}},
  CellHorizontalScrolling->True,
  Hyphenation->False,
  LanguageCategory->"Formula",
  ShowStringCharacters->True,
  FontFamily->"Courier",
  FontSize->10],

Cell[StyleData["Program", "Presentation"],
  CellMargins->{{34, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["Program", "PrintoutColor"],
  CellMargins->{{34, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["Program", "PrintoutGray"],
  CellMargins->{{34, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MathematicaInput"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  Hyphenation->False,
  LanguageCategory->"Formula",
  FontFamily->"Courier",
  FontWeight->"Bold"],

Cell[StyleData["MathematicaInput", "Presentation"],
  CellMargins->{{2, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["MathematicaInput", "PrintoutColor"],
  CellMargins->{{2, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["MathematicaInput", "PrintoutGray"],
  CellMargins->{{2, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell["\<\
The following styles are useful for numbered equations, \
figures, etc.  They automatically give the cell a FrameLabel \
containing a reference to a particular counter, and also increment \
that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{42, 85}, {Inherited, Inherited}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False,
  FontFamily->"Times"],

Cell[StyleData["NumberedEquation", "Presentation"],
  CellMargins->{{34, 10}, {Inherited, 6}},
  LineSpacing->{1, 0}],

Cell[StyleData["NumberedEquation", "PrintoutColor"],
  CellMargins->{{34, 4}, {4, 4}}],

Cell[StyleData["NumberedEquation", "PrintoutGray"],
  CellMargins->{{34, 4}, {4, 4}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["NumberedFigure"],
  CellMargins->{{55, 95}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Figure ", 
            CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], 
        None}},
  CounterIncrements->"NumberedFigure",
  FormatTypeAutoConvert->False,
  FontFamily->"Times"],

Cell[StyleData["NumberedFigure", "Presentation"],
  CellMargins->{{60, 80}, {Inherited, 6}},
  LineSpacing->{1, 0}],

Cell[StyleData["NumberedFigure", "PrintoutColor"],
  CellMargins->{{18, 80}, {4, 4}},
  FontSize->8],

Cell[StyleData["NumberedFigure", "PrintoutGray"],
  CellMargins->{{18, 80}, {4, 4}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["NumberedTable"],
  CellMargins->{{55, 95}, {Inherited, Inherited}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Table ", 
            CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], 
        None}},
  TextAlignment->Center,
  CounterIncrements->"NumberedTable",
  FormatTypeAutoConvert->False,
  FontFamily->"Times"],

Cell[StyleData["NumberedTable", "Presentation"],
  CellMargins->{{60, 80}, {Inherited, 6}},
  LineSpacing->{1, 0}],

Cell[StyleData["NumberedTable", "PrintoutColor"],
  CellMargins->{{18, 80}, {4, 4}},
  FontSize->8],

Cell[StyleData["NumberedTable", "PrintoutGray"],
  CellMargins->{{18, 80}, {4, 4}},
  FontSize->8]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same \
Notebook, or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True,
  "StrikeThrough"->False},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonFrame->"None",
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "PrintoutColor"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Hyperlink", "PrintoutGray"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["RefLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True,
  "StrikeThrough"->False},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ {"Conclusion.nb", #2}]}]&),
  Active->True,
  ButtonFrame->"None",
  ButtonNote->ButtonData}],

Cell[StyleData["RefLink", "PrintoutColor"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefLink", "PrintoutGray"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Navigation"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontSize->24,
  FontColor->RGBColor[1, 0.650004, 0],
  FontVariations->{"StrikeThrough"->False},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Navigation", "PrintoutColor"],
  FontColor->GrayLevel[0.949996],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Navigation", "PrintoutGray"],
  FontColor->GrayLevel[1],
  FontVariations->{"Underline"->False}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "PrintoutColor"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLink", "PrintoutGray"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "PrintoutColor"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnsLink", "PrintoutGray"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "PrintoutColor"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefGuideLink", "PrintoutGray"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "PrintoutColor"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["GettingStartedLink", "PrintoutGray"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "PrintoutColor"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLink", "PrintoutGray"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Section"],

Cell["\<\
The cells below define styles that are mixed in with the \
styles of most cells.  If a cell's FormatType matches the name of one \
of the styles defined below, then that style is applied between the \
cell's style and its own options. This is particularly true of Input \
and Output.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  PageWidth->Infinity,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  AutoItalicWords->{},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->12,
  Background->GrayLevel[1]],

Cell[StyleData["InputForm"],
  AllowInlineCells->False,
  StyleMenuListing->None],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{0.6, 1},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["StandardForm"],
  InputAutoReplacements->{
    "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
      ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
      Inherited},
  LineSpacing->{1.25, 0},
  StyleMenuListing->None],

Cell[StyleData["TraditionalForm"],
  InputAutoReplacements->{
    "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
      ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
      Inherited},
  LineSpacing->{1.25, 0},
  AutoSpacing->True,
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None],

Cell["\<\
The style defined below is mixed in to any cell that is in \
an inline cell within another.\
\>", "Text"],

Cell[StyleData["InlineCell"],
  TextAlignment->Left,
  ScriptLevel->1,
  StyleMenuListing->None],

Cell[StyleData["InlineCellEditing"],
  StyleMenuListing->None,
  Background->RGBColor[1, 0.749996, 0.8]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 364}, {156, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 37, 0, 64, "Subtitle"],
Cell[1767, 54, 193, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[1985, 62, 42, 0, 60, "Section"],
Cell[2030, 64, 172, 5, 39, 31, 0, "StyleData", "All", "Working"],
Cell[2205, 71, 176, 6, 50, 36, 0, "StyleData", "All", "Presentation"],
Cell[2384, 79, 148, 4, 32, 37, 0, "StyleData", "All", "PrintoutColor"],
Cell[2535, 85, 147, 4, 32, 36, 0, "StyleData", "All", "PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2719, 94, 35, 0, 60, "Section"],
Cell[2757, 96, 105, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[2887, 103, 790, 20, 54, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None],
Cell[3680, 125, 717, 18, 54, 43, 0, "StyleData", "Notebook", "Presentation",
  StyleMenuListing->None],
Cell[4400, 145, 742, 19, 54, 44, 0, "StyleData", "Notebook", "PrintoutColor",
  StyleMenuListing->None],
Cell[5145, 166, 734, 19, 38, 43, 0, "StyleData", "Notebook", "PrintoutGray",
  StyleMenuListing->None]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5928, 191, 27, 0, 60, "Section"],

Cell[CellGroupData[{
Cell[5980, 195, 1202, 31, 123, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}],
Cell[7185, 228, 107, 2, 121, 40, 0, "StyleData", "Title", "Presentation"],
Cell[7295, 232, 154, 4, 132, 41, 0, "StyleData", "Title", "PrintoutColor"],
Cell[7452, 238, 180, 5, 132, 40, 0, "StyleData", "Title", "PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7669, 248, 1175, 29, 55, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[8847, 279, 1166, 28, 70, 43, 0, "StyleData", "Subtitle", "Presentation",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[10016, 309, 109, 2, 70, 44, 0, "StyleData", "Subtitle", \
"PrintoutColor"],
Cell[10128, 313, 135, 3, 70, 43, 0, "StyleData", "Subtitle", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[10300, 321, 1170, 30, 56, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[11473, 353, 1161, 29, 70, 46, 0, "StyleData", "Subsubtitle", \
"Presentation",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[12637, 384, 112, 2, 70, 47, 0, "StyleData", "Subsubtitle", \
"PrintoutColor"],
Cell[12752, 388, 138, 3, 70, 46, 0, "StyleData", "Subsubtitle", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[12927, 396, 1273, 31, 63, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"TableHead", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsection", 0}, {"Subsubsection", 0}}],
Cell[14203, 429, 257, 5, 96, 42, 0, "StyleData", "Section", "Presentation"],
Cell[14463, 436, 254, 7, 56, 43, 0, "StyleData", "Section", "PrintoutColor"],
Cell[14720, 445, 253, 7, 56, 42, 0, "StyleData", "Section", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[15010, 457, 1211, 30, 57, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[16224, 489, 208, 4, 78, 45, 0, "StyleData", "Subsection", \
"Presentation"],
Cell[16435, 495, 282, 7, 52, 46, 0, "StyleData", "Subsection", \
"PrintoutColor"],
Cell[16720, 504, 281, 7, 52, 45, 0, "StyleData", "Subsection", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[17038, 516, 1143, 28, 50, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[18184, 546, 210, 4, 55, 48, 0, "StyleData", "Subsubsection", \
"Presentation"],
Cell[18397, 552, 333, 8, 46, 49, 0, "StyleData", "Subsubsection", \
"PrintoutColor"],
Cell[18733, 562, 332, 8, 46, 48, 0, "StyleData", "Subsubsection", \
"PrintoutGray"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19114, 576, 23, 0, 60, "Section"],

Cell[CellGroupData[{
Cell[19162, 580, 924, 23, 42, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[20089, 605, 939, 23, 42, 39, 0, "StyleData", "Text", "Presentation",
  CounterIncrements->"Text"],
Cell[21031, 630, 97, 1, 42, 40, 0, "StyleData", "Text", "PrintoutColor"],
Cell[21131, 633, 96, 1, 42, 39, 0, "StyleData", "Text", "PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21264, 639, 230, 7, 44, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[21497, 648, 184, 5, 70, 44, 0, "StyleData", "SmallText", \
"Presentation"],
Cell[21684, 655, 141, 3, 70, 45, 0, "StyleData", "SmallText", \
"PrintoutColor"],
Cell[21828, 660, 140, 3, 70, 44, 0, "StyleData", "SmallText", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[22005, 668, 934, 23, 28, 33, 0, "StyleData", "FirstParagraph", "All",
  CounterIncrements->"Text"],
Cell[22942, 693, 929, 22, 70, 49, 0, "StyleData", "FirstParagraph", \
"Presentation",
  CounterIncrements->"Text"],
Cell[23874, 717, 107, 1, 70, 50, 0, "StyleData", "FirstParagraph", \
"PrintoutColor"],
Cell[23984, 720, 106, 1, 70, 49, 0, "StyleData", "FirstParagraph", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[24127, 726, 934, 23, 40, 34, 0, "StyleData", "SingleParagraph", "All",
  CounterIncrements->"Text"],
Cell[25064, 751, 928, 22, 70, 50, 0, "StyleData", "SingleParagraph", \
"Presentation",
  CounterIncrements->"Text"],
Cell[25995, 775, 108, 1, 70, 51, 0, "StyleData", "SingleParagraph", \
"PrintoutColor"],
Cell[26106, 778, 107, 1, 70, 50, 0, "StyleData", "SingleParagraph", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[26250, 784, 931, 23, 40, 31, 0, "StyleData", "TextNoindent", "All",
  CounterIncrements->"Text"],
Cell[27184, 809, 876, 21, 70, 47, 0, "StyleData", "TextNoindent", \
"Presentation",
  CounterIncrements->"Text"],
Cell[28063, 832, 105, 1, 70, 48, 0, "StyleData", "TextNoindent", \
"PrintoutColor"],
Cell[28171, 835, 104, 1, 70, 47, 0, "StyleData", "TextNoindent", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[28312, 841, 891, 21, 40, 34, 0, "StyleData", "HighlightedText", "All"],
Cell[29206, 864, 50, 0, 42, 50, 0, "StyleData", "HighlightedText", \
"Presentation"],
Cell[29259, 866, 51, 0, 42, 51, 0, "StyleData", "HighlightedText", \
"PrintoutColor"],
Cell[29313, 868, 106, 2, 42, 50, 0, "StyleData", "HighlightedText", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[29456, 875, 86, 2, 36, 36, 0, "StyleData", "UnHighlightedText", "All"],
Cell[29545, 879, 102, 2, 35, 52, 0, "StyleData", "UnHighlightedText", \
"Presentation"],
Cell[29650, 883, 102, 2, 33, 53, 0, "StyleData", "UnHighlightedText", \
"PrintoutColor"],
Cell[29755, 887, 101, 2, 33, 52, 0, "StyleData", "UnHighlightedText", \
"PrintoutGray"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29905, 895, 31, 0, 60, "Section"],
Cell[29939, 897, 252, 5, 68, "Text"],

Cell[CellGroupData[{
Cell[30216, 906, 734, 20, 52, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[30953, 928, 726, 19, 58, 40, 0, "StyleData", "Input", "Presentation",
  CounterIncrements->"Input"],
Cell[31682, 949, 239, 6, 32, 41, 0, "StyleData", "Input", "PrintoutColor"],
Cell[31924, 957, 304, 8, 32, 40, 0, "StyleData", "Input", "PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32265, 970, 714, 19, 53, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[32982, 991, 690, 17, 56, 41, 0, "StyleData", "Output", "Presentation",
  CounterIncrements->"Output"],
Cell[33675, 1010, 195, 5, 30, 42, 0, "StyleData", "Output", "PrintoutColor"],
Cell[33873, 1017, 268, 7, 30, 41, 0, "StyleData", "Output", "PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34178, 1029, 697, 20, 37, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[34878, 1051, 81, 2, 38, 42, 0, "StyleData", "Message", "Presentation"],
Cell[34962, 1055, 173, 4, 27, 43, 0, "StyleData", "Message", \
"PrintoutColor"],
Cell[35138, 1061, 280, 7, 28, 42, 0, "StyleData", "Message", "PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35455, 1073, 717, 21, 37, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[36175, 1096, 79, 2, 39, 40, 0, "StyleData", "Print", "Presentation"],
Cell[36257, 1100, 178, 4, 29, 41, 0, "StyleData", "Print", "PrintoutColor"],
Cell[36438, 1106, 278, 7, 29, 40, 0, "StyleData", "Print", "PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36753, 1118, 467, 14, 54, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[37223, 1134, 83, 2, 49, 43, 0, "StyleData", "Graphics", "Presentation"],
Cell[37309, 1138, 161, 4, 49, 44, 0, "StyleData", "Graphics", \
"PrintoutColor"],
Cell[37473, 1144, 160, 4, 49, 43, 0, "StyleData", "Graphics", "PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37670, 1153, 128, 4, 35, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[37801, 1159, 44, 0, 70, 44, 0, "StyleData", "CellLabel", \
"Presentation"],
Cell[37848, 1161, 84, 2, 70, 45, 0, "StyleData", "CellLabel", \
"PrintoutColor"],
Cell[37935, 1165, 110, 3, 70, 44, 0, "StyleData", "CellLabel", \
"PrintoutGray"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[38094, 1174, 32, 0, 60, "Section"],

Cell[CellGroupData[{
Cell[38151, 1178, 326, 11, 52, 24, 0, "StyleData", "Table", "All",
  CounterIncrements->"TableHead"],
Cell[38480, 1191, 83, 1, 48, 41, 0, "StyleData", "Table", "PrintoutColor"],
Cell[38566, 1194, 82, 1, 48, 40, 0, "StyleData", "Table", "PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38685, 1200, 120, 3, 47, 28, 0, "StyleData", "TableHead", "All"],
Cell[38808, 1205, 60, 1, 49, 44, 0, "StyleData", "TableHead", \
"Presentation"],
Cell[38871, 1208, 118, 2, 41, 45, 0, "StyleData", "TableHead", \
"PrintoutColor"],
Cell[38992, 1212, 117, 2, 41, 44, 0, "StyleData", "TableHead", \
"PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39146, 1219, 105, 3, 38, 32, 0, "StyleData", "TableHeadText", "All"],
Cell[39254, 1224, 64, 1, 40, 48, 0, "StyleData", "TableHeadText", \
"Presentation"],
Cell[39321, 1227, 64, 1, 35, 49, 0, "StyleData", "TableHeadText", \
"PrintoutColor"],
Cell[39388, 1230, 63, 1, 35, 48, 0, "StyleData", "TableHeadText", \
"PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39488, 1236, 104, 3, 38, 29, 0, "StyleData", "ColumnHead", "All",
  CounterIncrements->"Table"],
Cell[39595, 1241, 45, 0, 70, 45, 0, "StyleData", "ColumnHead", \
"PrintoutGray"],
Cell[39643, 1243, 46, 0, 70, 46, 0, "StyleData", "ColumnHead", \
"PrintoutColor"]
}, Closed]],

Cell[CellGroupData[{
Cell[39726, 1248, 127, 4, 38, 28, 0, "StyleData", "TableText", "All"],
Cell[39856, 1254, 45, 0, 70, 45, 0, "StyleData", "TableText", \
"PrintoutColor"],
Cell[39904, 1256, 44, 0, 70, 44, 0, "StyleData", "TableText", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[39985, 1261, 161, 5, 38, 35, 0, "StyleData", "TableTextFormula", "All"],
Cell[40149, 1268, 52, 0, 70, 52, 0, "StyleData", "TableTextFormula", \
"PrintoutColor"],
Cell[40204, 1270, 51, 0, 70, 51, 0, "StyleData", "TableTextFormula", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[40292, 1275, 155, 5, 39, 28, 0, "StyleData", "TableNote", "All"],
Cell[40450, 1282, 60, 1, 70, 44, 0, "StyleData", "TableNote", \
"Presentation"],
Cell[40513, 1285, 60, 1, 70, 45, 0, "StyleData", "TableNote", \
"PrintoutColor"],
Cell[40576, 1288, 59, 1, 70, 44, 0, "StyleData", "TableNote", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[40672, 1294, 303, 10, 36, 31, 0, "StyleData", "2ColumnTable", "All"],
Cell[40978, 1306, 81, 1, 70, 48, 0, "StyleData", "2ColumnTable", \
"PrintoutColor"],
Cell[41062, 1309, 80, 1, 70, 47, 0, "StyleData", "2ColumnTable", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[41179, 1315, 305, 10, 36, 31, 0, "StyleData", "3ColumnTable", "All"],
Cell[41487, 1327, 81, 1, 70, 48, 0, "StyleData", "3ColumnTable", \
"PrintoutColor"],
Cell[41571, 1330, 80, 1, 70, 47, 0, "StyleData", "3ColumnTable", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[41688, 1336, 208, 6, 38, 31, 0, "StyleData", "ItemizedText", "All",
  CounterIncrements->"Text"],
Cell[41899, 1344, 105, 1, 70, 47, 0, "StyleData", "ItemizedText", \
"Presentation"],
Cell[42007, 1347, 48, 0, 70, 48, 0, "StyleData", "ItemizedText", \
"PrintoutColor"],
Cell[42058, 1349, 47, 0, 70, 47, 0, "StyleData", "ItemizedText", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[42142, 1354, 158, 4, 34, 35, 0, "StyleData", "ItemizedTextNote", "All",
  CounterIncrements->"Text"],
Cell[42303, 1360, 51, 0, 70, 51, 0, "StyleData", "ItemizedTextNote", \
"Presentation"],
Cell[42357, 1362, 52, 0, 70, 52, 0, "StyleData", "ItemizedTextNote", \
"PrintoutColor"],
Cell[42412, 1364, 51, 0, 70, 51, 0, "StyleData", "ItemizedTextNote", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[42500, 1369, 161, 5, 37, 31, 0, "StyleData", "IndentedText", "All",
  CounterIncrements->"Text"],
Cell[42664, 1376, 47, 0, 70, 47, 0, "StyleData", "IndentedText", \
"Presentation"],
Cell[42714, 1378, 106, 1, 70, 48, 0, "StyleData", "IndentedText", \
"PrintoutColor"],
Cell[42823, 1381, 105, 1, 70, 47, 0, "StyleData", "IndentedText", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[42965, 1387, 205, 7, 54, 23, 0, "StyleData", "Note", "All",
  CounterIncrements->"Text"],
Cell[43173, 1396, 104, 2, 70, 39, 0, "StyleData", "Note", "Presentation"],
Cell[43280, 1400, 105, 2, 70, 40, 0, "StyleData", "Note", "PrintoutColor"],
Cell[43388, 1404, 104, 2, 70, 39, 0, "StyleData", "Note", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[43529, 1411, 345, 10, 79, 25, 0, "StyleData", "Author", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[43877, 1423, 78, 1, 70, 41, 0, "StyleData", "Author", "Presentation"],
Cell[43958, 1426, 94, 2, 70, 42, 0, "StyleData", "Author", "PrintoutColor"],
Cell[44055, 1430, 93, 2, 70, 41, 0, "StyleData", "Author", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[44185, 1437, 348, 10, 79, 26, 0, "StyleData", "Address", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[44536, 1449, 80, 1, 70, 42, 0, "StyleData", "Address", "Presentation"],
Cell[44619, 1452, 96, 2, 70, 43, 0, "StyleData", "Address", "PrintoutColor"],
Cell[44718, 1456, 95, 2, 70, 42, 0, "StyleData", "Address", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[44850, 1463, 324, 10, 64, 27, 0, "StyleData", "Abstract", "All"],
Cell[45177, 1475, 87, 1, 70, 43, 0, "StyleData", "Abstract", "Presentation"],
Cell[45267, 1478, 44, 0, 70, 44, 0, "StyleData", "Abstract", \
"PrintoutColor"],
Cell[45314, 1480, 43, 0, 70, 43, 0, "StyleData", "Abstract", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[45394, 1485, 101, 2, 34, 26, 0, "StyleData", "Picture", "All"],
Cell[45498, 1489, 83, 1, 70, 42, 0, "StyleData", "Picture", "Presentation"],
Cell[45584, 1492, 84, 1, 70, 43, 0, "StyleData", "Picture", "PrintoutColor"],
Cell[45671, 1495, 83, 1, 70, 42, 0, "StyleData", "Picture", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[45791, 1501, 149, 5, 31, 26, 0, "StyleData", "Caption", "All"],
Cell[45943, 1508, 92, 2, 70, 42, 0, "StyleData", "Caption", "Presentation"],
Cell[46038, 1512, 92, 2, 70, 43, 0, "StyleData", "Caption", "PrintoutColor"],
Cell[46133, 1516, 91, 2, 70, 42, 0, "StyleData", "Caption", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[46261, 1523, 215, 6, 34, 30, 0, "StyleData", "MathCaption", "All"],
Cell[46479, 1531, 109, 2, 70, 46, 0, "StyleData", "MathCaption", \
"Presentation"],
Cell[46591, 1535, 149, 4, 70, 47, 0, "StyleData", "MathCaption", \
"PrintoutColor"],
Cell[46743, 1541, 148, 4, 70, 46, 0, "StyleData", "MathCaption", \
"PrintoutGray"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[46940, 1551, 37, 0, 60, "Section"],

Cell[CellGroupData[{
Cell[47002, 1555, 261, 8, 66, 32, 0, "StyleData", "ContentsTitle", "All",
  StyleMenuListing->None],
Cell[47266, 1565, 148, 4, 70, 49, 0, "StyleData", "ContentsTitle", \
"PrintoutColor"],
Cell[47417, 1571, 147, 4, 70, 48, 0, "StyleData", "ContentsTitle", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[47601, 1580, 238, 7, 37, 34, 0, "StyleData", "ContentsSection", "All",
  StyleMenuListing->None],
Cell[47842, 1589, 151, 4, 70, 51, 0, "StyleData", "ContentsSection", \
"PrintoutColor"],
Cell[47996, 1595, 150, 4, 70, 50, 0, "StyleData", "ContentsSection", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[48183, 1604, 191, 6, 39, 31, 0, "StyleData", "IndexSection", "All",
  StyleMenuListing->None],
Cell[48377, 1612, 124, 3, 70, 48, 0, "StyleData", "IndexSection", \
"PrintoutColor"],
Cell[48504, 1617, 123, 3, 70, 47, 0, "StyleData", "IndexSection", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[48664, 1625, 166, 4, 34, 27, 0, "StyleData", "Contents", "All",
  StyleMenuListing->None],
Cell[48833, 1631, 120, 3, 70, 44, 0, "StyleData", "Contents", \
"PrintoutColor"],
Cell[48956, 1636, 119, 3, 70, 43, 0, "StyleData", "Contents", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[49112, 1644, 108, 3, 34, 24, 0, "StyleData", "Index", "All",
  StyleMenuListing->None],
Cell[49223, 1649, 117, 3, 70, 41, 0, "StyleData", "Index", "PrintoutColor"],
Cell[49343, 1654, 116, 3, 70, 40, 0, "StyleData", "Index", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[49496, 1662, 116, 3, 34, 32, 0, "StyleData", "IndexSubentry", "All",
  StyleMenuListing->None],
Cell[49615, 1667, 125, 3, 70, 49, 0, "StyleData", "IndexSubentry", \
"PrintoutColor"],
Cell[49743, 1672, 124, 3, 70, 48, 0, "StyleData", "IndexSubentry", \
"PrintoutGray"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[49916, 1681, 41, 0, 60, "Section"],

Cell[CellGroupData[{
Cell[49982, 1685, 164, 5, 36, 28, 0, "StyleData", "ProofText", "All",
  CounterIncrements->"Text"],
Cell[50149, 1692, 104, 2, 50, 44, 0, "StyleData", "ProofText", \
"Presentation"],
Cell[50256, 1696, 93, 2, 26, 45, 0, "StyleData", "ProofText", \
"PrintoutColor"],
Cell[50352, 1700, 92, 2, 26, 44, 0, "StyleData", "ProofText", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[50481, 1707, 114, 3, 41, 24, 0, "StyleData", "Label", "All"],
Cell[50598, 1712, 100, 2, 70, 40, 0, "StyleData", "Label", "Presentation"],
Cell[50701, 1716, 113, 3, 70, 41, 0, "StyleData", "Label", "PrintoutColor"],
Cell[50817, 1721, 122, 3, 70, 40, 0, "StyleData", "Label", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[50976, 1729, 119, 3, 37, 29, 0, "StyleData", "Conclusion", "All"],
Cell[51098, 1734, 105, 2, 70, 45, 0, "StyleData", "Conclusion", \
"Presentation"],
Cell[51206, 1738, 118, 3, 70, 46, 0, "StyleData", "Conclusion", \
"PrintoutColor"],
Cell[51327, 1743, 127, 3, 70, 45, 0, "StyleData", "Conclusion", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[51491, 1751, 140, 3, 34, 29, 0, "StyleData", "Assumption", "All"],
Cell[51634, 1756, 103, 2, 70, 45, 0, "StyleData", "Assumption", \
"Presentation"],
Cell[51740, 1760, 118, 3, 70, 46, 0, "StyleData", "Assumption", \
"PrintoutColor"],
Cell[51861, 1765, 120, 3, 70, 45, 0, "StyleData", "Assumption", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[52018, 1773, 87, 2, 41, 29, 0, "StyleData", "Expression", "All"],
Cell[52108, 1777, 105, 2, 50, 45, 0, "StyleData", "Expression", \
"Presentation"],
Cell[52216, 1781, 118, 3, 37, 46, 0, "StyleData", "Expression", \
"PrintoutColor"],
Cell[52337, 1786, 93, 2, 37, 45, 0, "StyleData", "Expression", \
"PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52467, 1793, 54, 1, 38, 25, 0, "StyleData", "Indent", "All"],
Cell[52524, 1796, 70, 1, 70, 41, 0, "StyleData", "Indent", "Presentation"],
Cell[52597, 1799, 71, 1, 70, 42, 0, "StyleData", "Indent", "PrintoutColor"],
Cell[52671, 1802, 70, 1, 70, 41, 0, "StyleData", "Indent", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[52778, 1808, 53, 1, 38, 24, 0, "StyleData", "Blank", "All"],
Cell[52834, 1811, 69, 1, 70, 40, 0, "StyleData", "Blank", "Presentation"],
Cell[52906, 1814, 70, 1, 70, 41, 0, "StyleData", "Blank", "PrintoutColor"],
Cell[52979, 1817, 69, 1, 70, 40, 0, "StyleData", "Blank", "PrintoutGray"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[53097, 1824, 60, 0, 60, "Section"],

Cell[CellGroupData[{
Cell[53182, 1828, 488, 12, 38, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[53673, 1842, 100, 1, 70, 49, 0, "StyleData", "DisplayFormula", \
"Presentation"],
Cell[53776, 1845, 100, 1, 70, 50, 0, "StyleData", "DisplayFormula", \
"PrintoutColor"],
Cell[53879, 1848, 99, 1, 70, 49, 0, "StyleData", "DisplayFormula", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[54015, 1854, 584, 14, 38, 32, 0, "StyleData", "InferenceRule", "All"],
Cell[54602, 1870, 106, 1, 70, 48, 0, "StyleData", "InferenceRule", \
"Presentation"],
Cell[54711, 1873, 98, 1, 70, 49, 0, "StyleData", "InferenceRule", \
"PrintoutColor"],
Cell[54812, 1876, 136, 2, 70, 48, 0, "StyleData", "InferenceRule", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[54985, 1883, 217, 7, 38, 26, 0, "StyleData", "Program", "All"],
Cell[55205, 1892, 100, 1, 70, 42, 0, "StyleData", "Program", "Presentation"],
Cell[55308, 1895, 101, 1, 70, 43, 0, "StyleData", "Program", \
"PrintoutColor"],
Cell[55412, 1898, 100, 1, 70, 42, 0, "StyleData", "Program", "PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[55549, 1904, 202, 6, 33, 35, 0, "StyleData", "MathematicaInput", "All"],
Cell[55754, 1912, 108, 1, 70, 51, 0, "StyleData", "MathematicaInput", \
"Presentation"],
Cell[55865, 1915, 109, 1, 70, 52, 0, "StyleData", "MathematicaInput", \
"PrintoutColor"],
Cell[55977, 1918, 108, 1, 70, 51, 0, "StyleData", "MathematicaInput", \
"PrintoutGray"]
}, Closed]],
Cell[56100, 1922, 227, 5, 65, "Text"],

Cell[CellGroupData[{
Cell[56352, 1931, 424, 9, 38, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[56779, 1942, 117, 2, 40, 51, 0, "StyleData", "NumberedEquation", \
"Presentation"],
Cell[56899, 1946, 86, 1, 38, 52, 0, "StyleData", "NumberedEquation", \
"PrintoutColor"],
Cell[56988, 1949, 85, 1, 38, 51, 0, "StyleData", "NumberedEquation", \
"PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57110, 1955, 338, 8, 60, 33, 0, "StyleData", "NumberedFigure", "All",
  CounterIncrements->"NumberedFigure"],
Cell[57451, 1965, 115, 2, 70, 49, 0, "StyleData", "NumberedFigure", \
"Presentation"],
Cell[57569, 1969, 100, 2, 70, 50, 0, "StyleData", "NumberedFigure", \
"PrintoutColor"],
Cell[57672, 1973, 99, 2, 70, 49, 0, "StyleData", "NumberedFigure", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[57808, 1980, 359, 9, 60, 32, 0, "StyleData", "NumberedTable", "All",
  CounterIncrements->"NumberedTable"],
Cell[58170, 1991, 114, 2, 70, 48, 0, "StyleData", "NumberedTable", \
"Presentation"],
Cell[58287, 1995, 99, 2, 70, 49, 0, "StyleData", "NumberedTable", \
"PrintoutColor"],
Cell[58389, 1999, 98, 2, 70, 48, 0, "StyleData", "NumberedTable", \
"PrintoutGray"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[58536, 2007, 35, 0, 60, "Section"],
Cell[58574, 2009, 184, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[58783, 2017, 351, 10, 38, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[59137, 2029, 112, 2, 38, 45, 0, "StyleData", "Hyperlink", \
"PrintoutColor"],
Cell[59252, 2033, 111, 2, 38, 44, 0, "StyleData", "Hyperlink", \
"PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59400, 2040, 368, 10, 38, 26, 0, "StyleData", "RefLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[59771, 2052, 110, 2, 38, 43, 0, "StyleData", "RefLink", \
"PrintoutColor"],
Cell[59884, 2056, 109, 2, 38, 42, 0, "StyleData", "RefLink", "PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60030, 2063, 331, 9, 50, 29, 0, "StyleData", "Navigation", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[60364, 2074, 120, 2, 50, 46, 0, "StyleData", "Navigation", \
"PrintoutColor"],
Cell[60487, 2078, 112, 2, 50, 45, 0, "StyleData", "Navigation", \
"PrintoutGray"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60636, 2085, 339, 9, 38, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[60978, 2096, 115, 2, 70, 48, 0, "StyleData", "MainBookLink", \
"PrintoutColor"],
Cell[61096, 2100, 114, 2, 70, 47, 0, "StyleData", "MainBookLink", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[61247, 2107, 358, 10, 38, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[61608, 2119, 113, 2, 38, 46, 0, "StyleData", "AddOnsLink", \
"PrintoutColor"],
Cell[61724, 2123, 112, 2, 38, 45, 0, "StyleData", "AddOnsLink", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[61873, 2130, 368, 10, 37, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[62244, 2142, 115, 2, 70, 48, 0, "StyleData", "RefGuideLink", \
"PrintoutColor"],
Cell[62362, 2146, 114, 2, 70, 47, 0, "StyleData", "RefGuideLink", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[62513, 2153, 374, 10, 38, 37, 0, "StyleData", "GettingStartedLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[62890, 2165, 121, 2, 70, 54, 0, "StyleData", "GettingStartedLink", \
"PrintoutColor"],
Cell[63014, 2169, 120, 2, 70, 53, 0, "StyleData", "GettingStartedLink", \
"PrintoutGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[63171, 2176, 378, 10, 38, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[63552, 2188, 123, 2, 70, 56, 0, "StyleData", "OtherInformationLink", \
"PrintoutColor"],
Cell[63678, 2192, 122, 2, 70, 55, 0, "StyleData", "OtherInformationLink", \
"PrintoutGray"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63849, 2200, 33, 0, 60, "Section"],
Cell[63885, 2202, 121, 3, 70, "Text"],
Cell[64009, 2207, 226, 5, 70, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[64238, 2214, 295, 7, 70, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[64536, 2223, 400, 9, 70, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[64939, 2234, 387, 9, 70, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[65329, 2245, 401, 9, 70, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[65767, 2259, 36, 0, 40, "Section"],
Cell[65806, 2261, 307, 6, 86, "Text"],
Cell[66116, 2269, 314, 10, 37, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None],
Cell[66433, 2281, 81, 2, 38, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[66517, 2285, 151, 5, 37, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[66671, 2292, 267, 6, 38, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[66941, 2300, 384, 10, 38, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[67328, 2312, 115, 3, 32, "Text"],
Cell[67446, 2317, 96, 3, 38, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None],
Cell[67545, 2322, 104, 2, 54, 36, 0, "StyleData", "InlineCellEditing", "All",
  StyleMenuListing->None]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

