(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13425,        354]*)
(*NotebookOutlinePosition[     82289,       2570]*)
(*  CellTagsIndexPosition[     82219,       2564]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "A Set Theory Prover in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ": \nImplementation and Practical Applications"
}], "Title"],

Cell["Dissertation", "Subsubtitle"],

Cell["zur Erlangung des akademischen Grades", "Text",
  TextAlignment->Center],

Cell["\"Doktor der technischen Wissenschaften\"", "Subsubtitle",
  CellMargins->{{Inherited, Inherited}, {55, 5}},
  TextAlignment->Center],

Cell["Eingereicht von", "Text",
  TextAlignment->Center],

Cell["Dipl.-Ing.  Wolfgang Windsteiger", "Author",
  CellMargins->{{15, 15}, {25, Inherited}}],

Cell["Mai 2001", "Author",
  CellMargins->{{15, 15}, {25, Inherited}}],

Cell[TextData[Cell[BoxData[GridBox[{
        {\(Erster\ \(\(Begutachter\)\(:\)\)\), \(o . Univ . Prof . \ Dr . 
              Dr . h . c\ Bruno\ BUCHBERGER\)},
        {\(Zweiter\ \(\(Begutachter\)\(:\)\)\), \(o . Univ . Prof . Dr . 
              G\[UDoubleDot]nter\ PILZ\)}
        }]]]], "SingleParagraph",
  CellMargins->{{Inherited, Inherited}, {40, 40}},
  TextAlignment->Center,
  TextJustification->0,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnAlignments->{Left}}],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Angefertigt\ \(\(am\)\(:\)\)\), \(Forschungsinstitut\ f\
\[UDoubleDot]r\ symbolisches\ Rechnen\)},
          {" ", \(Technisch\ Naturwissenschaftliche\ Fakult\[ADoubleDot]t\)},
          {" ", \(Johannes\ Kepler\ Universit\[ADoubleDot]t\ Linz\)}
          }], TraditionalForm]]]], "SingleParagraph",
  TextAlignment->Center,
  TextJustification->0,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnAlignments->{Left}}],

Cell[CellGroupData[{

Cell["Eidesstattliche Erkl\[ADoubleDot]rung", "Subtitle",
  CellMargins->{{Inherited, Inherited}, {Inherited, 100}},
  PageBreakAbove->True],

Cell["\<\
Ich erkl\[ADoubleDot]re, dass ich die Dissertation selbstst\
\[ADoubleDot]ndig verfasst habe, andere als die angegebenen Quellen und \
Hilfsmittel nicht verwendet und mich auch ansonsten keiner unerlaubten Hilfe \
bedient habe.

Linz, Mai 2001\
\>", "SingleParagraph"],

Cell["Wolfgang Windsteiger          ", "Text",
  TextAlignment->Right,
  TextJustification->0],

Cell["Abstract", "Subtitle",
  PageBreakAbove->True],

Cell[TextData[{
  "In this thesis we introduce the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Set Theory prover, a method for automatically generating proofs of \
statements involving notions from set theory and its implementation in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system. The method follows the known natural deduction paradigm for \
automated theorem proving, which aims at generating mechanized proofs in a \
style similar to human mathematicians. Moreover, the prover applies a \"Prove\
\[Dash]Compute\[Dash]Solve\"\[Dash]strategy, which has already been applied \
successfully for generating proofs in elementary analysis, structuring proofs \
into phases of"
}], "SingleParagraph"],

Cell[TextData[{
  "applying standard inference techniques from predicate logic (i.e. ",
  StyleBox["proving",
    FontSlant->"Italic"],
  ")",
  ","
}], "ItemizedText"],

Cell[TextData[{
  "rewriting formulae using assumptions from the knowledge base (i.e. ",
  StyleBox["computing",
    FontSlant->"Italic"],
  ", ",
  StyleBox["simplifying",
    FontSlant->"Italic"],
  ")",
  ", and"
}], "ItemizedText"],

Cell[TextData[{
  "applying powerful methods from computer algebra for solving existentially \
quantified formulae (i.e. ",
  StyleBox["solving",
    FontSlant->"Italic"],
  ")",
  "."
}], "ItemizedText"],

Cell[TextData[{
  "The entire method is implemented in the frame of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system, whose most important principles will be outlined in order to show \
the integration of set theory proving into the existing software system. The \
power of the method is shown in many examples, organized into entire \
explorations of mathematical theories based on the theory of sets. These \
explorations also show the feasibility of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "'s approach to support the entire cycle of mathematical activities and, in \
particular, the interplay between proving and computing in the same language \
and the same underlying logic."
}], "SingleParagraph"],

Cell[TextData[{
  StyleBox["Keywords:",
    FontWeight->"Bold"],
  " Automated theorem proving, set theory, symbolic computation, logic, ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "."
}], "SingleParagraph"],

Cell["Zusammenfassung", "Subtitle",
  PageBreakAbove->True],

Cell[TextData[{
  "In dieser Dissertation wird ein auf Mengenlehre spezialisierter Beweiser \
des ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Systems vorgestellt. Es handelt sich dabei um eine Methode zum \
automatischen Generieren von mathematischen Beweisen von S\[ADoubleDot]tzen, \
die in ihrer Formulierung Konstrukte aus der Mengenlehre enthalten, die im \
Rahmen des ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Systems vollst\[ADoubleDot]ndig implementiert wurde. Die Erstellung von \
Beweisen folgt dem bekannten Paradigma des nat\[UDoubleDot]rlichen \
Schlie\[SZ]ens aus dem Gebiet des automatischen Beweisens, das die Erstellung \
von Beweisen zum Ziel hat, die jenen von \"menschlichen\" Mathematikern \
\[ADoubleDot]hnlich sind. Weiters kommt in dieser Methode eine \
\"Prove\[Dash]Compute\[Dash]Solve\" Strategie zur Anwendung, die schon f\
\[UDoubleDot]r Beweise in elementarer Analysis erfolgreich angewendet wurde, \
die Beweise in Zyklen von"
}], "SingleParagraph"],

Cell[TextData[{
  "Anwendung elementarer Beweistechniken aus der Pr\[ADoubleDot]dikatenlogik \
(i.e. ",
  StyleBox["proving",
    FontSlant->"Italic"],
  ")",
  ","
}], "ItemizedText"],

Cell[TextData[{
  "Umformen von Formeln unter Verwendung von Annahmen aus der Wissensbasis \
(i.e. ",
  StyleBox["computing",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Simplifizieren",
    FontSlant->"Italic"],
  ")",
  " und"
}], "ItemizedText"],

Cell[TextData[{
  "Anwendung von m\[ADoubleDot]chtigen Methoden aus dem Gebiet der \
Computeralgebra zum L\[ODoubleDot]sen von existenziellen Formeln (i.e. ",
  StyleBox["solving",
    FontSlant->"Italic"],
  ")"
}], "ItemizedText"],

Cell[TextData[{
  "strukturiert. Die Methode ist im Rahmen des ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Systems vollst\[ADoubleDot]ndig implementiert, dessen wichtigste \
Prinzipien erkl\[ADoubleDot]rt werden, sodass die Integration des Mengenlehre\
\[Dash]Beweisens in das bestehende System gezeigt werden kann. Die St\
\[ADoubleDot]rke der Methode wird anhand vieler Beispiele demonstriert, die \
im Sinne von vollst\[ADoubleDot]ndiger Erkundung mathematischer Theorien, die \
auf Mengenlehre aufbauen, organisiert sind. Diese Studien zeigen auch die \
Verwendbarkeit des ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Systems als Hilfsmittel in allen Abschnitten des mathematischen \
Arbeitens. Insbesondere zeigt sich hier das Zusammenspiel von Beweisen und \
Rechnen im Rahmen ein und derselben Sprache und zugrundeliegender Logik."
}], "SingleParagraph"],

Cell[TextData[{
  StyleBox["Schlagworte:",
    FontWeight->"Bold"],
  " Automatisches Beweisen, Mengenlehre, Symbolisches Rechnen, Logik, ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "."
}], "SingleParagraph"],

Cell["Acknowledgement", "Subtitle",
  PageBreakAbove->True,
  CellTags->"c:2"],

Cell[TextData[{
  "This is now the place where one usually acknowledges the inspiring \
environment in the Castle of Hagenberg and thanks Bruno Buchberger to have \
created it. For a rather standard wording of this see for instance [",
  Cell[BoxData[
      FormBox[
        StyleBox[
          ButtonBox["Wind92",
            ButtonData:>{"Conclusion.nb", "Wind92"},
            ButtonStyle->"Hyperlink",
            
            ButtonNote->
              "Windsteiger, W., 1992, Gr\[ODoubleDot]bner Bases: A \
Characterization by Syzygy Completeness and an Imp ..."],
          "Text"], TraditionalForm]]],
  "]. I want to thank Bruno much less for creating it but for maintaining it \
through all the years, which is, I guess, much harder than creating it from \
the scratch with a lot of motivated people around. Keeping everything \
together and trying never to loose the focus on the aims and goals that have \
originally motivated people to contribute to the Hagenberg project must be \
much more cumbersome."
}], "FirstParagraph"],

Cell[TextData[{
  "Working in projects at RISC under Bruno's leadership since 1989 I've \
learned a lot, I hope. Firstly, of course, some portion of mathematics and \
computer science, but what is worth much more is the constant training on the \
model in being a researcher in symbolic computation able of handling all the \
non\[Dash]mathematical facets of day\[Dash]to\[Dash]day work as well. His \
training in organization, cooperation with other people, discussing, writing \
up things, and getting one's own mind clear was and still is very valuable. I \
always enjoyed working in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " group and I hope I will do so for quite some years more.\nAfter finishing \
my diploma in 1992, which is now more than 9 years ago, I could for sure have \
worked much more focussed on getting the PhD earlier, no doubt. Instead, I \
did some other things, such as teaching algorithmic mathematics with Bruno at \
the Fachhochschule, teaching Mathematica and other things at the University \
of Linz, working for a company in Hagenberg (thanks Herbert!), working in a \
project at the university (thanks G\[UDoubleDot]nter, thanks Peter, thanks \
Herbert, thanks Susanne, I liked that!), which I do not regret at all for a \
single second. Unfortunately, all these engagements made the PhD take quite \
some time, a fact, which my father never saw with much joy. He would have \
liked to see my PhD after 3 years, at the latest. I never took this very \
serious and always told him that he will see this happen, sometime. When I \
printed out the thesis yesterday and looked through it for a last time, I \
thought that he would possibly have liked it also and I was very sorry that \
he could not live until now to see it. Sorry, maybe you can \"see\" it by \
other means, although I'm not the type of person who believes in these \
things. Anyway \[Ellipsis] I'll give one printout to my mother as \
compensation for that.\nThe last couple of months were rather boring with me, \
I fear, since I always found some time to work on writing the thesis. This \
time was, in particular, very hard for my dear girl\[Dash]friend, since we \
could not often enjoy being outside on some mountain or cycling through  the \
country\[Dash]side together. Sorry, Cornelia, I'll catch up during the next \
weeks.\nFinally, I also want to thank myself for doing everything as I did."
}], "Text"],

Cell[TextData[{
  "The work described in this thesis has been carried out in the frame of the \
",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " project at the RISC institute, which is supported most prominently by the \
\"Spezialforschungsbereich for Numerical and Symbolic Scientific Computing\" \
(SFB F013) at the University of Linz, the \"PROVE Project\" supported by the \
regional government of Upper Austria, and the european union \"CALCULEMUS \
Project\" (HPRN\[Dash]CT\[Dash]2000\[Dash]00102)."
}], "SmallText",
  CellFrame->{{0, 0}, {0.25, 0.25}}]
}, Open  ]],

Cell[TextData[ButtonBox["\[LowerRightArrow]",
  ButtonData:>{"MasterTOC.nb", None},
  ButtonStyle->"Navigation",
  ButtonNote->"Table of Contents"]], "SingleParagraph",
  TextAlignment->Right,
  TextJustification->0]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{748, 731},
WindowMargins->{{29, Automatic}, {Automatic, 39}},
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page", CounterFunction :> (Part[ 
              CharacterRange[ "a", "z"], #]&)]}], "PageNumber"], Inherited, 
      None}, {None, Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page", CounterFunction :> (Part[ 
              CharacterRange[ "a", "z"], #]&)]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{121.938, 121.938}, {144, 144}},
"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FacingPages"->False,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", \
"wwindste", "Diss", "Main"}, "Titlepage.nb.ps", CharacterEncoding -> \
"ISO8859-1"],
"Magnification"->1},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 0},
    ScriptMinSize->9,
    FontSize->14],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    LineSpacing->{1, 8},
    ParagraphSpacing->{0, 8},
    ScriptMinSize->12,
    FontSize->24],
  
  Cell[StyleData[All, "PrintoutColor"],
    PageWidth->PaperWidth,
    LineSpacing->{1, 3},
    FontSize->11,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "PrintoutGray"],
    PageWidth->PaperWidth,
    LineSpacing->{1, 3},
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notebook"],
    PrintingStyleEnvironment->"PrintoutGray",
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"PrintingMargins"->{{122, 122}, {144, 144}},
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellMargins->{{15, 15}, {Inherited, Inherited}},
    CellFrameLabelMargins->6,
    AutoItalicWords->{"Theorema", "THEOREMA"},
    LimitsPositioningTokens->{},
    AnimationDisplayTime->1.5,
    StyleMenuListing->None,
    Background->GrayLevel[0.949996]],
  
  Cell[StyleData["Notebook", "Presentation"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"PrintingMargins"->{{122, 122}, {144, 144}},
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellMargins->{{20, 20}, {Inherited, Inherited}},
    CellFrameLabelMargins->6,
    LimitsPositioningTokens->{},
    AnimationDisplayTime->1.5,
    StyleMenuListing->None,
    Background->GrayLevel[0.949996]],
  
  Cell[StyleData["Notebook", "PrintoutColor"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"PrintingMargins"->{{122, 122}, {144, 144}},
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {Inherited, Inherited}},
    CellFrameLabelMargins->6,
    LimitsPositioningTokens->{},
    AnimationDisplayTime->1.5,
    StyleMenuListing->None,
    Background->GrayLevel[0.949996]],
  
  Cell[StyleData["Notebook", "PrintoutGray"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"PrintingMargins"->{{122, 122}, {144, 144}},
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {Inherited, Inherited}},
    CellFrameLabelMargins->6,
    LimitsPositioningTokens->{},
    AnimationDisplayTime->1.5,
    StyleMenuListing->None,
    Background->GrayLevel[1]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{Inherited, Inherited}, {40, 30}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{1.2, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}},
    
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0.180392, 0.392157, 0.780392]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{Inherited, Inherited}, {20, 30}},
    FontSize->44],
  
  Cell[StyleData["Title", "PrintoutColor"],
    CellMargins->{{Inherited, Inherited}, {20, 30}},
    LineSpacing->{1.5, 0},
    FontSize->14],
  
  Cell[StyleData["Title", "PrintoutGray"],
    CellMargins->{{Inherited, Inherited}, {20, 30}},
    LineSpacing->{1.5, 0},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{Inherited, Inherited}, {10, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{1.2, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0.0627451, 0.588235, 0.6]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{Inherited, Inherited}, {15, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->34,
    FontColor->RGBColor[0.0627451, 0.588235, 0.6]],
  
  Cell[StyleData["Subtitle", "PrintoutColor"],
    CellMargins->{{Inherited, Inherited}, {2, 4}},
    FontSize->12],
  
  Cell[StyleData["Subtitle", "PrintoutGray"],
    CellMargins->{{Inherited, Inherited}, {2, 4}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{Inherited, Inherited}, {15, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    LineSpacing->{1.2, 0},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{Inherited, Inherited}, {30, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "PrintoutColor"],
    CellMargins->{{Inherited, Inherited}, {2, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "PrintoutGray"],
    CellMargins->{{Inherited, Inherited}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{Inherited, 0}, {8, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabels->{{Inherited, None}, {None, None}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    LineSpacing->{1.2, 0},
    CounterIncrements->"Section",
    CounterAssignments->{{"TableHead", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->22,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{Inherited, Inherited}, {20, 20}},
    CellElementSpacings->{"ClosedGroupTopMargin"->0},
    CellFrameLabels->{{None, Inherited}, {Inherited, Inherited}},
    FontSize->32],
  
  Cell[StyleData["Section", "PrintoutColor"],
    CellFrame->False,
    CellMargins->{{0, Inherited}, {8, 18}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Section"]}]], Inherited}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["Section", "PrintoutGray"],
    CellFrame->False,
    CellMargins->{{0, Inherited}, {8, 18}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Section"]}]], Inherited}, {Inherited, Inherited}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{Inherited, Inherited}, {8, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabels->{{Inherited, None}, {None, None}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    LineSpacing->{1.2, 0},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{Inherited, Inherited}, {15, 15}},
    CellFrameLabels->{{None, Inherited}, {Inherited, Inherited}},
    FontSize->26],
  
  Cell[StyleData["Subsection", "PrintoutColor"],
    CellMargins->{{0, Inherited}, {6, 16}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Section"], ".", 
              CounterBox[ "Subsection"]}]], Inherited}, {
        Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Subsection", "PrintoutGray"],
    CellMargins->{{0, Inherited}, {6, 16}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Section"], ".", 
              CounterBox[ "Subsection"]}]], Inherited}, {
        Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{Inherited, Inherited}, {6, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabels->{{Inherited, None}, {None, None}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    LineSpacing->{1.2, 0},
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{Inherited, Inherited}, {0, 15}},
    CellFrameLabels->{{None, Inherited}, {Inherited, Inherited}},
    FontSize->19],
  
  Cell[StyleData["Subsubsection", "PrintoutColor"],
    CellMargins->{{0, Inherited}, {4, 14}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "PrintoutGray"],
    CellMargins->{{0, Inherited}, {4, 14}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{Inherited, Inherited}, {6, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{Inherited, Inherited}, {6, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->0,
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "PrintoutColor"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Text", "PrintoutGray"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{Inherited, Inherited}, {6, 10}},
    TextJustification->1,
    LineSpacing->{1, 2},
    ParagraphSpacing->{0, 4},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{Inherited, Inherited}, {8, 8}},
    TextJustification->1,
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 8},
    FontSize->16],
  
  Cell[StyleData["SmallText", "PrintoutColor"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    TextJustification->1,
    FontSize->8],
  
  Cell[StyleData["SmallText", "PrintoutGray"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    TextJustification->1,
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FirstParagraph"],
    CellMargins->{{Inherited, Inherited}, {-6, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->0,
    CounterIncrements->"Text"],
  
  Cell[StyleData["FirstParagraph", "Presentation"],
    CellMargins->{{Inherited, Inherited}, {-6, 18}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    CounterIncrements->"Text"],
  
  Cell[StyleData["FirstParagraph", "PrintoutColor"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["FirstParagraph", "PrintoutGray"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SingleParagraph"],
    CellMargins->{{Inherited, Inherited}, {6, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->0,
    CounterIncrements->"Text"],
  
  Cell[StyleData["SingleParagraph", "Presentation"],
    CellMargins->{{Inherited, Inherited}, {6, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    CounterIncrements->"Text"],
  
  Cell[StyleData["SingleParagraph", "PrintoutColor"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["SingleParagraph", "PrintoutGray"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextNoindent"],
    CellMargins->{{Inherited, Inherited}, {6, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->0,
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextNoindent", "Presentation"],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextNoindent", "PrintoutColor"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["TextNoindent", "PrintoutGray"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["HighlightedText"],
    CellMargins->{{Inherited, Inherited}, {6, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    Hyphenation->True,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["HighlightedText", "Presentation"]],
  
  Cell[StyleData["HighlightedText", "PrintoutColor"]],
  
  Cell[StyleData["HighlightedText", "PrintoutGray"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0.6]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UnHighlightedText"],
    FontSize->10,
    FontColor->GrayLevel[0.659998]],
  
  Cell[StyleData["UnHighlightedText", "Presentation"],
    FontSize->11,
    FontColor->GrayLevel[0.659998]],
  
  Cell[StyleData["UnHighlightedText", "PrintoutColor"],
    FontSize->8,
    FontColor->GrayLevel[0.659998]],
  
  Cell[StyleData["UnHighlightedText", "PrintoutGray"],
    FontSize->8,
    FontColor->GrayLevel[0.659998]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->1,
    ShowCellBracket->True,
    CellMargins->{{80, Inherited}, {0, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelPositioning->Left,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.180392, 0.392157, 0.780392],
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    Background->RGBColor[1, 1, 0.917647]],
  
  Cell[StyleData["Input", "Presentation"],
    CellFrame->1,
    CellMargins->{{Inherited, Inherited}, {0, 10}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.180392, 0.392157, 0.780392],
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Plain",
    Background->RGBColor[1, 1, 0.917647]],
  
  Cell[StyleData["Input", "PrintoutColor"],
    ShowCellBracket->False,
    CellMargins->{{20, Inherited}, {Inherited, 1}},
    ShowCellLabel->False,
    CellFrameMargins->{{8, 8}, {2, 2}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["Input", "PrintoutGray"],
    ShowCellBracket->False,
    CellMargins->{{20, Inherited}, {0, 1}},
    ShowCellLabel->False,
    CellFrameMargins->{{8, 8}, {2, 2}},
    CellFrameColor->GrayLevel[0.749996],
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9,
    Background->GrayLevel[0.980011]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{1, 1}, {1, 0}},
    ShowCellBracket->True,
    CellMargins->{{80, Inherited}, {7, -1}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.180392, 0.392157, 0.780392],
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0.917647]],
  
  Cell[StyleData["Output", "Presentation"],
    CellFrame->{{1, 1}, {1, 0}},
    CellMargins->{{Inherited, Inherited}, {10, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.180392, 0.392157, 0.780392],
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0.917647]],
  
  Cell[StyleData["Output", "PrintoutColor"],
    ShowCellBracket->False,
    CellMargins->{{20, Inherited}, {1, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{8, 8}, {2, 2}},
    FontSize->9],
  
  Cell[StyleData["Output", "PrintoutGray"],
    ShowCellBracket->False,
    CellMargins->{{20, Inherited}, {1, Inherited}},
    ShowCellLabel->False,
    CellFrameMargins->{{8, 8}, {2, 2}},
    CellFrameColor->GrayLevel[0.749996],
    FontSize->9,
    Background->GrayLevel[0.980011]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellFrame->{{1, 1}, {0, 0}},
    ShowCellBracket->True,
    CellMargins->{{80, Inherited}, {0, -1}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->{{8, 8}, {4, 4}},
    CellFrameColor->RGBColor[0.180392, 0.392157, 0.780392],
    DefaultFormatType->StandardForm,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->12,
    FontColor->RGBColor[1, 0, 0],
    Background->RGBColor[0.666667, 0.835294, 0.776471]],
  
  Cell[StyleData["Message", "Presentation"],
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Message", "PrintoutColor"],
    ShowCellBracket->False,
    CellMargins->{{20, Inherited}, {-1, Inherited}},
    CellFrameMargins->{{8, 8}, {2, 2}},
    FontSize->8],
  
  Cell[StyleData["Message", "PrintoutGray"],
    ShowCellBracket->False,
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->{{8, 8}, {2, 2}},
    CellFrameColor->GrayLevel[0.749996],
    FontSize->8,
    FontColor->GrayLevel[0],
    Background->GrayLevel[0.850004]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellFrame->{{1, 1}, {0, 0}},
    ShowCellBracket->True,
    CellMargins->{{80, Inherited}, {0, -1}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->{{8, 8}, {4, 4}},
    CellFrameColor->RGBColor[0.180392, 0.392157, 0.780392],
    DefaultFormatType->StandardForm,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontColor->GrayLevel[0.2],
    Background->RGBColor[0.666667, 0.835294, 0.776471]],
  
  Cell[StyleData["Print", "Presentation"],
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Print", "PrintoutColor"],
    ShowCellBracket->False,
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->{{8, 8}, {2, 2}},
    FontSize->8],
  
  Cell[StyleData["Print", "PrintoutGray"],
    ShowCellBracket->False,
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->{{8, 8}, {2, 2}},
    CellFrameColor->GrayLevel[0.749996],
    FontSize->8,
    FontColor->GrayLevel[0],
    Background->GrayLevel[0.850004]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{80, 80}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageSize->{588, 294},
    StyleMenuListing->None,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageSize->{250, 250},
    FontSize->9],
  
  Cell[StyleData["Graphics", "PrintoutColor"],
    ShowCellBracket->False,
    CellMargins->{{30, 30}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontSize->9],
  
  Cell[StyleData["Graphics", "PrintoutGray"],
    ShowCellBracket->False,
    CellMargins->{{30, 30}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"]],
  
  Cell[StyleData["CellLabel", "PrintoutColor"],
    FontSize->7,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "PrintoutGray"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    CellMargins->{{40, 4}, {2, 20}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    ShowStringCharacters->True,
    LineIndent->0,
    CounterIncrements->"TableHead",
    FontFamily->"Times",
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["Table", "PrintoutColor"],
    CellMargins->{{Inherited, 0}, {2, 16}}],
  
  Cell[StyleData["Table", "PrintoutGray"],
    CellMargins->{{Inherited, 0}, {2, 16}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableHead"],
    CellMargins->{{40, Inherited}, {15, Inherited}},
    PageBreakAbove->False,
    FontSize->10],
  
  Cell[StyleData["TableHead", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["TableHead", "PrintoutColor"],
    CellMargins->{{Inherited, Inherited}, {12, Inherited}},
    FontSize->9],
  
  Cell[StyleData["TableHead", "PrintoutGray"],
    CellMargins->{{Inherited, Inherited}, {12, Inherited}},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableHeadText"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TableHeadText", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["TableHeadText", "PrintoutColor"],
    FontSize->9],
  
  Cell[StyleData["TableHeadText", "PrintoutGray"],
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ColumnHead"],
    CounterIncrements->"Table",
    FontFamily->"Times",
    FontSlant->"Plain"],
  
  Cell[StyleData["ColumnHead", "PrintoutGray"]],
  
  Cell[StyleData["ColumnHead", "PrintoutColor"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableText"],
    TextAlignment->Left,
    LineSpacing->{1, 1},
    ShowStringCharacters->True,
    FontFamily->"Times"],
  
  Cell[StyleData["TableText", "PrintoutColor"]],
  
  Cell[StyleData["TableText", "PrintoutGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableTextFormula"],
    TextAlignment->Left,
    LineSpacing->{1, 1},
    AutoSpacing->True,
    ShowStringCharacters->True,
    SingleLetterItalics->True],
  
  Cell[StyleData["TableTextFormula", "PrintoutColor"]],
  
  Cell[StyleData["TableTextFormula", "PrintoutGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TableNote"],
    CellMargins->{{20, 10}, {7, 1}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0.3, 0},
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["TableNote", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["TableNote", "PrintoutColor"],
    FontSize->9],
  
  Cell[StyleData["TableNote", "PrintoutGray"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontFamily->"Times",
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->{0.3, 0.7},
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnTable", "PrintoutColor"],
    CellMargins->{{2, 0}, {2, 8}}],
  
  Cell[StyleData["2ColumnTable", "PrintoutGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontFamily->"Times",
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.33,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnTable", "PrintoutColor"],
    CellMargins->{{2, 0}, {2, 8}}],
  
  Cell[StyleData["3ColumnTable", "PrintoutGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{35, Inherited}, {4, 4}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->0,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Presentation"],
    CellMargins->{{40, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["ItemizedText", "PrintoutColor"]],
  
  Cell[StyleData["ItemizedText", "PrintoutGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{35, 4}, {0, 4}},
    Hyphenation->True,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Presentation"]],
  
  Cell[StyleData["ItemizedTextNote", "PrintoutColor"]],
  
  Cell[StyleData["ItemizedTextNote", "PrintoutGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{42, 4}, {3, 3}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->0,
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Presentation"]],
  
  Cell[StyleData["IndentedText", "PrintoutColor"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["IndentedText", "PrintoutGray"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {4, 4}},
    CellHorizontalScrolling->True,
    TextJustification->1,
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->11],
  
  Cell[StyleData["Note", "Presentation"],
    CellMargins->{{2, 4}, {Inherited, Inherited}},
    FontSize->16],
  
  Cell[StyleData["Note", "PrintoutColor"],
    CellMargins->{{2, 4}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Note", "PrintoutGray"],
    CellMargins->{{2, 4}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{20, 20}, {45, 5}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 4}, {8, 4}},
    TextAlignment->Center,
    LineSpacing->{1, 3},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{20, 20}, {45, 10}}],
  
  Cell[StyleData["Author", "PrintoutColor"],
    CellMargins->{{20, 20}, {45, 5}},
    FontSize->10],
  
  Cell[StyleData["Author", "PrintoutGray"],
    CellMargins->{{20, 20}, {45, 5}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{20, 20}, {45, -40}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 4}, {8, 4}},
    TextAlignment->Center,
    LineSpacing->{1, 3},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    CellMargins->{{20, 20}, {45, -40}}],
  
  Cell[StyleData["Address", "PrintoutColor"],
    CellMargins->{{18, 20}, {45, -40}},
    FontSize->9],
  
  Cell[StyleData["Address", "PrintoutGray"],
    CellMargins->{{20, 20}, {45, -40}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{22, 22}, {4, 30}},
    CellFrameLabels->{{
      Inherited, Inherited}, {
        Inherited, Cell[ 
          "Abstract", FontWeight -> "Bold", CellSize -> {100, 20}]}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphSpacing->{0, 5},
    ParagraphIndent->0,
    FontFamily->"Times"],
  
  Cell[StyleData["Abstract", "Presentation"],
    CellMargins->{{27, 27}, {Inherited, 30}}],
  
  Cell[StyleData["Abstract", "PrintoutColor"]],
  
  Cell[StyleData["Abstract", "PrintoutGray"]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Presentation"],
    CellMargins->{{2, Inherited}, {0, 8}}],
  
  Cell[StyleData["Picture", "PrintoutColor"],
    CellMargins->{{2, Inherited}, {0, 8}}],
  
  Cell[StyleData["Picture", "PrintoutGray"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Presentation"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->12],
  
  Cell[StyleData["Caption", "PrintoutColor"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->8],
  
  Cell[StyleData["Caption", "PrintoutGray"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{16, 16}, {0, 14}},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Presentation"],
    CellMargins->{{42, 42}, {0, 14}},
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["MathCaption", "PrintoutColor"],
    CellMargins->{{4, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["MathCaption", "PrintoutGray"],
    CellMargins->{{4, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{10, 4}, {0, 18}},
    CellGroupingRules->{"SectionGrouping", 60},
    LineSpacing->{1, 11},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->26,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "PrintoutColor"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->18],
  
  Cell[StyleData["ContentsTitle", "PrintoutGray"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{35, 4}, {3, 18}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "PrintoutColor"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->11],
  
  Cell[StyleData["ContentsSection", "PrintoutGray"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "PrintoutColor"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12],
  
  Cell[StyleData["IndexSection", "PrintoutGray"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{50, 4}, {0, 5}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "PrintoutColor"],
    CellMargins->{{40, 5}, {0, 5}},
    FontFamily->"Palatino",
    FontSize->11],
  
  Cell[StyleData["Contents", "PrintoutGray"],
    CellMargins->{{40, 5}, {0, 5}},
    FontFamily->"Palatino",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "PrintoutColor"],
    CellMargins->{{13, 0}, {0, 0}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["Index", "PrintoutGray"],
    CellMargins->{{13, 0}, {0, 0}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "PrintoutColor"],
    CellMargins->{{24, 0}, {0, 0}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["IndexSubentry", "PrintoutGray"],
    CellMargins->{{24, 0}, {0, 0}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Proof Cells", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProofText"],
    CellMargins->{{12, 10}, {3, 3}},
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"Text",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["ProofText", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["ProofText", "PrintoutColor"],
    CellMargins->{{2, 2}, {0, 1}},
    FontSize->9],
  
  Cell[StyleData["ProofText", "PrintoutGray"],
    CellMargins->{{2, 2}, {0, 1}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Label"],
    CellMargins->{{20, 30}, {7, 7}},
    LineSpacing->{1, 3},
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Label", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Label", "PrintoutColor"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->9],
  
  Cell[StyleData["Label", "PrintoutGray"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->9,
    FontColor->GrayLevel[0.500008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Conclusion"],
    CellMargins->{{12, 10}, {3, 3}},
    LineSpacing->{1, 3},
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Conclusion", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Conclusion", "PrintoutColor"],
    CellMargins->{{8, 10}, {0, 1}},
    LineSpacing->{1, 1},
    FontSize->9],
  
  Cell[StyleData["Conclusion", "PrintoutGray"],
    CellMargins->{{2, 2}, {0, 1}},
    FontSize->9,
    FontColor->GrayLevel[0.100008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Assumption"],
    CellMargins->{{12, 10}, {0, 0}},
    LineSpacing->{1, 3},
    FontColor->RGBColor[0.270588, 0.545098, 0.454902]],
  
  Cell[StyleData["Assumption", "Presentation"],
    CellMargins->{{24, 10}, {0, 0}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Assumption", "PrintoutColor"],
    CellMargins->{{8, 10}, {0, 1}},
    LineSpacing->{1, 1},
    FontSize->9],
  
  Cell[StyleData["Assumption", "PrintoutGray"],
    CellMargins->{{2, 2}, {0, 1}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Expression"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3}],
  
  Cell[StyleData["Expression", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Expression", "PrintoutColor"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->9],
  
  Cell[StyleData["Expression", "PrintoutGray"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Indent"],
    CellSize->{25, Inherited}],
  
  Cell[StyleData["Indent", "Presentation"],
    CellSize->{30, Inherited}],
  
  Cell[StyleData["Indent", "PrintoutColor"],
    CellSize->{15, Inherited}],
  
  Cell[StyleData["Indent", "PrintoutGray"],
    CellSize->{15, Inherited}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Blank"],
    CellSize->{15, Inherited}],
  
  Cell[StyleData["Blank", "Presentation"],
    CellSize->{20, Inherited}],
  
  Cell[StyleData["Blank", "PrintoutColor"],
    CellSize->{10, Inherited}],
  
  Cell[StyleData["Blank", "PrintoutGray"],
    CellSize->{10, Inherited}]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas, Numbered Stuff, and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, 85}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    CellFrameMargins->20,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->TraditionalForm,
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{34, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["DisplayFormula", "PrintoutColor"],
    CellMargins->{{34, 4}, {Inherited, Inherited}}],
  
  Cell[StyleData["DisplayFormula", "PrintoutGray"],
    CellMargins->{{34, 4}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InferenceRule"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{Inherited, 85}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    CellFrameMargins->{{10, 4}, {8, 8}},
    CellFrameColor->RGBColor[0, 0, 0.788235],
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->TraditionalForm,
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InferenceRule", "Presentation"],
    CellMargins->{{Inherited, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["InferenceRule", "PrintoutColor"],
    CellMargins->{{0, 4}, {Inherited, Inherited}}],
  
  Cell[StyleData["InferenceRule", "PrintoutGray"],
    CellMargins->{{0, 4}, {Inherited, Inherited}},
    CellFrameColor->GrayLevel[0.500008]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{42, 4}, {8, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ShowStringCharacters->True,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Program", "PrintoutColor"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Program", "PrintoutGray"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathematicaInput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  
  Cell[StyleData["MathematicaInput", "Presentation"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["MathematicaInput", "PrintoutColor"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["MathematicaInput", "PrintoutGray"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 85}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{34, 10}, {Inherited, 6}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedEquation", "PrintoutColor"],
    CellMargins->{{34, 4}, {4, 4}}],
  
  Cell[StyleData["NumberedEquation", "PrintoutGray"],
    CellMargins->{{34, 4}, {4, 4}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 95}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    CellMargins->{{60, 80}, {Inherited, 6}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedFigure", "PrintoutColor"],
    CellMargins->{{18, 80}, {4, 4}},
    FontSize->8],
  
  Cell[StyleData["NumberedFigure", "PrintoutGray"],
    CellMargins->{{18, 80}, {4, 4}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 95}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    CellMargins->{{60, 80}, {Inherited, 6}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedTable", "PrintoutColor"],
    CellMargins->{{18, 80}, {4, 4}},
    FontSize->8],
  
  Cell[StyleData["NumberedTable", "PrintoutGray"],
    CellMargins->{{18, 80}, {4, 4}},
    FontSize->8]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True,
    "StrikeThrough"->False},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "PrintoutColor"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "PrintoutGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Navigation"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->24,
    FontColor->RGBColor[1, 0.650004, 0],
    FontVariations->{"StrikeThrough"->False},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Navigation", "PrintoutColor"],
    FontColor->GrayLevel[0.949996],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Navigation", "PrintoutGray"],
    FontColor->GrayLevel[1],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "PrintoutColor"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "PrintoutGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "PrintoutColor"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnLink", "PrintoutGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "PrintoutColor"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "PrintoutGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "PrintoutColor"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "PrintoutGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "PrintoutColor"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "PrintoutGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    AutoSpacing->True,
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Open  ]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:2"->{
    Cell[9071, 270, 78, 2, 45, "Subtitle",
      PageBreakAbove->True,
      CellTags->"c:2"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:2", 82098, 2556}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 156, 5, 160, "Title"],
Cell[1864, 57, 35, 0, 54, "Subsubtitle"],
Cell[1902, 59, 78, 1, 31, "Text"],
Cell[1983, 62, 139, 2, 87, "Subsubtitle"],
Cell[2125, 66, 56, 1, 31, "Text"],
Cell[2184, 69, 94, 1, 50, "Author"],
Cell[2281, 72, 70, 1, 50, "Author"],
Cell[2354, 75, 475, 10, 117, "SingleParagraph"],
Cell[2832, 87, 477, 10, 73, "SingleParagraph"],

Cell[CellGroupData[{
Cell[3334, 101, 140, 2, 143, "Subtitle",
  PageBreakAbove->True],
Cell[3477, 105, 278, 7, 88, "SingleParagraph"],
Cell[3758, 114, 94, 2, 31, "Text"],
Cell[3855, 118, 52, 1, 45, "Subtitle",
  PageBreakAbove->True],
Cell[3910, 121, 729, 14, 107, "SingleParagraph"],
Cell[4642, 137, 168, 6, 27, "ItemizedText"],
Cell[4813, 145, 235, 9, 27, "ItemizedText"],
Cell[5051, 156, 204, 7, 27, "ItemizedText"],
Cell[5258, 165, 736, 14, 126, "SingleParagraph"],
Cell[5997, 181, 217, 7, 31, "SingleParagraph"],
Cell[6217, 190, 59, 1, 45, "Subtitle",
  PageBreakAbove->True],
Cell[6279, 193, 1006, 19, 164, "SingleParagraph"],
Cell[7288, 214, 184, 7, 27, "ItemizedText"],
Cell[7475, 223, 250, 10, 46, "ItemizedText"],
Cell[7728, 235, 232, 6, 46, "ItemizedText"],
Cell[7963, 243, 884, 16, 145, "SingleParagraph"],
Cell[8850, 261, 218, 7, 31, "SingleParagraph"],
Cell[9071, 270, 78, 2, 45, "Subtitle",
  PageBreakAbove->True,
  CellTags->"c:2"],
Cell[9152, 274, 1039, 21, 114, "FirstParagraph"],
Cell[10194, 297, 2427, 34, 411, "Text"],
Cell[12624, 333, 566, 11, 88, "SmallText"]
}, Open  ]],
Cell[13205, 347, 216, 5, 42, "SingleParagraph"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

